import platformClient = require('purecloud-platform-client-v2');

declare module 'purecloud-platform-client-v2' {
	export const ApiClient: ApiClientClass;
}

declare class ApiClientClass {
	instance: ApiClientClass;
	config: Configuration;
    private proxyAgent: any;

	callApi(path: string, httpMethod: string, pathParams: { [key: string]: string; }, queryParams: { [key: string]: object; }, headerParams: { [key: string]: object; }, formParams: { [key: string]: object; }, bodyParam: any, authNames: Array<string>, contentTypes: Array<string>, accepts: Array<string>): Promise<any>;
	loginClientCredentialsGrant(clientId: string, clientSecret: string): Promise<AuthData>;
	loginImplicitGrant(clientId: string, redirectUri: string, opts?: LoginImplicitGrantOptions): Promise<AuthData>;
	loginCodeAuthorizationGrant(clientId: string, clientSecret: string, authCode: string, redirectUri: string): Promise<AuthData>;
	refreshCodeAuthorizationGrant(clientId: string, clientSecret: string, refreshToken: string): Promise<AuthData>;
	loginPKCEGrant(clientId: string, redirectUri: string, opts?: LoginPKCEGrantOptions, codeVerifier?: string): Promise<AuthData>;
	generatePKCECodeVerifier(nChar: number): string;
	computePKCECodeChallenge(code: string): Promise<string>;
	authorizePKCEGrant(clientId: string, codeVerifier: string, authCode: string, redirectUri: string): Promise<AuthData>;
	logout(logoutRedirectUri: string): void;
	setAccessToken(token: string): void;
	setEnvironment(environment: string): void;
	setPersistSettings(doPersist: boolean, prefix?: string): void;
	setReturnExtendedResponses(returnExtended: boolean): void;
	setStorageKey(storageKey: string): void;
	setProxyAgent(agent: any): void;
}

declare class LoginImplicitGrantOptions {
	state?: string;
}

declare class LoginPKCEGrantOptions {
	state?: string;
	org?: string;
	provider?: string;
}

declare class AuthData {
	accessToken: string;
	state?: string;
	tokenExpiryTime: number;
	tokenExpiryTimeString: string;
}

declare class ProxyConfig {
	host: string;
	port: number;
	protocol: string;
}

declare class Configuration {
	instance: Configuration;
	configPath: string;
	refresh_access_token: boolean;
	refresh_token_wait_max: number;
	live_reload_config: boolean;
	host: string;
	environment: string;
	basePath: string;
	authUrl: string;
	logger: Logger;
	config: any;
	setEnvironment(environment: string): void;
}

declare class Logger {
	log_level: string;
	log_format: string;
	log_file_path: string;
	log_to_console: boolean;
	log_response_body: boolean;
	log_request_body: boolean;
	logLevels: any;
	logLevelEnum: any;
	logFormatEnum: any;
	setLogger(): void;
}

declare class AlertingApi {  
  	deleteAlertingAlert(alertId: string): Promise<void>; 
  	deleteAlertingInteractionstatsAlert(alertId: string): Promise<void>; 
  	deleteAlertingInteractionstatsRule(ruleId: string): Promise<void>; 
  	deleteAlertingRule(ruleId: string): Promise<void>; 
  	getAlertingAlert(alertId: string): Promise<Models.CommonAlert>; 
  	getAlertingAlertsActive(): Promise<Models.ActiveAlertCount>; 
  	getAlertingInteractionstatsAlert(alertId: string, opts?: AlertingApi.getAlertingInteractionstatsAlertOptions): Promise<Models.InteractionStatsAlert>; 
  	getAlertingInteractionstatsAlerts(opts?: AlertingApi.getAlertingInteractionstatsAlertsOptions): Promise<Models.InteractionStatsAlertContainer>; 
  	getAlertingInteractionstatsAlertsUnread(): Promise<Models.UnreadMetric>; 
  	getAlertingInteractionstatsRule(ruleId: string, opts?: AlertingApi.getAlertingInteractionstatsRuleOptions): Promise<Models.InteractionStatsRule>; 
  	getAlertingInteractionstatsRules(opts?: AlertingApi.getAlertingInteractionstatsRulesOptions): Promise<Models.InteractionStatsRuleContainer>; 
  	getAlertingRule(ruleId: string): Promise<Models.CommonRule>; 
  	patchAlertingAlert(alertId: string, opts?: AlertingApi.patchAlertingAlertOptions): Promise<Models.CommonAlert>; 
  	patchAlertingAlertsBulk(body: Models.CommonAlertBulkUpdateRequest): Promise<Models.BulkResponse>; 
  	patchAlertingRulesBulk(body: Models.CommonRuleBulkUpdateNotificationsRequest): Promise<Models.BulkResponse>; 
  	postAlertingAlertsQuery(opts?: AlertingApi.postAlertingAlertsQueryOptions): Promise<Models.AlertListing>; 
  	postAlertingInteractionstatsRules(body: Models.InteractionStatsRule, opts?: AlertingApi.postAlertingInteractionstatsRulesOptions): Promise<Models.InteractionStatsRule>; 
  	postAlertingRules(body: Models.CommonRule): Promise<Models.CommonRule>; 
  	postAlertingRulesBulkRemove(body: Models.CommonRuleBulkDeleteRequest): Promise<Models.BulkResponse>; 
  	postAlertingRulesQuery(opts?: AlertingApi.postAlertingRulesQueryOptions): Promise<Models.CommonRuleContainer>; 
  	putAlertingAlert(alertId: string, opts?: AlertingApi.putAlertingAlertOptions): Promise<Models.UnreadStatus>; 
  	putAlertingInteractionstatsAlert(alertId: string, body: Models.UnreadStatus, opts?: AlertingApi.putAlertingInteractionstatsAlertOptions): Promise<Models.UnreadStatus>; 
  	putAlertingInteractionstatsRule(ruleId: string, body: Models.InteractionStatsRule, opts?: AlertingApi.putAlertingInteractionstatsRuleOptions): Promise<Models.InteractionStatsRule>; 
  	putAlertingRule(ruleId: string, body: Models.ModifiableRuleProperties): Promise<Models.CommonRule>;
}

declare namespace AlertingApi { 
	export interface getAlertingInteractionstatsAlertOptions { 
		"expand"?: Array<string>;
	}
	export interface getAlertingInteractionstatsAlertsOptions { 
		"expand"?: Array<string>;
	}
	export interface getAlertingInteractionstatsRuleOptions { 
		"expand"?: Array<string>;
	}
	export interface getAlertingInteractionstatsRulesOptions { 
		"expand"?: Array<string>;
	}
	export interface patchAlertingAlertOptions { 
		"body"?: Models.AlertRequest;
	}
	export interface postAlertingAlertsQueryOptions { 
		"body"?: Models.GetAlertQuery;
	}
	export interface postAlertingInteractionstatsRulesOptions { 
		"expand"?: Array<string>;
	}
	export interface postAlertingRulesQueryOptions { 
		"body"?: Models.GetRulesQuery;
	}
	export interface putAlertingAlertOptions { 
		"body"?: Models.AlertingUnreadStatus;
	}
	export interface putAlertingInteractionstatsAlertOptions { 
		"expand"?: Array<string>;
	}
	export interface putAlertingInteractionstatsRuleOptions { 
		"expand"?: Array<string>;
	}
}

declare class AnalyticsApi {  
  	deleteAnalyticsConversationsDetailsJob(jobId: string): Promise<void>; 
  	deleteAnalyticsReportingSchedule(scheduleId: string): Promise<void>; 
  	deleteAnalyticsUsersDetailsJob(jobId: string): Promise<void>; 
  	getAnalyticsActionsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsActionsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsActionsAggregatesJobResultsOptions): Promise<Models.ActionAsyncAggregateQueryResponse>; 
  	getAnalyticsBotflowReportingturns(botFlowId: string, opts?: AnalyticsApi.getAnalyticsBotflowReportingturnsOptions): Promise<Models.ReportingTurnsResponse>; 
  	getAnalyticsBotflowSessions(botFlowId: string, opts?: AnalyticsApi.getAnalyticsBotflowSessionsOptions): Promise<Models.SessionsResponse>; 
  	getAnalyticsBotsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsBotsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsBotsAggregatesJobResultsOptions): Promise<Models.BotAsyncAggregateQueryResponse>; 
  	getAnalyticsConversationDetails(conversationId: string): Promise<Models.AnalyticsConversationWithoutAttributes>; 
  	getAnalyticsConversationsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsConversationsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsConversationsAggregatesJobResultsOptions): Promise<Models.ConversationAsyncAggregateQueryResponse>; 
  	getAnalyticsConversationsDetails(opts?: AnalyticsApi.getAnalyticsConversationsDetailsOptions): Promise<Models.AnalyticsConversationWithoutAttributesMultiGetResponse>; 
  	getAnalyticsConversationsDetailsJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsConversationsDetailsJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsConversationsDetailsJobResultsOptions): Promise<Models.AnalyticsConversationAsyncQueryResponse>; 
  	getAnalyticsConversationsDetailsJobsAvailability(): Promise<Models.DataAvailabilityResponse>; 
  	getAnalyticsDataretentionSettings(): Promise<Models.AnalyticsDataRetentionResponse>; 
  	getAnalyticsEvaluationsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsEvaluationsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsEvaluationsAggregatesJobResultsOptions): Promise<Models.EvaluationAsyncAggregateQueryResponse>; 
  	getAnalyticsFlowexecutionsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsFlowexecutionsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsFlowexecutionsAggregatesJobResultsOptions): Promise<Models.FlowExecutionAsyncAggregateQueryResponse>; 
  	getAnalyticsFlowsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsFlowsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsFlowsAggregatesJobResultsOptions): Promise<Models.FlowAsyncAggregateQueryResponse>; 
  	getAnalyticsJourneysAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsJourneysAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsJourneysAggregatesJobResultsOptions): Promise<Models.JourneyAsyncAggregateQueryResponse>; 
  	getAnalyticsKnowledgeAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsKnowledgeAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsKnowledgeAggregatesJobResultsOptions): Promise<Models.KnowledgeAsyncAggregateQueryResponse>; 
  	getAnalyticsReportingDashboardsUser(userId: string): Promise<Models.DashboardUser>; 
  	getAnalyticsReportingDashboardsUsers(opts?: AnalyticsApi.getAnalyticsReportingDashboardsUsersOptions): Promise<Models.DashboardUserListing>; 
  	getAnalyticsReportingExports(opts?: AnalyticsApi.getAnalyticsReportingExportsOptions): Promise<Models.ReportingExportJobListing>; 
  	getAnalyticsReportingExportsMetadata(): Promise<Models.ReportingExportMetadataJobListing>; 
  	getAnalyticsReportingMetadata(opts?: AnalyticsApi.getAnalyticsReportingMetadataOptions): Promise<Models.ReportMetaDataEntityListing>; 
  	getAnalyticsReportingReportIdMetadata(reportId: string, opts?: AnalyticsApi.getAnalyticsReportingReportIdMetadataOptions): Promise<Models.ReportMetaData>; 
  	getAnalyticsReportingReportformats(): Promise<Array<string>>; 
  	getAnalyticsReportingSchedule(scheduleId: string): Promise<Models.ReportSchedule>; 
  	getAnalyticsReportingScheduleHistory(scheduleId: string, opts?: AnalyticsApi.getAnalyticsReportingScheduleHistoryOptions): Promise<Models.ReportRunEntryEntityDomainListing>; 
  	getAnalyticsReportingScheduleHistoryLatest(scheduleId: string): Promise<Models.ReportRunEntry>; 
  	getAnalyticsReportingScheduleHistoryRunId(runId: string, scheduleId: string): Promise<Models.ReportRunEntry>; 
  	getAnalyticsReportingSchedules(opts?: AnalyticsApi.getAnalyticsReportingSchedulesOptions): Promise<Models.ReportScheduleEntityListing>; 
  	getAnalyticsReportingSettings(): Promise<Models.AnalyticsReportingSettings>; 
  	getAnalyticsReportingSettingsUserDashboards(userId: string, opts?: AnalyticsApi.getAnalyticsReportingSettingsUserDashboardsOptions): Promise<Models.DashboardConfigurationListing>; 
  	getAnalyticsReportingTimeperiods(): Promise<Array<string>>; 
  	getAnalyticsResolutionsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsResolutionsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsResolutionsAggregatesJobResultsOptions): Promise<Models.ResolutionAsyncAggregateQueryResponse>; 
  	getAnalyticsSurveysAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsSurveysAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsSurveysAggregatesJobResultsOptions): Promise<Models.SurveyAsyncAggregateQueryResponse>; 
  	getAnalyticsTaskmanagementAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsTaskmanagementAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsTaskmanagementAggregatesJobResultsOptions): Promise<Models.TaskManagementAsyncAggregateQueryResponse>; 
  	getAnalyticsTranscriptsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsTranscriptsAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsTranscriptsAggregatesJobResultsOptions): Promise<Models.TranscriptAsyncAggregateQueryResponse>; 
  	getAnalyticsUsersAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsUsersAggregatesJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsUsersAggregatesJobResultsOptions): Promise<Models.UserAsyncAggregateQueryResponse>; 
  	getAnalyticsUsersDetailsJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsUsersDetailsJobResults(jobId: string, opts?: AnalyticsApi.getAnalyticsUsersDetailsJobResultsOptions): Promise<Models.AnalyticsUserDetailsAsyncQueryResponse>; 
  	getAnalyticsUsersDetailsJobsAvailability(): Promise<Models.DataAvailabilityResponse>; 
  	patchAnalyticsReportingSettings(body: Models.AnalyticsReportingSettings): Promise<Models.AnalyticsReportingSettings>; 
  	postAnalyticsActionsAggregatesJobs(body: Models.ActionAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsActionsAggregatesQuery(body: Models.ActionAggregationQuery): Promise<Models.ActionAggregateQueryResponse>; 
  	postAnalyticsBotsAggregatesJobs(body: Models.BotAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsBotsAggregatesQuery(body: Models.BotAggregationQuery): Promise<Models.BotAggregateQueryResponse>; 
  	postAnalyticsConversationDetailsProperties(conversationId: string, body: Models.PropertyIndexRequest): Promise<Models.PropertyIndexRequest>; 
  	postAnalyticsConversationsActivityQuery(body: Models.ConversationActivityQuery, opts?: AnalyticsApi.postAnalyticsConversationsActivityQueryOptions): Promise<Models.ConversationActivityResponse>; 
  	postAnalyticsConversationsAggregatesJobs(body: Models.ConversationAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsConversationsAggregatesQuery(body: Models.ConversationAggregationQuery): Promise<Models.ConversationAggregateQueryResponse>; 
  	postAnalyticsConversationsDetailsJobs(body: Models.AsyncConversationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsConversationsDetailsQuery(body: Models.ConversationQuery): Promise<Models.AnalyticsConversationQueryResponse>; 
  	postAnalyticsConversationsTranscriptsQuery(body: Models.TranscriptConversationDetailSearchRequest): Promise<Models.AnalyticsConversationWithoutAttributesMultiGetResponse>; 
  	postAnalyticsEvaluationsAggregatesJobs(body: Models.EvaluationAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsEvaluationsAggregatesQuery(body: Models.EvaluationAggregationQuery): Promise<Models.EvaluationAggregateQueryResponse>; 
  	postAnalyticsFlowexecutionsAggregatesJobs(body: Models.FlowExecutionAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsFlowexecutionsAggregatesQuery(body: Models.FlowExecutionAggregationQuery): Promise<Models.FlowExecutionAggregateQueryResponse>; 
  	postAnalyticsFlowsActivityQuery(body: Models.FlowActivityQuery, opts?: AnalyticsApi.postAnalyticsFlowsActivityQueryOptions): Promise<Models.FlowActivityResponse>; 
  	postAnalyticsFlowsAggregatesJobs(body: Models.FlowAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsFlowsAggregatesQuery(body: Models.FlowAggregationQuery): Promise<Models.FlowAggregateQueryResponse>; 
  	postAnalyticsFlowsObservationsQuery(body: Models.FlowObservationQuery): Promise<Models.FlowObservationQueryResponse>; 
  	postAnalyticsJourneysAggregatesJobs(body: Models.JourneyAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsJourneysAggregatesQuery(body: Models.JourneyAggregationQuery): Promise<Models.JourneyAggregateQueryResponse>; 
  	postAnalyticsKnowledgeAggregatesJobs(body: Models.KnowledgeAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsKnowledgeAggregatesQuery(body: Models.KnowledgeAggregationQuery): Promise<Models.KnowledgeAggregateQueryResponse>; 
  	postAnalyticsQueuesObservationsQuery(body: Models.QueueObservationQuery): Promise<Models.QueueObservationQueryResponse>; 
  	postAnalyticsRatelimitsAggregatesQuery(body: Models.RateLimitAggregationQuery): Promise<Models.RateLimitAggregateQueryResponse>; 
  	postAnalyticsReportingDashboardsUsersBulkRemove(body: Array<string>): Promise<void>; 
  	postAnalyticsReportingExports(body: Models.ReportingExportJobRequest): Promise<Models.ReportingExportJobResponse>; 
  	postAnalyticsReportingScheduleRunreport(scheduleId: string): Promise<Models.RunNowResponse>; 
  	postAnalyticsReportingSchedules(body: Models.ReportSchedule): Promise<Models.ReportSchedule>; 
  	postAnalyticsReportingSettingsDashboardsBulkRemove(body: Models.DashboardConfigurationBulkRequest): Promise<void>; 
  	postAnalyticsReportingSettingsDashboardsQuery(body: Models.DashboardConfigurationQueryRequest): Promise<Models.DashboardConfigurationListing>; 
  	postAnalyticsResolutionsAggregatesJobs(body: Models.ResolutionAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsRoutingActivityQuery(body: Models.RoutingActivityQuery, opts?: AnalyticsApi.postAnalyticsRoutingActivityQueryOptions): Promise<Models.RoutingActivityResponse>; 
  	postAnalyticsSurveysAggregatesJobs(body: Models.SurveyAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsSurveysAggregatesQuery(body: Models.SurveyAggregationQuery): Promise<Models.SurveyAggregateQueryResponse>; 
  	postAnalyticsTaskmanagementAggregatesJobs(body: Models.TaskManagementAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsTaskmanagementAggregatesQuery(body: Models.TaskManagementAggregationQuery): Promise<Models.TaskManagementAggregateQueryResponse>; 
  	postAnalyticsTeamsActivityQuery(body: Models.TeamActivityQuery, opts?: AnalyticsApi.postAnalyticsTeamsActivityQueryOptions): Promise<Models.TeamActivityResponse>; 
  	postAnalyticsTranscriptsAggregatesJobs(body: Models.TranscriptAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsTranscriptsAggregatesQuery(body: Models.TranscriptAggregationQuery): Promise<Models.TranscriptAggregateQueryResponse>; 
  	postAnalyticsUsersActivityQuery(body: Models.UserActivityQuery, opts?: AnalyticsApi.postAnalyticsUsersActivityQueryOptions): Promise<Models.UserActivityResponse>; 
  	postAnalyticsUsersAggregatesJobs(body: Models.UserAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsUsersAggregatesQuery(body: Models.UserAggregationQuery): Promise<Models.UserAggregateQueryResponse>; 
  	postAnalyticsUsersDetailsJobs(body: Models.AsyncUserDetailsQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsUsersDetailsQuery(body: Models.UserDetailsQuery): Promise<Models.AnalyticsUserDetailsQueryResponse>; 
  	postAnalyticsUsersObservationsQuery(body: Models.UserObservationQuery): Promise<Models.UserObservationQueryResponse>; 
  	putAnalyticsDataretentionSettings(body: Models.UpdateAnalyticsDataRetentionRequest): Promise<Models.AnalyticsDataRetentionResponse>; 
  	putAnalyticsReportingSchedule(scheduleId: string, body: Models.ReportSchedule): Promise<Models.ReportSchedule>;
}

declare namespace AnalyticsApi { 
	export interface getAnalyticsActionsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsBotflowReportingturnsOptions { 
		"after"?: string;
		"pageSize"?: string;
		"interval"?: string;
		"actionId"?: string;
		"sessionId"?: string;
		"language"?: string;
		"askActionResults"?: string;
	}
	export interface getAnalyticsBotflowSessionsOptions { 
		"after"?: string;
		"pageSize"?: string;
		"interval"?: string;
		"botResultCategories"?: string;
		"endLanguage"?: string;
	}
	export interface getAnalyticsBotsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsConversationsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsConversationsDetailsOptions { 
		"id"?: Array<string>;
	}
	export interface getAnalyticsConversationsDetailsJobResultsOptions { 
		"cursor"?: string;
		"pageSize"?: number;
	}
	export interface getAnalyticsEvaluationsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsFlowexecutionsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsFlowsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsJourneysAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsKnowledgeAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsReportingDashboardsUsersOptions { 
		"sortBy"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"id"?: Array<string>;
		"state"?: string;
	}
	export interface getAnalyticsReportingExportsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAnalyticsReportingMetadataOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"locale"?: string;
	}
	export interface getAnalyticsReportingReportIdMetadataOptions { 
		"locale"?: string;
	}
	export interface getAnalyticsReportingScheduleHistoryOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAnalyticsReportingSchedulesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAnalyticsReportingSettingsUserDashboardsOptions { 
		"sortBy"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"publicOnly"?: boolean;
		"favoriteOnly"?: boolean;
	}
	export interface getAnalyticsResolutionsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsSurveysAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsTaskmanagementAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsTranscriptsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsUsersAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsUsersDetailsJobResultsOptions { 
		"cursor"?: string;
		"pageSize"?: number;
	}
	export interface postAnalyticsConversationsActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postAnalyticsFlowsActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postAnalyticsRoutingActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postAnalyticsTeamsActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postAnalyticsUsersActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class ArchitectApi {  
  	deleteArchitectEmergencygroup(emergencyGroupId: string): Promise<void>; 
  	deleteArchitectGrammar(grammarId: string): Promise<object>; 
  	deleteArchitectGrammarLanguage(grammarId: string, languageCode: string): Promise<void>; 
  	deleteArchitectGrammarLanguageFilesDtmf(grammarId: string, languageCode: string): Promise<void>; 
  	deleteArchitectGrammarLanguageFilesVoice(grammarId: string, languageCode: string): Promise<void>; 
  	deleteArchitectIvr(ivrId: string): Promise<void>; 
  	deleteArchitectPrompt(promptId: string, opts?: ArchitectApi.deleteArchitectPromptOptions): Promise<void>; 
  	deleteArchitectPromptResource(promptId: string, languageCode: string): Promise<void>; 
  	deleteArchitectPromptResourceAudio(promptId: string, languageCode: string): Promise<void>; 
  	deleteArchitectPrompts(id: Array<string>): Promise<Models.Operation>; 
  	deleteArchitectSchedule(scheduleId: string): Promise<void>; 
  	deleteArchitectSchedulegroup(scheduleGroupId: string): Promise<void>; 
  	deleteArchitectSystempromptResource(promptId: string, languageCode: string): Promise<void>; 
  	deleteFlow(flowId: string): Promise<void>; 
  	deleteFlowInstancesSettingsLoglevels(flowId: string): Promise<void>; 
  	deleteFlows(id: Array<string>): Promise<Models.Operation>; 
  	deleteFlowsDatatable(datatableId: string, opts?: ArchitectApi.deleteFlowsDatatableOptions): Promise<void>; 
  	deleteFlowsDatatableRow(datatableId: string, rowId: string): Promise<void>; 
  	deleteFlowsInstancesSettingsLoglevelsDefault(): Promise<void>; 
  	deleteFlowsMilestone(milestoneId: string): Promise<object>; 
  	getArchitectDependencytracking(name: string, opts?: ArchitectApi.getArchitectDependencytrackingOptions): Promise<Models.DependencyObjectEntityListing>; 
  	getArchitectDependencytrackingBuild(): Promise<Models.DependencyStatus>; 
  	getArchitectDependencytrackingConsumedresources(id: string, version: string, objectType: string, opts?: ArchitectApi.getArchitectDependencytrackingConsumedresourcesOptions): Promise<Models.ConsumedResourcesEntityListing>; 
  	getArchitectDependencytrackingConsumingresources(id: string, objectType: string, opts?: ArchitectApi.getArchitectDependencytrackingConsumingresourcesOptions): Promise<Models.ConsumingResourcesEntityListing>; 
  	getArchitectDependencytrackingDeletedresourceconsumers(opts?: ArchitectApi.getArchitectDependencytrackingDeletedresourceconsumersOptions): Promise<Models.DependencyObjectEntityListing>; 
  	getArchitectDependencytrackingObject(id: string, opts?: ArchitectApi.getArchitectDependencytrackingObjectOptions): Promise<Models.DependencyObject>; 
  	getArchitectDependencytrackingType(typeId: string): Promise<Models.DependencyType>; 
  	getArchitectDependencytrackingTypes(opts?: ArchitectApi.getArchitectDependencytrackingTypesOptions): Promise<Models.DependencyTypeEntityListing>; 
  	getArchitectDependencytrackingUpdatedresourceconsumers(opts?: ArchitectApi.getArchitectDependencytrackingUpdatedresourceconsumersOptions): Promise<Models.DependencyObjectEntityListing>; 
  	getArchitectEmergencygroup(emergencyGroupId: string): Promise<Models.EmergencyGroup>; 
  	getArchitectEmergencygroups(opts?: ArchitectApi.getArchitectEmergencygroupsOptions): Promise<Models.EmergencyGroupListing>; 
  	getArchitectEmergencygroupsDivisionviews(opts?: ArchitectApi.getArchitectEmergencygroupsDivisionviewsOptions): Promise<Models.EmergencyGroupDivisionViewEntityListing>; 
  	getArchitectGrammar(grammarId: string, opts?: ArchitectApi.getArchitectGrammarOptions): Promise<Models.Grammar>; 
  	getArchitectGrammarLanguage(grammarId: string, languageCode: string): Promise<Models.GrammarLanguage>; 
  	getArchitectGrammars(opts?: ArchitectApi.getArchitectGrammarsOptions): Promise<Models.GrammarListing>; 
  	getArchitectIvr(ivrId: string): Promise<Models.IVR>; 
  	getArchitectIvrs(opts?: ArchitectApi.getArchitectIvrsOptions): Promise<Models.IVREntityListing>; 
  	getArchitectIvrsDivisionviews(opts?: ArchitectApi.getArchitectIvrsDivisionviewsOptions): Promise<Models.IVRDivisionViewEntityListing>; 
  	getArchitectPrompt(promptId: string, opts?: ArchitectApi.getArchitectPromptOptions): Promise<Models.Prompt>; 
  	getArchitectPromptHistoryHistoryId(promptId: string, historyId: string, opts?: ArchitectApi.getArchitectPromptHistoryHistoryIdOptions): Promise<Models.HistoryListing>; 
  	getArchitectPromptResource(promptId: string, languageCode: string): Promise<Models.PromptAsset>; 
  	getArchitectPromptResources(promptId: string, opts?: ArchitectApi.getArchitectPromptResourcesOptions): Promise<Models.PromptAssetEntityListing>; 
  	getArchitectPrompts(opts?: ArchitectApi.getArchitectPromptsOptions): Promise<Models.PromptEntityListing>; 
  	getArchitectSchedule(scheduleId: string): Promise<Models.Schedule>; 
  	getArchitectSchedulegroup(scheduleGroupId: string): Promise<Models.ScheduleGroup>; 
  	getArchitectSchedulegroups(opts?: ArchitectApi.getArchitectSchedulegroupsOptions): Promise<Models.ScheduleGroupEntityListing>; 
  	getArchitectSchedulegroupsDivisionviews(opts?: ArchitectApi.getArchitectSchedulegroupsDivisionviewsOptions): Promise<Models.ScheduleGroupDivisionViewEntityListing>; 
  	getArchitectSchedules(opts?: ArchitectApi.getArchitectSchedulesOptions): Promise<Models.ScheduleEntityListing>; 
  	getArchitectSchedulesDivisionviews(opts?: ArchitectApi.getArchitectSchedulesDivisionviewsOptions): Promise<Models.ScheduleDivisionViewEntityListing>; 
  	getArchitectSystemprompt(promptId: string, opts?: ArchitectApi.getArchitectSystempromptOptions): Promise<Models.SystemPrompt>; 
  	getArchitectSystempromptHistoryHistoryId(promptId: string, historyId: string, opts?: ArchitectApi.getArchitectSystempromptHistoryHistoryIdOptions): Promise<Models.HistoryListing>; 
  	getArchitectSystempromptResource(promptId: string, languageCode: string): Promise<Models.SystemPromptAsset>; 
  	getArchitectSystempromptResources(promptId: string, opts?: ArchitectApi.getArchitectSystempromptResourcesOptions): Promise<Models.SystemPromptAssetEntityListing>; 
  	getArchitectSystemprompts(opts?: ArchitectApi.getArchitectSystempromptsOptions): Promise<Models.SystemPromptEntityListing>; 
  	getFlow(flowId: string, opts?: ArchitectApi.getFlowOptions): Promise<Models.Flow>; 
  	getFlowHistoryHistoryId(flowId: string, historyId: string, opts?: ArchitectApi.getFlowHistoryHistoryIdOptions): Promise<Models.HistoryListing>; 
  	getFlowInstancesSettingsLoglevels(flowId: string, opts?: ArchitectApi.getFlowInstancesSettingsLoglevelsOptions): Promise<Models.FlowSettingsResponse>; 
  	getFlowLatestconfiguration(flowId: string, opts?: ArchitectApi.getFlowLatestconfigurationOptions): Promise<object>; 
  	getFlowVersion(flowId: string, versionId: string, opts?: ArchitectApi.getFlowVersionOptions): Promise<Models.FlowVersion>; 
  	getFlowVersionConfiguration(flowId: string, versionId: string, opts?: ArchitectApi.getFlowVersionConfigurationOptions): Promise<object>; 
  	getFlowVersionHealth(flowId: string, versionId: string, opts?: ArchitectApi.getFlowVersionHealthOptions): Promise<Models.FlowHealth>; 
  	getFlowVersionIntentHealth(flowId: string, versionId: string, intentId: string, language: string): Promise<Models.FlowHealthIntent>; 
  	getFlowVersionIntentUtteranceHealth(flowId: string, versionId: string, intentId: string, utteranceId: string, language: string): Promise<Models.FlowHealthUtterance>; 
  	getFlowVersions(flowId: string, opts?: ArchitectApi.getFlowVersionsOptions): Promise<Models.FlowVersionEntityListing>; 
  	getFlows(opts?: ArchitectApi.getFlowsOptions): Promise<Models.FlowEntityListing>; 
  	getFlowsDatatable(datatableId: string, opts?: ArchitectApi.getFlowsDatatableOptions): Promise<Models.DataTable>; 
  	getFlowsDatatableExportJob(datatableId: string, exportJobId: string): Promise<Models.DataTableExportJob>; 
  	getFlowsDatatableImportJob(datatableId: string, importJobId: string): Promise<Models.DataTableImportJob>; 
  	getFlowsDatatableImportJobs(datatableId: string, opts?: ArchitectApi.getFlowsDatatableImportJobsOptions): Promise<Models.DataTableImportEntityListing>; 
  	getFlowsDatatableRow(datatableId: string, rowId: string, opts?: ArchitectApi.getFlowsDatatableRowOptions): Promise<{ [key: string]: object; }>; 
  	getFlowsDatatableRows(datatableId: string, opts?: ArchitectApi.getFlowsDatatableRowsOptions): Promise<Models.DataTableRowEntityListing>; 
  	getFlowsDatatables(opts?: ArchitectApi.getFlowsDatatablesOptions): Promise<Models.DataTablesDomainEntityListing>; 
  	getFlowsDatatablesDivisionview(datatableId: string, opts?: ArchitectApi.getFlowsDatatablesDivisionviewOptions): Promise<Models.DataTable>; 
  	getFlowsDatatablesDivisionviews(opts?: ArchitectApi.getFlowsDatatablesDivisionviewsOptions): Promise<Models.DataTablesDomainEntityListing>; 
  	getFlowsDivisionviews(opts?: ArchitectApi.getFlowsDivisionviewsOptions): Promise<Models.FlowDivisionViewEntityListing>; 
  	getFlowsExecution(flowExecutionId: string): Promise<Models.FlowRuntimeExecution>; 
  	getFlowsInstance(instanceId: string, opts?: ArchitectApi.getFlowsInstanceOptions): Promise<Models.GetFlowExecutionDataJobResult>; 
  	getFlowsInstancesJob(jobId: string): Promise<Models.GetFlowExecutionDataJobResult>; 
  	getFlowsInstancesQuerycapabilities(opts?: ArchitectApi.getFlowsInstancesQuerycapabilitiesOptions): Promise<Models.FlowsQueryCriteriaResponse>; 
  	getFlowsInstancesSettingsExecutiondata(): Promise<Models.ExecutionDataFlowSettingsResponse>; 
  	getFlowsInstancesSettingsLoglevels(opts?: ArchitectApi.getFlowsInstancesSettingsLoglevelsOptions): Promise<Models.FlowSettingsResponseEntityListing>; 
  	getFlowsInstancesSettingsLoglevelsCharacteristics(): Promise<Models.FlowLogLevelCharacteristicsDefinitions>; 
  	getFlowsInstancesSettingsLoglevelsDefault(opts?: ArchitectApi.getFlowsInstancesSettingsLoglevelsDefaultOptions): Promise<Models.FlowSettingsResponse>; 
  	getFlowsJob(jobId: string, opts?: ArchitectApi.getFlowsJobOptions): Promise<Models.ArchitectJobStateResponse>; 
  	getFlowsMilestone(milestoneId: string): Promise<Models.FlowMilestone>; 
  	getFlowsMilestones(opts?: ArchitectApi.getFlowsMilestonesOptions): Promise<Models.FlowMilestoneListing>; 
  	getFlowsMilestonesDivisionviews(opts?: ArchitectApi.getFlowsMilestonesDivisionviewsOptions): Promise<Models.FlowMilestoneDivisionViewEntityListing>; 
  	getFlowsOutcome(flowOutcomeId: string): Promise<Models.FlowOutcome>; 
  	getFlowsOutcomes(opts?: ArchitectApi.getFlowsOutcomesOptions): Promise<Models.FlowOutcomeListing>; 
  	getFlowsOutcomesDivisionviews(opts?: ArchitectApi.getFlowsOutcomesDivisionviewsOptions): Promise<Models.FlowOutcomeDivisionViewEntityListing>; 
  	patchArchitectGrammar(grammarId: string, opts?: ArchitectApi.patchArchitectGrammarOptions): Promise<Models.Grammar>; 
  	patchArchitectGrammarLanguage(grammarId: string, languageCode: string, opts?: ArchitectApi.patchArchitectGrammarLanguageOptions): Promise<Models.GrammarLanguage>; 
  	patchFlowsInstancesSettingsExecutiondata(body: Models.ExecutionDataSettingsRequest): Promise<Models.ExecutionDataFlowSettingsResponse>; 
  	postArchitectDependencytrackingBuild(): Promise<void>; 
  	postArchitectEmergencygroups(body: Models.EmergencyGroup): Promise<Models.EmergencyGroup>; 
  	postArchitectGrammarLanguageFilesDtmf(grammarId: string, languageCode: string, body: Models.GrammarFileUploadRequest): Promise<Models.UploadUrlResponse>; 
  	postArchitectGrammarLanguageFilesVoice(grammarId: string, languageCode: string, body: Models.GrammarFileUploadRequest): Promise<Models.UploadUrlResponse>; 
  	postArchitectGrammarLanguages(grammarId: string, body: Models.GrammarLanguage): Promise<Models.GrammarLanguage>; 
  	postArchitectGrammars(body: Models.Grammar): Promise<Models.Grammar>; 
  	postArchitectIvrs(body: Models.IVR): Promise<Models.IVR>; 
  	postArchitectPromptHistory(promptId: string): Promise<Models.Operation>; 
  	postArchitectPromptResources(promptId: string, body: Models.PromptAssetCreate): Promise<Models.PromptAsset>; 
  	postArchitectPrompts(body: Models.Prompt): Promise<Models.Prompt>; 
  	postArchitectSchedulegroups(body: Models.ScheduleGroup): Promise<Models.ScheduleGroup>; 
  	postArchitectSchedules(body: Models.Schedule): Promise<Models.Schedule>; 
  	postArchitectSystempromptHistory(promptId: string): Promise<Models.Operation>; 
  	postArchitectSystempromptResources(promptId: string, body: Models.SystemPromptAsset): Promise<Models.SystemPromptAsset>; 
  	postFlowHistory(flowId: string): Promise<Models.Operation>; 
  	postFlowInstancesSettingsLoglevels(flowId: string, body: Models.FlowLogLevelRequest, opts?: ArchitectApi.postFlowInstancesSettingsLoglevelsOptions): Promise<Models.FlowSettingsResponse>; 
  	postFlowVersions(flowId: string, body: object): Promise<Models.FlowVersion>; 
  	postFlows(body: Models.Flow, opts?: ArchitectApi.postFlowsOptions): Promise<Models.Flow>; 
  	postFlowsActionsCheckin(flow: string): Promise<Models.Operation>; 
  	postFlowsActionsCheckout(flow: string): Promise<Models.Flow>; 
  	postFlowsActionsDeactivate(flow: string): Promise<Models.Flow>; 
  	postFlowsActionsPublish(flow: string, opts?: ArchitectApi.postFlowsActionsPublishOptions): Promise<Models.Operation>; 
  	postFlowsActionsRevert(flow: string): Promise<Models.Flow>; 
  	postFlowsActionsUnlock(flow: string): Promise<Models.Flow>; 
  	postFlowsDatatableExportJobs(datatableId: string): Promise<Models.DataTableExportJob>; 
  	postFlowsDatatableImportJobs(datatableId: string, body: Models.DataTableImportJob): Promise<Models.DataTableImportJob>; 
  	postFlowsDatatableRows(datatableId: string, dataTableRow: object): Promise<{ [key: string]: object; }>; 
  	postFlowsDatatables(body: Models.DataTable): Promise<Models.DataTable>; 
  	postFlowsExecutions(flowLaunchRequest: Models.FlowExecutionLaunchRequest): Promise<Models.FlowExecutionLaunchResponse>; 
  	postFlowsInstancesJobs(body: Models.ExecutionDataRequest, opts?: ArchitectApi.postFlowsInstancesJobsOptions): Promise<Models.GetFlowExecutionDataJobResult>; 
  	postFlowsInstancesQuery(body: Models.CriteriaQuery, opts?: ArchitectApi.postFlowsInstancesQueryOptions): Promise<Models.FlowResultEntityListing>; 
  	postFlowsJobs(): Promise<Models.RegisterArchitectJobResponse>; 
  	postFlowsMilestones(opts?: ArchitectApi.postFlowsMilestonesOptions): Promise<Models.FlowMilestone>; 
  	postFlowsOutcomes(opts?: ArchitectApi.postFlowsOutcomesOptions): Promise<Models.FlowOutcome>; 
  	putArchitectEmergencygroup(emergencyGroupId: string, body: Models.EmergencyGroup): Promise<Models.EmergencyGroup>; 
  	putArchitectIvr(ivrId: string, body: Models.IVR): Promise<Models.IVR>; 
  	putArchitectPrompt(promptId: string, body: Models.Prompt): Promise<Models.Prompt>; 
  	putArchitectPromptResource(promptId: string, languageCode: string, body: Models.PromptAsset): Promise<Models.PromptAsset>; 
  	putArchitectSchedule(scheduleId: string, body: Models.Schedule): Promise<Models.Schedule>; 
  	putArchitectSchedulegroup(scheduleGroupId: string, body: Models.ScheduleGroup): Promise<Models.ScheduleGroup>; 
  	putArchitectSystempromptResource(promptId: string, languageCode: string, body: Models.SystemPromptAsset): Promise<Models.SystemPromptAsset>; 
  	putFlow(flowId: string, body: Models.Flow): Promise<Models.Flow>; 
  	putFlowInstancesSettingsLoglevels(flowId: string, body: Models.FlowLogLevelRequest, opts?: ArchitectApi.putFlowInstancesSettingsLoglevelsOptions): Promise<Models.FlowSettingsResponse>; 
  	putFlowsDatatable(datatableId: string, body: Models.DataTable, opts?: ArchitectApi.putFlowsDatatableOptions): Promise<Models.DataTable>; 
  	putFlowsDatatableRow(datatableId: string, rowId: string, opts?: ArchitectApi.putFlowsDatatableRowOptions): Promise<{ [key: string]: object; }>; 
  	putFlowsInstancesSettingsLoglevelsDefault(body: Models.FlowLogLevelRequest, opts?: ArchitectApi.putFlowsInstancesSettingsLoglevelsDefaultOptions): Promise<Models.FlowSettingsResponse>; 
  	putFlowsMilestone(milestoneId: string, opts?: ArchitectApi.putFlowsMilestoneOptions): Promise<Models.FlowMilestone>; 
  	putFlowsOutcome(flowOutcomeId: string, opts?: ArchitectApi.putFlowsOutcomeOptions): Promise<Models.Operation>;
}

declare namespace ArchitectApi { 
	export interface deleteArchitectPromptOptions { 
		"allResources"?: boolean;
	}
	export interface deleteFlowsDatatableOptions { 
		"force"?: boolean;
	}
	export interface getArchitectDependencytrackingOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"objectType"?: Array<string>;
		"consumedResources"?: boolean;
		"consumingResources"?: boolean;
		"consumedResourceType"?: Array<string>;
		"consumingResourceType"?: Array<string>;
	}
	export interface getArchitectDependencytrackingConsumedresourcesOptions { 
		"resourceType"?: Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getArchitectDependencytrackingConsumingresourcesOptions { 
		"resourceType"?: Array<string>;
		"version"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"flowFilter"?: string;
	}
	export interface getArchitectDependencytrackingDeletedresourceconsumersOptions { 
		"name"?: string;
		"objectType"?: Array<string>;
		"flowFilter"?: string;
		"consumedResources"?: boolean;
		"consumedResourceType"?: Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getArchitectDependencytrackingObjectOptions { 
		"version"?: string;
		"objectType"?: string;
		"consumedResources"?: boolean;
		"consumingResources"?: boolean;
		"consumedResourceType"?: Array<string>;
		"consumingResourceType"?: Array<string>;
		"consumedResourceRequest"?: boolean;
	}
	export interface getArchitectDependencytrackingTypesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getArchitectDependencytrackingUpdatedresourceconsumersOptions { 
		"name"?: string;
		"objectType"?: Array<string>;
		"consumedResources"?: boolean;
		"consumedResourceType"?: Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getArchitectEmergencygroupsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
	}
	export interface getArchitectEmergencygroupsDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getArchitectGrammarOptions { 
		"includeFileUrls"?: boolean;
	}
	export interface getArchitectGrammarsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"description"?: string;
		"nameOrDescription"?: string;
		"includeFileUrls"?: boolean;
	}
	export interface getArchitectIvrsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"dnis"?: string;
		"scheduleGroup"?: string;
	}
	export interface getArchitectIvrsDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getArchitectPromptOptions { 
		"includeMediaUris"?: boolean;
		"includeResources"?: boolean;
		"language"?: Array<string>;
	}
	export interface getArchitectPromptHistoryHistoryIdOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"action"?: Array<string>;
	}
	export interface getArchitectPromptResourcesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getArchitectPromptsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"name"?: Array<string>;
		"description"?: string;
		"nameOrDescription"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"includeMediaUris"?: boolean;
		"includeResources"?: boolean;
		"language"?: Array<string>;
	}
	export interface getArchitectSchedulegroupsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"scheduleIds"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getArchitectSchedulegroupsDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getArchitectSchedulesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getArchitectSchedulesDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getArchitectSystempromptOptions { 
		"includeMediaUris"?: boolean;
		"includeResources"?: boolean;
		"language"?: Array<string>;
	}
	export interface getArchitectSystempromptHistoryHistoryIdOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"action"?: Array<string>;
	}
	export interface getArchitectSystempromptResourcesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getArchitectSystempromptsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"description"?: string;
		"nameOrDescription"?: string;
		"includeMediaUris"?: boolean;
		"includeResources"?: boolean;
		"language"?: Array<string>;
	}
	export interface getFlowOptions { 
		"deleted"?: boolean;
	}
	export interface getFlowHistoryHistoryIdOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"action"?: Array<string>;
	}
	export interface getFlowInstancesSettingsLoglevelsOptions { 
		"expand"?: Array<string>;
	}
	export interface getFlowLatestconfigurationOptions { 
		"deleted"?: boolean;
	}
	export interface getFlowVersionOptions { 
		"deleted"?: string;
	}
	export interface getFlowVersionConfigurationOptions { 
		"deleted"?: string;
	}
	export interface getFlowVersionHealthOptions { 
		"language"?: string;
	}
	export interface getFlowVersionsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"deleted"?: boolean;
	}
	export interface getFlowsOptions { 
		"type"?: Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"description"?: string;
		"nameOrDescription"?: string;
		"publishVersionId"?: string;
		"editableBy"?: string;
		"lockedBy"?: string;
		"lockedByClientId"?: string;
		"secure"?: string;
		"deleted"?: boolean;
		"includeSchemas"?: boolean;
		"publishedAfter"?: string;
		"publishedBefore"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getFlowsDatatableOptions { 
		"expand"?: string;
	}
	export interface getFlowsDatatableImportJobsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getFlowsDatatableRowOptions { 
		"showbrief"?: boolean;
	}
	export interface getFlowsDatatableRowsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"showbrief"?: boolean;
		"sortOrder"?: string;
	}
	export interface getFlowsDatatablesOptions { 
		"expand"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"divisionId"?: Array<string>;
		"name"?: string;
	}
	export interface getFlowsDatatablesDivisionviewOptions { 
		"expand"?: string;
	}
	export interface getFlowsDatatablesDivisionviewsOptions { 
		"expand"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"divisionId"?: Array<string>;
		"name"?: string;
	}
	export interface getFlowsDivisionviewsOptions { 
		"type"?: Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"publishVersionId"?: string;
		"publishedAfter"?: string;
		"publishedBefore"?: string;
		"divisionId"?: Array<string>;
		"includeSchemas"?: boolean;
	}
	export interface getFlowsInstanceOptions { 
		"expand"?: string;
	}
	export interface getFlowsInstancesQuerycapabilitiesOptions { 
		"expand"?: string;
	}
	export interface getFlowsInstancesSettingsLoglevelsOptions { 
		"expand"?: Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getFlowsInstancesSettingsLoglevelsDefaultOptions { 
		"expand"?: Array<string>;
	}
	export interface getFlowsJobOptions { 
		"expand"?: Array<string>;
	}
	export interface getFlowsMilestonesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"description"?: string;
		"nameOrDescription"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getFlowsMilestonesDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getFlowsOutcomesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"description"?: string;
		"nameOrDescription"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getFlowsOutcomesDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface patchArchitectGrammarOptions { 
		"body"?: Models.Grammar;
	}
	export interface patchArchitectGrammarLanguageOptions { 
		"body"?: Models.GrammarLanguageUpdate;
	}
	export interface postFlowInstancesSettingsLoglevelsOptions { 
		"expand"?: Array<string>;
	}
	export interface postFlowsOptions { 
		"language"?: string;
	}
	export interface postFlowsActionsPublishOptions { 
		"version"?: string;
	}
	export interface postFlowsInstancesJobsOptions { 
		"expand"?: string;
	}
	export interface postFlowsInstancesQueryOptions { 
		"indexOnly"?: boolean;
		"pageSize"?: number;
	}
	export interface postFlowsMilestonesOptions { 
		"body"?: Models.FlowMilestone;
	}
	export interface postFlowsOutcomesOptions { 
		"body"?: Models.FlowOutcome;
	}
	export interface putFlowInstancesSettingsLoglevelsOptions { 
		"expand"?: Array<string>;
	}
	export interface putFlowsDatatableOptions { 
		"expand"?: string;
	}
	export interface putFlowsDatatableRowOptions { 
		"body"?: object;
	}
	export interface putFlowsInstancesSettingsLoglevelsDefaultOptions { 
		"expand"?: Array<string>;
	}
	export interface putFlowsMilestoneOptions { 
		"body"?: Models.FlowMilestone;
	}
	export interface putFlowsOutcomeOptions { 
		"body"?: Models.FlowOutcome;
	}
}

declare class AuditApi {  
  	getAuditsQueryRealtimeServicemapping(): Promise<Models.AuditQueryServiceMapping>; 
  	getAuditsQueryServicemapping(): Promise<Models.AuditQueryServiceMapping>; 
  	getAuditsQueryTransactionId(transactionId: string): Promise<Models.AuditQueryExecutionStatusResponse>; 
  	getAuditsQueryTransactionIdResults(transactionId: string, opts?: AuditApi.getAuditsQueryTransactionIdResultsOptions): Promise<Models.AuditQueryExecutionResultsResponse>; 
  	postAuditsQuery(body: Models.AuditQueryRequest): Promise<Models.AuditQueryExecutionStatusResponse>; 
  	postAuditsQueryRealtime(body: Models.AuditRealtimeQueryRequest, opts?: AuditApi.postAuditsQueryRealtimeOptions): Promise<Models.AuditRealtimeQueryResultsResponse>;
}

declare namespace AuditApi { 
	export interface getAuditsQueryTransactionIdResultsOptions { 
		"cursor"?: string;
		"pageSize"?: number;
		"expand"?: Array<string>;
	}
	export interface postAuditsQueryRealtimeOptions { 
		"expand"?: Array<string>;
	}
}

declare class AuthorizationApi {  
  	deleteAuthorizationDivision(divisionId: string, opts?: AuthorizationApi.deleteAuthorizationDivisionOptions): Promise<void>; 
  	deleteAuthorizationRole(roleId: string): Promise<void>; 
  	deleteAuthorizationSubjectDivisionRole(subjectId: string, divisionId: string, roleId: string): Promise<void>; 
  	getAuthorizationDivision(divisionId: string, opts?: AuthorizationApi.getAuthorizationDivisionOptions): Promise<Models.AuthzDivision>; 
  	getAuthorizationDivisionGrants(divisionId: string, opts?: AuthorizationApi.getAuthorizationDivisionGrantsOptions): Promise<Models.AuthzDivisionGrantEntityListing>; 
  	getAuthorizationDivisions(opts?: AuthorizationApi.getAuthorizationDivisionsOptions): Promise<Models.AuthzDivisionEntityListing>; 
  	getAuthorizationDivisionsHome(): Promise<Models.AuthzDivision>; 
  	getAuthorizationDivisionsLimit(): Promise<number>; 
  	getAuthorizationDivisionspermittedMe(permission: string, opts?: AuthorizationApi.getAuthorizationDivisionspermittedMeOptions): Promise<Array<Models.AuthzDivision>>; 
  	getAuthorizationDivisionspermittedPagedMe(permission: string, opts?: AuthorizationApi.getAuthorizationDivisionspermittedPagedMeOptions): Promise<Models.DivsPermittedEntityListing>; 
  	getAuthorizationDivisionspermittedPagedSubjectId(subjectId: string, permission: string, opts?: AuthorizationApi.getAuthorizationDivisionspermittedPagedSubjectIdOptions): Promise<Models.DivsPermittedEntityListing>; 
  	getAuthorizationPermissions(opts?: AuthorizationApi.getAuthorizationPermissionsOptions): Promise<Models.PermissionCollectionEntityListing>; 
  	getAuthorizationProducts(): Promise<Models.OrganizationProductEntityListing>; 
  	getAuthorizationRole(roleId: string, opts?: AuthorizationApi.getAuthorizationRoleOptions): Promise<Models.DomainOrganizationRole>; 
  	getAuthorizationRoleComparedefaultRightRoleId(leftRoleId: string, rightRoleId: string): Promise<Models.DomainOrgRoleDifference>; 
  	getAuthorizationRoleSubjectgrants(roleId: string, opts?: AuthorizationApi.getAuthorizationRoleSubjectgrantsOptions): Promise<Models.SubjectDivisionGrantsEntityListing>; 
  	getAuthorizationRoleUsers(roleId: string, opts?: AuthorizationApi.getAuthorizationRoleUsersOptions): Promise<Models.UserEntityListing>; 
  	getAuthorizationRoles(opts?: AuthorizationApi.getAuthorizationRolesOptions): Promise<Models.OrganizationRoleEntityListing>; 
  	getAuthorizationSettings(): Promise<Models.AuthorizationSettings>; 
  	getAuthorizationSubject(subjectId: string, opts?: AuthorizationApi.getAuthorizationSubjectOptions): Promise<Models.AuthzSubject>; 
  	getAuthorizationSubjectsMe(opts?: AuthorizationApi.getAuthorizationSubjectsMeOptions): Promise<Models.AuthzSubject>; 
  	getAuthorizationSubjectsRolecounts(opts?: AuthorizationApi.getAuthorizationSubjectsRolecountsOptions): Promise<{ [key: string]: object; }>; 
  	getUserRoles(subjectId: string): Promise<Models.UserAuthorization>; 
  	patchAuthorizationRole(roleId: string, body: Models.DomainOrganizationRole): Promise<Models.DomainOrganizationRole>; 
  	patchAuthorizationSettings(body: Models.AuthorizationSettings): Promise<Models.AuthorizationSettings>; 
  	postAuthorizationDivisionObject(divisionId: string, objectType: string, body: Array<string>): Promise<void>; 
  	postAuthorizationDivisionRestore(divisionId: string, opts?: AuthorizationApi.postAuthorizationDivisionRestoreOptions): Promise<Models.AuthzDivision>; 
  	postAuthorizationDivisions(body: Models.AuthzDivision): Promise<Models.AuthzDivision>; 
  	postAuthorizationRole(roleId: string, body: Models.SubjectDivisions, opts?: AuthorizationApi.postAuthorizationRoleOptions): Promise<void>; 
  	postAuthorizationRoleComparedefaultRightRoleId(leftRoleId: string, rightRoleId: string, body: Models.DomainOrganizationRole): Promise<Models.DomainOrgRoleDifference>; 
  	postAuthorizationRoles(body: Models.DomainOrganizationRoleCreate): Promise<Models.DomainOrganizationRole>; 
  	postAuthorizationRolesDefault(opts?: AuthorizationApi.postAuthorizationRolesDefaultOptions): Promise<Models.OrganizationRoleEntityListing>; 
  	postAuthorizationSubjectBulkadd(subjectId: string, body: Models.RoleDivisionGrants, opts?: AuthorizationApi.postAuthorizationSubjectBulkaddOptions): Promise<void>; 
  	postAuthorizationSubjectBulkremove(subjectId: string, body: Models.RoleDivisionGrants): Promise<void>; 
  	postAuthorizationSubjectBulkreplace(subjectId: string, body: Models.RoleDivisionGrants, opts?: AuthorizationApi.postAuthorizationSubjectBulkreplaceOptions): Promise<void>; 
  	postAuthorizationSubjectDivisionRole(subjectId: string, divisionId: string, roleId: string, opts?: AuthorizationApi.postAuthorizationSubjectDivisionRoleOptions): Promise<void>; 
  	putAuthorizationDivision(divisionId: string, body: Models.AuthzDivision): Promise<Models.AuthzDivision>; 
  	putAuthorizationRole(roleId: string, body: Models.DomainOrganizationRoleUpdate): Promise<Models.DomainOrganizationRole>; 
  	putAuthorizationRoleUsersAdd(roleId: string, body: Array<string>): Promise<Array<string>>; 
  	putAuthorizationRoleUsersRemove(roleId: string, body: Array<string>): Promise<Array<string>>; 
  	putAuthorizationRolesDefault(body: Array<Models.DomainOrganizationRole>): Promise<Models.OrganizationRoleEntityListing>; 
  	putUserRoles(subjectId: string, body: Array<string>): Promise<Models.UserAuthorization>;
}

declare namespace AuthorizationApi { 
	export interface deleteAuthorizationDivisionOptions { 
		"force"?: boolean;
	}
	export interface getAuthorizationDivisionOptions { 
		"objectCount"?: boolean;
	}
	export interface getAuthorizationDivisionGrantsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAuthorizationDivisionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"objectCount"?: boolean;
		"id"?: Array<string>;
		"name"?: string;
	}
	export interface getAuthorizationDivisionspermittedMeOptions { 
		"name"?: string;
	}
	export interface getAuthorizationDivisionspermittedPagedMeOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAuthorizationDivisionspermittedPagedSubjectIdOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAuthorizationPermissionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"queryType"?: string;
		"query"?: string;
	}
	export interface getAuthorizationRoleOptions { 
		"userCount"?: boolean;
		"expand"?: Array<string>;
	}
	export interface getAuthorizationRoleSubjectgrantsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getAuthorizationRoleUsersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getAuthorizationRolesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"name"?: string;
		"permission"?: Array<string>;
		"defaultRoleId"?: Array<string>;
		"userCount"?: boolean;
		"id"?: Array<string>;
	}
	export interface getAuthorizationSubjectOptions { 
		"includeDuplicates"?: boolean;
	}
	export interface getAuthorizationSubjectsMeOptions { 
		"includeDuplicates"?: boolean;
	}
	export interface getAuthorizationSubjectsRolecountsOptions { 
		"id"?: Array<string>;
	}
	export interface postAuthorizationDivisionRestoreOptions { 
		"body"?: Models.AuthzDivision;
	}
	export interface postAuthorizationRoleOptions { 
		"subjectType"?: string;
	}
	export interface postAuthorizationRolesDefaultOptions { 
		"force"?: boolean;
	}
	export interface postAuthorizationSubjectBulkaddOptions { 
		"subjectType"?: string;
	}
	export interface postAuthorizationSubjectBulkreplaceOptions { 
		"subjectType"?: string;
	}
	export interface postAuthorizationSubjectDivisionRoleOptions { 
		"subjectType"?: string;
	}
}

declare class BillingApi {  
  	getBillingReportsBillableusage(startDate: string, endDate: string): Promise<Models.BillingUsageReport>; 
  	getBillingTrusteebillingoverviewTrustorOrgId(trustorOrgId: string, opts?: BillingApi.getBillingTrusteebillingoverviewTrustorOrgIdOptions): Promise<Models.TrusteeBillingOverview>;
}

declare namespace BillingApi { 
	export interface getBillingTrusteebillingoverviewTrustorOrgIdOptions { 
		"billingPeriodIndex"?: number;
	}
}

declare class CarrierServicesApi {  
  	getCarrierservicesIntegrationsEmergencylocationsMe(phoneNumber: string): Promise<Models.EmergencyLocation>; 
  	postCarrierservicesIntegrationsEmergencylocationsMe(opts?: CarrierServicesApi.postCarrierservicesIntegrationsEmergencylocationsMeOptions): Promise<Models.EmergencyLocation>;
}

declare namespace CarrierServicesApi { 
	export interface postCarrierservicesIntegrationsEmergencylocationsMeOptions { 
		"body"?: Models.EmergencyLocation;
	}
}

declare class ChatApi {  
  	deleteChatsRoomMessage(roomJid: string, messageId: string): Promise<void>; 
  	deleteChatsRoomMessagesPin(roomJid: string, pinnedMessageId: string): Promise<void>; 
  	deleteChatsRoomParticipant(roomJid: string, userId: string): Promise<void>; 
  	deleteChatsUserMessage(userId: string, messageId: string): Promise<void>; 
  	deleteChatsUserMessagesPin(userId: string, pinnedMessageId: string): Promise<void>; 
  	getChatsMessage(messageId: string): Promise<Models.ChatMessageResponse>; 
  	getChatsRoom(roomJid: string): Promise<Models.Room>; 
  	getChatsRoomMessage(roomJid: string, messageIds: string): Promise<Models.ChatMessageEntityListing>; 
  	getChatsRoomMessages(roomJid: string, opts?: ChatApi.getChatsRoomMessagesOptions): Promise<Models.ChatMessageEntityListing>; 
  	getChatsRoomParticipant(roomJid: string, participantJid: string): Promise<Models.RoomParticipant>; 
  	getChatsRoomParticipants(roomJid: string): Promise<Models.RoomParticipantsResponse>; 
  	getChatsSettings(): Promise<Models.ChatSettings>; 
  	getChatsThreadMessages(threadId: string, opts?: ChatApi.getChatsThreadMessagesOptions): Promise<Models.ChatMessageEntityListing>; 
  	getChatsUser(userId: string): Promise<Models.OneOnOne>; 
  	getChatsUserMessage(userId: string, messageIds: string): Promise<Models.ChatMessageEntityListing>; 
  	getChatsUserMessages(userId: string, opts?: ChatApi.getChatsUserMessagesOptions): Promise<Models.ChatMessageResponse>; 
  	getChatsUserSettings(userId: string): Promise<Models.ChatUserSettings>; 
  	patchChatsRoom(roomJid: string, body: Models.RoomUpdateRequest): Promise<void>; 
  	patchChatsRoomMessage(roomJid: string, messageId: string, body: Models.SendMessageBody): Promise<Models.ChatSendMessageResponse>; 
  	patchChatsSettings(body: Models.ChatSettings): Promise<Models.ChatSettings>; 
  	patchChatsUserMessage(userId: string, messageId: string, body: Models.SendMessageBody): Promise<Models.ChatSendMessageResponse>; 
  	patchChatsUserSettings(userId: string, body: Models.ChatUserSettings): Promise<Models.ChatUserSettings>; 
  	postChatsRoomMessages(roomJid: string, body: Models.SendMessageBody): Promise<Models.ChatSendMessageResponse>; 
  	postChatsRoomMessagesPins(roomJid: string, body: Models.PinnedMessageRequest): Promise<void>; 
  	postChatsRoomParticipant(roomJid: string, userId: string): Promise<void>; 
  	postChatsRooms(body: Models.CreateRoomRequest): Promise<Models.CreateRoomResponse>; 
  	postChatsUserMessages(userId: string, body: Models.SendMessageBody): Promise<Models.ChatSendMessageResponse>; 
  	postChatsUserMessagesPins(userId: string, body: Models.PinnedMessageRequest): Promise<void>; 
  	putChatsMessageReactions(messageId: string, body: Models.ChatReactionUpdate): Promise<void>; 
  	putChatsSettings(body: Models.ChatSettings): Promise<Models.ChatSettings>;
}

declare namespace ChatApi { 
	export interface getChatsRoomMessagesOptions { 
		"limit"?: string;
		"before"?: string;
		"after"?: string;
	}
	export interface getChatsThreadMessagesOptions { 
		"limit"?: string;
		"before"?: string;
		"after"?: string;
	}
	export interface getChatsUserMessagesOptions { 
		"limit"?: string;
		"before"?: string;
		"after"?: string;
	}
}

declare class CoachingApi {  
  	deleteCoachingAppointment(appointmentId: string): Promise<Models.CoachingAppointmentReference>; 
  	deleteCoachingAppointmentAnnotation(appointmentId: string, annotationId: string): Promise<void>; 
  	getCoachingAppointment(appointmentId: string): Promise<Models.CoachingAppointmentResponse>; 
  	getCoachingAppointmentAnnotation(appointmentId: string, annotationId: string): Promise<Models.CoachingAnnotation>; 
  	getCoachingAppointmentAnnotations(appointmentId: string, opts?: CoachingApi.getCoachingAppointmentAnnotationsOptions): Promise<Models.CoachingAnnotationList>; 
  	getCoachingAppointmentStatuses(appointmentId: string, opts?: CoachingApi.getCoachingAppointmentStatusesOptions): Promise<Models.CoachingAppointmentStatusResponseList>; 
  	getCoachingAppointments(userIds: Array<string>, opts?: CoachingApi.getCoachingAppointmentsOptions): Promise<Models.CoachingAppointmentResponseList>; 
  	getCoachingAppointmentsMe(opts?: CoachingApi.getCoachingAppointmentsMeOptions): Promise<Models.CoachingAppointmentResponseList>; 
  	getCoachingNotification(notificationId: string, opts?: CoachingApi.getCoachingNotificationOptions): Promise<Models.CoachingNotification>; 
  	getCoachingNotifications(opts?: CoachingApi.getCoachingNotificationsOptions): Promise<Models.CoachingNotificationList>; 
  	patchCoachingAppointment(appointmentId: string, body: Models.UpdateCoachingAppointmentRequest): Promise<Models.CoachingAppointmentResponse>; 
  	patchCoachingAppointmentAnnotation(appointmentId: string, annotationId: string, body: Models.CoachingAnnotation): Promise<Models.CoachingAnnotation>; 
  	patchCoachingAppointmentStatus(appointmentId: string, body: Models.CoachingAppointmentStatusRequest): Promise<Models.CoachingAppointmentStatusResponse>; 
  	patchCoachingNotification(notificationId: string, body: Models.CoachingNotification): Promise<Models.CoachingNotification>; 
  	postCoachingAppointmentAnnotations(appointmentId: string, body: Models.CoachingAnnotationCreateRequest): Promise<Models.CoachingAnnotation>; 
  	postCoachingAppointmentConversations(appointmentId: string, body: Models.AddConversationRequest): Promise<Models.AddConversationResponse>; 
  	postCoachingAppointments(body: Models.CreateCoachingAppointmentRequest): Promise<Models.CoachingAppointmentResponse>; 
  	postCoachingAppointmentsAggregatesQuery(body: Models.CoachingAppointmentAggregateRequest): Promise<Models.CoachingAppointmentAggregateResponse>; 
  	postCoachingScheduleslotsQuery(body: Models.CoachingSlotsRequest): Promise<Models.CoachingSlotsResponse>;
}

declare namespace CoachingApi { 
	export interface getCoachingAppointmentAnnotationsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getCoachingAppointmentStatusesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getCoachingAppointmentsOptions { 
		"interval"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"statuses"?: Array<string>;
		"facilitatorIds"?: Array<string>;
		"sortOrder"?: string;
		"relationships"?: Array<string>;
		"completionInterval"?: string;
		"overdue"?: string;
		"intervalCondition"?: string;
	}
	export interface getCoachingAppointmentsMeOptions { 
		"interval"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"statuses"?: Array<string>;
		"facilitatorIds"?: Array<string>;
		"sortOrder"?: string;
		"relationships"?: Array<string>;
		"completionInterval"?: string;
		"overdue"?: string;
		"intervalCondition"?: string;
	}
	export interface getCoachingNotificationOptions { 
		"expand"?: Array<string>;
	}
	export interface getCoachingNotificationsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"expand"?: Array<string>;
	}
}

declare class ContentManagementApi {  
  	deleteContentmanagementDocument(documentId: string, opts?: ContentManagementApi.deleteContentmanagementDocumentOptions): Promise<void>; 
  	deleteContentmanagementShare(shareId: string): Promise<void>; 
  	deleteContentmanagementStatusStatusId(statusId: string): Promise<void>; 
  	deleteContentmanagementWorkspace(workspaceId: string, opts?: ContentManagementApi.deleteContentmanagementWorkspaceOptions): Promise<void>; 
  	deleteContentmanagementWorkspaceMember(workspaceId: string, memberId: string): Promise<void>; 
  	deleteContentmanagementWorkspaceTagvalue(workspaceId: string, tagId: string): Promise<void>; 
  	getContentmanagementDocument(documentId: string, opts?: ContentManagementApi.getContentmanagementDocumentOptions): Promise<Models.Document>; 
  	getContentmanagementDocumentContent(documentId: string, opts?: ContentManagementApi.getContentmanagementDocumentContentOptions): Promise<Models.DownloadResponse>; 
  	getContentmanagementDocuments(workspaceId: string, opts?: ContentManagementApi.getContentmanagementDocumentsOptions): Promise<Models.DocumentEntityListing>; 
  	getContentmanagementQuery(queryPhrase: string, opts?: ContentManagementApi.getContentmanagementQueryOptions): Promise<Models.QueryResults>; 
  	getContentmanagementSecurityprofile(securityProfileId: string): Promise<Models.SecurityProfile>; 
  	getContentmanagementSecurityprofiles(): Promise<Models.SecurityProfileEntityListing>; 
  	getContentmanagementShare(shareId: string, opts?: ContentManagementApi.getContentmanagementShareOptions): Promise<Models.Share>; 
  	getContentmanagementSharedSharedId(sharedId: string, opts?: ContentManagementApi.getContentmanagementSharedSharedIdOptions): Promise<Models.SharedResponse>; 
  	getContentmanagementShares(opts?: ContentManagementApi.getContentmanagementSharesOptions): Promise<Models.ShareEntityListing>; 
  	getContentmanagementStatus(opts?: ContentManagementApi.getContentmanagementStatusOptions): Promise<Models.CommandStatusEntityListing>; 
  	getContentmanagementStatusStatusId(statusId: string): Promise<Models.CommandStatus>; 
  	getContentmanagementUsage(): Promise<Models.Usage>; 
  	getContentmanagementWorkspace(workspaceId: string, opts?: ContentManagementApi.getContentmanagementWorkspaceOptions): Promise<Models.Workspace>; 
  	getContentmanagementWorkspaceDocuments(workspaceId: string, opts?: ContentManagementApi.getContentmanagementWorkspaceDocumentsOptions): Promise<Models.DocumentEntityListing>; 
  	getContentmanagementWorkspaceMember(workspaceId: string, memberId: string, opts?: ContentManagementApi.getContentmanagementWorkspaceMemberOptions): Promise<Models.WorkspaceMember>; 
  	getContentmanagementWorkspaceMembers(workspaceId: string, opts?: ContentManagementApi.getContentmanagementWorkspaceMembersOptions): Promise<Models.WorkspaceMemberEntityListing>; 
  	getContentmanagementWorkspaceTagvalue(workspaceId: string, tagId: string, opts?: ContentManagementApi.getContentmanagementWorkspaceTagvalueOptions): Promise<Models.TagValue>; 
  	getContentmanagementWorkspaceTagvalues(workspaceId: string, opts?: ContentManagementApi.getContentmanagementWorkspaceTagvaluesOptions): Promise<Models.TagValueEntityListing>; 
  	getContentmanagementWorkspaces(opts?: ContentManagementApi.getContentmanagementWorkspacesOptions): Promise<Models.WorkspaceEntityListing>; 
  	postContentmanagementDocument(documentId: string, body: Models.DocumentUpdate, opts?: ContentManagementApi.postContentmanagementDocumentOptions): Promise<Models.Document>; 
  	postContentmanagementDocumentContent(documentId: string, body: Models.ReplaceRequest, opts?: ContentManagementApi.postContentmanagementDocumentContentOptions): Promise<Models.ReplaceResponse>; 
  	postContentmanagementDocuments(body: Models.DocumentUpload, opts?: ContentManagementApi.postContentmanagementDocumentsOptions): Promise<Models.Document>; 
  	postContentmanagementQuery(body: Models.QueryRequest, opts?: ContentManagementApi.postContentmanagementQueryOptions): Promise<Models.QueryResults>; 
  	postContentmanagementShares(body: Models.CreateShareRequest): Promise<Models.CreateShareResponse>; 
  	postContentmanagementWorkspaceTagvalues(workspaceId: string, body: Models.TagValue): Promise<Models.TagValue>; 
  	postContentmanagementWorkspaceTagvaluesQuery(workspaceId: string, body: Models.TagQueryRequest, opts?: ContentManagementApi.postContentmanagementWorkspaceTagvaluesQueryOptions): Promise<Models.TagValueEntityListing>; 
  	postContentmanagementWorkspaces(body: Models.WorkspaceCreate): Promise<Models.Workspace>; 
  	putContentmanagementWorkspace(workspaceId: string, body: Models.Workspace): Promise<Models.Workspace>; 
  	putContentmanagementWorkspaceMember(workspaceId: string, memberId: string, body: Models.WorkspaceMember): Promise<Models.WorkspaceMember>; 
  	putContentmanagementWorkspaceTagvalue(workspaceId: string, tagId: string, body: Models.TagValue): Promise<Models.TagValue>;
}

declare namespace ContentManagementApi { 
	export interface deleteContentmanagementDocumentOptions { 
		"override"?: boolean;
	}
	export interface deleteContentmanagementWorkspaceOptions { 
		"moveChildrenToWorkspaceId"?: string;
	}
	export interface getContentmanagementDocumentOptions { 
		"expand"?: Array<string>;
	}
	export interface getContentmanagementDocumentContentOptions { 
		"disposition"?: string;
		"contentType"?: string;
	}
	export interface getContentmanagementDocumentsOptions { 
		"name"?: string;
		"expand"?: Array<string>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getContentmanagementQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getContentmanagementShareOptions { 
		"expand"?: Array<string>;
	}
	export interface getContentmanagementSharedSharedIdOptions { 
		"redirect"?: boolean;
		"disposition"?: string;
		"contentType"?: string;
		"expand"?: string;
	}
	export interface getContentmanagementSharesOptions { 
		"entityId"?: string;
		"expand"?: Array<string>;
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getContentmanagementStatusOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getContentmanagementWorkspaceOptions { 
		"expand"?: Array<string>;
	}
	export interface getContentmanagementWorkspaceDocumentsOptions { 
		"expand"?: Array<string>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getContentmanagementWorkspaceMemberOptions { 
		"expand"?: Array<string>;
	}
	export interface getContentmanagementWorkspaceMembersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: Array<string>;
	}
	export interface getContentmanagementWorkspaceTagvalueOptions { 
		"expand"?: Array<string>;
	}
	export interface getContentmanagementWorkspaceTagvaluesOptions { 
		"value"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: Array<string>;
	}
	export interface getContentmanagementWorkspacesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"access"?: Array<string>;
		"expand"?: Array<string>;
	}
	export interface postContentmanagementDocumentOptions { 
		"expand"?: string;
		"override"?: boolean;
	}
	export interface postContentmanagementDocumentContentOptions { 
		"override"?: boolean;
	}
	export interface postContentmanagementDocumentsOptions { 
		"copySource"?: string;
		"moveSource"?: string;
		"override"?: boolean;
	}
	export interface postContentmanagementQueryOptions { 
		"expand"?: string;
	}
	export interface postContentmanagementWorkspaceTagvaluesQueryOptions { 
		"expand"?: Array<string>;
	}
}

declare class ConversationsApi {  
  	deleteAnalyticsConversationsDetailsJob(jobId: string): Promise<void>; 
  	deleteConversationParticipantCode(conversationId: string, participantId: string, addCommunicationCode: string): Promise<void>; 
  	deleteConversationParticipantFlaggedreason(conversationId: string, participantId: string): Promise<void>; 
  	deleteConversationsCallParticipantConsult(conversationId: string, participantId: string): Promise<void>; 
  	deleteConversationsEmailMessagesDraftAttachment(conversationId: string, attachmentId: string): Promise<void>; 
  	deleteConversationsMessagesCachedmediaCachedMediaItemId(cachedMediaItemId: string): Promise<void>; 
  	deleteConversationsMessagingIntegrationsFacebookIntegrationId(integrationId: string): Promise<void>; 
  	deleteConversationsMessagingIntegrationsInstagramIntegrationId(integrationId: string): Promise<void>; 
  	deleteConversationsMessagingIntegrationsLineIntegrationId(integrationId: string): Promise<void>; 
  	deleteConversationsMessagingIntegrationsOpenIntegrationId(integrationId: string): Promise<void>; 
  	deleteConversationsMessagingIntegrationsTwitterIntegrationId(integrationId: string): Promise<void>; 
  	deleteConversationsMessagingIntegrationsWhatsappIntegrationId(integrationId: string): Promise<Models.WhatsAppIntegration>; 
  	deleteConversationsMessagingSetting(messageSettingId: string): Promise<void>; 
  	deleteConversationsMessagingSettingsDefault(): Promise<void>; 
  	deleteConversationsMessagingSupportedcontentSupportedContentId(supportedContentId: string): Promise<void>; 
  	getAnalyticsConversationDetails(conversationId: string): Promise<Models.AnalyticsConversationWithoutAttributes>; 
  	getAnalyticsConversationsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsConversationsAggregatesJobResults(jobId: string, opts?: ConversationsApi.getAnalyticsConversationsAggregatesJobResultsOptions): Promise<Models.ConversationAsyncAggregateQueryResponse>; 
  	getAnalyticsConversationsDetails(opts?: ConversationsApi.getAnalyticsConversationsDetailsOptions): Promise<Models.AnalyticsConversationWithoutAttributesMultiGetResponse>; 
  	getAnalyticsConversationsDetailsJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsConversationsDetailsJobResults(jobId: string, opts?: ConversationsApi.getAnalyticsConversationsDetailsJobResultsOptions): Promise<Models.AnalyticsConversationAsyncQueryResponse>; 
  	getAnalyticsConversationsDetailsJobsAvailability(): Promise<Models.DataAvailabilityResponse>; 
  	getConversation(conversationId: string): Promise<Models.Conversation>; 
  	getConversationParticipantSecureivrsession(conversationId: string, participantId: string, secureSessionId: string): Promise<Models.SecureSession>; 
  	getConversationParticipantSecureivrsessions(conversationId: string, participantId: string): Promise<Models.SecureSessionEntityListing>; 
  	getConversationParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationSecureattributes(conversationId: string): Promise<Models.ConversationSecureAttributes>; 
  	getConversations(opts?: ConversationsApi.getConversationsOptions): Promise<Models.ConversationEntityListing>; 
  	getConversationsCall(conversationId: string): Promise<Models.CallConversation>; 
  	getConversationsCallParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsCallParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsCallParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationsCallParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsCallParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationsCallback(conversationId: string): Promise<Models.CallbackConversation>; 
  	getConversationsCallbackParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsCallbackParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsCallbackParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationsCallbackParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsCallbackParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationsCallbacks(): Promise<Models.CallbackConversationEntityListing>; 
  	getConversationsCalls(): Promise<Models.CallConversationEntityListing>; 
  	getConversationsCallsHistory(opts?: ConversationsApi.getConversationsCallsHistoryOptions): Promise<Models.CallHistoryConversationEntityListing>; 
  	getConversationsCallsMaximumconferenceparties(): Promise<Models.MaxParticipants>; 
  	getConversationsChat(conversationId: string): Promise<Models.ChatConversation>; 
  	getConversationsChatMessage(conversationId: string, messageId: string): Promise<Models.WebChatMessage>; 
  	getConversationsChatMessages(conversationId: string, opts?: ConversationsApi.getConversationsChatMessagesOptions): Promise<Models.WebChatMessageEntityList>; 
  	getConversationsChatParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsChatParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsChatParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationsChatParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsChatParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationsChats(): Promise<Models.ChatConversationEntityListing>; 
  	getConversationsCobrowsesession(conversationId: string): Promise<Models.CobrowseConversation>; 
  	getConversationsCobrowsesessionParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsCobrowsesessionParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsCobrowsesessionParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationsCobrowsesessionParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsCobrowsesessionParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationsCobrowsesessions(): Promise<Models.CobrowseConversationEntityListing>; 
  	getConversationsEmail(conversationId: string): Promise<Models.EmailConversation>; 
  	getConversationsEmailMessage(conversationId: string, messageId: string): Promise<Models.EmailMessage>; 
  	getConversationsEmailMessages(conversationId: string): Promise<Models.EmailMessagePreviewListing>; 
  	getConversationsEmailMessagesDraft(conversationId: string): Promise<Models.EmailMessage>; 
  	getConversationsEmailParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsEmailParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsEmailParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationsEmailParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsEmailParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationsEmailSettings(conversationId: string): Promise<Models.EmailsSettings>; 
  	getConversationsEmails(): Promise<Models.EmailConversationEntityListing>; 
  	getConversationsKeyconfiguration(keyconfigurationsId: string): Promise<Models.ConversationEncryptionConfiguration>; 
  	getConversationsKeyconfigurations(): Promise<Models.ConversationEncryptionConfigurationListing>; 
  	getConversationsMessage(conversationId: string): Promise<Models.MessageConversation>; 
  	getConversationsMessageCommunicationMessagesMediaMediaId(conversationId: string, communicationId: string, mediaId: string): Promise<Models.MessageMediaData>; 
  	getConversationsMessageDetails(messageId: string, opts?: ConversationsApi.getConversationsMessageDetailsOptions): Promise<Models.MessageData>; 
  	getConversationsMessageMessage(conversationId: string, messageId: string, opts?: ConversationsApi.getConversationsMessageMessageOptions): Promise<Models.MessageData>; 
  	getConversationsMessageParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsMessageParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsMessageParticipantWrapup(conversationId: string, participantId: string, opts?: ConversationsApi.getConversationsMessageParticipantWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsMessageParticipantWrapupcodes(conversationId: string, participantId: string): Promise<Array<Models.WrapupCode>>; 
  	getConversationsMessages(): Promise<Models.MessageConversationEntityListing>; 
  	getConversationsMessagesCachedmedia(opts?: ConversationsApi.getConversationsMessagesCachedmediaOptions): Promise<Models.CachedMediaItemEntityListing>; 
  	getConversationsMessagesCachedmediaCachedMediaItemId(cachedMediaItemId: string): Promise<Models.CachedMediaItem>; 
  	getConversationsMessagingFacebookApp(): Promise<Models.FacebookAppCredentials>; 
  	getConversationsMessagingFacebookPermissions(): Promise<Models.FacebookPermissionEntityListing>; 
  	getConversationsMessagingIntegrations(opts?: ConversationsApi.getConversationsMessagingIntegrationsOptions): Promise<Models.MessagingIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsFacebook(opts?: ConversationsApi.getConversationsMessagingIntegrationsFacebookOptions): Promise<Models.FacebookIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsFacebookIntegrationId(integrationId: string, opts?: ConversationsApi.getConversationsMessagingIntegrationsFacebookIntegrationIdOptions): Promise<Models.FacebookIntegration>; 
  	getConversationsMessagingIntegrationsInstagram(opts?: ConversationsApi.getConversationsMessagingIntegrationsInstagramOptions): Promise<Models.InstagramIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsInstagramIntegrationId(integrationId: string, opts?: ConversationsApi.getConversationsMessagingIntegrationsInstagramIntegrationIdOptions): Promise<Models.InstagramIntegration>; 
  	getConversationsMessagingIntegrationsLine(opts?: ConversationsApi.getConversationsMessagingIntegrationsLineOptions): Promise<Models.LineIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsLineIntegrationId(integrationId: string, opts?: ConversationsApi.getConversationsMessagingIntegrationsLineIntegrationIdOptions): Promise<Models.LineIntegration>; 
  	getConversationsMessagingIntegrationsOpen(opts?: ConversationsApi.getConversationsMessagingIntegrationsOpenOptions): Promise<Models.OpenIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsOpenIntegrationId(integrationId: string, opts?: ConversationsApi.getConversationsMessagingIntegrationsOpenIntegrationIdOptions): Promise<Models.OpenIntegration>; 
  	getConversationsMessagingIntegrationsTwitter(opts?: ConversationsApi.getConversationsMessagingIntegrationsTwitterOptions): Promise<Models.TwitterIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsTwitterIntegrationId(integrationId: string, opts?: ConversationsApi.getConversationsMessagingIntegrationsTwitterIntegrationIdOptions): Promise<Models.TwitterIntegration>; 
  	getConversationsMessagingIntegrationsWhatsapp(opts?: ConversationsApi.getConversationsMessagingIntegrationsWhatsappOptions): Promise<Models.WhatsAppIntegrationEntityListing>; 
  	getConversationsMessagingIntegrationsWhatsappIntegrationId(integrationId: string, opts?: ConversationsApi.getConversationsMessagingIntegrationsWhatsappIntegrationIdOptions): Promise<Models.WhatsAppIntegration>; 
  	getConversationsMessagingSetting(messageSettingId: string): Promise<Models.MessagingSetting>; 
  	getConversationsMessagingSettings(opts?: ConversationsApi.getConversationsMessagingSettingsOptions): Promise<Models.MessagingConfigListing>; 
  	getConversationsMessagingSettingsDefault(): Promise<Models.MessagingSetting>; 
  	getConversationsMessagingSticker(messengerType: string, opts?: ConversationsApi.getConversationsMessagingStickerOptions): Promise<Models.MessagingStickerEntityListing>; 
  	getConversationsMessagingSupportedcontent(opts?: ConversationsApi.getConversationsMessagingSupportedcontentOptions): Promise<Models.SupportedContentListing>; 
  	getConversationsMessagingSupportedcontentDefault(): Promise<Models.SupportedContent>; 
  	getConversationsMessagingSupportedcontentSupportedContentId(supportedContentId: string): Promise<Models.SupportedContent>; 
  	getConversationsMessagingThreadingtimeline(): Promise<Models.ConversationThreadingWindow>; 
  	getConversationsScreenshareParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsScreenshareParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsSettings(): Promise<Models.Settings>; 
  	getConversationsSocialParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsSocialParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsVideoDetails(conferenceId: string): Promise<Models.VideoConferenceDetails>; 
  	getConversationsVideoParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.getConversationsVideoParticipantCommunicationWrapupOptions): Promise<Models.AssignedWrapupCode>; 
  	getConversationsVideosMeeting(meetingId: string): Promise<Models.MeetingIdRecord>; 
  	patchConversationParticipant(conversationId: string, participantId: string, body: Models.MediaParticipantRequest): Promise<void>; 
  	patchConversationParticipantAttributes(conversationId: string, participantId: string, body: Models.ParticipantAttributes): Promise<void>; 
  	patchConversationSecureattributes(conversationId: string, body: Models.ConversationSecureAttributes): Promise<string>; 
  	patchConversationUtilizationlabel(conversationId: string, body: Models.ConversationUtilizationLabelUpdate): Promise<string>; 
  	patchConversationsAftercallworkConversationIdParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.AfterCallWorkUpdate): Promise<Models.AfterCallWorkUpdate>; 
  	patchConversationsCall(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	patchConversationsCallParticipant(conversationId: string, participantId: string, body: Models.MediaParticipantRequest): Promise<void>; 
  	patchConversationsCallParticipantAttributes(conversationId: string, participantId: string, body: Models.ParticipantAttributes): Promise<Models.ParticipantAttributes>; 
  	patchConversationsCallParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.MediaParticipantRequest): Promise<object>; 
  	patchConversationsCallParticipantConsult(conversationId: string, participantId: string, body: Models.ConsultTransferUpdate): Promise<Models.ConsultTransferResponse>; 
  	patchConversationsCallback(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	patchConversationsCallbackParticipant(conversationId: string, participantId: string, body: Models.MediaParticipantRequest): Promise<void>; 
  	patchConversationsCallbackParticipantAttributes(conversationId: string, participantId: string, body: Models.ParticipantAttributes): Promise<Models.ParticipantAttributes>; 
  	patchConversationsCallbackParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.MediaParticipantRequest): Promise<object>; 
  	patchConversationsCallbacks(body: Models.PatchCallbackRequest): Promise<Models.PatchCallbackResponse>; 
  	patchConversationsChat(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	patchConversationsChatParticipant(conversationId: string, participantId: string, body: Models.MediaParticipantRequest): Promise<void>; 
  	patchConversationsChatParticipantAttributes(conversationId: string, participantId: string, body: Models.ParticipantAttributes): Promise<Models.ParticipantAttributes>; 
  	patchConversationsChatParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.MediaParticipantRequest): Promise<object>; 
  	patchConversationsCobrowsesession(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	patchConversationsCobrowsesessionParticipant(conversationId: string, participantId: string, opts?: ConversationsApi.patchConversationsCobrowsesessionParticipantOptions): Promise<void>; 
  	patchConversationsCobrowsesessionParticipantAttributes(conversationId: string, participantId: string, opts?: ConversationsApi.patchConversationsCobrowsesessionParticipantAttributesOptions): Promise<Models.ParticipantAttributes>; 
  	patchConversationsCobrowsesessionParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.MediaParticipantRequest): Promise<object>; 
  	patchConversationsEmail(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	patchConversationsEmailMessagesDraft(conversationId: string, opts?: ConversationsApi.patchConversationsEmailMessagesDraftOptions): Promise<Models.EmailMessage>; 
  	patchConversationsEmailParticipant(conversationId: string, participantId: string, body: Models.MediaParticipantRequest): Promise<void>; 
  	patchConversationsEmailParticipantAttributes(conversationId: string, participantId: string, body: Models.ParticipantAttributes): Promise<Models.ParticipantAttributes>; 
  	patchConversationsEmailParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.MediaParticipantRequest): Promise<object>; 
  	patchConversationsMessage(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	patchConversationsMessageParticipant(conversationId: string, participantId: string, opts?: ConversationsApi.patchConversationsMessageParticipantOptions): Promise<void>; 
  	patchConversationsMessageParticipantAttributes(conversationId: string, participantId: string, opts?: ConversationsApi.patchConversationsMessageParticipantAttributesOptions): Promise<Models.ParticipantAttributes>; 
  	patchConversationsMessageParticipantCommunication(conversationId: string, participantId: string, communicationId: string, body: Models.MediaParticipantRequest): Promise<object>; 
  	patchConversationsMessagingIntegrationsFacebookIntegrationId(integrationId: string, body: Models.FacebookIntegrationUpdateRequest): Promise<Models.FacebookIntegration>; 
  	patchConversationsMessagingIntegrationsInstagramIntegrationId(integrationId: string, body: Models.InstagramIntegrationUpdateRequest): Promise<Models.InstagramIntegration>; 
  	patchConversationsMessagingIntegrationsOpenIntegrationId(integrationId: string, body: Models.OpenIntegrationUpdateRequest): Promise<Models.OpenIntegration>; 
  	patchConversationsMessagingIntegrationsTwitterIntegrationId(integrationId: string, body: Models.TwitterIntegrationRequest): Promise<Models.TwitterIntegration>; 
  	patchConversationsMessagingIntegrationsWhatsappEmbeddedsignupIntegrationId(integrationId: string, body: Models.WhatsAppEmbeddedSignupIntegrationActivationRequest): Promise<Models.WhatsAppIntegration>; 
  	patchConversationsMessagingIntegrationsWhatsappIntegrationId(integrationId: string, body: Models.WhatsAppIntegrationUpdateRequest): Promise<Models.WhatsAppIntegration>; 
  	patchConversationsMessagingSetting(messageSettingId: string, body: Models.MessagingSettingPatchRequest): Promise<Models.MessagingSetting>; 
  	patchConversationsMessagingSupportedcontentSupportedContentId(supportedContentId: string, body: Models.SupportedContent): Promise<Models.SupportedContent>; 
  	patchConversationsSettings(body: Models.Settings): Promise<void>; 
  	postAnalyticsConversationDetailsProperties(conversationId: string, body: Models.PropertyIndexRequest): Promise<Models.PropertyIndexRequest>; 
  	postAnalyticsConversationsActivityQuery(body: Models.ConversationActivityQuery, opts?: ConversationsApi.postAnalyticsConversationsActivityQueryOptions): Promise<Models.ConversationActivityResponse>; 
  	postAnalyticsConversationsAggregatesJobs(body: Models.ConversationAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsConversationsAggregatesQuery(body: Models.ConversationAggregationQuery): Promise<Models.ConversationAggregateQueryResponse>; 
  	postAnalyticsConversationsDetailsJobs(body: Models.AsyncConversationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsConversationsDetailsQuery(body: Models.ConversationQuery): Promise<Models.AnalyticsConversationQueryResponse>; 
  	postConversationAssign(conversationId: string, body: Models.ConversationUser): Promise<string>; 
  	postConversationBarge(conversationId: string): Promise<void>; 
  	postConversationCobrowse(conversationId: string): Promise<Models.CobrowseWebMessagingSession>; 
  	postConversationDisconnect(conversationId: string): Promise<string>; 
  	postConversationParticipantCallbacks(conversationId: string, participantId: string, opts?: ConversationsApi.postConversationParticipantCallbacksOptions): Promise<void>; 
  	postConversationParticipantDigits(conversationId: string, participantId: string, opts?: ConversationsApi.postConversationParticipantDigitsOptions): Promise<void>; 
  	postConversationParticipantReplace(conversationId: string, participantId: string, body: Models.TransferRequest): Promise<void>; 
  	postConversationParticipantReplaceAgent(conversationId: string, participantId: string, body: Models.TransferToAgentRequest): Promise<void>; 
  	postConversationParticipantReplaceExternal(conversationId: string, participantId: string, body: Models.TransferToExternalRequest): Promise<void>; 
  	postConversationParticipantReplaceQueue(conversationId: string, participantId: string, body: Models.TransferToQueueRequest): Promise<void>; 
  	postConversationParticipantSecureivrsessions(conversationId: string, participantId: string, opts?: ConversationsApi.postConversationParticipantSecureivrsessionsOptions): Promise<Models.SecureSession>; 
  	postConversationSummaryFeedback(conversationId: string, summaryId: string, opts?: ConversationsApi.postConversationSummaryFeedbackOptions): Promise<void>; 
  	postConversationsCall(conversationId: string, body: Models.CallCommand): Promise<Models.Conversation>; 
  	postConversationsCallParticipantBarge(conversationId: string, participantId: string): Promise<void>; 
  	postConversationsCallParticipantCoach(conversationId: string, participantId: string): Promise<void>; 
  	postConversationsCallParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsCallParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsCallParticipantConsult(conversationId: string, participantId: string, body: Models.ConsultTransfer): Promise<Models.ConsultTransferResponse>; 
  	postConversationsCallParticipantConsultAgent(conversationId: string, participantId: string, body: Models.ConsultTransferToAgent): Promise<Models.ConsultTransferResponse>; 
  	postConversationsCallParticipantConsultExternal(conversationId: string, participantId: string, body: Models.ConsultTransferToExternal): Promise<Models.ConsultTransferResponse>; 
  	postConversationsCallParticipantConsultQueue(conversationId: string, participantId: string, body: Models.ConsultTransferToQueue): Promise<Models.ConsultTransferResponse>; 
  	postConversationsCallParticipantMonitor(conversationId: string, participantId: string): Promise<void>; 
  	postConversationsCallParticipantReplace(conversationId: string, participantId: string, body: Models.TransferRequest): Promise<void>; 
  	postConversationsCallParticipants(conversationId: string, body: Models.Conversation): Promise<Models.Conversation>; 
  	postConversationsCallbackParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsCallbackParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsCallbackParticipantReplace(conversationId: string, participantId: string, body: Models.TransferRequest): Promise<void>; 
  	postConversationsCallbacks(body: Models.CreateCallbackCommand): Promise<Models.CreateCallbackResponse>; 
  	postConversationsCallbacksBulkDisconnect(body: Models.BulkCallbackDisconnectRequest): Promise<void>; 
  	postConversationsCallbacksBulkUpdate(body: Models.BulkCallbackPatchRequest): Promise<Models.BulkCallbackPatchResponse>; 
  	postConversationsCalls(body: Models.CreateCallRequest): Promise<Models.CreateCallResponse>; 
  	postConversationsChatCommunicationMessages(conversationId: string, communicationId: string, body: Models.CreateWebChatMessageRequest): Promise<Models.WebChatMessage>; 
  	postConversationsChatCommunicationTyping(conversationId: string, communicationId: string): Promise<Models.WebChatTyping>; 
  	postConversationsChatParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsChatParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsChatParticipantReplace(conversationId: string, participantId: string, body: Models.TransferRequest): Promise<void>; 
  	postConversationsChats(body: Models.CreateWebChatRequest): Promise<Models.ChatConversation>; 
  	postConversationsCobrowsesessionParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsCobrowsesessionParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsCobrowsesessionParticipantReplace(conversationId: string, participantId: string, opts?: ConversationsApi.postConversationsCobrowsesessionParticipantReplaceOptions): Promise<void>; 
  	postConversationsEmailInboundmessages(conversationId: string, body: Models.InboundMessageRequest): Promise<Models.EmailConversation>; 
  	postConversationsEmailMessages(conversationId: string, body: Models.EmailMessage): Promise<Models.EmailMessageReply>; 
  	postConversationsEmailMessagesDraftAttachmentsCopy(conversationId: string, body: Models.CopyAttachmentsRequest): Promise<Models.EmailMessage>; 
  	postConversationsEmailParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsEmailParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsEmailParticipantReplace(conversationId: string, participantId: string, body: Models.TransferRequest): Promise<void>; 
  	postConversationsEmails(body: Models.CreateEmailRequest): Promise<Models.EmailConversation>; 
  	postConversationsEmailsAgentless(body: Models.AgentlessEmailSendRequestDto): Promise<Models.AgentlessEmailSendResponseDto>; 
  	postConversationsFaxes(body: Models.FaxSendRequest): Promise<Models.FaxSendResponse>; 
  	postConversationsKeyconfigurations(body: Models.ConversationEncryptionConfiguration): Promise<Models.ConversationEncryptionConfiguration>; 
  	postConversationsKeyconfigurationsValidate(body: Models.ConversationEncryptionConfiguration): Promise<Models.ConversationEncryptionConfiguration>; 
  	postConversationsMessageCommunicationMessages(conversationId: string, communicationId: string, body: Models.AdditionalMessage, opts?: ConversationsApi.postConversationsMessageCommunicationMessagesOptions): Promise<Models.MessageData>; 
  	postConversationsMessageCommunicationMessagesMedia(conversationId: string, communicationId: string): Promise<Models.MessageMediaData>; 
  	postConversationsMessageCommunicationTyping(conversationId: string, communicationId: string, body: Models.MessageTypingEventRequest): Promise<void>; 
  	postConversationsMessageInboundOpenEvent(integrationId: string, body: Models.OpenInboundNormalizedEvent): Promise<Models.OpenEventNormalizedMessage>; 
  	postConversationsMessageInboundOpenMessage(integrationId: string, body: Models.OpenInboundNormalizedMessage): Promise<Models.OpenMessageNormalizedMessage>; 
  	postConversationsMessageInboundOpenReceipt(integrationId: string, body: Models.OpenInboundNormalizedReceipt): Promise<Models.OpenReceiptNormalizedMessage>; 
  	postConversationsMessageMessagesBulk(conversationId: string, opts?: ConversationsApi.postConversationsMessageMessagesBulkOptions): Promise<Models.TextMessageListing>; 
  	postConversationsMessageParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsMessageParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsMessageParticipantMonitor(conversationId: string, participantId: string): Promise<void>; 
  	postConversationsMessageParticipantReplace(conversationId: string, participantId: string, body: Models.TransferRequest): Promise<void>; 
  	postConversationsMessages(body: Models.CreateOutboundMessagingConversationRequest): Promise<Models.MessageConversation>; 
  	postConversationsMessagesAgentless(body: Models.SendAgentlessOutboundMessageRequest): Promise<Models.SendAgentlessOutboundMessageResponse>; 
  	postConversationsMessagesInboundOpen(body: Models.OpenNormalizedMessage): Promise<Models.OpenNormalizedMessage>; 
  	postConversationsMessagingIntegrationsFacebook(body: Models.FacebookIntegrationRequest): Promise<Models.FacebookIntegration>; 
  	postConversationsMessagingIntegrationsInstagram(body: Models.InstagramIntegrationRequest): Promise<Models.InstagramIntegration>; 
  	postConversationsMessagingIntegrationsLine(body: Models.LineIntegrationRequest): Promise<Models.LineIntegration>; 
  	postConversationsMessagingIntegrationsOpen(body: Models.OpenIntegrationRequest): Promise<Models.OpenIntegration>; 
  	postConversationsMessagingIntegrationsTwitter(body: Models.TwitterIntegrationRequest): Promise<Models.TwitterIntegration>; 
  	postConversationsMessagingIntegrationsWhatsapp(body: Models.WhatsAppIntegrationRequest): Promise<Models.WhatsAppIntegration>; 
  	postConversationsMessagingIntegrationsWhatsappEmbeddedsignup(body: Models.WhatsAppEmbeddedSignupIntegrationRequest): Promise<Models.WhatsAppIntegration>; 
  	postConversationsMessagingSettings(body: Models.MessagingSettingRequest): Promise<Models.MessagingSetting>; 
  	postConversationsMessagingSupportedcontent(body: Models.SupportedContent): Promise<Models.SupportedContent>; 
  	postConversationsParticipantsAttributesSearch(body: Models.ConversationParticipantSearchRequest): Promise<Models.JsonCursorSearchResponse>; 
  	postConversationsScreenshareParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsScreenshareParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsSocialParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsSocialParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsVideoParticipantCommunicationWrapup(conversationId: string, participantId: string, communicationId: string, opts?: ConversationsApi.postConversationsVideoParticipantCommunicationWrapupOptions): Promise<void>; 
  	postConversationsVideosMeetings(body: Models.GenerateMeetingIdRequest): Promise<Models.MeetingIdRecord>; 
  	putConversationParticipantFlaggedreason(conversationId: string, participantId: string): Promise<void>; 
  	putConversationSecureattributes(conversationId: string, body: Models.ConversationSecureAttributes): Promise<string>; 
  	putConversationTags(conversationId: string, body: Models.ConversationTagsUpdate): Promise<string>; 
  	putConversationsCallParticipantCommunicationUuidata(conversationId: string, participantId: string, communicationId: string, body: Models.SetUuiDataRequest): Promise<object>; 
  	putConversationsCallRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsCallbackRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsChatRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsCobrowsesessionRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsEmailMessagesDraft(conversationId: string, body: Models.EmailMessage): Promise<Models.EmailMessage>; 
  	putConversationsEmailRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsKeyconfiguration(keyconfigurationsId: string, body: Models.ConversationEncryptionConfiguration): Promise<Models.ConversationEncryptionConfiguration>; 
  	putConversationsMessageRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsMessagingIntegrationsLineIntegrationId(integrationId: string, body: Models.LineIntegrationRequest): Promise<Models.LineIntegration>; 
  	putConversationsMessagingSettingsDefault(body: Models.MessagingSettingDefaultRequest): Promise<Models.MessagingSetting>; 
  	putConversationsMessagingSupportedcontentDefault(body: Models.SupportedContentReference): Promise<Models.SupportedContent>; 
  	putConversationsMessagingThreadingtimeline(body: Models.ConversationThreadingWindow): Promise<Models.ConversationThreadingWindow>; 
  	putConversationsScreenshareRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsSocialRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>; 
  	putConversationsVideoRecordingstate(conversationId: string, body: Models.SetRecordingState): Promise<string>;
}

declare namespace ConversationsApi { 
	export interface getAnalyticsConversationsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsConversationsDetailsOptions { 
		"id"?: Array<string>;
	}
	export interface getAnalyticsConversationsDetailsJobResultsOptions { 
		"cursor"?: string;
		"pageSize"?: number;
	}
	export interface getConversationParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsOptions { 
		"communicationType"?: string;
	}
	export interface getConversationsCallParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsCallParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsCallbackParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsCallbackParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsCallsHistoryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"interval"?: string;
		"expand"?: Array<string>;
	}
	export interface getConversationsChatMessagesOptions { 
		"after"?: string;
		"before"?: string;
		"sortOrder"?: string;
		"maxResults"?: number;
	}
	export interface getConversationsChatParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsChatParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsCobrowsesessionParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsCobrowsesessionParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsEmailParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsEmailParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsMessageDetailsOptions { 
		"useNormalizedMessage"?: boolean;
	}
	export interface getConversationsMessageMessageOptions { 
		"useNormalizedMessage"?: boolean;
	}
	export interface getConversationsMessageParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsMessageParticipantWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsMessagesCachedmediaOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"url"?: string;
	}
	export interface getConversationsMessagingIntegrationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: Array<string>;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsFacebookOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsFacebookIntegrationIdOptions { 
		"expand"?: string;
	}
	export interface getConversationsMessagingIntegrationsInstagramOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsInstagramIntegrationIdOptions { 
		"expand"?: string;
	}
	export interface getConversationsMessagingIntegrationsLineOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsLineIntegrationIdOptions { 
		"expand"?: string;
	}
	export interface getConversationsMessagingIntegrationsOpenOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsOpenIntegrationIdOptions { 
		"expand"?: string;
	}
	export interface getConversationsMessagingIntegrationsTwitterOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsTwitterIntegrationIdOptions { 
		"expand"?: string;
	}
	export interface getConversationsMessagingIntegrationsWhatsappOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"supportedContentId"?: string;
		"messagingSettingId"?: string;
	}
	export interface getConversationsMessagingIntegrationsWhatsappIntegrationIdOptions { 
		"expand"?: string;
	}
	export interface getConversationsMessagingSettingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getConversationsMessagingStickerOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getConversationsMessagingSupportedcontentOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getConversationsScreenshareParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsSocialParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface getConversationsVideoParticipantCommunicationWrapupOptions { 
		"provisional"?: boolean;
	}
	export interface patchConversationsCobrowsesessionParticipantOptions { 
		"body"?: Models.MediaParticipantRequest;
	}
	export interface patchConversationsCobrowsesessionParticipantAttributesOptions { 
		"body"?: Models.ParticipantAttributes;
	}
	export interface patchConversationsEmailMessagesDraftOptions { 
		"autoFill"?: boolean;
		"discard"?: boolean;
		"body"?: Models.DraftManipulationRequest;
	}
	export interface patchConversationsMessageParticipantOptions { 
		"body"?: Models.MediaParticipantRequest;
	}
	export interface patchConversationsMessageParticipantAttributesOptions { 
		"body"?: Models.ParticipantAttributes;
	}
	export interface postAnalyticsConversationsActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postConversationParticipantCallbacksOptions { 
		"body"?: Models.CreateCallbackOnConversationCommand;
	}
	export interface postConversationParticipantDigitsOptions { 
		"body"?: Models.Digits;
	}
	export interface postConversationParticipantSecureivrsessionsOptions { 
		"body"?: Models.CreateSecureSession;
	}
	export interface postConversationSummaryFeedbackOptions { 
		"body"?: Models.FeedbackAddRequest;
	}
	export interface postConversationsCallParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsCallbackParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsChatParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsCobrowsesessionParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsCobrowsesessionParticipantReplaceOptions { 
		"body"?: Models.TransferRequest;
	}
	export interface postConversationsEmailParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsMessageCommunicationMessagesOptions { 
		"useNormalizedMessage"?: boolean;
	}
	export interface postConversationsMessageMessagesBulkOptions { 
		"useNormalizedMessage"?: boolean;
		"body"?: Array<string>;
	}
	export interface postConversationsMessageParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsScreenshareParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsSocialParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
	export interface postConversationsVideoParticipantCommunicationWrapupOptions { 
		"body"?: Models.WrapupInput;
	}
}

declare class DataExtensionsApi {  
  	getDataextensionsCoretype(coretypeName: string): Promise<Models.Coretype>; 
  	getDataextensionsCoretypes(): Promise<Models.CoretypeListing>; 
  	getDataextensionsLimits(): Promise<Models.SchemaQuantityLimits>;
}

declare namespace DataExtensionsApi { 
}

declare class DownloadsApi {  
  	getDownload(downloadId: string, opts?: DownloadsApi.getDownloadOptions): Promise<Models.UrlResponse>;
}

declare namespace DownloadsApi { 
	export interface getDownloadOptions { 
		"contentDisposition"?: string;
		"issueRedirect"?: boolean;
		"redirectToAuth"?: boolean;
	}
}

declare class EmailsApi {  
  	getEmailsSettings(): Promise<Models.EmailSettings>; 
  	patchEmailsSettings(opts?: EmailsApi.patchEmailsSettingsOptions): Promise<Models.EmailSettings>;
}

declare namespace EmailsApi { 
	export interface patchEmailsSettingsOptions { 
		"body"?: Models.EmailSettings;
	}
}

declare class EventsApi {  
  	postEventsConversations(body: Models.BatchConversationEventRequest): Promise<Models.BatchEventResponse>; 
  	postEventsUsersPresence(body: Models.BatchUserPresenceEventRequest): Promise<Models.BatchEventResponse>; 
  	postEventsUsersRoutingstatus(body: Models.BatchUserRoutingStatusEventRequest): Promise<Models.BatchEventResponse>;
}

declare namespace EventsApi { 
}

declare class ExternalContactsApi {  
  	deleteExternalcontactsContact(contactId: string): Promise<object>; 
  	deleteExternalcontactsContactNote(contactId: string, noteId: string): Promise<object>; 
  	deleteExternalcontactsContactsSchema(schemaId: string): Promise<void>; 
  	deleteExternalcontactsOrganization(externalOrganizationId: string): Promise<object>; 
  	deleteExternalcontactsOrganizationNote(externalOrganizationId: string, noteId: string): Promise<object>; 
  	deleteExternalcontactsOrganizationTrustor(externalOrganizationId: string): Promise<void>; 
  	deleteExternalcontactsRelationship(relationshipId: string): Promise<object>; 
  	getExternalcontactsContact(contactId: string, opts?: ExternalContactsApi.getExternalcontactsContactOptions): Promise<Models.ExternalContact>; 
  	getExternalcontactsContactIdentifiers(contactId: string): Promise<Models.EntityListing>; 
  	getExternalcontactsContactJourneySessions(contactId: string, opts?: ExternalContactsApi.getExternalcontactsContactJourneySessionsOptions): Promise<Models.SessionListing>; 
  	getExternalcontactsContactNote(contactId: string, noteId: string, opts?: ExternalContactsApi.getExternalcontactsContactNoteOptions): Promise<Models.Note>; 
  	getExternalcontactsContactNotes(contactId: string, opts?: ExternalContactsApi.getExternalcontactsContactNotesOptions): Promise<Models.NoteListing>; 
  	getExternalcontactsContactUnresolved(contactId: string, opts?: ExternalContactsApi.getExternalcontactsContactUnresolvedOptions): Promise<Models.ExternalContact>; 
  	getExternalcontactsContacts(opts?: ExternalContactsApi.getExternalcontactsContactsOptions): Promise<Models.ContactListing>; 
  	getExternalcontactsContactsSchema(schemaId: string): Promise<Models.DataSchema>; 
  	getExternalcontactsContactsSchemaVersion(schemaId: string, versionId: string): Promise<Models.DataSchema>; 
  	getExternalcontactsContactsSchemaVersions(schemaId: string): Promise<Models.DataSchema>; 
  	getExternalcontactsContactsSchemas(): Promise<Models.DataSchemaListing>; 
  	getExternalcontactsOrganization(externalOrganizationId: string, opts?: ExternalContactsApi.getExternalcontactsOrganizationOptions): Promise<Models.ExternalOrganization>; 
  	getExternalcontactsOrganizationContacts(externalOrganizationId: string, opts?: ExternalContactsApi.getExternalcontactsOrganizationContactsOptions): Promise<Models.ContactListing>; 
  	getExternalcontactsOrganizationNote(externalOrganizationId: string, noteId: string, opts?: ExternalContactsApi.getExternalcontactsOrganizationNoteOptions): Promise<Models.Note>; 
  	getExternalcontactsOrganizationNotes(externalOrganizationId: string, opts?: ExternalContactsApi.getExternalcontactsOrganizationNotesOptions): Promise<Models.NoteListing>; 
  	getExternalcontactsOrganizationRelationships(externalOrganizationId: string, opts?: ExternalContactsApi.getExternalcontactsOrganizationRelationshipsOptions): Promise<Models.RelationshipListing>; 
  	getExternalcontactsOrganizations(opts?: ExternalContactsApi.getExternalcontactsOrganizationsOptions): Promise<Models.ExternalOrganizationListing>; 
  	getExternalcontactsOrganizationsSchema(schemaId: string): Promise<Models.DataSchema>; 
  	getExternalcontactsOrganizationsSchemaVersion(schemaId: string, versionId: string): Promise<Models.DataSchema>; 
  	getExternalcontactsOrganizationsSchemaVersions(schemaId: string): Promise<Models.DataSchema>; 
  	getExternalcontactsOrganizationsSchemas(): Promise<Models.DataSchemaListing>; 
  	getExternalcontactsRelationship(relationshipId: string, opts?: ExternalContactsApi.getExternalcontactsRelationshipOptions): Promise<Models.Relationship>; 
  	getExternalcontactsReversewhitepageslookup(lookupVal: string, opts?: ExternalContactsApi.getExternalcontactsReversewhitepageslookupOptions): Promise<Models.ReverseWhitepagesLookupResult>; 
  	getExternalcontactsScanContacts(opts?: ExternalContactsApi.getExternalcontactsScanContactsOptions): Promise<Models.CursorContactListing>; 
  	getExternalcontactsScanNotes(opts?: ExternalContactsApi.getExternalcontactsScanNotesOptions): Promise<Models.CursorNoteListing>; 
  	getExternalcontactsScanOrganizations(opts?: ExternalContactsApi.getExternalcontactsScanOrganizationsOptions): Promise<Models.CursorOrganizationListing>; 
  	getExternalcontactsScanRelationships(opts?: ExternalContactsApi.getExternalcontactsScanRelationshipsOptions): Promise<Models.CursorRelationshipListing>; 
  	patchExternalcontactsContactIdentifiers(contactId: string, body: Models.IdentifierClaimRequest): Promise<Models.ContactIdentifier>; 
  	postExternalcontactsBulkContacts(body: Models.BulkIdsRequest): Promise<Models.BulkFetchContactsResponse>; 
  	postExternalcontactsBulkContactsAdd(body: Models.BulkContactsRequest): Promise<Models.BulkContactsResponse>; 
  	postExternalcontactsBulkContactsRemove(body: Models.BulkIdsRequest): Promise<Models.BulkDeleteResponse>; 
  	postExternalcontactsBulkContactsUnresolved(body: Models.BulkIdsRequest): Promise<Models.BulkFetchContactsResponse>; 
  	postExternalcontactsBulkContactsUpdate(body: Models.BulkContactsRequest): Promise<Models.BulkContactsResponse>; 
  	postExternalcontactsBulkNotes(body: Models.BulkIdsRequest): Promise<Models.BulkFetchNotesResponse>; 
  	postExternalcontactsBulkNotesAdd(body: Models.BulkNotesRequest): Promise<Models.BulkNotesResponse>; 
  	postExternalcontactsBulkNotesRemove(body: Models.BulkIdsRequest): Promise<Models.BulkDeleteResponse>; 
  	postExternalcontactsBulkNotesUpdate(body: Models.BulkNotesRequest): Promise<Models.BulkNotesResponse>; 
  	postExternalcontactsBulkOrganizations(body: Models.BulkIdsRequest): Promise<Models.BulkFetchOrganizationsResponse>; 
  	postExternalcontactsBulkOrganizationsAdd(body: Models.BulkOrganizationsRequest): Promise<Models.BulkOrganizationsResponse>; 
  	postExternalcontactsBulkOrganizationsRemove(body: Models.BulkIdsRequest): Promise<Models.BulkDeleteResponse>; 
  	postExternalcontactsBulkOrganizationsUpdate(body: Models.BulkOrganizationsRequest): Promise<Models.BulkOrganizationsResponse>; 
  	postExternalcontactsBulkRelationships(body: Models.BulkIdsRequest): Promise<Models.BulkFetchRelationshipsResponse>; 
  	postExternalcontactsBulkRelationshipsAdd(body: Models.BulkRelationshipsRequest): Promise<Models.BulkRelationshipsResponse>; 
  	postExternalcontactsBulkRelationshipsRemove(body: Models.BulkIdsRequest): Promise<Models.BulkDeleteResponse>; 
  	postExternalcontactsBulkRelationshipsUpdate(body: Models.BulkRelationshipsRequest): Promise<Models.BulkRelationshipsResponse>; 
  	postExternalcontactsContactNotes(contactId: string, body: Models.Note): Promise<Models.Note>; 
  	postExternalcontactsContactPromotion(contactId: string): Promise<Models.ExternalContact>; 
  	postExternalcontactsContacts(body: Models.ExternalContact): Promise<Models.ExternalContact>; 
  	postExternalcontactsContactsSchemas(body: Models.DataSchema): Promise<Models.DataSchema>; 
  	postExternalcontactsIdentifierlookup(identifier: Models.ContactIdentifier): Promise<Models.ExternalContact>; 
  	postExternalcontactsMergeContacts(body: Models.MergeRequest): Promise<Models.ExternalContact>; 
  	postExternalcontactsOrganizationNotes(externalOrganizationId: string, body: Models.Note): Promise<Models.Note>; 
  	postExternalcontactsOrganizations(body: Models.ExternalOrganization): Promise<Models.ExternalOrganization>; 
  	postExternalcontactsOrganizationsSchemas(body: Models.DataSchema): Promise<Models.DataSchema>; 
  	postExternalcontactsRelationships(body: Models.Relationship): Promise<Models.Relationship>; 
  	putExternalcontactsContact(contactId: string, body: Models.ExternalContact): Promise<Models.ExternalContact>; 
  	putExternalcontactsContactNote(contactId: string, noteId: string, body: Models.Note): Promise<Models.Note>; 
  	putExternalcontactsContactsSchema(schemaId: string, body: Models.DataSchema): Promise<Models.DataSchema>; 
  	putExternalcontactsConversation(conversationId: string, body: Models.ConversationAssociation): Promise<void>; 
  	putExternalcontactsOrganization(externalOrganizationId: string, body: Models.ExternalOrganization): Promise<Models.ExternalOrganization>; 
  	putExternalcontactsOrganizationNote(externalOrganizationId: string, noteId: string, body: Models.Note): Promise<Models.Note>; 
  	putExternalcontactsOrganizationTrustorTrustorId(externalOrganizationId: string, trustorId: string): Promise<Models.ExternalOrganizationTrustorLink>; 
  	putExternalcontactsOrganizationsSchema(schemaId: string, body: Models.DataSchema): Promise<Models.DataSchema>; 
  	putExternalcontactsRelationship(relationshipId: string, body: Models.Relationship): Promise<Models.Relationship>;
}

declare namespace ExternalContactsApi { 
	export interface getExternalcontactsContactOptions { 
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsContactJourneySessionsOptions { 
		"pageSize"?: string;
		"after"?: string;
		"includeMerged"?: boolean;
	}
	export interface getExternalcontactsContactNoteOptions { 
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsContactNotesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsContactUnresolvedOptions { 
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsContactsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"q"?: string;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsOrganizationOptions { 
		"expand"?: string;
		"includeTrustors"?: boolean;
	}
	export interface getExternalcontactsOrganizationContactsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"q"?: string;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsOrganizationNoteOptions { 
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsOrganizationNotesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsOrganizationRelationshipsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"sortOrder"?: string;
	}
	export interface getExternalcontactsOrganizationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"q"?: string;
		"trustorId"?: Array<string>;
		"sortOrder"?: string;
		"expand"?: Array<string>;
		"includeTrustors"?: boolean;
	}
	export interface getExternalcontactsRelationshipOptions { 
		"expand"?: string;
	}
	export interface getExternalcontactsReversewhitepageslookupOptions { 
		"expand"?: Array<string>;
	}
	export interface getExternalcontactsScanContactsOptions { 
		"limit"?: number;
		"cursor"?: string;
	}
	export interface getExternalcontactsScanNotesOptions { 
		"limit"?: number;
		"cursor"?: string;
	}
	export interface getExternalcontactsScanOrganizationsOptions { 
		"limit"?: number;
		"cursor"?: string;
	}
	export interface getExternalcontactsScanRelationshipsOptions { 
		"limit"?: number;
		"cursor"?: string;
	}
}

declare class FaxApi {  
  	deleteFaxDocument(documentId: string): Promise<void>; 
  	getFaxDocument(documentId: string): Promise<Models.FaxDocument>; 
  	getFaxDocumentContent(documentId: string): Promise<Models.DownloadResponse>; 
  	getFaxDocuments(opts?: FaxApi.getFaxDocumentsOptions): Promise<Models.FaxDocumentEntityListing>; 
  	getFaxSettings(): Promise<Models.FaxConfig>; 
  	getFaxSummary(): Promise<Models.FaxSummary>; 
  	putFaxDocument(documentId: string, body: Models.FaxDocument): Promise<Models.FaxDocument>; 
  	putFaxSettings(opts?: FaxApi.putFaxSettingsOptions): Promise<Models.FaxConfig>;
}

declare namespace FaxApi { 
	export interface getFaxDocumentsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface putFaxSettingsOptions { 
		"body"?: Models.FaxConfig;
	}
}

declare class FlowsApi {  
  	getAnalyticsFlowsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsFlowsAggregatesJobResults(jobId: string, opts?: FlowsApi.getAnalyticsFlowsAggregatesJobResultsOptions): Promise<Models.FlowAsyncAggregateQueryResponse>; 
  	postAnalyticsFlowsActivityQuery(body: Models.FlowActivityQuery, opts?: FlowsApi.postAnalyticsFlowsActivityQueryOptions): Promise<Models.FlowActivityResponse>; 
  	postAnalyticsFlowsAggregatesJobs(body: Models.FlowAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsFlowsAggregatesQuery(body: Models.FlowAggregationQuery): Promise<Models.FlowAggregateQueryResponse>; 
  	postAnalyticsFlowsObservationsQuery(body: Models.FlowObservationQuery): Promise<Models.FlowObservationQueryResponse>;
}

declare namespace FlowsApi { 
	export interface getAnalyticsFlowsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface postAnalyticsFlowsActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class GamificationApi {  
  	deleteEmployeeperformanceExternalmetricsDefinition(metricId: string): Promise<void>; 
  	getEmployeeperformanceExternalmetricsDefinition(metricId: string): Promise<Models.ExternalMetricDefinition>; 
  	getEmployeeperformanceExternalmetricsDefinitions(opts?: GamificationApi.getEmployeeperformanceExternalmetricsDefinitionsOptions): Promise<Models.ExternalMetricDefinitionListing>; 
  	getGamificationInsights(filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, primaryPeriodStartWorkday: string, opts?: GamificationApi.getGamificationInsightsOptions): Promise<Models.InsightsSummary>; 
  	getGamificationInsightsDetails(filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, primaryPeriodStartWorkday: string): Promise<Models.InsightsDetails>; 
  	getGamificationInsightsGroupsTrends(filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, comparativePeriodEndWorkday: string, primaryPeriodStartWorkday: string, primaryPeriodEndWorkday: string): Promise<Models.InsightsTrend>; 
  	getGamificationInsightsGroupsTrendsAll(filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, comparativePeriodEndWorkday: string, primaryPeriodStartWorkday: string, primaryPeriodEndWorkday: string): Promise<Models.InsightsTrend>; 
  	getGamificationInsightsMembers(filterType: string, filterId: string, granularity: string, startWorkday: string): Promise<Models.InsightsAgents>; 
  	getGamificationInsightsTrends(filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, comparativePeriodEndWorkday: string, primaryPeriodStartWorkday: string, primaryPeriodEndWorkday: string): Promise<Models.UserInsightsTrend>; 
  	getGamificationInsightsUserDetails(userId: string, filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, primaryPeriodStartWorkday: string): Promise<Models.InsightsDetails>; 
  	getGamificationInsightsUserTrends(userId: string, filterType: string, filterId: string, granularity: string, comparativePeriodStartWorkday: string, comparativePeriodEndWorkday: string, primaryPeriodStartWorkday: string, primaryPeriodEndWorkday: string): Promise<Models.UserInsightsTrend>; 
  	getGamificationLeaderboard(startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationLeaderboardOptions): Promise<Models.Leaderboard>; 
  	getGamificationLeaderboardAll(filterType: string, filterId: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationLeaderboardAllOptions): Promise<Models.Leaderboard>; 
  	getGamificationLeaderboardAllBestpoints(filterType: string, filterId: string): Promise<Models.OverallBestPoints>; 
  	getGamificationLeaderboardBestpoints(): Promise<Models.OverallBestPoints>; 
  	getGamificationMetricdefinition(metricDefinitionId: string): Promise<Models.MetricDefinition>; 
  	getGamificationMetricdefinitions(): Promise<Models.GetMetricDefinitionsResponse>; 
  	getGamificationProfile(profileId: string): Promise<Models.PerformanceProfile>; 
  	getGamificationProfileMembers(profileId: string): Promise<Models.MemberListing>; 
  	getGamificationProfileMetric(profileId: string, metricId: string, opts?: GamificationApi.getGamificationProfileMetricOptions): Promise<Models.Metric>; 
  	getGamificationProfileMetrics(profileId: string, opts?: GamificationApi.getGamificationProfileMetricsOptions): Promise<Models.GetMetricResponse>; 
  	getGamificationProfileMetricsObjectivedetails(profileId: string, opts?: GamificationApi.getGamificationProfileMetricsObjectivedetailsOptions): Promise<Models.GetMetricsResponse>; 
  	getGamificationProfiles(): Promise<Models.GetProfilesResponse>; 
  	getGamificationProfilesUser(userId: string, opts?: GamificationApi.getGamificationProfilesUserOptions): Promise<Models.PerformanceProfile>; 
  	getGamificationProfilesUsersMe(opts?: GamificationApi.getGamificationProfilesUsersMeOptions): Promise<Models.PerformanceProfile>; 
  	getGamificationScorecards(workday: string, opts?: GamificationApi.getGamificationScorecardsOptions): Promise<Models.WorkdayMetricListing>; 
  	getGamificationScorecardsAttendance(startWorkday: string, endWorkday: string): Promise<Models.AttendanceStatusListing>; 
  	getGamificationScorecardsBestpoints(): Promise<Models.UserBestPoints>; 
  	getGamificationScorecardsPointsAlltime(endWorkday: string): Promise<Models.AllTimePoints>; 
  	getGamificationScorecardsPointsAverage(workday: string): Promise<Models.SingleWorkdayAveragePoints>; 
  	getGamificationScorecardsPointsTrends(startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsPointsTrendsOptions): Promise<Models.WorkdayPointsTrend>; 
  	getGamificationScorecardsProfileMetricUserValuesTrends(profileId: string, metricId: string, userId: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsProfileMetricUserValuesTrendsOptions): Promise<Models.MetricValueTrendAverage>; 
  	getGamificationScorecardsProfileMetricUsersValuesTrends(profileId: string, metricId: string, filterType: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsProfileMetricUsersValuesTrendsOptions): Promise<Models.MetricValueTrendAverage>; 
  	getGamificationScorecardsProfileMetricValuesTrends(profileId: string, metricId: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsProfileMetricValuesTrendsOptions): Promise<Models.MetricValueTrendAverage>; 
  	getGamificationScorecardsUser(userId: string, workday: string, opts?: GamificationApi.getGamificationScorecardsUserOptions): Promise<Models.WorkdayMetricListing>; 
  	getGamificationScorecardsUserAttendance(userId: string, startWorkday: string, endWorkday: string): Promise<Models.AttendanceStatusListing>; 
  	getGamificationScorecardsUserBestpoints(userId: string): Promise<Models.UserBestPoints>; 
  	getGamificationScorecardsUserPointsAlltime(userId: string, endWorkday: string): Promise<Models.AllTimePoints>; 
  	getGamificationScorecardsUserPointsTrends(userId: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsUserPointsTrendsOptions): Promise<Models.WorkdayPointsTrend>; 
  	getGamificationScorecardsUserValuesTrends(userId: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsUserValuesTrendsOptions): Promise<Models.WorkdayValuesTrend>; 
  	getGamificationScorecardsUsersPointsAverage(filterType: string, filterId: string, workday: string): Promise<Models.SingleWorkdayAveragePoints>; 
  	getGamificationScorecardsUsersValuesAverage(filterType: string, filterId: string, workday: string, opts?: GamificationApi.getGamificationScorecardsUsersValuesAverageOptions): Promise<Models.SingleWorkdayAverageValues>; 
  	getGamificationScorecardsUsersValuesTrends(filterType: string, filterId: string, startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsUsersValuesTrendsOptions): Promise<Models.WorkdayValuesTrend>; 
  	getGamificationScorecardsValuesAverage(workday: string, opts?: GamificationApi.getGamificationScorecardsValuesAverageOptions): Promise<Models.SingleWorkdayAverageValues>; 
  	getGamificationScorecardsValuesTrends(startWorkday: string, endWorkday: string, opts?: GamificationApi.getGamificationScorecardsValuesTrendsOptions): Promise<Models.WorkdayValuesTrend>; 
  	getGamificationStatus(): Promise<Models.GamificationStatus>; 
  	getGamificationTemplate(templateId: string): Promise<Models.ObjectiveTemplate>; 
  	getGamificationTemplates(): Promise<Models.GetTemplatesResponse>; 
  	patchEmployeeperformanceExternalmetricsDefinition(metricId: string, body: Models.ExternalMetricDefinitionUpdateRequest): Promise<Models.ExternalMetricDefinition>; 
  	postEmployeeperformanceExternalmetricsData(opts?: GamificationApi.postEmployeeperformanceExternalmetricsDataOptions): Promise<Models.ExternalMetricDataWriteResponse>; 
  	postEmployeeperformanceExternalmetricsDefinitions(opts?: GamificationApi.postEmployeeperformanceExternalmetricsDefinitionsOptions): Promise<Models.ExternalMetricDefinition>; 
  	postGamificationProfileActivate(profileId: string): Promise<Models.PerformanceProfile>; 
  	postGamificationProfileDeactivate(profileId: string): Promise<Models.PerformanceProfile>; 
  	postGamificationProfileMembers(profileId: string, body: Models.AssignUsers): Promise<Models.Assignment>; 
  	postGamificationProfileMembersValidate(profileId: string, body: Models.ValidateAssignUsers): Promise<Models.AssignmentValidation>; 
  	postGamificationProfileMetricLink(sourceProfileId: string, sourceMetricId: string, body: Models.TargetPerformanceProfile): Promise<Models.Metric>; 
  	postGamificationProfileMetrics(profileId: string, body: Models.CreateMetric): Promise<Models.Metric>; 
  	postGamificationProfiles(body: Models.CreatePerformanceProfile, opts?: GamificationApi.postGamificationProfilesOptions): Promise<Models.PerformanceProfile>; 
  	postGamificationProfilesUserQuery(userId: string, body: Models.UserProfilesInDateRangeRequest): Promise<Models.UserProfilesInDateRange>; 
  	postGamificationProfilesUsersMeQuery(body: Models.UserProfilesInDateRangeRequest): Promise<Models.UserProfilesInDateRange>; 
  	putGamificationProfile(profileId: string, opts?: GamificationApi.putGamificationProfileOptions): Promise<Models.PerformanceProfile>; 
  	putGamificationProfileMetric(profileId: string, metricId: string, body: Models.CreateMetric): Promise<Models.Metric>; 
  	putGamificationStatus(status: Models.GamificationStatus): Promise<Models.GamificationStatus>;
}

declare namespace GamificationApi { 
	export interface getEmployeeperformanceExternalmetricsDefinitionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getGamificationInsightsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortKey"?: string;
		"sortMetricId"?: string;
		"sortOrder"?: string;
		"userIds"?: string;
	}
	export interface getGamificationLeaderboardOptions { 
		"metricId"?: string;
	}
	export interface getGamificationLeaderboardAllOptions { 
		"metricId"?: string;
	}
	export interface getGamificationProfileMetricOptions { 
		"workday"?: string;
	}
	export interface getGamificationProfileMetricsOptions { 
		"expand"?: Array<string>;
		"workday"?: string;
		"metricIds"?: string;
	}
	export interface getGamificationProfileMetricsObjectivedetailsOptions { 
		"workday"?: string;
	}
	export interface getGamificationProfilesUserOptions { 
		"workday"?: string;
	}
	export interface getGamificationProfilesUsersMeOptions { 
		"workday"?: string;
	}
	export interface getGamificationScorecardsOptions { 
		"expand"?: Array<string>;
	}
	export interface getGamificationScorecardsPointsTrendsOptions { 
		"dayOfWeek"?: string;
	}
	export interface getGamificationScorecardsProfileMetricUserValuesTrendsOptions { 
		"referenceWorkday"?: string;
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsProfileMetricUsersValuesTrendsOptions { 
		"filterId"?: string;
		"referenceWorkday"?: string;
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsProfileMetricValuesTrendsOptions { 
		"filterType"?: string;
		"referenceWorkday"?: string;
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsUserOptions { 
		"expand"?: Array<string>;
	}
	export interface getGamificationScorecardsUserPointsTrendsOptions { 
		"dayOfWeek"?: string;
	}
	export interface getGamificationScorecardsUserValuesTrendsOptions { 
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsUsersValuesAverageOptions { 
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsUsersValuesTrendsOptions { 
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsValuesAverageOptions { 
		"timeZone"?: string;
	}
	export interface getGamificationScorecardsValuesTrendsOptions { 
		"filterType"?: string;
		"referenceWorkday"?: string;
		"timeZone"?: string;
	}
	export interface postEmployeeperformanceExternalmetricsDataOptions { 
		"body"?: Models.ExternalMetricDataWriteRequest;
	}
	export interface postEmployeeperformanceExternalmetricsDefinitionsOptions { 
		"body"?: Models.ExternalMetricDefinitionCreateRequest;
	}
	export interface postGamificationProfilesOptions { 
		"copyMetrics"?: boolean;
	}
	export interface putGamificationProfileOptions { 
		"body"?: Models.PerformanceProfile;
	}
}

declare class GeneralDataProtectionRegulationApi {  
  	getGdprRequest(requestId: string): Promise<Models.GDPRRequest>; 
  	getGdprRequests(opts?: GeneralDataProtectionRegulationApi.getGdprRequestsOptions): Promise<Models.GDPRRequestEntityListing>; 
  	getGdprSubjects(searchType: string, searchValue: string): Promise<Models.GDPRSubjectEntityListing>; 
  	postGdprRequests(body: Models.GDPRRequest, opts?: GeneralDataProtectionRegulationApi.postGdprRequestsOptions): Promise<Models.GDPRRequest>;
}

declare namespace GeneralDataProtectionRegulationApi { 
	export interface getGdprRequestsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postGdprRequestsOptions { 
		"deleteConfirmed"?: boolean;
	}
}

declare class GeolocationApi {  
  	getGeolocationsSettings(): Promise<Models.GeolocationSettings>; 
  	getUserGeolocation(userId: string, clientId: string): Promise<Models.Geolocation>; 
  	patchGeolocationsSettings(body: Models.GeolocationSettings): Promise<Models.GeolocationSettings>; 
  	patchUserGeolocation(userId: string, clientId: string, body: Models.Geolocation): Promise<Models.Geolocation>;
}

declare namespace GeolocationApi { 
}

declare class GreetingsApi {  
  	deleteGreeting(greetingId: string): Promise<void>; 
  	getGreeting(greetingId: string): Promise<Models.Greeting>; 
  	getGreetingMedia(greetingId: string, opts?: GreetingsApi.getGreetingMediaOptions): Promise<Models.GreetingMediaInfo>; 
  	getGreetings(opts?: GreetingsApi.getGreetingsOptions): Promise<Models.DomainEntityListing>; 
  	getGreetingsDefaults(): Promise<Models.DefaultGreetingList>; 
  	getGroupGreetings(groupId: string, opts?: GreetingsApi.getGroupGreetingsOptions): Promise<Models.GreetingListing>; 
  	getGroupGreetingsDefaults(groupId: string): Promise<Models.DefaultGreetingList>; 
  	getUserGreetings(userId: string, opts?: GreetingsApi.getUserGreetingsOptions): Promise<Models.DomainEntityListing>; 
  	getUserGreetingsDefaults(userId: string): Promise<Models.DefaultGreetingList>; 
  	postGreetings(body: Models.Greeting): Promise<Models.Greeting>; 
  	postGroupGreetings(groupId: string, body: Models.Greeting): Promise<Models.Greeting>; 
  	postUserGreetings(userId: string, body: Models.Greeting): Promise<Models.Greeting>; 
  	putGreeting(greetingId: string, body: Models.Greeting): Promise<Models.Greeting>; 
  	putGreetingsDefaults(body: Models.DefaultGreetingList): Promise<Models.DefaultGreetingList>; 
  	putGroupGreetingsDefaults(groupId: string, body: Models.DefaultGreetingList): Promise<Models.DefaultGreetingList>; 
  	putUserGreetingsDefaults(userId: string, body: Models.DefaultGreetingList): Promise<Models.DefaultGreetingList>;
}

declare namespace GreetingsApi { 
	export interface getGreetingMediaOptions { 
		"formatId"?: string;
	}
	export interface getGreetingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getGroupGreetingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getUserGreetingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class GroupsApi {  
  	deleteGroup(groupId: string): Promise<void>; 
  	deleteGroupDynamicsettings(groupId: string): Promise<void>; 
  	deleteGroupMembers(groupId: string, ids: string): Promise<object>; 
  	getFieldconfig(type: string): Promise<Models.FieldConfig>; 
  	getGroup(groupId: string): Promise<Models.Group>; 
  	getGroupDynamicsettings(groupId: string): Promise<Models.DynamicGroupDefinition>; 
  	getGroupIndividuals(groupId: string): Promise<Models.UserEntityListing>; 
  	getGroupMembers(groupId: string, opts?: GroupsApi.getGroupMembersOptions): Promise<Models.UserEntityListing>; 
  	getGroupProfile(groupId: string, opts?: GroupsApi.getGroupProfileOptions): Promise<Models.GroupProfile>; 
  	getGroups(opts?: GroupsApi.getGroupsOptions): Promise<Models.GroupEntityListing>; 
  	getGroupsSearch(q64: string, opts?: GroupsApi.getGroupsSearchOptions): Promise<Models.GroupsSearchResponse>; 
  	getProfilesGroups(opts?: GroupsApi.getProfilesGroupsOptions): Promise<Models.GroupProfileEntityListing>; 
  	postGroupMembers(groupId: string, body: Models.GroupMembersUpdate): Promise<object>; 
  	postGroups(body: Models.GroupCreate): Promise<Models.Group>; 
  	postGroupsDynamicsettingsPreview(body: Models.DynamicGroupQuery): Promise<Models.DynamicGroupQueryPreview>; 
  	postGroupsSearch(body: Models.GroupSearchRequest): Promise<Models.GroupsSearchResponse>; 
  	putGroup(groupId: string, opts?: GroupsApi.putGroupOptions): Promise<Models.Group>; 
  	putGroupDynamicsettings(groupId: string, body: Models.DynamicGroupQuery): Promise<void>;
}

declare namespace GroupsApi { 
	export interface getGroupMembersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getGroupProfileOptions { 
		"fields"?: string;
	}
	export interface getGroupsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"jabberId"?: Array<string>;
		"sortOrder"?: string;
	}
	export interface getGroupsSearchOptions { 
		"expand"?: Array<string>;
	}
	export interface getProfilesGroupsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"jabberId"?: Array<string>;
		"sortOrder"?: string;
	}
	export interface putGroupOptions { 
		"body"?: Models.GroupUpdate;
	}
}

declare class IdentityProviderApi {  
  	deleteIdentityprovider(providerId: string): Promise<void>; 
  	deleteIdentityprovidersAdfs(): Promise<object>; 
  	deleteIdentityprovidersCic(): Promise<object>; 
  	deleteIdentityprovidersGeneric(): Promise<object>; 
  	deleteIdentityprovidersGsuite(): Promise<object>; 
  	deleteIdentityprovidersIdentitynow(): Promise<object>; 
  	deleteIdentityprovidersOkta(): Promise<object>; 
  	deleteIdentityprovidersOnelogin(): Promise<object>; 
  	deleteIdentityprovidersPing(): Promise<object>; 
  	deleteIdentityprovidersPurecloud(): Promise<object>; 
  	deleteIdentityprovidersPureengage(): Promise<object>; 
  	deleteIdentityprovidersSalesforce(): Promise<object>; 
  	getIdentityprovider(providerId: string): Promise<Models.CustomProvider>; 
  	getIdentityproviders(): Promise<Models.IdentityProviderEntityListing>; 
  	getIdentityprovidersAdfs(): Promise<Models.ADFS>; 
  	getIdentityprovidersCic(): Promise<Models.CustomerInteractionCenter>; 
  	getIdentityprovidersGeneric(): Promise<Models.GenericSAML>; 
  	getIdentityprovidersGsuite(): Promise<Models.GSuite>; 
  	getIdentityprovidersIdentitynow(): Promise<Models.IdentityNow>; 
  	getIdentityprovidersOkta(): Promise<Models.Okta>; 
  	getIdentityprovidersOnelogin(): Promise<Models.OneLogin>; 
  	getIdentityprovidersPing(): Promise<Models.PingIdentity>; 
  	getIdentityprovidersPurecloud(): Promise<Models.PureCloud>; 
  	getIdentityprovidersPureengage(): Promise<Models.PureEngage>; 
  	getIdentityprovidersSalesforce(): Promise<Models.Salesforce>; 
  	postIdentityproviders(body: Models.CustomProvider): Promise<Models.CustomProvider>; 
  	putIdentityprovider(providerId: string, body: Models.CustomProvider): Promise<Models.CustomProvider>; 
  	putIdentityprovidersAdfs(body: Models.ADFS): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersCic(body: Models.CustomerInteractionCenter): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersGeneric(body: Models.GenericSAML): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersGsuite(body: Models.GSuite): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersIdentitynow(body: Models.IdentityNow): Promise<Models.IdentityNow>; 
  	putIdentityprovidersOkta(body: Models.Okta): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersOnelogin(body: Models.OneLogin): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersPing(body: Models.PingIdentity): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersPurecloud(body: Models.PureCloud): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersPureengage(body: Models.PureEngage): Promise<Models.IdentityProvider>; 
  	putIdentityprovidersSalesforce(body: Models.Salesforce): Promise<Models.IdentityProvider>;
}

declare namespace IdentityProviderApi { 
}

declare class InfrastructureAsCodeApi {  
  	getInfrastructureascodeAccelerator(acceleratorId: string, opts?: InfrastructureAsCodeApi.getInfrastructureascodeAcceleratorOptions): Promise<Models.AcceleratorSpecification>; 
  	getInfrastructureascodeAccelerators(opts?: InfrastructureAsCodeApi.getInfrastructureascodeAcceleratorsOptions): Promise<Models.AcceleratorList>; 
  	getInfrastructureascodeJob(jobId: string, opts?: InfrastructureAsCodeApi.getInfrastructureascodeJobOptions): Promise<Models.InfrastructureascodeJob>; 
  	getInfrastructureascodeJobs(opts?: InfrastructureAsCodeApi.getInfrastructureascodeJobsOptions): Promise<Models.InfrastructureascodeJob>; 
  	postInfrastructureascodeJobs(body: Models.AcceleratorInput): Promise<Models.InfrastructureascodeJob>;
}

declare namespace InfrastructureAsCodeApi { 
	export interface getInfrastructureascodeAcceleratorOptions { 
		"preferredLanguage"?: string;
	}
	export interface getInfrastructureascodeAcceleratorsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"description"?: string;
		"origin"?: string;
		"type"?: string;
		"classification"?: string;
		"tags"?: string;
	}
	export interface getInfrastructureascodeJobOptions { 
		"details"?: boolean;
	}
	export interface getInfrastructureascodeJobsOptions { 
		"maxResults"?: number;
		"includeErrors"?: boolean;
		"sortBy"?: string;
		"sortOrder"?: string;
		"acceleratorId"?: string;
		"submittedBy"?: string;
		"status"?: string;
	}
}

declare class IntegrationsApi {  
  	deleteIntegration(integrationId: string): Promise<Models.Integration>; 
  	deleteIntegrationsAction(actionId: string): Promise<void>; 
  	deleteIntegrationsActionDraft(actionId: string): Promise<void>; 
  	deleteIntegrationsCredential(credentialId: string): Promise<void>; 
  	getIntegration(integrationId: string, opts?: IntegrationsApi.getIntegrationOptions): Promise<Models.Integration>; 
  	getIntegrationConfigCurrent(integrationId: string): Promise<Models.IntegrationConfiguration>; 
  	getIntegrations(opts?: IntegrationsApi.getIntegrationsOptions): Promise<Models.IntegrationEntityListing>; 
  	getIntegrationsAction(actionId: string, opts?: IntegrationsApi.getIntegrationsActionOptions): Promise<Models.Action>; 
  	getIntegrationsActionDraft(actionId: string, opts?: IntegrationsApi.getIntegrationsActionDraftOptions): Promise<Models.Action>; 
  	getIntegrationsActionDraftFunction(actionId: string): Promise<Models.FunctionConfig>; 
  	getIntegrationsActionDraftSchema(actionId: string, fileName: string): Promise<Models.JsonSchemaDocument>; 
  	getIntegrationsActionDraftTemplate(actionId: string, fileName: string): Promise<string>; 
  	getIntegrationsActionDraftValidation(actionId: string): Promise<Models.DraftValidationResult>; 
  	getIntegrationsActionFunction(actionId: string): Promise<Models.FunctionConfig>; 
  	getIntegrationsActionSchema(actionId: string, fileName: string): Promise<Models.JsonSchemaDocument>; 
  	getIntegrationsActionTemplate(actionId: string, fileName: string): Promise<string>; 
  	getIntegrationsActions(opts?: IntegrationsApi.getIntegrationsActionsOptions): Promise<Models.ActionEntityListing>; 
  	getIntegrationsActionsCategories(opts?: IntegrationsApi.getIntegrationsActionsCategoriesOptions): Promise<Models.CategoryEntityListing>; 
  	getIntegrationsActionsCertificates(opts?: IntegrationsApi.getIntegrationsActionsCertificatesOptions): Promise<Models.ActionCertificateListing>; 
  	getIntegrationsActionsDrafts(opts?: IntegrationsApi.getIntegrationsActionsDraftsOptions): Promise<Models.ActionEntityListing>; 
  	getIntegrationsActionsFunctionsRuntimes(): Promise<Array<Models.FunctionRuntime>>; 
  	getIntegrationsBotconnectorIntegrationIdBot(integrationId: string, botId: string, opts?: IntegrationsApi.getIntegrationsBotconnectorIntegrationIdBotOptions): Promise<Models.BotConnectorBot>; 
  	getIntegrationsBotconnectorIntegrationIdBotVersions(integrationId: string, botId: string, opts?: IntegrationsApi.getIntegrationsBotconnectorIntegrationIdBotVersionsOptions): Promise<Models.BotConnectorBotVersionSummaryEntityListing>; 
  	getIntegrationsBotconnectorIntegrationIdBots(integrationId: string): Promise<Models.BotList>; 
  	getIntegrationsBotconnectorIntegrationIdBotsSummaries(integrationId: string, opts?: IntegrationsApi.getIntegrationsBotconnectorIntegrationIdBotsSummariesOptions): Promise<Models.BotConnectorBotSummaryEntityListing>; 
  	getIntegrationsClientapps(opts?: IntegrationsApi.getIntegrationsClientappsOptions): Promise<Models.ClientAppEntityListing>; 
  	getIntegrationsClientappsUnifiedcommunications(opts?: IntegrationsApi.getIntegrationsClientappsUnifiedcommunicationsOptions): Promise<Models.UCIntegrationListing>; 
  	getIntegrationsCredential(credentialId: string): Promise<Models.Credential>; 
  	getIntegrationsCredentials(opts?: IntegrationsApi.getIntegrationsCredentialsOptions): Promise<Models.CredentialInfoListing>; 
  	getIntegrationsCredentialsTypes(): Promise<Models.CredentialTypeListing>; 
  	getIntegrationsSpeechDialogflowAgent(agentId: string): Promise<Models.DialogflowAgent>; 
  	getIntegrationsSpeechDialogflowAgents(opts?: IntegrationsApi.getIntegrationsSpeechDialogflowAgentsOptions): Promise<Models.DialogflowAgentSummaryEntityListing>; 
  	getIntegrationsSpeechDialogflowcxAgent(agentId: string): Promise<Models.DialogflowCXAgent>; 
  	getIntegrationsSpeechDialogflowcxAgents(opts?: IntegrationsApi.getIntegrationsSpeechDialogflowcxAgentsOptions): Promise<Models.DialogflowCXAgentSummaryEntityListing>; 
  	getIntegrationsSpeechLexBotAlias(aliasId: string): Promise<Models.LexBotAlias>; 
  	getIntegrationsSpeechLexBotBotIdAliases(botId: string, opts?: IntegrationsApi.getIntegrationsSpeechLexBotBotIdAliasesOptions): Promise<Models.LexBotAliasEntityListing>; 
  	getIntegrationsSpeechLexBots(opts?: IntegrationsApi.getIntegrationsSpeechLexBotsOptions): Promise<Models.LexBotEntityListing>; 
  	getIntegrationsSpeechLexv2BotAlias(aliasId: string): Promise<Models.LexV2BotAlias>; 
  	getIntegrationsSpeechLexv2BotBotIdAliases(botId: string, opts?: IntegrationsApi.getIntegrationsSpeechLexv2BotBotIdAliasesOptions): Promise<Models.LexV2BotAliasEntityListing>; 
  	getIntegrationsSpeechLexv2Bots(opts?: IntegrationsApi.getIntegrationsSpeechLexv2BotsOptions): Promise<Models.LexV2BotEntityListing>; 
  	getIntegrationsSpeechNuanceNuanceIntegrationIdBot(nuanceIntegrationId: string, botId: string, opts?: IntegrationsApi.getIntegrationsSpeechNuanceNuanceIntegrationIdBotOptions): Promise<Models.NuanceBot>; 
  	getIntegrationsSpeechNuanceNuanceIntegrationIdBotJob(nuanceIntegrationId: string, botId: string, jobId: string): Promise<Models.AsyncJob>; 
  	getIntegrationsSpeechNuanceNuanceIntegrationIdBotJobResults(nuanceIntegrationId: string, botId: string, jobId: string): Promise<Models.NuanceBot>; 
  	getIntegrationsSpeechNuanceNuanceIntegrationIdBots(nuanceIntegrationId: string, opts?: IntegrationsApi.getIntegrationsSpeechNuanceNuanceIntegrationIdBotsOptions): Promise<Models.NuanceBotEntityListing>; 
  	getIntegrationsSpeechNuanceNuanceIntegrationIdBotsJob(nuanceIntegrationId: string, jobId: string): Promise<Models.AsyncJob>; 
  	getIntegrationsSpeechNuanceNuanceIntegrationIdBotsJobResults(nuanceIntegrationId: string, jobId: string): Promise<Models.NuanceBotEntityListing>; 
  	getIntegrationsSpeechSttEngine(engineId: string): Promise<Models.SttEngineEntity>; 
  	getIntegrationsSpeechSttEngines(opts?: IntegrationsApi.getIntegrationsSpeechSttEnginesOptions): Promise<Models.SttEngineEntityListing>; 
  	getIntegrationsSpeechTtsEngine(engineId: string, opts?: IntegrationsApi.getIntegrationsSpeechTtsEngineOptions): Promise<Models.TtsEngineEntity>; 
  	getIntegrationsSpeechTtsEngineVoice(engineId: string, voiceId: string): Promise<Models.TtsVoiceEntity>; 
  	getIntegrationsSpeechTtsEngineVoices(engineId: string, opts?: IntegrationsApi.getIntegrationsSpeechTtsEngineVoicesOptions): Promise<Models.TtsVoiceEntityListing>; 
  	getIntegrationsSpeechTtsEngines(opts?: IntegrationsApi.getIntegrationsSpeechTtsEnginesOptions): Promise<Models.TtsEngineEntityListing>; 
  	getIntegrationsSpeechTtsSettings(): Promise<Models.TtsSettings>; 
  	getIntegrationsType(typeId: string): Promise<Models.IntegrationType>; 
  	getIntegrationsTypeConfigschema(typeId: string, configType: string): Promise<Models.JsonSchemaDocument>; 
  	getIntegrationsTypes(opts?: IntegrationsApi.getIntegrationsTypesOptions): Promise<Models.IntegrationTypeEntityListing>; 
  	getIntegrationsUnifiedcommunicationsClientapp(ucIntegrationId: string): Promise<Models.UnifiedCommunicationsIntegration>; 
  	getIntegrationsUnifiedcommunicationsClientapps(opts?: IntegrationsApi.getIntegrationsUnifiedcommunicationsClientappsOptions): Promise<Models.UnifiedCommunicationsIntegrationListing>; 
  	getIntegrationsUserapps(opts?: IntegrationsApi.getIntegrationsUserappsOptions): Promise<Models.UserAppEntityListing>; 
  	patchIntegration(integrationId: string, opts?: IntegrationsApi.patchIntegrationOptions): Promise<Models.Integration>; 
  	patchIntegrationsAction(actionId: string, body: Models.UpdateActionInput): Promise<Models.Action>; 
  	patchIntegrationsActionDraft(actionId: string, body: Models.UpdateDraftInput): Promise<Models.Action>; 
  	postIntegrations(opts?: IntegrationsApi.postIntegrationsOptions): Promise<Models.Integration>; 
  	postIntegrationsActionDraft(actionId: string): Promise<Models.Action>; 
  	postIntegrationsActionDraftFunctionUpload(actionId: string, body: Models.FunctionUploadRequest): Promise<Models.FunctionUploadResponse>; 
  	postIntegrationsActionDraftPublish(actionId: string, body: Models.PublishDraftInput): Promise<Models.Action>; 
  	postIntegrationsActionDraftTest(actionId: string, body: object): Promise<Models.TestExecutionResult>; 
  	postIntegrationsActionExecute(actionId: string, body: object): Promise<object>; 
  	postIntegrationsActionTest(actionId: string, body: object): Promise<Models.TestExecutionResult>; 
  	postIntegrationsActions(body: Models.PostActionInput): Promise<Models.Action>; 
  	postIntegrationsActionsDrafts(body: Models.PostActionInput): Promise<Models.Action>; 
  	postIntegrationsCredentials(opts?: IntegrationsApi.postIntegrationsCredentialsOptions): Promise<Models.CredentialInfo>; 
  	postIntegrationsSpeechNuanceNuanceIntegrationIdBotJobs(nuanceIntegrationId: string, botId: string, opts?: IntegrationsApi.postIntegrationsSpeechNuanceNuanceIntegrationIdBotJobsOptions): Promise<Models.AsyncJob>; 
  	postIntegrationsSpeechNuanceNuanceIntegrationIdBotsJobs(nuanceIntegrationId: string, opts?: IntegrationsApi.postIntegrationsSpeechNuanceNuanceIntegrationIdBotsJobsOptions): Promise<Models.AsyncJob>; 
  	postIntegrationsSpeechNuanceNuanceIntegrationIdBotsLaunchValidate(nuanceIntegrationId: string, settings: Models.BotExecutionConfiguration): Promise<void>; 
  	putIntegrationConfigCurrent(integrationId: string, opts?: IntegrationsApi.putIntegrationConfigCurrentOptions): Promise<Models.IntegrationConfiguration>; 
  	putIntegrationsActionDraftFunction(actionId: string, body: Models.Function): Promise<Models.FunctionConfig>; 
  	putIntegrationsBotconnectorIntegrationIdBots(integrationId: string, botList: Models.BotList): Promise<void>; 
  	putIntegrationsCredential(credentialId: string, opts?: IntegrationsApi.putIntegrationsCredentialOptions): Promise<Models.CredentialInfo>; 
  	putIntegrationsSpeechNuanceNuanceIntegrationIdBotsLaunchSettings(nuanceIntegrationId: string, settings: Models.NuanceBotLaunchSettings): Promise<void>; 
  	putIntegrationsSpeechTtsSettings(body: Models.TtsSettings): Promise<Models.TtsSettings>; 
  	putIntegrationsUnifiedcommunicationThirdpartypresences(ucIntegrationId: string, body: Array<Models.UCThirdPartyPresence>): Promise<string>;
}

declare namespace IntegrationsApi { 
	export interface getIntegrationOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getIntegrationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getIntegrationsActionOptions { 
		"expand"?: string;
		"includeConfig"?: boolean;
	}
	export interface getIntegrationsActionDraftOptions { 
		"expand"?: string;
		"includeConfig"?: boolean;
	}
	export interface getIntegrationsActionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"nextPage"?: string;
		"previousPage"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"category"?: string;
		"name"?: string;
		"ids"?: string;
		"secure"?: string;
		"includeAuthActions"?: string;
	}
	export interface getIntegrationsActionsCategoriesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"nextPage"?: string;
		"previousPage"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"secure"?: string;
	}
	export interface getIntegrationsActionsCertificatesOptions { 
		"status"?: string;
		"type"?: string;
	}
	export interface getIntegrationsActionsDraftsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"nextPage"?: string;
		"previousPage"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"category"?: string;
		"name"?: string;
		"ids"?: string;
		"secure"?: string;
		"includeAuthActions"?: string;
	}
	export interface getIntegrationsBotconnectorIntegrationIdBotOptions { 
		"version"?: string;
	}
	export interface getIntegrationsBotconnectorIntegrationIdBotVersionsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getIntegrationsBotconnectorIntegrationIdBotsSummariesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getIntegrationsClientappsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getIntegrationsClientappsUnifiedcommunicationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getIntegrationsCredentialsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getIntegrationsSpeechDialogflowAgentsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"name"?: string;
	}
	export interface getIntegrationsSpeechDialogflowcxAgentsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"name"?: string;
	}
	export interface getIntegrationsSpeechLexBotBotIdAliasesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"status"?: string;
		"name"?: string;
	}
	export interface getIntegrationsSpeechLexBotsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"name"?: string;
	}
	export interface getIntegrationsSpeechLexv2BotBotIdAliasesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"status"?: string;
		"name"?: string;
	}
	export interface getIntegrationsSpeechLexv2BotsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"name"?: string;
	}
	export interface getIntegrationsSpeechNuanceNuanceIntegrationIdBotOptions { 
		"expand"?: Array<string>;
		"targetChannel"?: string;
	}
	export interface getIntegrationsSpeechNuanceNuanceIntegrationIdBotsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"onlyRegisteredBots"?: boolean;
	}
	export interface getIntegrationsSpeechSttEnginesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"name"?: string;
	}
	export interface getIntegrationsSpeechTtsEngineOptions { 
		"includeVoices"?: boolean;
	}
	export interface getIntegrationsSpeechTtsEngineVoicesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getIntegrationsSpeechTtsEnginesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"includeVoices"?: boolean;
		"name"?: string;
		"language"?: string;
	}
	export interface getIntegrationsTypesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getIntegrationsUnifiedcommunicationsClientappsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
	}
	export interface getIntegrationsUserappsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"appHost"?: string;
	}
	export interface patchIntegrationOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"body"?: Models.Integration;
	}
	export interface postIntegrationsOptions { 
		"body"?: Models.CreateIntegrationRequest;
	}
	export interface postIntegrationsCredentialsOptions { 
		"body"?: Models.Credential;
	}
	export interface postIntegrationsSpeechNuanceNuanceIntegrationIdBotJobsOptions { 
		"expand"?: Array<string>;
		"body"?: string;
	}
	export interface postIntegrationsSpeechNuanceNuanceIntegrationIdBotsJobsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"onlyRegisteredBots"?: boolean;
	}
	export interface putIntegrationConfigCurrentOptions { 
		"body"?: Models.IntegrationConfiguration;
	}
	export interface putIntegrationsCredentialOptions { 
		"body"?: Models.Credential;
	}
}

declare class JourneyApi {  
  	deleteJourneyActionmap(actionMapId: string): Promise<void>; 
  	deleteJourneyActiontemplate(actionTemplateId: string, opts?: JourneyApi.deleteJourneyActiontemplateOptions): Promise<void>; 
  	deleteJourneyOutcome(outcomeId: string): Promise<void>; 
  	deleteJourneyOutcomesPredictor(predictorId: string): Promise<void>; 
  	deleteJourneySegment(segmentId: string): Promise<void>; 
  	deleteJourneyView(viewId: string): Promise<void>; 
  	getAnalyticsJourneysAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsJourneysAggregatesJobResults(jobId: string, opts?: JourneyApi.getAnalyticsJourneysAggregatesJobResultsOptions): Promise<Models.JourneyAsyncAggregateQueryResponse>; 
  	getExternalcontactsContactJourneySessions(contactId: string, opts?: JourneyApi.getExternalcontactsContactJourneySessionsOptions): Promise<Models.SessionListing>; 
  	getJourneyActionmap(actionMapId: string): Promise<Models.ActionMap>; 
  	getJourneyActionmaps(opts?: JourneyApi.getJourneyActionmapsOptions): Promise<Models.ActionMapListing>; 
  	getJourneyActionmapsEstimatesJob(jobId: string): Promise<string>; 
  	getJourneyActionmapsEstimatesJobResults(jobId: string): Promise<Models.ActionMapEstimateResult>; 
  	getJourneyActiontarget(actionTargetId: string): Promise<Models.ActionTarget>; 
  	getJourneyActiontargets(opts?: JourneyApi.getJourneyActiontargetsOptions): Promise<Models.ActionTargetListing>; 
  	getJourneyActiontemplate(actionTemplateId: string): Promise<Models.ActionTemplate>; 
  	getJourneyActiontemplates(opts?: JourneyApi.getJourneyActiontemplatesOptions): Promise<Models.ActionTemplateListing>; 
  	getJourneyDeploymentCustomerPing(deploymentId: string, customerCookieId: string, opts?: JourneyApi.getJourneyDeploymentCustomerPingOptions): Promise<Models.DeploymentPing>; 
  	getJourneyOutcome(outcomeId: string): Promise<Models.Outcome>; 
  	getJourneyOutcomes(opts?: JourneyApi.getJourneyOutcomesOptions): Promise<Models.OutcomeListing>; 
  	getJourneyOutcomesAttributionsJob(jobId: string): Promise<Models.OutcomeAttributionJobStateResponse>; 
  	getJourneyOutcomesAttributionsJobResults(jobId: string): Promise<Models.OutcomeAttributionResponseListing>; 
  	getJourneyOutcomesPredictor(predictorId: string): Promise<Models.OutcomePredictor>; 
  	getJourneyOutcomesPredictors(): Promise<Models.OutcomePredictorListing>; 
  	getJourneySegment(segmentId: string): Promise<Models.JourneySegment>; 
  	getJourneySegments(opts?: JourneyApi.getJourneySegmentsOptions): Promise<Models.SegmentListing>; 
  	getJourneySession(sessionId: string): Promise<Models.Session>; 
  	getJourneySessionEvents(sessionId: string, opts?: JourneyApi.getJourneySessionEventsOptions): Promise<Models.EventListing>; 
  	getJourneySessionOutcomescores(sessionId: string): Promise<Models.OutcomeScoresResult>; 
  	getJourneyView(viewId: string): Promise<Models.JourneyView>; 
  	getJourneyViewVersion(viewId: string, versionId: string): Promise<Models.JourneyView>; 
  	getJourneyViewVersionJob(viewId: string, journeyVersionId: string, jobId: string): Promise<Models.JourneyViewJob>; 
  	getJourneyViewVersionJobResults(viewId: string, journeyViewVersion: string, jobId: string): Promise<Models.JourneyViewResult>; 
  	getJourneyViewVersionJobsLatest(viewId: string, journeyVersionId: string): Promise<Models.JourneyViewJob>; 
  	getJourneyViews(): Promise<Models.AddressableEntityListing>; 
  	getJourneyViewsEventdefinition(eventDefinitionId: string): Promise<Models.JourneyEventDefinition>; 
  	getJourneyViewsEventdefinitions(): Promise<Models.JourneyEventDefinitionListing>; 
  	patchJourneyActionmap(actionMapId: string, opts?: JourneyApi.patchJourneyActionmapOptions): Promise<Models.ActionMap>; 
  	patchJourneyActiontarget(actionTargetId: string, opts?: JourneyApi.patchJourneyActiontargetOptions): Promise<Models.ActionTarget>; 
  	patchJourneyActiontemplate(actionTemplateId: string, opts?: JourneyApi.patchJourneyActiontemplateOptions): Promise<Models.ActionTemplate>; 
  	patchJourneyOutcome(outcomeId: string, opts?: JourneyApi.patchJourneyOutcomeOptions): Promise<Models.Outcome>; 
  	patchJourneySegment(segmentId: string, opts?: JourneyApi.patchJourneySegmentOptions): Promise<Models.JourneySegment>; 
  	postAnalyticsJourneysAggregatesJobs(body: Models.JourneyAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsJourneysAggregatesQuery(body: Models.JourneyAggregationQuery): Promise<Models.JourneyAggregateQueryResponse>; 
  	postJourneyActionmaps(opts?: JourneyApi.postJourneyActionmapsOptions): Promise<Models.ActionMap>; 
  	postJourneyActionmapsEstimatesJobs(body: Models.ActionMapEstimateRequest): Promise<Models.EstimateJobAsyncResponse>; 
  	postJourneyActiontemplates(opts?: JourneyApi.postJourneyActiontemplatesOptions): Promise<Models.ActionTemplate>; 
  	postJourneyDeploymentActionevent(deploymentId: string, body: Models.ActionEventRequest): Promise<void>; 
  	postJourneyDeploymentAppevents(deploymentId: string, opts?: JourneyApi.postJourneyDeploymentAppeventsOptions): Promise<Models.AppEventResponse>; 
  	postJourneyFlowsPathsQuery(opts?: JourneyApi.postJourneyFlowsPathsQueryOptions): Promise<Models.FlowPaths>; 
  	postJourneyOutcomes(opts?: JourneyApi.postJourneyOutcomesOptions): Promise<Models.Outcome>; 
  	postJourneyOutcomesAttributionsJobs(opts?: JourneyApi.postJourneyOutcomesAttributionsJobsOptions): Promise<Models.OutcomeAttributionAsyncResponse>; 
  	postJourneyOutcomesPredictors(opts?: JourneyApi.postJourneyOutcomesPredictorsOptions): Promise<Models.OutcomePredictor>; 
  	postJourneySegments(opts?: JourneyApi.postJourneySegmentsOptions): Promise<Models.JourneySegment>; 
  	postJourneyViewVersionJobs(viewId: string, journeyVersionId: string): Promise<Models.JourneyViewJob>; 
  	postJourneyViewVersions(viewId: string, body: Models.JourneyView): Promise<Models.JourneyView>; 
  	postJourneyViews(body: Models.JourneyView): Promise<Models.JourneyView>; 
  	postJourneyViewsEncodingsValidate(opts?: JourneyApi.postJourneyViewsEncodingsValidateOptions): Promise<Models.EntityListing>;
}

declare namespace JourneyApi { 
	export interface deleteJourneyActiontemplateOptions { 
		"hardDelete"?: boolean;
	}
	export interface getAnalyticsJourneysAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getExternalcontactsContactJourneySessionsOptions { 
		"pageSize"?: string;
		"after"?: string;
		"includeMerged"?: boolean;
	}
	export interface getJourneyActionmapsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"filterField"?: string;
		"filterValue"?: string;
		"actionMapIds"?: Array<string>;
		"queryFields"?: Array<string>;
		"queryValue"?: string;
	}
	export interface getJourneyActiontargetsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getJourneyActiontemplatesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"mediaType"?: string;
		"state"?: string;
		"queryFields"?: Array<string>;
		"queryValue"?: string;
	}
	export interface getJourneyDeploymentCustomerPingOptions { 
		"dl"?: string;
		"dt"?: string;
		"appNamespace"?: string;
		"sessionId"?: string;
		"sinceLastBeaconMilliseconds"?: number;
	}
	export interface getJourneyOutcomesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"outcomeIds"?: Array<string>;
		"queryFields"?: Array<string>;
		"queryValue"?: string;
	}
	export interface getJourneySegmentsOptions { 
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"isActive"?: boolean;
		"segmentIds"?: Array<string>;
		"queryFields"?: Array<string>;
		"queryValue"?: string;
	}
	export interface getJourneySessionEventsOptions { 
		"pageSize"?: string;
		"after"?: string;
	}
	export interface patchJourneyActionmapOptions { 
		"body"?: Models.PatchActionMap;
	}
	export interface patchJourneyActiontargetOptions { 
		"body"?: Models.PatchActionTarget;
	}
	export interface patchJourneyActiontemplateOptions { 
		"body"?: Models.PatchActionTemplate;
	}
	export interface patchJourneyOutcomeOptions { 
		"body"?: Models.PatchOutcome;
	}
	export interface patchJourneySegmentOptions { 
		"body"?: Models.PatchSegment;
	}
	export interface postJourneyActionmapsOptions { 
		"body"?: Models.ActionMap;
	}
	export interface postJourneyActiontemplatesOptions { 
		"body"?: Models.ActionTemplate;
	}
	export interface postJourneyDeploymentAppeventsOptions { 
		"body"?: Models.AppEventRequest;
	}
	export interface postJourneyFlowsPathsQueryOptions { 
		"body"?: Models.FlowPathsQuery;
	}
	export interface postJourneyOutcomesOptions { 
		"body"?: Models.OutcomeRequest;
	}
	export interface postJourneyOutcomesAttributionsJobsOptions { 
		"body"?: Models.OutcomeAttributionListing;
	}
	export interface postJourneyOutcomesPredictorsOptions { 
		"body"?: Models.OutcomePredictorRequest;
	}
	export interface postJourneySegmentsOptions { 
		"body"?: Models.JourneySegmentRequest;
	}
	export interface postJourneyViewsEncodingsValidateOptions { 
		"body"?: Array<Models.Label>;
	}
}

declare class KnowledgeApi {  
  	deleteKnowledgeKnowledgebase(knowledgeBaseId: string): Promise<Models.KnowledgeBase>; 
  	deleteKnowledgeKnowledgebaseCategory(knowledgeBaseId: string, categoryId: string): Promise<Models.CategoryResponse>; 
  	deleteKnowledgeKnowledgebaseDocument(knowledgeBaseId: string, documentId: string): Promise<void>; 
  	deleteKnowledgeKnowledgebaseDocumentVariation(documentVariationId: string, documentId: string, knowledgeBaseId: string): Promise<void>; 
  	deleteKnowledgeKnowledgebaseExportJob(knowledgeBaseId: string, exportJobId: string): Promise<void>; 
  	deleteKnowledgeKnowledgebaseImportJob(knowledgeBaseId: string, importJobId: string): Promise<void>; 
  	deleteKnowledgeKnowledgebaseLabel(knowledgeBaseId: string, labelId: string): Promise<Models.LabelResponse>; 
  	deleteKnowledgeKnowledgebaseLanguageCategory(categoryId: string, knowledgeBaseId: string, languageCode: string): Promise<Models.KnowledgeCategory>; 
  	deleteKnowledgeKnowledgebaseLanguageDocument(documentId: string, knowledgeBaseId: string, languageCode: string): Promise<Models.KnowledgeDocument>; 
  	deleteKnowledgeKnowledgebaseLanguageDocumentsImport(knowledgeBaseId: string, languageCode: string, importId: string): Promise<void>; 
  	getKnowledgeGuestSessionCategories(sessionId: string, opts?: KnowledgeApi.getKnowledgeGuestSessionCategoriesOptions): Promise<Models.GuestCategoryResponseListing>; 
  	getKnowledgeGuestSessionDocument(sessionId: string, documentId: string): Promise<Models.KnowledgeGuestDocumentResponse>; 
  	getKnowledgeGuestSessionDocuments(sessionId: string, opts?: KnowledgeApi.getKnowledgeGuestSessionDocumentsOptions): Promise<Models.KnowledgeGuestDocumentResponseListing>; 
  	getKnowledgeKnowledgebase(knowledgeBaseId: string): Promise<Models.KnowledgeBase>; 
  	getKnowledgeKnowledgebaseCategories(knowledgeBaseId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseCategoriesOptions): Promise<Models.CategoryResponseListing>; 
  	getKnowledgeKnowledgebaseCategory(knowledgeBaseId: string, categoryId: string): Promise<Models.CategoryResponse>; 
  	getKnowledgeKnowledgebaseDocument(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentOptions): Promise<Models.KnowledgeDocumentResponse>; 
  	getKnowledgeKnowledgebaseDocumentFeedback(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentFeedbackOptions): Promise<Models.KnowledgeDocumentFeedbackResponseListing>; 
  	getKnowledgeKnowledgebaseDocumentFeedbackFeedbackId(knowledgeBaseId: string, documentId: string, feedbackId: string): Promise<Models.KnowledgeDocumentFeedbackResponse>; 
  	getKnowledgeKnowledgebaseDocumentVariation(documentVariationId: string, documentId: string, knowledgeBaseId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentVariationOptions): Promise<Models.DocumentVariation>; 
  	getKnowledgeKnowledgebaseDocumentVariations(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentVariationsOptions): Promise<Models.DocumentVariationListing>; 
  	getKnowledgeKnowledgebaseDocumentVersion(knowledgeBaseId: string, documentId: string, versionId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentVersionOptions): Promise<Models.KnowledgeDocumentVersion>; 
  	getKnowledgeKnowledgebaseDocumentVersionVariation(knowledgeBaseId: string, documentId: string, versionId: string, variationId: string): Promise<Models.KnowledgeDocumentVersionVariation>; 
  	getKnowledgeKnowledgebaseDocumentVersionVariations(knowledgeBaseId: string, documentId: string, versionId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentVersionVariationsOptions): Promise<Models.KnowledgeDocumentVersionVariationListing>; 
  	getKnowledgeKnowledgebaseDocumentVersions(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentVersionsOptions): Promise<Models.KnowledgeDocumentVersionListing>; 
  	getKnowledgeKnowledgebaseDocuments(knowledgeBaseId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseDocumentsOptions): Promise<Models.KnowledgeDocumentResponseListing>; 
  	getKnowledgeKnowledgebaseExportJob(knowledgeBaseId: string, exportJobId: string): Promise<Models.KnowledgeExportJobResponse>; 
  	getKnowledgeKnowledgebaseImportJob(knowledgeBaseId: string, importJobId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseImportJobOptions): Promise<Models.KnowledgeImportJobResponse>; 
  	getKnowledgeKnowledgebaseLabel(knowledgeBaseId: string, labelId: string): Promise<Models.LabelResponse>; 
  	getKnowledgeKnowledgebaseLabels(knowledgeBaseId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseLabelsOptions): Promise<Models.LabelListing>; 
  	getKnowledgeKnowledgebaseLanguageCategories(knowledgeBaseId: string, languageCode: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseLanguageCategoriesOptions): Promise<Models.CategoryListing>; 
  	getKnowledgeKnowledgebaseLanguageCategory(categoryId: string, knowledgeBaseId: string, languageCode: string): Promise<Models.KnowledgeExtendedCategory>; 
  	getKnowledgeKnowledgebaseLanguageDocument(documentId: string, knowledgeBaseId: string, languageCode: string): Promise<Models.KnowledgeDocument>; 
  	getKnowledgeKnowledgebaseLanguageDocumentUpload(documentId: string, knowledgeBaseId: string, languageCode: string, uploadId: string): Promise<Models.KnowledgeDocumentContentUpload>; 
  	getKnowledgeKnowledgebaseLanguageDocuments(knowledgeBaseId: string, languageCode: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseLanguageDocumentsOptions): Promise<Models.DocumentListing>; 
  	getKnowledgeKnowledgebaseLanguageDocumentsImport(knowledgeBaseId: string, languageCode: string, importId: string): Promise<Models.KnowledgeImport>; 
  	getKnowledgeKnowledgebaseLanguageTraining(knowledgeBaseId: string, languageCode: string, trainingId: string): Promise<Models.KnowledgeTraining>; 
  	getKnowledgeKnowledgebaseLanguageTrainings(knowledgeBaseId: string, languageCode: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseLanguageTrainingsOptions): Promise<Models.TrainingListing>; 
  	getKnowledgeKnowledgebaseOperations(knowledgeBaseId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseOperationsOptions): Promise<Models.OperationListing>; 
  	getKnowledgeKnowledgebaseOperationsUsersQuery(knowledgeBaseId: string): Promise<Models.OperationCreatorUserResponse>; 
  	getKnowledgeKnowledgebaseParseJob(knowledgeBaseId: string, parseJobId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseParseJobOptions): Promise<Models.KnowledgeParseJobResponse>; 
  	getKnowledgeKnowledgebaseUnansweredGroup(knowledgeBaseId: string, groupId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseUnansweredGroupOptions): Promise<Models.UnansweredGroup>; 
  	getKnowledgeKnowledgebaseUnansweredGroupPhrasegroup(knowledgeBaseId: string, groupId: string, phraseGroupId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseUnansweredGroupPhrasegroupOptions): Promise<Models.UnansweredPhraseGroup>; 
  	getKnowledgeKnowledgebaseUnansweredGroups(knowledgeBaseId: string, opts?: KnowledgeApi.getKnowledgeKnowledgebaseUnansweredGroupsOptions): Promise<Models.UnansweredGroups>; 
  	getKnowledgeKnowledgebaseUploadsUrlsJob(knowledgeBaseId: string, jobId: string): Promise<Models.GetUploadSourceUrlJobStatusResponse>; 
  	getKnowledgeKnowledgebases(opts?: KnowledgeApi.getKnowledgeKnowledgebasesOptions): Promise<Models.KnowledgeBaseListing>; 
  	patchKnowledgeGuestSessionDocumentsSearchSearchId(sessionId: string, searchId: string, body: Models.SearchUpdateRequest): Promise<void>; 
  	patchKnowledgeKnowledgebase(knowledgeBaseId: string, body: Models.KnowledgeBaseUpdateRequest): Promise<Models.KnowledgeBase>; 
  	patchKnowledgeKnowledgebaseCategory(knowledgeBaseId: string, categoryId: string, body: Models.CategoryUpdateRequest): Promise<Models.CategoryResponse>; 
  	patchKnowledgeKnowledgebaseDocument(knowledgeBaseId: string, documentId: string, body: Models.KnowledgeDocumentReq): Promise<Models.KnowledgeDocumentResponse>; 
  	patchKnowledgeKnowledgebaseDocumentVariation(documentVariationId: string, documentId: string, knowledgeBaseId: string, body: Models.DocumentVariation): Promise<Models.DocumentVariation>; 
  	patchKnowledgeKnowledgebaseDocumentsSearchSearchId(knowledgeBaseId: string, searchId: string, opts?: KnowledgeApi.patchKnowledgeKnowledgebaseDocumentsSearchSearchIdOptions): Promise<void>; 
  	patchKnowledgeKnowledgebaseImportJob(knowledgeBaseId: string, importJobId: string, body: Models.ImportStatusRequest): Promise<Models.KnowledgeImportJobResponse>; 
  	patchKnowledgeKnowledgebaseLabel(knowledgeBaseId: string, labelId: string, body: Models.LabelUpdateRequest): Promise<Models.LabelResponse>; 
  	patchKnowledgeKnowledgebaseLanguageCategory(categoryId: string, knowledgeBaseId: string, languageCode: string, body: Models.KnowledgeCategoryRequest): Promise<Models.KnowledgeExtendedCategory>; 
  	patchKnowledgeKnowledgebaseLanguageDocument(documentId: string, knowledgeBaseId: string, languageCode: string, body: Models.KnowledgeDocumentRequest): Promise<Models.KnowledgeDocument>; 
  	patchKnowledgeKnowledgebaseLanguageDocuments(knowledgeBaseId: string, languageCode: string, body: Array<Models.KnowledgeDocumentBulkRequest>): Promise<Models.DocumentListing>; 
  	patchKnowledgeKnowledgebaseLanguageDocumentsImport(knowledgeBaseId: string, languageCode: string, importId: string, body: Models.ImportStatusRequest): Promise<Models.KnowledgeImport>; 
  	patchKnowledgeKnowledgebaseParseJob(knowledgeBaseId: string, parseJobId: string, body: Models.KnowledgeParseJobRequestPatch): Promise<void>; 
  	patchKnowledgeKnowledgebaseUnansweredGroupPhrasegroup(knowledgeBaseId: string, groupId: string, phraseGroupId: string, body: Models.UnansweredPhraseGroupPatchRequestBody): Promise<Models.UnansweredPhraseGroupUpdateResponse>; 
  	postKnowledgeDocumentuploads(body: Models.UploadUrlRequest): Promise<Models.UploadUrlResponse>; 
  	postKnowledgeGuestSessionDocumentCopies(sessionId: string, documentId: string, opts?: KnowledgeApi.postKnowledgeGuestSessionDocumentCopiesOptions): Promise<void>; 
  	postKnowledgeGuestSessionDocumentFeedback(sessionId: string, documentId: string, opts?: KnowledgeApi.postKnowledgeGuestSessionDocumentFeedbackOptions): Promise<Models.KnowledgeGuestDocumentFeedback>; 
  	postKnowledgeGuestSessionDocumentViews(sessionId: string, documentId: string, opts?: KnowledgeApi.postKnowledgeGuestSessionDocumentViewsOptions): Promise<void>; 
  	postKnowledgeGuestSessionDocumentsPresentations(sessionId: string, opts?: KnowledgeApi.postKnowledgeGuestSessionDocumentsPresentationsOptions): Promise<void>; 
  	postKnowledgeGuestSessionDocumentsSearch(sessionId: string, opts?: KnowledgeApi.postKnowledgeGuestSessionDocumentsSearchOptions): Promise<Models.KnowledgeDocumentGuestSearch>; 
  	postKnowledgeGuestSessionDocumentsSearchSuggestions(sessionId: string, opts?: KnowledgeApi.postKnowledgeGuestSessionDocumentsSearchSuggestionsOptions): Promise<Models.KnowledgeGuestDocumentSuggestion>; 
  	postKnowledgeGuestSessions(body: Models.KnowledgeGuestSession): Promise<Models.KnowledgeGuestSession>; 
  	postKnowledgeKnowledgebaseCategories(knowledgeBaseId: string, body: Models.CategoryCreateRequest): Promise<Models.CategoryResponse>; 
  	postKnowledgeKnowledgebaseDocumentCopies(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseDocumentCopiesOptions): Promise<void>; 
  	postKnowledgeKnowledgebaseDocumentFeedback(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseDocumentFeedbackOptions): Promise<Models.KnowledgeDocumentFeedbackResponse>; 
  	postKnowledgeKnowledgebaseDocumentVariations(knowledgeBaseId: string, documentId: string, body: Models.DocumentVariation): Promise<Models.DocumentVariation>; 
  	postKnowledgeKnowledgebaseDocumentVersions(knowledgeBaseId: string, documentId: string, body: Models.KnowledgeDocumentVersion): Promise<Models.KnowledgeDocumentVersion>; 
  	postKnowledgeKnowledgebaseDocumentViews(knowledgeBaseId: string, documentId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseDocumentViewsOptions): Promise<void>; 
  	postKnowledgeKnowledgebaseDocuments(knowledgeBaseId: string, body: Models.KnowledgeDocumentReq): Promise<Models.KnowledgeDocumentResponse>; 
  	postKnowledgeKnowledgebaseDocumentsBulkRemove(knowledgeBaseId: string, body: Models.KnowledgeDocumentBulkRemoveRequest): Promise<Models.BulkResponse>; 
  	postKnowledgeKnowledgebaseDocumentsBulkUpdate(knowledgeBaseId: string, body: Models.KnowledgeDocumentBulkUpdateRequest): Promise<Models.BulkResponse>; 
  	postKnowledgeKnowledgebaseDocumentsPresentations(knowledgeBaseId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseDocumentsPresentationsOptions): Promise<void>; 
  	postKnowledgeKnowledgebaseDocumentsSearch(knowledgeBaseId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseDocumentsSearchOptions): Promise<Models.KnowledgeDocumentSearch>; 
  	postKnowledgeKnowledgebaseDocumentsSearchSuggestions(knowledgeBaseId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseDocumentsSearchSuggestionsOptions): Promise<Models.KnowledgeDocumentSuggestion>; 
  	postKnowledgeKnowledgebaseDocumentsVersionsBulkAdd(knowledgeBaseId: string, body: Models.KnowledgeDocumentBulkVersionAddRequest): Promise<Models.BulkResponse>; 
  	postKnowledgeKnowledgebaseExportJobs(knowledgeBaseId: string, body: Models.KnowledgeExportJobRequest): Promise<Models.KnowledgeExportJobResponse>; 
  	postKnowledgeKnowledgebaseImportJobs(knowledgeBaseId: string, body: Models.KnowledgeImportJobRequest): Promise<Models.KnowledgeImportJobResponse>; 
  	postKnowledgeKnowledgebaseLabels(knowledgeBaseId: string, body: Models.LabelCreateRequest): Promise<Models.LabelResponse>; 
  	postKnowledgeKnowledgebaseLanguageCategories(knowledgeBaseId: string, languageCode: string, body: Models.KnowledgeCategoryRequest): Promise<Models.KnowledgeExtendedCategory>; 
  	postKnowledgeKnowledgebaseLanguageDocumentUploads(documentId: string, knowledgeBaseId: string, languageCode: string, body: Models.KnowledgeDocumentContentUpload): Promise<Models.KnowledgeDocumentContentUpload>; 
  	postKnowledgeKnowledgebaseLanguageDocuments(knowledgeBaseId: string, languageCode: string, body: Models.KnowledgeDocumentRequest): Promise<Models.KnowledgeDocument>; 
  	postKnowledgeKnowledgebaseLanguageDocumentsImports(knowledgeBaseId: string, languageCode: string, body: Models.KnowledgeImport): Promise<Models.KnowledgeImport>; 
  	postKnowledgeKnowledgebaseLanguageTrainingPromote(knowledgeBaseId: string, languageCode: string, trainingId: string): Promise<Models.KnowledgeTraining>; 
  	postKnowledgeKnowledgebaseLanguageTrainings(knowledgeBaseId: string, languageCode: string): Promise<Models.KnowledgeTraining>; 
  	postKnowledgeKnowledgebaseParseJobImport(knowledgeBaseId: string, parseJobId: string, body: Models.KnowledgeParseJobRequestImport): Promise<void>; 
  	postKnowledgeKnowledgebaseParseJobs(knowledgeBaseId: string, body: Models.KnowledgeParseJobRequest): Promise<Models.KnowledgeParseJobResponse>; 
  	postKnowledgeKnowledgebaseSearch(knowledgeBaseId: string, opts?: KnowledgeApi.postKnowledgeKnowledgebaseSearchOptions): Promise<Models.KnowledgeSearchResponse>; 
  	postKnowledgeKnowledgebaseUploadsUrlsJobs(knowledgeBaseId: string, body: Models.CreateUploadSourceUrlJobRequest): Promise<Models.CreateUploadSourceUrlJobResponse>; 
  	postKnowledgeKnowledgebases(body: Models.KnowledgeBaseCreateRequest): Promise<Models.KnowledgeBase>;
}

declare namespace KnowledgeApi { 
	export interface getKnowledgeGuestSessionCategoriesOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"parentId"?: string;
		"isRoot"?: boolean;
		"name"?: string;
		"sortBy"?: string;
		"expand"?: string;
		"includeDocumentCount"?: boolean;
	}
	export interface getKnowledgeGuestSessionDocumentsOptions { 
		"categoryId"?: Array<string>;
		"pageSize"?: number;
	}
	export interface getKnowledgeKnowledgebaseCategoriesOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"parentId"?: string;
		"isRoot"?: boolean;
		"name"?: string;
		"sortBy"?: string;
		"expand"?: string;
		"includeDocumentCount"?: boolean;
	}
	export interface getKnowledgeKnowledgebaseDocumentOptions { 
		"expand"?: Array<string>;
		"state"?: string;
	}
	export interface getKnowledgeKnowledgebaseDocumentFeedbackOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"onlyCommented"?: boolean;
		"documentVersionId"?: string;
		"documentVariationId"?: string;
		"appType"?: string;
		"queryType"?: string;
		"userId"?: string;
		"queueId"?: string;
		"state"?: string;
	}
	export interface getKnowledgeKnowledgebaseDocumentVariationOptions { 
		"documentState"?: string;
	}
	export interface getKnowledgeKnowledgebaseDocumentVariationsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"documentState"?: string;
	}
	export interface getKnowledgeKnowledgebaseDocumentVersionOptions { 
		"expand"?: Array<string>;
	}
	export interface getKnowledgeKnowledgebaseDocumentVersionVariationsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
	}
	export interface getKnowledgeKnowledgebaseDocumentVersionsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"expand"?: Array<string>;
	}
	export interface getKnowledgeKnowledgebaseDocumentsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"interval"?: string;
		"documentId"?: Array<string>;
		"categoryId"?: Array<string>;
		"includeSubcategories"?: boolean;
		"includeDrafts"?: boolean;
		"labelIds"?: Array<string>;
		"expand"?: Array<string>;
		"externalIds"?: Array<string>;
	}
	export interface getKnowledgeKnowledgebaseImportJobOptions { 
		"expand"?: Array<string>;
	}
	export interface getKnowledgeKnowledgebaseLabelsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"name"?: string;
		"includeDocumentCount"?: boolean;
	}
	export interface getKnowledgeKnowledgebaseLanguageCategoriesOptions { 
		"before"?: string;
		"after"?: string;
		"limit"?: string;
		"pageSize"?: string;
		"name"?: string;
	}
	export interface getKnowledgeKnowledgebaseLanguageDocumentsOptions { 
		"before"?: string;
		"after"?: string;
		"limit"?: string;
		"pageSize"?: string;
		"categories"?: string;
		"title"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"documentIds"?: Array<string>;
	}
	export interface getKnowledgeKnowledgebaseLanguageTrainingsOptions { 
		"before"?: string;
		"after"?: string;
		"limit"?: string;
		"pageSize"?: string;
		"knowledgeDocumentsState"?: string;
	}
	export interface getKnowledgeKnowledgebaseOperationsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"userId"?: Array<string>;
		"type"?: Array<string>;
		"status"?: Array<string>;
		"interval"?: string;
	}
	export interface getKnowledgeKnowledgebaseParseJobOptions { 
		"expand"?: Array<string>;
	}
	export interface getKnowledgeKnowledgebaseUnansweredGroupOptions { 
		"app"?: string;
		"dateStart"?: string;
		"dateEnd"?: string;
	}
	export interface getKnowledgeKnowledgebaseUnansweredGroupPhrasegroupOptions { 
		"app"?: string;
		"dateStart"?: string;
		"dateEnd"?: string;
	}
	export interface getKnowledgeKnowledgebaseUnansweredGroupsOptions { 
		"app"?: string;
		"dateStart"?: string;
		"dateEnd"?: string;
	}
	export interface getKnowledgeKnowledgebasesOptions { 
		"before"?: string;
		"after"?: string;
		"limit"?: string;
		"pageSize"?: string;
		"name"?: string;
		"coreLanguage"?: string;
		"published"?: boolean;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface patchKnowledgeKnowledgebaseDocumentsSearchSearchIdOptions { 
		"body"?: Models.SearchUpdateRequest;
	}
	export interface postKnowledgeGuestSessionDocumentCopiesOptions { 
		"body"?: Models.KnowledgeGuestDocumentCopy;
	}
	export interface postKnowledgeGuestSessionDocumentFeedbackOptions { 
		"body"?: Models.KnowledgeGuestDocumentFeedback;
	}
	export interface postKnowledgeGuestSessionDocumentViewsOptions { 
		"body"?: Models.KnowledgeGuestDocumentView;
	}
	export interface postKnowledgeGuestSessionDocumentsPresentationsOptions { 
		"body"?: Models.KnowledgeGuestDocumentPresentation;
	}
	export interface postKnowledgeGuestSessionDocumentsSearchOptions { 
		"expand"?: Array<string>;
		"body"?: Models.KnowledgeDocumentGuestSearchRequest;
	}
	export interface postKnowledgeGuestSessionDocumentsSearchSuggestionsOptions { 
		"body"?: Models.KnowledgeGuestDocumentSuggestionRequest;
	}
	export interface postKnowledgeKnowledgebaseDocumentCopiesOptions { 
		"body"?: Models.KnowledgeDocumentCopy;
	}
	export interface postKnowledgeKnowledgebaseDocumentFeedbackOptions { 
		"body"?: Models.KnowledgeDocumentFeedback;
	}
	export interface postKnowledgeKnowledgebaseDocumentViewsOptions { 
		"body"?: Models.KnowledgeDocumentView;
	}
	export interface postKnowledgeKnowledgebaseDocumentsPresentationsOptions { 
		"body"?: Models.KnowledgeDocumentPresentation;
	}
	export interface postKnowledgeKnowledgebaseDocumentsSearchOptions { 
		"expand"?: Array<string>;
		"body"?: Models.KnowledgeDocumentSearchRequest;
	}
	export interface postKnowledgeKnowledgebaseDocumentsSearchSuggestionsOptions { 
		"body"?: Models.KnowledgeDocumentSuggestionRequest;
	}
	export interface postKnowledgeKnowledgebaseSearchOptions { 
		"body"?: Models.KnowledgeSearchRequest;
	}
}

declare class LanguageUnderstandingApi {  
  	deleteLanguageunderstandingDomain(domainId: string): Promise<void>; 
  	deleteLanguageunderstandingDomainFeedbackFeedbackId(domainId: string, feedbackId: string): Promise<void>; 
  	deleteLanguageunderstandingDomainVersion(domainId: string, domainVersionId: string): Promise<void>; 
  	deleteLanguageunderstandingMiner(minerId: string): Promise<void>; 
  	deleteLanguageunderstandingMinerDraft(minerId: string, draftId: string): Promise<void>; 
  	getLanguageunderstandingDomain(domainId: string): Promise<Models.NluDomain>; 
  	getLanguageunderstandingDomainFeedback(domainId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingDomainFeedbackOptions): Promise<Models.NluFeedbackListing>; 
  	getLanguageunderstandingDomainFeedbackFeedbackId(domainId: string, feedbackId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingDomainFeedbackFeedbackIdOptions): Promise<Models.NluFeedbackResponse>; 
  	getLanguageunderstandingDomainVersion(domainId: string, domainVersionId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingDomainVersionOptions): Promise<Models.NluDomainVersion>; 
  	getLanguageunderstandingDomainVersionReport(domainId: string, domainVersionId: string): Promise<Models.NluDomainVersionQualityReport>; 
  	getLanguageunderstandingDomainVersions(domainId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingDomainVersionsOptions): Promise<Models.NluDomainVersionListing>; 
  	getLanguageunderstandingDomains(opts?: LanguageUnderstandingApi.getLanguageunderstandingDomainsOptions): Promise<Models.NluDomainListing>; 
  	getLanguageunderstandingMiner(minerId: string): Promise<Models.Miner>; 
  	getLanguageunderstandingMinerDraft(minerId: string, draftId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingMinerDraftOptions): Promise<Models.Draft>; 
  	getLanguageunderstandingMinerDrafts(minerId: string): Promise<Models.DraftListing>; 
  	getLanguageunderstandingMinerIntent(minerId: string, intentId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingMinerIntentOptions): Promise<Models.MinerIntent>; 
  	getLanguageunderstandingMinerIntents(minerId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingMinerIntentsOptions): Promise<Models.MinedIntentsListing>; 
  	getLanguageunderstandingMinerTopic(minerId: string, topicId: string, opts?: LanguageUnderstandingApi.getLanguageunderstandingMinerTopicOptions): Promise<Models.MinerTopic>; 
  	getLanguageunderstandingMinerTopicPhrase(minerId: string, topicId: string, phraseId: string): Promise<Models.MinerTopicPhrase>; 
  	getLanguageunderstandingMinerTopics(minerId: string): Promise<Models.MinerTopicsListing>; 
  	getLanguageunderstandingMiners(opts?: LanguageUnderstandingApi.getLanguageunderstandingMinersOptions): Promise<Models.MinerListing>; 
  	getLanguageunderstandingSettings(): Promise<Models.NluOrganization>; 
  	patchLanguageunderstandingDomain(domainId: string, body: Models.NluDomain): Promise<Models.NluDomain>; 
  	patchLanguageunderstandingMinerDraft(minerId: string, draftId: string, opts?: LanguageUnderstandingApi.patchLanguageunderstandingMinerDraftOptions): Promise<Models.Draft>; 
  	postLanguageunderstandingDomainFeedback(domainId: string, body: Models.NluFeedbackRequest): Promise<Models.NluFeedbackResponse>; 
  	postLanguageunderstandingDomainVersionDetect(domainId: string, domainVersionId: string, body: Models.NluDetectionRequest): Promise<Models.NluDetectionResponse>; 
  	postLanguageunderstandingDomainVersionPublish(domainId: string, domainVersionId: string): Promise<Models.NluDomainVersion>; 
  	postLanguageunderstandingDomainVersionTrain(domainId: string, domainVersionId: string): Promise<Models.NluDomainVersionTrainingResponse>; 
  	postLanguageunderstandingDomainVersions(domainId: string, body: Models.NluDomainVersion, opts?: LanguageUnderstandingApi.postLanguageunderstandingDomainVersionsOptions): Promise<Models.NluDomainVersion>; 
  	postLanguageunderstandingDomains(body: Models.NluDomain): Promise<Models.NluDomain>; 
  	postLanguageunderstandingMinerDrafts(minerId: string, body: Models.Draft): Promise<Models.Draft>; 
  	postLanguageunderstandingMinerExecute(minerId: string, opts?: LanguageUnderstandingApi.postLanguageunderstandingMinerExecuteOptions): Promise<Models.Miner>; 
  	postLanguageunderstandingMiners(body: Models.Miner): Promise<Models.Miner>; 
  	putLanguageunderstandingDomainVersion(domainId: string, domainVersionId: string, body: Models.NluDomainVersion): Promise<Models.NluDomainVersion>;
}

declare namespace LanguageUnderstandingApi { 
	export interface getLanguageunderstandingDomainFeedbackOptions { 
		"intentName"?: string;
		"assessment"?: string;
		"dateStart"?: string;
		"dateEnd"?: string;
		"includeDeleted"?: boolean;
		"language"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"enableCursorPagination"?: boolean;
		"includeTrainingUtterances"?: boolean;
		"after"?: string;
		"fields"?: Array<string>;
	}
	export interface getLanguageunderstandingDomainFeedbackFeedbackIdOptions { 
		"fields"?: Array<string>;
	}
	export interface getLanguageunderstandingDomainVersionOptions { 
		"includeUtterances"?: boolean;
	}
	export interface getLanguageunderstandingDomainVersionsOptions { 
		"includeUtterances"?: boolean;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getLanguageunderstandingDomainsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getLanguageunderstandingMinerDraftOptions { 
		"draftIntentId"?: string;
		"draftTopicId"?: string;
	}
	export interface getLanguageunderstandingMinerIntentOptions { 
		"expand"?: string;
	}
	export interface getLanguageunderstandingMinerIntentsOptions { 
		"expand"?: string;
	}
	export interface getLanguageunderstandingMinerTopicOptions { 
		"expand"?: string;
	}
	export interface getLanguageunderstandingMinersOptions { 
		"minerType"?: string;
	}
	export interface patchLanguageunderstandingMinerDraftOptions { 
		"body"?: Models.DraftRequest;
	}
	export interface postLanguageunderstandingDomainVersionsOptions { 
		"includeUtterances"?: boolean;
	}
	export interface postLanguageunderstandingMinerExecuteOptions { 
		"body"?: Models.MinerExecuteRequest;
	}
}

declare class LanguagesApi {  
  	deleteLanguage(languageId: string): Promise<void>; 
  	getLanguage(languageId: string): Promise<Models.Language>; 
  	getLanguages(opts?: LanguagesApi.getLanguagesOptions): Promise<Models.LanguageEntityListing>; 
  	getLanguagesTranslations(): Promise<Models.AvailableTranslations>; 
  	getLanguagesTranslationsBuiltin(language: string): Promise<{ [key: string]: object; }>; 
  	getLanguagesTranslationsOrganization(language: string): Promise<{ [key: string]: object; }>; 
  	getLanguagesTranslationsUser(userId: string): Promise<{ [key: string]: object; }>; 
  	postLanguages(body: Models.Language): Promise<Models.Language>;
}

declare namespace LanguagesApi { 
	export interface getLanguagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"name"?: string;
	}
}

declare class LearningApi {  
  	deleteLearningAssignment(assignmentId: string): Promise<void>; 
  	deleteLearningModule(moduleId: string): Promise<void>; 
  	getLearningAssignment(assignmentId: string, opts?: LearningApi.getLearningAssignmentOptions): Promise<Models.LearningAssignment>; 
  	getLearningAssignments(opts?: LearningApi.getLearningAssignmentsOptions): Promise<Models.LearningAssignmentsDomainEntity>; 
  	getLearningAssignmentsMe(opts?: LearningApi.getLearningAssignmentsMeOptions): Promise<Models.LearningAssignmentsDomainEntity>; 
  	getLearningModule(moduleId: string, opts?: LearningApi.getLearningModuleOptions): Promise<Models.LearningModule>; 
  	getLearningModuleJob(moduleId: string, jobId: string): Promise<Models.LearningModuleJobResponse>; 
  	getLearningModuleRule(moduleId: string): Promise<Models.LearningModuleRule>; 
  	getLearningModuleVersion(moduleId: string, versionId: string, opts?: LearningApi.getLearningModuleVersionOptions): Promise<Models.LearningModule>; 
  	getLearningModules(opts?: LearningApi.getLearningModulesOptions): Promise<Models.LearningModulesDomainEntityListing>; 
  	getLearningModulesAssignments(userIds: Array<string>, opts?: LearningApi.getLearningModulesAssignmentsOptions): Promise<Models.AssignedLearningModuleDomainEntityListing>; 
  	getLearningModulesCoverartCoverArtId(coverArtId: string): Promise<Models.LearningModuleCoverArtResponse>; 
  	patchLearningAssignment(assignmentId: string, opts?: LearningApi.patchLearningAssignmentOptions): Promise<Models.LearningAssignment>; 
  	patchLearningAssignmentReschedule(assignmentId: string, opts?: LearningApi.patchLearningAssignmentRescheduleOptions): Promise<Models.LearningAssignment>; 
  	patchLearningModuleUserAssignments(moduleId: string, userId: string, body: Models.LearningAssignmentExternalUpdate): Promise<Models.LearningAssignment>; 
  	postLearningAssessmentsScoring(body: Models.LearningAssessmentScoringRequest): Promise<Models.AssessmentScoringSet>; 
  	postLearningAssignmentReassign(assignmentId: string): Promise<Models.LearningAssignment>; 
  	postLearningAssignmentReset(assignmentId: string): Promise<Models.LearningAssignment>; 
  	postLearningAssignments(opts?: LearningApi.postLearningAssignmentsOptions): Promise<Models.LearningAssignment>; 
  	postLearningAssignmentsAggregatesQuery(body: Models.LearningAssignmentAggregateParam): Promise<Models.LearningAssignmentAggregateResponse>; 
  	postLearningAssignmentsBulkadd(opts?: LearningApi.postLearningAssignmentsBulkaddOptions): Promise<Models.LearningAssignmentBulkAddResponse>; 
  	postLearningAssignmentsBulkremove(opts?: LearningApi.postLearningAssignmentsBulkremoveOptions): Promise<Models.LearningAssignmentBulkRemoveResponse>; 
  	postLearningModuleJobs(moduleId: string, body: Models.LearningModuleJobRequest): Promise<Models.LearningModuleJobResponse>; 
  	postLearningModulePublish(moduleId: string, opts?: LearningApi.postLearningModulePublishOptions): Promise<Models.LearningModulePublishResponse>; 
  	postLearningModules(body: Models.LearningModuleRequest): Promise<Models.LearningModule>; 
  	postLearningRulesQuery(pageSize: number, pageNumber: number, body: Models.LearningAssignmentUserQuery): Promise<Models.LearningAssignmentUserListing>; 
  	postLearningScheduleslotsQuery(body: Models.LearningScheduleSlotsQueryRequest): Promise<Models.LearningScheduleSlotsQueryResponse>; 
  	putLearningModule(moduleId: string, body: Models.LearningModuleRequest): Promise<Models.LearningModule>; 
  	putLearningModuleRule(moduleId: string, body: Models.LearningModuleRule): Promise<Models.LearningModuleRule>;
}

declare namespace LearningApi { 
	export interface getLearningAssignmentOptions { 
		"expand"?: Array<string>;
	}
	export interface getLearningAssignmentsOptions { 
		"moduleId"?: string;
		"interval"?: string;
		"completionInterval"?: string;
		"overdue"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"pass"?: string;
		"minPercentageScore"?: number;
		"maxPercentageScore"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"userId"?: Array<string>;
		"types"?: Array<string>;
		"states"?: Array<string>;
		"expand"?: Array<string>;
	}
	export interface getLearningAssignmentsMeOptions { 
		"moduleId"?: string;
		"interval"?: string;
		"completionInterval"?: string;
		"overdue"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"pass"?: string;
		"minPercentageScore"?: number;
		"maxPercentageScore"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"types"?: Array<string>;
		"states"?: Array<string>;
		"expand"?: Array<string>;
	}
	export interface getLearningModuleOptions { 
		"expand"?: Array<string>;
	}
	export interface getLearningModuleVersionOptions { 
		"expand"?: Array<string>;
	}
	export interface getLearningModulesOptions { 
		"isArchived"?: boolean;
		"types"?: Array<string>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"searchTerm"?: string;
		"expand"?: Array<string>;
		"isPublished"?: string;
		"statuses"?: Array<string>;
		"externalIds"?: Array<string>;
	}
	export interface getLearningModulesAssignmentsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"searchTerm"?: string;
		"overdue"?: string;
		"assignmentStates"?: Array<string>;
		"expand"?: Array<string>;
	}
	export interface patchLearningAssignmentOptions { 
		"body"?: Models.LearningAssignmentUpdate;
	}
	export interface patchLearningAssignmentRescheduleOptions { 
		"body"?: Models.LearningAssignmentReschedule;
	}
	export interface postLearningAssignmentsOptions { 
		"body"?: Models.LearningAssignmentCreate;
	}
	export interface postLearningAssignmentsBulkaddOptions { 
		"body"?: Array<Models.LearningAssignmentItem>;
	}
	export interface postLearningAssignmentsBulkremoveOptions { 
		"body"?: Array<string>;
	}
	export interface postLearningModulePublishOptions { 
		"body"?: Models.LearningModulePublishRequest;
	}
}

declare class LicenseApi {  
  	getLicenseDefinition(licenseId: string): Promise<Models.LicenseDefinition>; 
  	getLicenseDefinitions(): Promise<Array<Models.LicenseDefinition>>; 
  	getLicenseToggle(featureName: string): Promise<Models.LicenseOrgToggle>; 
  	getLicenseUser(userId: string): Promise<Models.LicenseUser>; 
  	getLicenseUsers(opts?: LicenseApi.getLicenseUsersOptions): Promise<Models.UserLicensesEntityListing>; 
  	postLicenseInfer(opts?: LicenseApi.postLicenseInferOptions): Promise<Array<string>>; 
  	postLicenseOrganization(opts?: LicenseApi.postLicenseOrganizationOptions): Promise<Array<Models.LicenseUpdateStatus>>; 
  	postLicenseToggle(featureName: string): Promise<Models.LicenseOrgToggle>; 
  	postLicenseUsers(opts?: LicenseApi.postLicenseUsersOptions): Promise<{ [key: string]: object; }>;
}

declare namespace LicenseApi { 
	export interface getLicenseUsersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postLicenseInferOptions { 
		"body"?: Array<string>;
	}
	export interface postLicenseOrganizationOptions { 
		"body"?: Models.LicenseBatchAssignmentRequest;
	}
	export interface postLicenseUsersOptions { 
		"body"?: Array<string>;
	}
}

declare class LocationsApi {  
  	deleteLocation(locationId: string): Promise<void>; 
  	getLocation(locationId: string, opts?: LocationsApi.getLocationOptions): Promise<Models.LocationDefinition>; 
  	getLocationSublocations(locationId: string): Promise<Models.LocationEntityListing>; 
  	getLocations(opts?: LocationsApi.getLocationsOptions): Promise<Models.LocationEntityListing>; 
  	getLocationsSearch(q64: string, opts?: LocationsApi.getLocationsSearchOptions): Promise<Models.LocationsSearchResponse>; 
  	patchLocation(locationId: string, body: Models.LocationUpdateDefinition): Promise<Models.LocationDefinition>; 
  	postLocations(body: Models.LocationCreateDefinition): Promise<Models.LocationDefinition>; 
  	postLocationsSearch(body: Models.LocationSearchRequest): Promise<Models.LocationsSearchResponse>;
}

declare namespace LocationsApi { 
	export interface getLocationOptions { 
		"expand"?: Array<string>;
	}
	export interface getLocationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"sortOrder"?: string;
	}
	export interface getLocationsSearchOptions { 
		"expand"?: Array<string>;
	}
}

declare class LogCaptureApi {  
  	deleteDiagnosticsLogcaptureBrowserUser(userId: string): Promise<void>; 
  	getDiagnosticsLogcaptureBrowserEntriesDownloadJob(jobId: string): Promise<Models.LogCaptureDownloadExecutionResponse>; 
  	getDiagnosticsLogcaptureBrowserUser(userId: string): Promise<Models.LogCaptureUserConfiguration>; 
  	getDiagnosticsLogcaptureBrowserUsers(opts?: LogCaptureApi.getDiagnosticsLogcaptureBrowserUsersOptions): Promise<Models.PagelessEntityListing>; 
  	postDiagnosticsLogcaptureBrowserEntriesDownloadJobs(opts?: LogCaptureApi.postDiagnosticsLogcaptureBrowserEntriesDownloadJobsOptions): Promise<Models.LogCaptureDownloadExecutionResponse>; 
  	postDiagnosticsLogcaptureBrowserEntriesQuery(opts?: LogCaptureApi.postDiagnosticsLogcaptureBrowserEntriesQueryOptions): Promise<Models.LogCaptureQueryResponse>; 
  	postDiagnosticsLogcaptureBrowserUser(userId: string, opts?: LogCaptureApi.postDiagnosticsLogcaptureBrowserUserOptions): Promise<Models.LogCaptureUserConfiguration>;
}

declare namespace LogCaptureApi { 
	export interface getDiagnosticsLogcaptureBrowserUsersOptions { 
		"includeExpired"?: boolean;
	}
	export interface postDiagnosticsLogcaptureBrowserEntriesDownloadJobsOptions { 
		"body"?: Models.LogCaptureQueryRequest;
	}
	export interface postDiagnosticsLogcaptureBrowserEntriesQueryOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"body"?: Models.LogCaptureQueryRequest;
	}
	export interface postDiagnosticsLogcaptureBrowserUserOptions { 
		"body"?: Models.LogCaptureUserConfiguration;
	}
}

declare class MessagingApi {  
  	deleteMessagingSetting(messageSettingId: string): Promise<void>; 
  	deleteMessagingSettingsDefault(): Promise<void>; 
  	deleteMessagingSupportedcontentSupportedContentId(supportedContentId: string): Promise<void>; 
  	getMessagingSetting(messageSettingId: string): Promise<Models.MessagingSetting>; 
  	getMessagingSettings(opts?: MessagingApi.getMessagingSettingsOptions): Promise<Models.MessagingConfigListing>; 
  	getMessagingSettingsDefault(): Promise<Models.MessagingSetting>; 
  	getMessagingSupportedcontent(opts?: MessagingApi.getMessagingSupportedcontentOptions): Promise<Models.SupportedContentListing>; 
  	getMessagingSupportedcontentSupportedContentId(supportedContentId: string): Promise<Models.SupportedContent>; 
  	patchMessagingSetting(messageSettingId: string, body: Models.MessagingSettingRequest): Promise<Models.MessagingSetting>; 
  	patchMessagingSupportedcontentSupportedContentId(supportedContentId: string, body: Models.SupportedContent): Promise<Models.SupportedContent>; 
  	postMessagingSettings(body: Models.MessagingSettingRequest): Promise<Models.MessagingSetting>; 
  	postMessagingSupportedcontent(body: Models.SupportedContent): Promise<Models.SupportedContent>; 
  	putMessagingSettingsDefault(body: Models.MessagingSettingDefaultRequest): Promise<Models.MessagingSetting>;
}

declare namespace MessagingApi { 
	export interface getMessagingSettingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getMessagingSupportedcontentOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class MobileDevicesApi {  
  	deleteMobiledevice(deviceId: string): Promise<void>; 
  	getMobiledevice(deviceId: string): Promise<Models.UserDevice>; 
  	getMobiledevices(opts?: MobileDevicesApi.getMobiledevicesOptions): Promise<Models.DirectoryUserDevicesListing>; 
  	postMobiledevices(body: Models.UserDevice): Promise<Models.UserDevice>; 
  	putMobiledevice(deviceId: string, opts?: MobileDevicesApi.putMobiledeviceOptions): Promise<Models.UserDevice>;
}

declare namespace MobileDevicesApi { 
	export interface getMobiledevicesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface putMobiledeviceOptions { 
		"body"?: Models.UserDevice;
	}
}

declare class NotificationsApi {  
  	deleteNotificationsChannelSubscriptions(channelId: string): Promise<void>; 
  	getNotificationsAvailabletopics(opts?: NotificationsApi.getNotificationsAvailabletopicsOptions): Promise<Models.AvailableTopicEntityListing>; 
  	getNotificationsChannelSubscriptions(channelId: string): Promise<Models.ChannelTopicEntityListing>; 
  	getNotificationsChannels(opts?: NotificationsApi.getNotificationsChannelsOptions): Promise<Models.ChannelEntityListing>; 
  	headNotificationsChannel(channelId: string): Promise<void>; 
  	postNotificationsChannelSubscriptions(channelId: string, body: Array<Models.ChannelTopic>, opts?: NotificationsApi.postNotificationsChannelSubscriptionsOptions): Promise<Models.ChannelTopicEntityListing>; 
  	postNotificationsChannels(): Promise<Models.Channel>; 
  	putNotificationsChannelSubscriptions(channelId: string, body: Array<Models.ChannelTopic>, opts?: NotificationsApi.putNotificationsChannelSubscriptionsOptions): Promise<Models.ChannelTopicEntityListing>;
}

declare namespace NotificationsApi { 
	export interface getNotificationsAvailabletopicsOptions { 
		"expand"?: Array<string>;
		"includePreview"?: boolean;
	}
	export interface getNotificationsChannelsOptions { 
		"includechannels"?: string;
	}
	export interface postNotificationsChannelSubscriptionsOptions { 
		"ignoreErrors"?: boolean;
	}
	export interface putNotificationsChannelSubscriptionsOptions { 
		"ignoreErrors"?: boolean;
	}
}

declare class OAuthApi {  
  	deleteOauthClient(clientId: string): Promise<void>; 
  	getOauthAuthorization(clientId: string, opts?: OAuthApi.getOauthAuthorizationOptions): Promise<Models.OAuthAuthorization>; 
  	getOauthAuthorizations(opts?: OAuthApi.getOauthAuthorizationsOptions): Promise<Models.OAuthAuthorizationListing>; 
  	getOauthClient(clientId: string): Promise<Models.OAuthClient>; 
  	getOauthClientUsageQueryResult(executionId: string, clientId: string): Promise<Models.ApiUsageQueryResult>; 
  	getOauthClientUsageSummary(clientId: string, opts?: OAuthApi.getOauthClientUsageSummaryOptions): Promise<Models.UsageExecutionResult>; 
  	getOauthClients(): Promise<Models.OAuthClientEntityListing>; 
  	getOauthScope(scopeId: string, opts?: OAuthApi.getOauthScopeOptions): Promise<Models.OAuthScope>; 
  	getOauthScopes(opts?: OAuthApi.getOauthScopesOptions): Promise<Models.OAuthScopeListing>; 
  	postOauthClientSecret(clientId: string): Promise<Models.OAuthClient>; 
  	postOauthClientUsageQuery(clientId: string, body: Models.ApiUsageClientQuery): Promise<Models.UsageExecutionResult>; 
  	postOauthClients(body: Models.OAuthClientRequest): Promise<Models.OAuthClient>; 
  	putOauthClient(clientId: string, body: Models.OAuthClientRequest): Promise<Models.OAuthClient>;
}

declare namespace OAuthApi { 
	export interface getOauthAuthorizationOptions { 
		"acceptLanguage"?: string;
	}
	export interface getOauthAuthorizationsOptions { 
		"acceptLanguage"?: string;
	}
	export interface getOauthClientUsageSummaryOptions { 
		"days"?: string;
	}
	export interface getOauthScopeOptions { 
		"acceptLanguage"?: string;
	}
	export interface getOauthScopesOptions { 
		"acceptLanguage"?: string;
	}
}

declare class ObjectsApi {  
  	deleteAuthorizationDivision(divisionId: string, opts?: ObjectsApi.deleteAuthorizationDivisionOptions): Promise<void>; 
  	getAuthorizationDivision(divisionId: string, opts?: ObjectsApi.getAuthorizationDivisionOptions): Promise<Models.AuthzDivision>; 
  	getAuthorizationDivisions(opts?: ObjectsApi.getAuthorizationDivisionsOptions): Promise<Models.AuthzDivisionEntityListing>; 
  	getAuthorizationDivisionsHome(): Promise<Models.AuthzDivision>; 
  	getAuthorizationDivisionsLimit(): Promise<number>; 
  	postAuthorizationDivisionObject(divisionId: string, objectType: string, body: Array<string>): Promise<void>; 
  	postAuthorizationDivisionRestore(divisionId: string, opts?: ObjectsApi.postAuthorizationDivisionRestoreOptions): Promise<Models.AuthzDivision>; 
  	postAuthorizationDivisions(body: Models.AuthzDivision): Promise<Models.AuthzDivision>; 
  	putAuthorizationDivision(divisionId: string, body: Models.AuthzDivision): Promise<Models.AuthzDivision>;
}

declare namespace ObjectsApi { 
	export interface deleteAuthorizationDivisionOptions { 
		"force"?: boolean;
	}
	export interface getAuthorizationDivisionOptions { 
		"objectCount"?: boolean;
	}
	export interface getAuthorizationDivisionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"objectCount"?: boolean;
		"id"?: Array<string>;
		"name"?: string;
	}
	export interface postAuthorizationDivisionRestoreOptions { 
		"body"?: Models.AuthzDivision;
	}
}

declare class OperationalEventsApi {  
  	getUsageEventsDefinition(eventDefinitionId: string): Promise<Models.EventDefinition>; 
  	getUsageEventsDefinitions(): Promise<Models.EventDefinitionListing>;
}

declare namespace OperationalEventsApi { 
}

declare class OrganizationApi {  
  	getFieldconfig(type: string): Promise<Models.FieldConfig>; 
  	getOrganizationsAuthenticationSettings(): Promise<Models.OrgAuthSettings>; 
  	getOrganizationsEmbeddedintegration(): Promise<Models.EmbeddedIntegration>; 
  	getOrganizationsIpaddressauthentication(): Promise<Models.IpAddressAuthentication>; 
  	getOrganizationsLimitsChangerequest(requestId: string): Promise<Models.LimitChangeRequestDetails>; 
  	getOrganizationsLimitsChangerequests(opts?: OrganizationApi.getOrganizationsLimitsChangerequestsOptions): Promise<Models.LimitChangeRequestsEntityListing>; 
  	getOrganizationsLimitsDocs(): Promise<Models.LimitDocumentation>; 
  	getOrganizationsLimitsNamespace(namespaceName: string): Promise<Models.LimitsEntityListing>; 
  	getOrganizationsLimitsNamespaceDefaults(namespaceName: string): Promise<Models.LimitsEntityListing>; 
  	getOrganizationsLimitsNamespaces(opts?: OrganizationApi.getOrganizationsLimitsNamespacesOptions): Promise<object>; 
  	getOrganizationsMe(): Promise<Models.Organization>; 
  	getOrganizationsWhitelist(): Promise<Models.OrgWhitelistSettings>; 
  	patchOrganizationsAuthenticationSettings(body: Models.OrgAuthSettings): Promise<Models.OrgAuthSettings>; 
  	patchOrganizationsFeature(featureName: string, enabled: Models.FeatureState): Promise<Models.OrganizationFeatures>; 
  	putOrganizationsEmbeddedintegration(body: Models.EmbeddedIntegration): Promise<Models.EmbeddedIntegration>; 
  	putOrganizationsIpaddressauthentication(body: Models.IpAddressAuthentication): Promise<Models.IpAddressAuthentication>; 
  	putOrganizationsMe(opts?: OrganizationApi.putOrganizationsMeOptions): Promise<Models.Organization>; 
  	putOrganizationsWhitelist(body: Models.OrgWhitelistSettings): Promise<Models.OrgWhitelistSettings>;
}

declare namespace OrganizationApi { 
	export interface getOrganizationsLimitsChangerequestsOptions { 
		"after"?: number;
		"before"?: number;
		"status"?: string;
		"pageSize"?: number;
		"expand"?: Array<string>;
	}
	export interface getOrganizationsLimitsNamespacesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface putOrganizationsMeOptions { 
		"body"?: Models.Organization;
	}
}

declare class OrganizationAuthorizationApi {  
  	deleteOrgauthorizationTrustee(trusteeOrgId: string): Promise<void>; 
  	deleteOrgauthorizationTrusteeCloneduser(trusteeOrgId: string, trusteeUserId: string): Promise<void>; 
  	deleteOrgauthorizationTrusteeGroup(trusteeOrgId: string, trusteeGroupId: string): Promise<void>; 
  	deleteOrgauthorizationTrusteeGroupRoles(trusteeOrgId: string, trusteeGroupId: string): Promise<void>; 
  	deleteOrgauthorizationTrusteeUser(trusteeOrgId: string, trusteeUserId: string): Promise<void>; 
  	deleteOrgauthorizationTrusteeUserRoles(trusteeOrgId: string, trusteeUserId: string): Promise<void>; 
  	deleteOrgauthorizationTrustees(id: Array<string>): Promise<void>; 
  	deleteOrgauthorizationTrustor(trustorOrgId: string): Promise<void>; 
  	deleteOrgauthorizationTrustorCloneduser(trustorOrgId: string, trusteeUserId: string): Promise<void>; 
  	deleteOrgauthorizationTrustorGroup(trustorOrgId: string, trustorGroupId: string): Promise<void>; 
  	deleteOrgauthorizationTrustorUser(trustorOrgId: string, trusteeUserId: string): Promise<void>; 
  	deleteOrgauthorizationTrustors(id: Array<string>): Promise<void>; 
  	getOrgauthorizationPairing(pairingId: string): Promise<Models.TrustRequest>; 
  	getOrgauthorizationTrustee(trusteeOrgId: string): Promise<Models.Trustee>; 
  	getOrgauthorizationTrusteeClonedusers(trusteeOrgId: string): Promise<Models.ClonedUserEntityListing>; 
  	getOrgauthorizationTrusteeGroup(trusteeOrgId: string, trusteeGroupId: string): Promise<Models.TrustGroup>; 
  	getOrgauthorizationTrusteeGroupRoles(trusteeOrgId: string, trusteeGroupId: string): Promise<Models.UserAuthorization>; 
  	getOrgauthorizationTrusteeGroups(trusteeOrgId: string, opts?: OrganizationAuthorizationApi.getOrgauthorizationTrusteeGroupsOptions): Promise<Models.TrustGroupEntityListing>; 
  	getOrgauthorizationTrusteeUser(trusteeOrgId: string, trusteeUserId: string): Promise<Models.TrustUser>; 
  	getOrgauthorizationTrusteeUserRoles(trusteeOrgId: string, trusteeUserId: string): Promise<Models.UserAuthorization>; 
  	getOrgauthorizationTrusteeUsers(trusteeOrgId: string, opts?: OrganizationAuthorizationApi.getOrgauthorizationTrusteeUsersOptions): Promise<Models.TrustUserEntityListing>; 
  	getOrgauthorizationTrustees(opts?: OrganizationAuthorizationApi.getOrgauthorizationTrusteesOptions): Promise<Models.TrustEntityListing>; 
  	getOrgauthorizationTrusteesDefault(): Promise<Models.Trustee>; 
  	getOrgauthorizationTrustor(trustorOrgId: string): Promise<Models.Trustor>; 
  	getOrgauthorizationTrustorCloneduser(trustorOrgId: string, trusteeUserId: string): Promise<Models.ClonedUser>; 
  	getOrgauthorizationTrustorClonedusers(trustorOrgId: string): Promise<Models.ClonedUserEntityListing>; 
  	getOrgauthorizationTrustorGroup(trustorOrgId: string, trustorGroupId: string): Promise<Models.TrustGroup>; 
  	getOrgauthorizationTrustorGroups(trustorOrgId: string, opts?: OrganizationAuthorizationApi.getOrgauthorizationTrustorGroupsOptions): Promise<Models.TrustGroupEntityListing>; 
  	getOrgauthorizationTrustorUser(trustorOrgId: string, trusteeUserId: string): Promise<Models.TrustUser>; 
  	getOrgauthorizationTrustorUsers(trustorOrgId: string, opts?: OrganizationAuthorizationApi.getOrgauthorizationTrustorUsersOptions): Promise<Models.TrustUserEntityListing>; 
  	getOrgauthorizationTrustors(opts?: OrganizationAuthorizationApi.getOrgauthorizationTrustorsOptions): Promise<Models.TrustorEntityListing>; 
  	postOrgauthorizationPairings(body: Models.TrustRequestCreate): Promise<Models.TrustRequest>; 
  	postOrgauthorizationTrusteeGroups(trusteeOrgId: string, body: Models.TrustMemberCreate): Promise<Models.TrustGroup>; 
  	postOrgauthorizationTrusteeUsers(trusteeOrgId: string, body: Models.TrustMemberCreate): Promise<Models.TrustUser>; 
  	postOrgauthorizationTrustees(body: Models.TrustCreate): Promise<Models.Trustee>; 
  	postOrgauthorizationTrusteesAudits(body: Models.TrusteeAuditQueryRequest, opts?: OrganizationAuthorizationApi.postOrgauthorizationTrusteesAuditsOptions): Promise<object>; 
  	postOrgauthorizationTrusteesDefault(opts?: OrganizationAuthorizationApi.postOrgauthorizationTrusteesDefaultOptions): Promise<Models.Trustee>; 
  	postOrgauthorizationTrustorAudits(body: Models.TrustorAuditQueryRequest, opts?: OrganizationAuthorizationApi.postOrgauthorizationTrustorAuditsOptions): Promise<object>; 
  	putOrgauthorizationTrustee(trusteeOrgId: string, body: Models.TrustUpdate): Promise<Models.Trustee>; 
  	putOrgauthorizationTrusteeGroupRoledivisions(trusteeOrgId: string, trusteeGroupId: string, body: Models.RoleDivisionGrants): Promise<Models.UserAuthorization>; 
  	putOrgauthorizationTrusteeGroupRoles(trusteeOrgId: string, trusteeGroupId: string, body: Array<string>): Promise<Models.UserAuthorization>; 
  	putOrgauthorizationTrusteeUserRoledivisions(trusteeOrgId: string, trusteeUserId: string, body: Models.RoleDivisionGrants): Promise<Models.UserAuthorization>; 
  	putOrgauthorizationTrusteeUserRoles(trusteeOrgId: string, trusteeUserId: string, body: Array<string>): Promise<Models.UserAuthorization>; 
  	putOrgauthorizationTrustorCloneduser(trustorOrgId: string, trusteeUserId: string): Promise<Models.ClonedUser>; 
  	putOrgauthorizationTrustorGroup(trustorOrgId: string, trustorGroupId: string): Promise<Models.TrustGroup>; 
  	putOrgauthorizationTrustorUser(trustorOrgId: string, trusteeUserId: string): Promise<Models.TrustUser>;
}

declare namespace OrganizationAuthorizationApi { 
	export interface getOrgauthorizationTrusteeGroupsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getOrgauthorizationTrusteeUsersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getOrgauthorizationTrusteesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getOrgauthorizationTrustorGroupsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getOrgauthorizationTrustorUsersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getOrgauthorizationTrustorsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postOrgauthorizationTrusteesAuditsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface postOrgauthorizationTrusteesDefaultOptions { 
		"assignDefaultRole"?: boolean;
		"autoExpire"?: boolean;
	}
	export interface postOrgauthorizationTrustorAuditsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
}

declare class OutboundApi {  
  	deleteOutboundAttemptlimit(attemptLimitsId: string): Promise<void>; 
  	deleteOutboundCallabletimeset(callableTimeSetId: string): Promise<void>; 
  	deleteOutboundCallanalysisresponseset(callAnalysisSetId: string): Promise<void>; 
  	deleteOutboundCampaign(campaignId: string): Promise<Models.Campaign>; 
  	deleteOutboundCampaignProgress(campaignId: string): Promise<void>; 
  	deleteOutboundCampaignrule(campaignRuleId: string): Promise<void>; 
  	deleteOutboundContactlist(contactListId: string): Promise<void>; 
  	deleteOutboundContactlistContact(contactListId: string, contactId: string): Promise<void>; 
  	deleteOutboundContactlistContacts(contactListId: string, contactIds: Array<string>): Promise<void>; 
  	deleteOutboundContactlistfilter(contactListFilterId: string): Promise<void>; 
  	deleteOutboundContactlists(id: Array<string>): Promise<void>; 
  	deleteOutboundContactlisttemplate(contactListTemplateId: string): Promise<void>; 
  	deleteOutboundContactlisttemplates(id: Array<string>): Promise<void>; 
  	deleteOutboundDigitalruleset(digitalRuleSetId: string): Promise<void>; 
  	deleteOutboundDnclist(dncListId: string): Promise<void>; 
  	deleteOutboundDnclistCustomexclusioncolumns(dncListId: string, opts?: OutboundApi.deleteOutboundDnclistCustomexclusioncolumnsOptions): Promise<void>; 
  	deleteOutboundDnclistEmailaddresses(dncListId: string, opts?: OutboundApi.deleteOutboundDnclistEmailaddressesOptions): Promise<void>; 
  	deleteOutboundDnclistPhonenumbers(dncListId: string, opts?: OutboundApi.deleteOutboundDnclistPhonenumbersOptions): Promise<void>; 
  	deleteOutboundFilespecificationtemplate(fileSpecificationTemplateId: string): Promise<void>; 
  	deleteOutboundFilespecificationtemplatesBulk(id: Array<string>): Promise<void>; 
  	deleteOutboundImporttemplate(importTemplateId: string): Promise<void>; 
  	deleteOutboundImporttemplates(id: Array<string>): Promise<void>; 
  	deleteOutboundMessagingcampaign(messagingCampaignId: string): Promise<Models.MessagingCampaign>; 
  	deleteOutboundMessagingcampaignProgress(messagingCampaignId: string): Promise<void>; 
  	deleteOutboundRuleset(ruleSetId: string): Promise<void>; 
  	deleteOutboundSchedulesCampaign(campaignId: string): Promise<void>; 
  	deleteOutboundSchedulesEmailcampaign(emailCampaignId: string): Promise<void>; 
  	deleteOutboundSchedulesMessagingcampaign(messagingCampaignId: string): Promise<void>; 
  	deleteOutboundSchedulesSequence(sequenceId: string): Promise<void>; 
  	deleteOutboundSequence(sequenceId: string): Promise<void>; 
  	getOutboundAttemptlimit(attemptLimitsId: string): Promise<Models.AttemptLimits>; 
  	getOutboundAttemptlimits(opts?: OutboundApi.getOutboundAttemptlimitsOptions): Promise<Models.AttemptLimitsEntityListing>; 
  	getOutboundCallabletimeset(callableTimeSetId: string): Promise<Models.CallableTimeSet>; 
  	getOutboundCallabletimesets(opts?: OutboundApi.getOutboundCallabletimesetsOptions): Promise<Models.CallableTimeSetEntityListing>; 
  	getOutboundCallanalysisresponseset(callAnalysisSetId: string): Promise<Models.ResponseSet>; 
  	getOutboundCallanalysisresponsesets(opts?: OutboundApi.getOutboundCallanalysisresponsesetsOptions): Promise<Models.ResponseSetEntityListing>; 
  	getOutboundCampaign(campaignId: string): Promise<Models.Campaign>; 
  	getOutboundCampaignAgentownedmappingpreviewResults(campaignId: string): Promise<Models.AgentOwnedMappingPreviewListing>; 
  	getOutboundCampaignDiagnostics(campaignId: string): Promise<Models.CampaignDiagnostics>; 
  	getOutboundCampaignInteractions(campaignId: string): Promise<Models.CampaignInteractions>; 
  	getOutboundCampaignProgress(campaignId: string): Promise<Models.CampaignProgress>; 
  	getOutboundCampaignStats(campaignId: string): Promise<Models.CampaignStats>; 
  	getOutboundCampaignrule(campaignRuleId: string): Promise<Models.CampaignRule>; 
  	getOutboundCampaignrules(opts?: OutboundApi.getOutboundCampaignrulesOptions): Promise<Models.CampaignRuleEntityListing>; 
  	getOutboundCampaigns(opts?: OutboundApi.getOutboundCampaignsOptions): Promise<Models.CampaignEntityListing>; 
  	getOutboundCampaignsAll(opts?: OutboundApi.getOutboundCampaignsAllOptions): Promise<Models.CommonCampaignEntityListing>; 
  	getOutboundCampaignsAllDivisionviews(opts?: OutboundApi.getOutboundCampaignsAllDivisionviewsOptions): Promise<Models.CommonCampaignDivisionViewEntityListing>; 
  	getOutboundCampaignsDivisionview(campaignId: string): Promise<Models.CampaignDivisionView>; 
  	getOutboundCampaignsDivisionviews(opts?: OutboundApi.getOutboundCampaignsDivisionviewsOptions): Promise<Models.CampaignDivisionViewListing>; 
  	getOutboundContactlist(contactListId: string, opts?: OutboundApi.getOutboundContactlistOptions): Promise<Models.ContactList>; 
  	getOutboundContactlistContact(contactListId: string, contactId: string): Promise<Models.DialerContact>; 
  	getOutboundContactlistExport(contactListId: string, opts?: OutboundApi.getOutboundContactlistExportOptions): Promise<Models.ExportUri>; 
  	getOutboundContactlistImportstatus(contactListId: string): Promise<Models.ImportStatus>; 
  	getOutboundContactlistTimezonemappingpreview(contactListId: string): Promise<Models.TimeZoneMappingPreview>; 
  	getOutboundContactlistfilter(contactListFilterId: string): Promise<Models.ContactListFilter>; 
  	getOutboundContactlistfilters(opts?: OutboundApi.getOutboundContactlistfiltersOptions): Promise<Models.ContactListFilterEntityListing>; 
  	getOutboundContactlists(opts?: OutboundApi.getOutboundContactlistsOptions): Promise<Models.ContactListEntityListing>; 
  	getOutboundContactlistsDivisionview(contactListId: string, opts?: OutboundApi.getOutboundContactlistsDivisionviewOptions): Promise<Models.ContactListDivisionView>; 
  	getOutboundContactlistsDivisionviews(opts?: OutboundApi.getOutboundContactlistsDivisionviewsOptions): Promise<Models.ContactListDivisionViewListing>; 
  	getOutboundContactlisttemplate(contactListTemplateId: string): Promise<Models.ContactListTemplate>; 
  	getOutboundContactlisttemplates(opts?: OutboundApi.getOutboundContactlisttemplatesOptions): Promise<Models.ContactListTemplateEntityListing>; 
  	getOutboundDigitalruleset(digitalRuleSetId: string): Promise<Models.DigitalRuleSet>; 
  	getOutboundDigitalrulesets(opts?: OutboundApi.getOutboundDigitalrulesetsOptions): Promise<Models.DigitalRuleSetEntityListing>; 
  	getOutboundDnclist(dncListId: string, opts?: OutboundApi.getOutboundDnclistOptions): Promise<Models.DncList>; 
  	getOutboundDnclistExport(dncListId: string, opts?: OutboundApi.getOutboundDnclistExportOptions): Promise<Models.ExportUri>; 
  	getOutboundDnclistImportstatus(dncListId: string): Promise<Models.ImportStatus>; 
  	getOutboundDnclists(opts?: OutboundApi.getOutboundDnclistsOptions): Promise<Models.DncListEntityListing>; 
  	getOutboundDnclistsDivisionview(dncListId: string, opts?: OutboundApi.getOutboundDnclistsDivisionviewOptions): Promise<Models.DncListDivisionView>; 
  	getOutboundDnclistsDivisionviews(opts?: OutboundApi.getOutboundDnclistsDivisionviewsOptions): Promise<Models.DncListDivisionViewListing>; 
  	getOutboundEvent(eventId: string): Promise<Models.EventLog>; 
  	getOutboundEvents(opts?: OutboundApi.getOutboundEventsOptions): Promise<Models.DialerEventEntityListing>; 
  	getOutboundFilespecificationtemplate(fileSpecificationTemplateId: string): Promise<Models.FileSpecificationTemplate>; 
  	getOutboundFilespecificationtemplates(opts?: OutboundApi.getOutboundFilespecificationtemplatesOptions): Promise<Models.FileSpecificationTemplateEntityListing>; 
  	getOutboundImporttemplate(importTemplateId: string, opts?: OutboundApi.getOutboundImporttemplateOptions): Promise<Models.ImportTemplate>; 
  	getOutboundImporttemplateImportstatus(importTemplateId: string, opts?: OutboundApi.getOutboundImporttemplateImportstatusOptions): Promise<Models.ImportStatus>; 
  	getOutboundImporttemplates(opts?: OutboundApi.getOutboundImporttemplatesOptions): Promise<Models.ImportTemplateEntityListing>; 
  	getOutboundMessagingcampaign(messagingCampaignId: string): Promise<Models.MessagingCampaign>; 
  	getOutboundMessagingcampaignDiagnostics(messagingCampaignId: string): Promise<Models.MessagingCampaignDiagnostics>; 
  	getOutboundMessagingcampaignProgress(messagingCampaignId: string): Promise<Models.CampaignProgress>; 
  	getOutboundMessagingcampaigns(opts?: OutboundApi.getOutboundMessagingcampaignsOptions): Promise<Models.MessagingCampaignEntityListing>; 
  	getOutboundMessagingcampaignsDivisionview(messagingCampaignId: string): Promise<Models.MessagingCampaignDivisionView>; 
  	getOutboundMessagingcampaignsDivisionviews(opts?: OutboundApi.getOutboundMessagingcampaignsDivisionviewsOptions): Promise<Models.MessagingCampaignDivisionViewEntityListing>; 
  	getOutboundRuleset(ruleSetId: string): Promise<Models.RuleSet>; 
  	getOutboundRulesets(opts?: OutboundApi.getOutboundRulesetsOptions): Promise<Models.RuleSetEntityListing>; 
  	getOutboundSchedulesCampaign(campaignId: string): Promise<Models.CampaignSchedule>; 
  	getOutboundSchedulesCampaigns(): Promise<Array<Models.CampaignSchedule>>; 
  	getOutboundSchedulesEmailcampaign(emailCampaignId: string): Promise<Models.EmailCampaignSchedule>; 
  	getOutboundSchedulesEmailcampaigns(): Promise<Models.EmailCampaignScheduleEntityListing>; 
  	getOutboundSchedulesMessagingcampaign(messagingCampaignId: string): Promise<Models.MessagingCampaignSchedule>; 
  	getOutboundSchedulesMessagingcampaigns(): Promise<Models.MessagingCampaignScheduleEntityListing>; 
  	getOutboundSchedulesSequence(sequenceId: string): Promise<Models.SequenceSchedule>; 
  	getOutboundSchedulesSequences(): Promise<Array<Models.SequenceSchedule>>; 
  	getOutboundSequence(sequenceId: string): Promise<Models.CampaignSequence>; 
  	getOutboundSequences(opts?: OutboundApi.getOutboundSequencesOptions): Promise<Models.CampaignSequenceEntityListing>; 
  	getOutboundSettings(): Promise<Models.OutboundSettings>; 
  	getOutboundWrapupcodemappings(): Promise<Models.WrapUpCodeMapping>; 
  	patchOutboundDnclistCustomexclusioncolumns(dncListId: string, body: Models.DncPatchCustomExclusionColumnsRequest): Promise<void>; 
  	patchOutboundDnclistEmailaddresses(dncListId: string, body: Models.DncPatchEmailsRequest): Promise<void>; 
  	patchOutboundDnclistPhonenumbers(dncListId: string, body: Models.DncPatchPhoneNumbersRequest): Promise<void>; 
  	patchOutboundSettings(body: Models.OutboundSettings): Promise<void>; 
  	postOutboundAttemptlimits(body: Models.AttemptLimits): Promise<Models.AttemptLimits>; 
  	postOutboundAudits(body: Models.DialerAuditRequest, opts?: OutboundApi.postOutboundAuditsOptions): Promise<Models.AuditSearchResult>; 
  	postOutboundCallabletimesets(body: Models.CallableTimeSet): Promise<Models.CallableTimeSet>; 
  	postOutboundCallanalysisresponsesets(body: Models.ResponseSet): Promise<Models.ResponseSet>; 
  	postOutboundCampaignAgentownedmappingpreview(campaignId: string): Promise<object>; 
  	postOutboundCampaignCallbackSchedule(campaignId: string, body: Models.ContactCallbackRequest): Promise<Models.ContactCallbackRequest>; 
  	postOutboundCampaignrules(body: Models.CampaignRule): Promise<Models.CampaignRule>; 
  	postOutboundCampaigns(body: Models.Campaign): Promise<Models.Campaign>; 
  	postOutboundCampaignsProgress(body: Array<string>): Promise<Array<Models.CampaignProgress>>; 
  	postOutboundContactlistClear(contactListId: string): Promise<void>; 
  	postOutboundContactlistContacts(contactListId: string, body: Array<Models.WritableDialerContact>, opts?: OutboundApi.postOutboundContactlistContactsOptions): Promise<Array<Models.DialerContact>>; 
  	postOutboundContactlistContactsBulk(contactListId: string, body: Array<string>): Promise<Array<Models.DialerContact>>; 
  	postOutboundContactlistExport(contactListId: string, opts?: OutboundApi.postOutboundContactlistExportOptions): Promise<Models.DomainEntityRef>; 
  	postOutboundContactlistfilters(body: Models.ContactListFilter): Promise<Models.ContactListFilter>; 
  	postOutboundContactlistfiltersBulkRetrieve(body: Models.ContactListFilterBulkRetrieveBody): Promise<Models.ContactListFilterEntityListing>; 
  	postOutboundContactlistfiltersPreview(body: Models.ContactListFilter): Promise<Models.FilterPreviewResponse>; 
  	postOutboundContactlists(body: Models.ContactList): Promise<Models.ContactList>; 
  	postOutboundContactlisttemplates(body: Models.ContactListTemplate): Promise<Models.ContactListTemplate>; 
  	postOutboundContactlisttemplatesBulkAdd(body: Array<Models.ContactListTemplate>): Promise<Models.ContactListTemplateEntityListing>; 
  	postOutboundContactlisttemplatesBulkRetrieve(body: Models.ContactListTemplateBulkRetrieveBody): Promise<Models.ContactListTemplateEntityListing>; 
  	postOutboundConversationDnc(conversationId: string): Promise<void>; 
  	postOutboundDigitalrulesets(body: Models.DigitalRuleSet): Promise<Models.DigitalRuleSet>; 
  	postOutboundDnclistEmailaddresses(dncListId: string, body: Array<string>): Promise<void>; 
  	postOutboundDnclistExport(dncListId: string): Promise<Models.DomainEntityRef>; 
  	postOutboundDnclistPhonenumbers(dncListId: string, body: Array<string>, opts?: OutboundApi.postOutboundDnclistPhonenumbersOptions): Promise<void>; 
  	postOutboundDnclists(body: Models.DncListCreate): Promise<Models.DncList>; 
  	postOutboundFilespecificationtemplates(body: Models.FileSpecificationTemplate): Promise<Models.FileSpecificationTemplate>; 
  	postOutboundImporttemplates(body: Models.ImportTemplate): Promise<Models.ImportTemplate>; 
  	postOutboundImporttemplatesBulkAdd(body: Array<Models.ImportTemplate>): Promise<Models.ImportTemplateEntityListing>; 
  	postOutboundMessagingcampaigns(body: Models.MessagingCampaign): Promise<Models.MessagingCampaign>; 
  	postOutboundMessagingcampaignsProgress(body: Array<string>): Promise<Array<Models.CampaignProgress>>; 
  	postOutboundRulesets(body: Models.RuleSet): Promise<Models.RuleSet>; 
  	postOutboundSequences(body: Models.CampaignSequence): Promise<Models.CampaignSequence>; 
  	putOutboundAttemptlimit(attemptLimitsId: string, body: Models.AttemptLimits): Promise<Models.AttemptLimits>; 
  	putOutboundCallabletimeset(callableTimeSetId: string, body: Models.CallableTimeSet): Promise<Models.CallableTimeSet>; 
  	putOutboundCallanalysisresponseset(callAnalysisSetId: string, body: Models.ResponseSet): Promise<Models.ResponseSet>; 
  	putOutboundCampaign(campaignId: string, body: Models.Campaign): Promise<Models.Campaign>; 
  	putOutboundCampaignAgent(campaignId: string, userId: string, body: Models.Agent): Promise<string>; 
  	putOutboundCampaignrule(campaignRuleId: string, body: Models.CampaignRule): Promise<Models.CampaignRule>; 
  	putOutboundContactlist(contactListId: string, body: Models.ContactList): Promise<Models.ContactList>; 
  	putOutboundContactlistContact(contactListId: string, contactId: string, body: Models.DialerContact): Promise<Models.DialerContact>; 
  	putOutboundContactlistfilter(contactListFilterId: string, body: Models.ContactListFilter): Promise<Models.ContactListFilter>; 
  	putOutboundContactlisttemplate(contactListTemplateId: string, body: Models.ContactListTemplate): Promise<Models.ContactListTemplate>; 
  	putOutboundDigitalruleset(digitalRuleSetId: string, body: Models.DigitalRuleSet): Promise<Models.DigitalRuleSet>; 
  	putOutboundDnclist(dncListId: string, body: Models.DncList): Promise<Models.DncList>; 
  	putOutboundFilespecificationtemplate(fileSpecificationTemplateId: string, body: Models.FileSpecificationTemplate): Promise<Models.FileSpecificationTemplate>; 
  	putOutboundImporttemplate(importTemplateId: string, body: Models.ImportTemplate): Promise<Models.ImportTemplate>; 
  	putOutboundMessagingcampaign(messagingCampaignId: string, body: Models.MessagingCampaign): Promise<Models.MessagingCampaign>; 
  	putOutboundRuleset(ruleSetId: string, body: Models.RuleSet): Promise<Models.RuleSet>; 
  	putOutboundSchedulesCampaign(campaignId: string, body: Models.CampaignSchedule): Promise<Models.CampaignSchedule>; 
  	putOutboundSchedulesEmailcampaign(emailCampaignId: string, body: Models.EmailCampaignSchedule): Promise<Models.EmailCampaignSchedule>; 
  	putOutboundSchedulesMessagingcampaign(messagingCampaignId: string, body: Models.MessagingCampaignSchedule): Promise<Models.MessagingCampaignSchedule>; 
  	putOutboundSchedulesSequence(sequenceId: string, body: Models.SequenceSchedule): Promise<Models.SequenceSchedule>; 
  	putOutboundSequence(sequenceId: string, body: Models.CampaignSequence): Promise<Models.CampaignSequence>; 
  	putOutboundWrapupcodemappings(body: Models.WrapUpCodeMapping): Promise<Models.WrapUpCodeMapping>;
}

declare namespace OutboundApi { 
	export interface deleteOutboundDnclistCustomexclusioncolumnsOptions { 
		"expiredOnly"?: boolean;
	}
	export interface deleteOutboundDnclistEmailaddressesOptions { 
		"expiredOnly"?: boolean;
	}
	export interface deleteOutboundDnclistPhonenumbersOptions { 
		"expiredOnly"?: boolean;
	}
	export interface getOutboundAttemptlimitsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundCallabletimesetsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundCallanalysisresponsesetsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundCampaignrulesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundCampaignsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"filterType"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"contactListId"?: string;
		"dncListIds"?: string;
		"distributionQueueId"?: string;
		"edgeGroupId"?: string;
		"callAnalysisResponseSetId"?: string;
		"divisionId"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundCampaignsAllOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
		"mediaType"?: Array<string>;
		"sortOrder"?: string;
	}
	export interface getOutboundCampaignsAllDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
		"mediaType"?: Array<string>;
		"sortOrder"?: string;
	}
	export interface getOutboundCampaignsDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"filterType"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundContactlistOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
	}
	export interface getOutboundContactlistExportOptions { 
		"download"?: string;
	}
	export interface getOutboundContactlistfiltersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"contactListId"?: string;
	}
	export interface getOutboundContactlistsOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"divisionId"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundContactlistsDivisionviewOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
	}
	export interface getOutboundContactlistsDivisionviewsOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
		"pageSize"?: number;
		"pageNumber"?: number;
		"filterType"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundContactlisttemplatesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundDigitalrulesetsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"id"?: Array<string>;
	}
	export interface getOutboundDnclistOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
	}
	export interface getOutboundDnclistExportOptions { 
		"download"?: string;
	}
	export interface getOutboundDnclistsOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"dncSourceType"?: string;
		"divisionId"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundDnclistsDivisionviewOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
	}
	export interface getOutboundDnclistsDivisionviewsOptions { 
		"includeImportStatus"?: boolean;
		"includeSize"?: boolean;
		"pageSize"?: number;
		"pageNumber"?: number;
		"filterType"?: string;
		"name"?: string;
		"dncSourceType"?: string;
		"id"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundEventsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"filterType"?: string;
		"category"?: string;
		"level"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundFilespecificationtemplatesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundImporttemplateOptions { 
		"includeImportStatus"?: boolean;
	}
	export interface getOutboundImporttemplateImportstatusOptions { 
		"listNamePrefix"?: string;
	}
	export interface getOutboundImporttemplatesOptions { 
		"includeImportStatus"?: boolean;
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"contactListTemplateId"?: string;
	}
	export interface getOutboundMessagingcampaignsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"contactListId"?: string;
		"divisionId"?: Array<string>;
		"type"?: string;
		"senderSmsPhoneNumber"?: string;
		"id"?: Array<string>;
	}
	export interface getOutboundMessagingcampaignsDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"name"?: string;
		"type"?: string;
		"id"?: Array<string>;
		"senderSmsPhoneNumber"?: string;
	}
	export interface getOutboundRulesetsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getOutboundSequencesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"allowEmptyResult"?: boolean;
		"filterType"?: string;
		"name"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface postOutboundAuditsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"facetsOnly"?: boolean;
	}
	export interface postOutboundContactlistContactsOptions { 
		"priority"?: boolean;
		"clearSystemData"?: boolean;
		"doNotQueue"?: boolean;
	}
	export interface postOutboundContactlistExportOptions { 
		"body"?: Models.ContactsExportRequest;
	}
	export interface postOutboundDnclistPhonenumbersOptions { 
		"expirationDateTime"?: string;
	}
}

declare class PresenceApi {  
  	deletePresenceDefinition0(definitionId: string): Promise<void>; 
  	deletePresenceSource(sourceId: string): Promise<void>; 
  	deletePresencedefinition(presenceId: string): Promise<void>; 
  	getPresenceDefinition0(definitionId: string, opts?: PresenceApi.getPresenceDefinition0Options): Promise<Models.OrganizationPresenceDefinition>; 
  	getPresenceDefinitions0(opts?: PresenceApi.getPresenceDefinitions0Options): Promise<Models.OrganizationPresenceDefinitionEntityListing>; 
  	getPresenceSettings(): Promise<Models.PresenceSettings>; 
  	getPresenceSource(sourceId: string): Promise<Models.Source>; 
  	getPresenceSources(opts?: PresenceApi.getPresenceSourcesOptions): Promise<Models.SourceEntityListing>; 
  	getPresenceUserPrimarysource(userId: string): Promise<Models.UserPrimarySource>; 
  	getPresencedefinition(presenceId: string, opts?: PresenceApi.getPresencedefinitionOptions): Promise<Models.OrganizationPresence>; 
  	getPresencedefinitions(opts?: PresenceApi.getPresencedefinitionsOptions): Promise<Models.OrganizationPresenceEntityListing>; 
  	getSystempresences(): Promise<Array<Models.SystemPresence>>; 
  	getUserPresence(userId: string, sourceId: string): Promise<Models.UserPresence>; 
  	getUserPresencesPurecloud(userId: string): Promise<Models.UserPresence>; 
  	getUsersPresenceBulk(sourceId: string, opts?: PresenceApi.getUsersPresenceBulkOptions): Promise<Array<Models.UcUserPresence>>; 
  	getUsersPresencesPurecloudBulk(opts?: PresenceApi.getUsersPresencesPurecloudBulkOptions): Promise<Array<Models.UcUserPresence>>; 
  	patchUserPresence(userId: string, sourceId: string, body: Models.UserPresence): Promise<Models.UserPresence>; 
  	patchUserPresencesPurecloud(userId: string, body: Models.UserPresence): Promise<Models.UserPresence>; 
  	postPresenceDefinitions0(body: Models.OrganizationPresenceDefinition): Promise<Models.OrganizationPresenceDefinition>; 
  	postPresenceSources(body: Models.Source): Promise<Models.Source>; 
  	postPresencedefinitions(body: Models.OrganizationPresence): Promise<Models.OrganizationPresence>; 
  	putPresenceDefinition0(definitionId: string, body: Models.OrganizationPresenceDefinition): Promise<Models.OrganizationPresenceDefinition>; 
  	putPresenceSettings(body: Models.PresenceSettings): Promise<Models.PresenceSettings>; 
  	putPresenceSource(sourceId: string, body: Models.Source): Promise<Models.Source>; 
  	putPresenceUserPrimarysource(userId: string, body: Models.UserPrimarySource): Promise<Models.UserPrimarySource>; 
  	putPresencedefinition(presenceId: string, body: Models.OrganizationPresence): Promise<Models.OrganizationPresence>; 
  	putUsersPresencesBulk(body: Array<Models.MutableUserPresence>): Promise<Array<Models.UserPresence>>;
}

declare namespace PresenceApi { 
	export interface getPresenceDefinition0Options { 
		"localeCode"?: string;
	}
	export interface getPresenceDefinitions0Options { 
		"deactivated"?: string;
		"divisionId"?: Array<string>;
		"localeCode"?: string;
	}
	export interface getPresenceSourcesOptions { 
		"deactivated"?: string;
	}
	export interface getPresencedefinitionOptions { 
		"localeCode"?: string;
	}
	export interface getPresencedefinitionsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"deleted"?: string;
		"localeCode"?: string;
	}
	export interface getUsersPresenceBulkOptions { 
		"id"?: Array<string>;
	}
	export interface getUsersPresencesPurecloudBulkOptions { 
		"id"?: Array<string>;
	}
}

declare class ProcessAutomationApi {  
  	deleteProcessautomationTrigger(triggerId: string): Promise<void>; 
  	getProcessautomationTrigger(triggerId: string): Promise<Models.Trigger>; 
  	getProcessautomationTriggers(opts?: ProcessAutomationApi.getProcessautomationTriggersOptions): Promise<Models.TriggerEntityListing>; 
  	getProcessautomationTriggersTopics(opts?: ProcessAutomationApi.getProcessautomationTriggersTopicsOptions): Promise<Models.TopicCursorEntityListing>; 
  	postProcessautomationTriggerTest(triggerId: string, opts?: ProcessAutomationApi.postProcessautomationTriggerTestOptions): Promise<Models.TestModeResults>; 
  	postProcessautomationTriggers(body: Models.CreateTriggerRequest): Promise<Models.Trigger>; 
  	postProcessautomationTriggersTopicTest(topicName: string, opts?: ProcessAutomationApi.postProcessautomationTriggersTopicTestOptions): Promise<Models.TestModeEventResults>; 
  	putProcessautomationTrigger(triggerId: string, body: Models.UpdateTriggerRequest): Promise<Models.Trigger>;
}

declare namespace ProcessAutomationApi { 
	export interface getProcessautomationTriggersOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
		"topicName"?: string;
		"enabled"?: boolean;
		"hasDelayBy"?: boolean;
	}
	export interface getProcessautomationTriggersTopicsOptions { 
		"before"?: string;
		"after"?: string;
		"pageSize"?: string;
	}
	export interface postProcessautomationTriggerTestOptions { 
		"body"?: string;
	}
	export interface postProcessautomationTriggersTopicTestOptions { 
		"body"?: string;
	}
}

declare class QualityApi {  
  	deleteQualityCalibration(calibrationId: string, calibratorId: string): Promise<Models.Calibration>; 
  	deleteQualityConversationEvaluation(conversationId: string, evaluationId: string, opts?: QualityApi.deleteQualityConversationEvaluationOptions): Promise<Models.EvaluationResponse>; 
  	deleteQualityForm(formId: string): Promise<void>; 
  	deleteQualityFormsEvaluation(formId: string): Promise<void>; 
  	deleteQualityFormsSurvey(formId: string): Promise<void>; 
  	getAnalyticsEvaluationsAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsEvaluationsAggregatesJobResults(jobId: string, opts?: QualityApi.getAnalyticsEvaluationsAggregatesJobResultsOptions): Promise<Models.EvaluationAsyncAggregateQueryResponse>; 
  	getAnalyticsSurveysAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsSurveysAggregatesJobResults(jobId: string, opts?: QualityApi.getAnalyticsSurveysAggregatesJobResultsOptions): Promise<Models.SurveyAsyncAggregateQueryResponse>; 
  	getQualityAgentsActivity(opts?: QualityApi.getQualityAgentsActivityOptions): Promise<Models.AgentActivityEntityListing>; 
  	getQualityCalibration(calibrationId: string, opts?: QualityApi.getQualityCalibrationOptions): Promise<Models.Calibration>; 
  	getQualityCalibrations(calibratorId: string, opts?: QualityApi.getQualityCalibrationsOptions): Promise<Models.CalibrationEntityListing>; 
  	getQualityConversationEvaluation(conversationId: string, evaluationId: string, opts?: QualityApi.getQualityConversationEvaluationOptions): Promise<Models.EvaluationResponse>; 
  	getQualityConversationSurveys(conversationId: string): Promise<Array<Models.Survey>>; 
  	getQualityConversationsAuditsQueryTransactionId(transactionId: string): Promise<Models.QualityAuditQueryExecutionStatusResponse>; 
  	getQualityConversationsAuditsQueryTransactionIdResults(transactionId: string, opts?: QualityApi.getQualityConversationsAuditsQueryTransactionIdResultsOptions): Promise<Models.QualityAuditQueryExecutionResultsResponse>; 
  	getQualityEvaluationsQuery(opts?: QualityApi.getQualityEvaluationsQueryOptions): Promise<Models.EvaluationEntityListing>; 
  	getQualityEvaluatorsActivity(opts?: QualityApi.getQualityEvaluatorsActivityOptions): Promise<Models.EvaluatorActivityEntityListing>; 
  	getQualityForm(formId: string): Promise<Models.EvaluationFormResponse>; 
  	getQualityFormVersions(formId: string, opts?: QualityApi.getQualityFormVersionsOptions): Promise<Models.EvaluationFormResponseEntityListing>; 
  	getQualityForms(opts?: QualityApi.getQualityFormsOptions): Promise<Models.EvaluationFormResponseEntityListing>; 
  	getQualityFormsEvaluation(formId: string): Promise<Models.EvaluationFormResponse>; 
  	getQualityFormsEvaluationVersions(formId: string, opts?: QualityApi.getQualityFormsEvaluationVersionsOptions): Promise<Models.EvaluationFormResponseEntityListing>; 
  	getQualityFormsEvaluations(opts?: QualityApi.getQualityFormsEvaluationsOptions): Promise<Models.EvaluationFormResponseEntityListing>; 
  	getQualityFormsEvaluationsBulkContexts(contextId: Array<string>): Promise<Array<Models.EvaluationFormResponse>>; 
  	getQualityFormsSurvey(formId: string): Promise<Models.SurveyForm>; 
  	getQualityFormsSurveyVersions(formId: string, opts?: QualityApi.getQualityFormsSurveyVersionsOptions): Promise<Models.SurveyFormEntityListing>; 
  	getQualityFormsSurveys(opts?: QualityApi.getQualityFormsSurveysOptions): Promise<Models.SurveyFormEntityListing>; 
  	getQualityFormsSurveysBulk(id: Array<string>): Promise<Models.SurveyFormEntityListing>; 
  	getQualityFormsSurveysBulkContexts(contextId: Array<string>, opts?: QualityApi.getQualityFormsSurveysBulkContextsOptions): Promise<Array<Models.SurveyForm>>; 
  	getQualityPublishedform(formId: string): Promise<Models.EvaluationFormResponse>; 
  	getQualityPublishedforms(opts?: QualityApi.getQualityPublishedformsOptions): Promise<Models.EvaluationFormResponseEntityListing>; 
  	getQualityPublishedformsEvaluation(formId: string): Promise<Models.EvaluationFormResponse>; 
  	getQualityPublishedformsEvaluations(opts?: QualityApi.getQualityPublishedformsEvaluationsOptions): Promise<Models.EvaluationFormResponseEntityListing>; 
  	getQualityPublishedformsSurvey(formId: string): Promise<Models.SurveyForm>; 
  	getQualityPublishedformsSurveys(opts?: QualityApi.getQualityPublishedformsSurveysOptions): Promise<Models.SurveyFormEntityListing>; 
  	getQualitySurvey(surveyId: string): Promise<Models.Survey>; 
  	getQualitySurveysScorable(customerSurveyUrl: string): Promise<Models.ScorableSurvey>; 
  	patchQualityFormsSurvey(formId: string, body: Models.SurveyForm): Promise<Models.SurveyForm>; 
  	postAnalyticsEvaluationsAggregatesJobs(body: Models.EvaluationAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsEvaluationsAggregatesQuery(body: Models.EvaluationAggregationQuery): Promise<Models.EvaluationAggregateQueryResponse>; 
  	postAnalyticsSurveysAggregatesJobs(body: Models.SurveyAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsSurveysAggregatesQuery(body: Models.SurveyAggregationQuery): Promise<Models.SurveyAggregateQueryResponse>; 
  	postQualityCalibrations(body: Models.CalibrationCreate, opts?: QualityApi.postQualityCalibrationsOptions): Promise<Models.Calibration>; 
  	postQualityConversationEvaluations(conversationId: string, body: Models.EvaluationCreateBody, opts?: QualityApi.postQualityConversationEvaluationsOptions): Promise<Models.Evaluation>; 
  	postQualityConversationsAuditsQuery(body: Models.QMAuditQueryRequest): Promise<Models.QualityAuditQueryExecutionStatusResponse>; 
  	postQualityEvaluationsAggregatesQueryMe(body: Models.EvaluationAggregationQueryMe): Promise<Models.EvaluationAggregateQueryResponse>; 
  	postQualityEvaluationsScoring(body: Models.EvaluationFormAndScoringSet): Promise<Models.EvaluationScoringSet>; 
  	postQualityForms(body: Models.EvaluationForm): Promise<Models.EvaluationFormResponse>; 
  	postQualityFormsEvaluations(body: Models.EvaluationForm): Promise<Models.EvaluationFormResponse>; 
  	postQualityFormsSurveys(body: Models.SurveyForm): Promise<Models.SurveyForm>; 
  	postQualityPublishedforms(body: Models.PublishForm): Promise<Models.EvaluationFormResponse>; 
  	postQualityPublishedformsEvaluations(body: Models.PublishForm): Promise<Models.EvaluationFormResponse>; 
  	postQualityPublishedformsSurveys(body: Models.PublishForm): Promise<Models.SurveyForm>; 
  	postQualitySurveysScoring(body: Models.SurveyFormAndScoringSet): Promise<Models.SurveyScoringSet>; 
  	putQualityCalibration(calibrationId: string, body: Models.Calibration): Promise<Models.Calibration>; 
  	putQualityConversationEvaluation(conversationId: string, evaluationId: string, body: Models.Evaluation, opts?: QualityApi.putQualityConversationEvaluationOptions): Promise<Models.EvaluationResponse>; 
  	putQualityForm(formId: string, body: Models.EvaluationForm): Promise<Models.EvaluationFormResponse>; 
  	putQualityFormsEvaluation(formId: string, body: Models.EvaluationForm): Promise<Models.EvaluationFormResponse>; 
  	putQualityFormsSurvey(formId: string, body: Models.SurveyForm): Promise<Models.SurveyForm>; 
  	putQualitySurveysScorable(customerSurveyUrl: string, body: Models.ScorableSurvey): Promise<Models.ScorableSurvey>;
}

declare namespace QualityApi { 
	export interface deleteQualityConversationEvaluationOptions { 
		"expand"?: string;
	}
	export interface getAnalyticsEvaluationsAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsSurveysAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getQualityAgentsActivityOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"agentUserId"?: Array<string>;
		"evaluatorUserId"?: string;
		"name"?: string;
		"group"?: string;
		"agentTeamId"?: string;
		"formContextId"?: string;
	}
	export interface getQualityCalibrationOptions { 
		"calibratorId"?: string;
		"conversationId"?: string;
	}
	export interface getQualityCalibrationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"conversationId"?: string;
		"startTime"?: string;
		"endTime"?: string;
	}
	export interface getQualityConversationEvaluationOptions { 
		"expand"?: string;
	}
	export interface getQualityConversationsAuditsQueryTransactionIdResultsOptions { 
		"cursor"?: string;
		"pageSize"?: number;
		"expand"?: Array<string>;
	}
	export interface getQualityEvaluationsQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"conversationId"?: string;
		"agentUserId"?: string;
		"agentTeamId"?: string;
		"evaluatorUserId"?: string;
		"assigneeUserId"?: string;
		"queueId"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"formContextId"?: string;
		"evaluationState"?: Array<string>;
		"isReleased"?: boolean;
		"agentHasRead"?: boolean;
		"expandAnswerTotalScores"?: boolean;
		"maximum"?: number;
		"sortOrder"?: string;
	}
	export interface getQualityEvaluatorsActivityOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"name"?: string;
		"permission"?: Array<string>;
		"group"?: string;
		"agentTeamId"?: string;
	}
	export interface getQualityFormVersionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getQualityFormsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"nextPage"?: string;
		"previousPage"?: string;
		"expand"?: string;
		"name"?: string;
		"sortOrder"?: string;
	}
	export interface getQualityFormsEvaluationVersionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getQualityFormsEvaluationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"nextPage"?: string;
		"previousPage"?: string;
		"expand"?: string;
		"name"?: string;
		"sortOrder"?: string;
	}
	export interface getQualityFormsSurveyVersionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getQualityFormsSurveysOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"nextPage"?: string;
		"previousPage"?: string;
		"expand"?: string;
		"name"?: string;
		"sortOrder"?: string;
	}
	export interface getQualityFormsSurveysBulkContextsOptions { 
		"published"?: boolean;
	}
	export interface getQualityPublishedformsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"onlyLatestPerContext"?: boolean;
	}
	export interface getQualityPublishedformsEvaluationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"onlyLatestPerContext"?: boolean;
	}
	export interface getQualityPublishedformsSurveysOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"onlyLatestEnabledPerContext"?: boolean;
	}
	export interface postQualityCalibrationsOptions { 
		"expand"?: string;
	}
	export interface postQualityConversationEvaluationsOptions { 
		"expand"?: string;
	}
	export interface putQualityConversationEvaluationOptions { 
		"expand"?: string;
	}
}

declare class RecordingApi {  
  	deleteConversationRecordingAnnotation(conversationId: string, recordingId: string, annotationId: string): Promise<void>; 
  	deleteOrphanrecording(orphanId: string): Promise<Models.OrphanRecording>; 
  	deleteRecordingCrossplatformMediaretentionpolicies(ids: string): Promise<void>; 
  	deleteRecordingCrossplatformMediaretentionpolicy(policyId: string): Promise<void>; 
  	deleteRecordingJob(jobId: string): Promise<void>; 
  	deleteRecordingMediaretentionpolicies(ids: string): Promise<void>; 
  	deleteRecordingMediaretentionpolicy(policyId: string): Promise<void>; 
  	getConversationRecording(conversationId: string, recordingId: string, opts?: RecordingApi.getConversationRecordingOptions): Promise<Models.Recording>; 
  	getConversationRecordingAnnotation(conversationId: string, recordingId: string, annotationId: string): Promise<Models.Annotation>; 
  	getConversationRecordingAnnotations(conversationId: string, recordingId: string): Promise<Array<Models.Annotation>>; 
  	getConversationRecordingmetadata(conversationId: string): Promise<Array<Models.RecordingMetadata>>; 
  	getConversationRecordingmetadataRecordingId(conversationId: string, recordingId: string): Promise<Models.RecordingMetadata>; 
  	getConversationRecordings(conversationId: string, opts?: RecordingApi.getConversationRecordingsOptions): Promise<Array<Models.Recording>>; 
  	getOrphanrecording(orphanId: string): Promise<Models.OrphanRecording>; 
  	getOrphanrecordingMedia(orphanId: string, opts?: RecordingApi.getOrphanrecordingMediaOptions): Promise<Models.Recording>; 
  	getOrphanrecordings(opts?: RecordingApi.getOrphanrecordingsOptions): Promise<Models.OrphanRecordingListing>; 
  	getRecordingBatchrequest(jobId: string): Promise<Models.BatchDownloadJobStatusResult>; 
  	getRecordingCrossplatformMediaretentionpolicies(opts?: RecordingApi.getRecordingCrossplatformMediaretentionpoliciesOptions): Promise<Models.PolicyEntityListing>; 
  	getRecordingCrossplatformMediaretentionpolicy(policyId: string): Promise<Models.CrossPlatformPolicy>; 
  	getRecordingJob(jobId: string): Promise<Models.RecordingJob>; 
  	getRecordingJobFailedrecordings(jobId: string, opts?: RecordingApi.getRecordingJobFailedrecordingsOptions): Promise<Models.FailedRecordingEntityListing>; 
  	getRecordingJobs(opts?: RecordingApi.getRecordingJobsOptions): Promise<Models.RecordingJobEntityListing>; 
  	getRecordingKeyconfiguration(keyConfigurationId: string): Promise<Models.RecordingEncryptionConfiguration>; 
  	getRecordingKeyconfigurations(): Promise<Models.RecordingEncryptionConfigurationListing>; 
  	getRecordingMediaretentionpolicies(opts?: RecordingApi.getRecordingMediaretentionpoliciesOptions): Promise<Models.PolicyEntityListing>; 
  	getRecordingMediaretentionpolicy(policyId: string): Promise<Models.Policy>; 
  	getRecordingRecordingkeys(opts?: RecordingApi.getRecordingRecordingkeysOptions): Promise<Models.EncryptionKeyEntityListing>; 
  	getRecordingRecordingkeysRotationschedule(): Promise<Models.KeyRotationSchedule>; 
  	getRecordingSettings(opts?: RecordingApi.getRecordingSettingsOptions): Promise<Models.RecordingSettings>; 
  	getRecordingUploadsReport(reportId: string): Promise<Models.RecordingUploadReport>; 
  	getRecordingsRetentionQuery(retentionThresholdDays: number, opts?: RecordingApi.getRecordingsRetentionQueryOptions): Promise<Models.RecordingRetentionCursorEntityListing>; 
  	getRecordingsScreensessions(opts?: RecordingApi.getRecordingsScreensessionsOptions): Promise<Models.ScreenRecordingSessionListing>; 
  	getRecordingsScreensessionsDetails(): Promise<Models.ScreenRecordingActiveSessions>; 
  	patchRecordingCrossplatformMediaretentionpolicy(policyId: string, body: Models.CrossPlatformPolicyUpdate): Promise<Models.CrossPlatformPolicy>; 
  	patchRecordingMediaretentionpolicy(policyId: string, body: Models.PolicyUpdate): Promise<Models.Policy>; 
  	patchRecordingsScreensession(recordingSessionId: string, opts?: RecordingApi.patchRecordingsScreensessionOptions): Promise<void>; 
  	postConversationRecordingAnnotations(conversationId: string, recordingId: string, body: Models.Annotation): Promise<Models.Annotation>; 
  	postRecordingBatchrequests(body: Models.BatchDownloadJobSubmission): Promise<Models.BatchDownloadJobSubmissionResult>; 
  	postRecordingCrossplatformMediaretentionpolicies(body: Models.CrossPlatformPolicyCreate): Promise<Models.CrossPlatformPolicy>; 
  	postRecordingJobs(body: Models.RecordingJobsQuery): Promise<Models.RecordingJob>; 
  	postRecordingKeyconfigurations(body: Models.RecordingEncryptionConfiguration): Promise<Models.RecordingEncryptionConfiguration>; 
  	postRecordingKeyconfigurationsValidate(body: Models.RecordingEncryptionConfiguration): Promise<Models.RecordingEncryptionConfiguration>; 
  	postRecordingLocalkeys(body: Models.LocalEncryptionKeyRequest): Promise<Models.EncryptionKey>; 
  	postRecordingMediaretentionpolicies(body: Models.PolicyCreate): Promise<Models.Policy>; 
  	postRecordingRecordingkeys(): Promise<Models.EncryptionKey>; 
  	postRecordingUploadsReports(body: Models.RecordingUploadReportRequest): Promise<Models.RecordingUploadReport>; 
  	postRecordingsDeletionprotection(body: Models.ConversationDeletionProtectionQuery): Promise<Array<Models.AddressableEntityRef>>; 
  	postRecordingsScreensessionsAcknowledge(body: Models.AcknowledgeScreenRecordingRequest): Promise<void>; 
  	postRecordingsScreensessionsMetadata(body: Models.ScreenRecordingMetaDataRequest): Promise<void>; 
  	putConversationRecording(conversationId: string, recordingId: string, body: Models.Recording, opts?: RecordingApi.putConversationRecordingOptions): Promise<Models.Recording>; 
  	putConversationRecordingAnnotation(conversationId: string, recordingId: string, annotationId: string, body: Models.Annotation): Promise<Models.Annotation>; 
  	putOrphanrecording(orphanId: string, opts?: RecordingApi.putOrphanrecordingOptions): Promise<Models.Recording>; 
  	putRecordingCrossplatformMediaretentionpolicy(policyId: string, body: Models.CrossPlatformPolicy): Promise<Models.CrossPlatformPolicy>; 
  	putRecordingJob(jobId: string, body: Models.ExecuteRecordingJobsQuery): Promise<Models.RecordingJob>; 
  	putRecordingKeyconfiguration(keyConfigurationId: string, body: Models.RecordingEncryptionConfiguration): Promise<Models.RecordingEncryptionConfiguration>; 
  	putRecordingMediaretentionpolicy(policyId: string, body: Models.Policy): Promise<Models.Policy>; 
  	putRecordingRecordingkeysRotationschedule(body: Models.KeyRotationSchedule): Promise<Models.KeyRotationSchedule>; 
  	putRecordingSettings(body: Models.RecordingSettings): Promise<Models.RecordingSettings>; 
  	putRecordingsDeletionprotection(opts?: RecordingApi.putRecordingsDeletionprotectionOptions): Promise<void>;
}

declare namespace RecordingApi { 
	export interface getConversationRecordingOptions { 
		"formatId"?: string;
		"emailFormatId"?: string;
		"chatFormatId"?: string;
		"messageFormatId"?: string;
		"download"?: boolean;
		"fileName"?: string;
		"locale"?: string;
		"mediaFormats"?: Array<string>;
	}
	export interface getConversationRecordingsOptions { 
		"maxWaitMs"?: number;
		"formatId"?: string;
		"mediaFormats"?: Array<string>;
	}
	export interface getOrphanrecordingMediaOptions { 
		"formatId"?: string;
		"emailFormatId"?: string;
		"chatFormatId"?: string;
		"messageFormatId"?: string;
		"download"?: boolean;
		"fileName"?: string;
		"locale"?: string;
		"mediaFormats"?: Array<string>;
	}
	export interface getOrphanrecordingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"hasConversation"?: boolean;
		"media"?: string;
	}
	export interface getRecordingCrossplatformMediaretentionpoliciesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"summary"?: boolean;
		"hasErrors"?: boolean;
		"deleteDaysThreshold"?: number;
	}
	export interface getRecordingJobFailedrecordingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"includeTotal"?: boolean;
		"cursor"?: string;
	}
	export interface getRecordingJobsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"state"?: string;
		"showOnlyMyJobs"?: boolean;
		"jobType"?: string;
		"includeTotal"?: boolean;
		"cursor"?: string;
	}
	export interface getRecordingMediaretentionpoliciesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"expand"?: Array<string>;
		"nextPage"?: string;
		"previousPage"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"summary"?: boolean;
		"hasErrors"?: boolean;
		"deleteDaysThreshold"?: number;
	}
	export interface getRecordingRecordingkeysOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getRecordingSettingsOptions { 
		"createDefault"?: boolean;
	}
	export interface getRecordingsRetentionQueryOptions { 
		"cursor"?: string;
		"pageSize"?: number;
	}
	export interface getRecordingsScreensessionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface patchRecordingsScreensessionOptions { 
		"body"?: Models.ScreenRecordingSessionRequest;
	}
	export interface putConversationRecordingOptions { 
		"clearExport"?: boolean;
	}
	export interface putOrphanrecordingOptions { 
		"body"?: Models.OrphanUpdateRequest;
	}
	export interface putRecordingsDeletionprotectionOptions { 
		"protect"?: boolean;
		"body"?: Models.ConversationDeletionProtectionQuery;
	}
}

declare class ResponseManagementApi {  
  	deleteResponsemanagementLibrary(libraryId: string): Promise<void>; 
  	deleteResponsemanagementResponse(responseId: string): Promise<void>; 
  	deleteResponsemanagementResponseasset(responseAssetId: string): Promise<void>; 
  	getResponsemanagementLibraries(opts?: ResponseManagementApi.getResponsemanagementLibrariesOptions): Promise<Models.LibraryEntityListing>; 
  	getResponsemanagementLibrary(libraryId: string): Promise<Models.Library>; 
  	getResponsemanagementResponse(responseId: string, opts?: ResponseManagementApi.getResponsemanagementResponseOptions): Promise<Models.Response>; 
  	getResponsemanagementResponseasset(responseAssetId: string): Promise<Models.ResponseAsset>; 
  	getResponsemanagementResponseassetsStatusStatusId(statusId: string): Promise<Models.ResponseAssetStatus>; 
  	getResponsemanagementResponses(libraryId: string, opts?: ResponseManagementApi.getResponsemanagementResponsesOptions): Promise<Models.ResponseEntityListing>; 
  	postResponsemanagementLibraries(body: Models.Library): Promise<Models.Library>; 
  	postResponsemanagementLibrariesBulk(body: Models.LibraryBatchRequest): Promise<Models.LibraryEntityListing>; 
  	postResponsemanagementResponseassetsSearch(body: Models.ResponseAssetSearchRequest, opts?: ResponseManagementApi.postResponsemanagementResponseassetsSearchOptions): Promise<Models.ResponseAssetSearchResults>; 
  	postResponsemanagementResponseassetsUploads(body: Models.CreateResponseAssetRequest): Promise<Models.CreateResponseAssetResponse>; 
  	postResponsemanagementResponses(body: Models.Response, opts?: ResponseManagementApi.postResponsemanagementResponsesOptions): Promise<Models.Response>; 
  	postResponsemanagementResponsesQuery(body: Models.ResponseQueryRequest): Promise<Models.ResponseQueryResults>; 
  	putResponsemanagementLibrary(libraryId: string, body: Models.Library): Promise<Models.Library>; 
  	putResponsemanagementResponse(responseId: string, body: Models.Response, opts?: ResponseManagementApi.putResponsemanagementResponseOptions): Promise<Models.Response>; 
  	putResponsemanagementResponseasset(responseAssetId: string, body: Models.ResponseAssetRequest): Promise<Models.ResponseAsset>;
}

declare namespace ResponseManagementApi { 
	export interface getResponsemanagementLibrariesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"messagingTemplateFilter"?: string;
		"libraryPrefix"?: string;
	}
	export interface getResponsemanagementResponseOptions { 
		"expand"?: string;
	}
	export interface getResponsemanagementResponsesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"expand"?: string;
	}
	export interface postResponsemanagementResponseassetsSearchOptions { 
		"expand"?: Array<string>;
	}
	export interface postResponsemanagementResponsesOptions { 
		"expand"?: string;
	}
	export interface putResponsemanagementResponseOptions { 
		"expand"?: string;
	}
}

declare class RoutingApi {  
  	deleteRoutingAssessment(assessmentId: string): Promise<void>; 
  	deleteRoutingEmailDomain(domainId: string): Promise<void>; 
  	deleteRoutingEmailDomainRoute(domainName: string, routeId: string): Promise<void>; 
  	deleteRoutingEmailOutboundDomain(domainId: string): Promise<void>; 
  	deleteRoutingLanguage(languageId: string): Promise<void>; 
  	deleteRoutingPredictor(predictorId: string): Promise<void>; 
  	deleteRoutingQueue(queueId: string, opts?: RoutingApi.deleteRoutingQueueOptions): Promise<void>; 
  	deleteRoutingQueueMember(queueId: string, memberId: string): Promise<void>; 
  	deleteRoutingQueueUser(queueId: string, memberId: string): Promise<void>; 
  	deleteRoutingQueueWrapupcode(queueId: string, codeId: string): Promise<void>; 
  	deleteRoutingSettings(): Promise<void>; 
  	deleteRoutingSkill(skillId: string): Promise<void>; 
  	deleteRoutingSkillgroup(skillGroupId: string): Promise<void>; 
  	deleteRoutingSmsAddress(addressId: string): Promise<void>; 
  	deleteRoutingSmsPhonenumber(addressId: string): Promise<void>; 
  	deleteRoutingUserUtilization(userId: string): Promise<void>; 
  	deleteRoutingUtilization(): Promise<void>; 
  	deleteRoutingUtilizationLabel(labelId: string, opts?: RoutingApi.deleteRoutingUtilizationLabelOptions): Promise<void>; 
  	deleteRoutingUtilizationTag(tagId: string, opts?: RoutingApi.deleteRoutingUtilizationTagOptions): Promise<void>; 
  	deleteRoutingWrapupcode(codeId: string): Promise<void>; 
  	deleteUserRoutinglanguage(userId: string, languageId: string): Promise<void>; 
  	deleteUserRoutingskill(userId: string, skillId: string): Promise<void>; 
  	getRoutingAssessment(assessmentId: string): Promise<Models.BenefitAssessment>; 
  	getRoutingAssessments(opts?: RoutingApi.getRoutingAssessmentsOptions): Promise<Models.AssessmentListing>; 
  	getRoutingAssessmentsJob(jobId: string): Promise<Models.BenefitAssessmentJob>; 
  	getRoutingAssessmentsJobs(opts?: RoutingApi.getRoutingAssessmentsJobsOptions): Promise<Models.AssessmentJobListing>; 
  	getRoutingAvailablemediatypes(): Promise<Models.AvailableMediaTypeEntityListing>; 
  	getRoutingEmailDomain(domainId: string): Promise<Models.InboundDomain>; 
  	getRoutingEmailDomainRoute(domainName: string, routeId: string): Promise<Models.InboundRoute>; 
  	getRoutingEmailDomainRoutes(domainName: string, opts?: RoutingApi.getRoutingEmailDomainRoutesOptions): Promise<Models.InboundRouteEntityListing>; 
  	getRoutingEmailDomains(opts?: RoutingApi.getRoutingEmailDomainsOptions): Promise<Models.InboundDomainEntityListing>; 
  	getRoutingEmailOutboundDomain(domainId: string): Promise<Models.OutboundDomain>; 
  	getRoutingEmailOutboundDomainActivation(domainId: string): Promise<Models.EmailOutboundDomainResult>; 
  	getRoutingEmailOutboundDomainSearch(domainId: string): Promise<Models.OutboundDomain>; 
  	getRoutingEmailOutboundDomains(opts?: RoutingApi.getRoutingEmailOutboundDomainsOptions): Promise<Models.OutboundDomainEntityListing>; 
  	getRoutingEmailSetup(): Promise<Models.EmailSetup>; 
  	getRoutingLanguage(languageId: string): Promise<Models.Language>; 
  	getRoutingLanguages(opts?: RoutingApi.getRoutingLanguagesOptions): Promise<Models.LanguageEntityListing>; 
  	getRoutingMessageRecipient(recipientId: string): Promise<Models.Recipient>; 
  	getRoutingMessageRecipients(opts?: RoutingApi.getRoutingMessageRecipientsOptions): Promise<Models.RecipientListing>; 
  	getRoutingPredictor(predictorId: string): Promise<Models.Predictor>; 
  	getRoutingPredictorModelFeatures(predictorId: string, modelId: string): Promise<Models.PredictorModelFeatureListing>; 
  	getRoutingPredictorModels(predictorId: string): Promise<Models.PredictorModels>; 
  	getRoutingPredictors(opts?: RoutingApi.getRoutingPredictorsOptions): Promise<Models.PredictorListing>; 
  	getRoutingPredictorsKeyperformanceindicators(opts?: RoutingApi.getRoutingPredictorsKeyperformanceindicatorsOptions): Promise<Array<Models.KeyPerformanceIndicator>>; 
  	getRoutingQueue(queueId: string): Promise<Models.Queue>; 
  	getRoutingQueueComparisonperiod(queueId: string, comparisonPeriodId: string): Promise<Models.ComparisonPeriod>; 
  	getRoutingQueueComparisonperiods(queueId: string): Promise<Models.ComparisonPeriodListing>; 
  	getRoutingQueueEstimatedwaittime(queueId: string, opts?: RoutingApi.getRoutingQueueEstimatedwaittimeOptions): Promise<Models.EstimatedWaitTimePredictions>; 
  	getRoutingQueueMediatypeEstimatedwaittime(queueId: string, mediaType: string): Promise<Models.EstimatedWaitTimePredictions>; 
  	getRoutingQueueMembers(queueId: string, opts?: RoutingApi.getRoutingQueueMembersOptions): Promise<Models.QueueMemberEntityListing>; 
  	getRoutingQueueUsers(queueId: string, opts?: RoutingApi.getRoutingQueueUsersOptions): Promise<Models.QueueMemberEntityListingV1>; 
  	getRoutingQueueWrapupcodes(queueId: string, opts?: RoutingApi.getRoutingQueueWrapupcodesOptions): Promise<Models.WrapupCodeEntityListing>; 
  	getRoutingQueues(opts?: RoutingApi.getRoutingQueuesOptions): Promise<Models.QueueEntityListing>; 
  	getRoutingQueuesDivisionviews(opts?: RoutingApi.getRoutingQueuesDivisionviewsOptions): Promise<Models.QueueEntityListing>; 
  	getRoutingQueuesDivisionviewsAll(opts?: RoutingApi.getRoutingQueuesDivisionviewsAllOptions): Promise<Models.QueueEntityListing>; 
  	getRoutingQueuesMe(opts?: RoutingApi.getRoutingQueuesMeOptions): Promise<Models.UserQueueEntityListing>; 
  	getRoutingSettings(): Promise<Models.RoutingSettings>; 
  	getRoutingSettingsContactcenter(): Promise<Models.ContactCenterSettings>; 
  	getRoutingSettingsTranscription(): Promise<Models.TranscriptionSettings>; 
  	getRoutingSkill(skillId: string): Promise<Models.RoutingSkill>; 
  	getRoutingSkillgroup(skillGroupId: string): Promise<Models.SkillGroup>; 
  	getRoutingSkillgroupMembers(skillGroupId: string, opts?: RoutingApi.getRoutingSkillgroupMembersOptions): Promise<Models.SkillGroupMemberEntityListing>; 
  	getRoutingSkillgroupMembersDivisions(skillGroupId: string, opts?: RoutingApi.getRoutingSkillgroupMembersDivisionsOptions): Promise<Models.SkillGroupMemberDivisionList>; 
  	getRoutingSkillgroups(opts?: RoutingApi.getRoutingSkillgroupsOptions): Promise<Models.SkillGroupEntityListing>; 
  	getRoutingSkills(opts?: RoutingApi.getRoutingSkillsOptions): Promise<Models.SkillEntityListing>; 
  	getRoutingSmsAddress(addressId: string): Promise<Models.SmsAddress>; 
  	getRoutingSmsAddresses(opts?: RoutingApi.getRoutingSmsAddressesOptions): Promise<Models.SmsAddressEntityListing>; 
  	getRoutingSmsAvailablephonenumbers(countryCode: string, phoneNumberType: string, opts?: RoutingApi.getRoutingSmsAvailablephonenumbersOptions): Promise<Models.SMSAvailablePhoneNumberEntityListing>; 
  	getRoutingSmsPhonenumber(addressId: string, opts?: RoutingApi.getRoutingSmsPhonenumberOptions): Promise<Models.SmsPhoneNumber>; 
  	getRoutingSmsPhonenumbers(opts?: RoutingApi.getRoutingSmsPhonenumbersOptions): Promise<Models.SmsPhoneNumberEntityListing>; 
  	getRoutingUserUtilization(userId: string): Promise<Models.AgentMaxUtilizationResponse>; 
  	getRoutingUtilization(): Promise<Models.UtilizationResponse>; 
  	getRoutingUtilizationLabel(labelId: string): Promise<Models.UtilizationLabel>; 
  	getRoutingUtilizationLabelAgents(labelId: string): Promise<Array<object>>; 
  	getRoutingUtilizationLabels(opts?: RoutingApi.getRoutingUtilizationLabelsOptions): Promise<Models.UtilizationLabelEntityListing>; 
  	getRoutingUtilizationTag(tagId: string): Promise<Models.UtilizationTag>; 
  	getRoutingUtilizationTagAgents(tagId: string): Promise<Array<object>>; 
  	getRoutingUtilizationTags(opts?: RoutingApi.getRoutingUtilizationTagsOptions): Promise<Models.UtilizationTagEntityListing>; 
  	getRoutingWrapupcode(codeId: string): Promise<Models.WrapupCode>; 
  	getRoutingWrapupcodes(opts?: RoutingApi.getRoutingWrapupcodesOptions): Promise<Models.WrapupCodeEntityListing>; 
  	getRoutingWrapupcodesDivisionview(codeId: string): Promise<Models.WrapupCode>; 
  	getRoutingWrapupcodesDivisionviews(opts?: RoutingApi.getRoutingWrapupcodesDivisionviewsOptions): Promise<Models.WrapupCodeEntityListing>; 
  	getUserQueues(userId: string, opts?: RoutingApi.getUserQueuesOptions): Promise<Models.UserQueueEntityListing>; 
  	getUserRoutinglanguages(userId: string, opts?: RoutingApi.getUserRoutinglanguagesOptions): Promise<Models.UserLanguageEntityListing>; 
  	getUserRoutingskills(userId: string, opts?: RoutingApi.getUserRoutingskillsOptions): Promise<Models.UserSkillEntityListing>; 
  	getUserSkillgroups(userId: string, opts?: RoutingApi.getUserSkillgroupsOptions): Promise<Models.UserSkillGroupEntityListing>; 
  	patchRoutingConversation(conversationId: string, body: Models.RoutingConversationAttributesRequest): Promise<Models.RoutingConversationAttributesResponse>; 
  	patchRoutingEmailDomain(domainId: string, body: Models.InboundDomainPatchRequest): Promise<Models.InboundDomain>; 
  	patchRoutingEmailDomainValidate(domainId: string, body: Models.InboundDomainPatchRequest): Promise<Models.InboundDomain>; 
  	patchRoutingPredictor(predictorId: string, opts?: RoutingApi.patchRoutingPredictorOptions): Promise<Models.Predictor>; 
  	patchRoutingQueueMember(queueId: string, memberId: string, body: Models.QueueMember): Promise<void>; 
  	patchRoutingQueueMembers(queueId: string, body: Array<Models.QueueMember>): Promise<Models.QueueMemberEntityListing>; 
  	patchRoutingQueueUser(queueId: string, memberId: string, body: Models.QueueMember): Promise<void>; 
  	patchRoutingQueueUsers(queueId: string, body: Array<Models.QueueMember>): Promise<Models.QueueMemberEntityListingV1>; 
  	patchRoutingSettingsContactcenter(body: Models.ContactCenterSettings): Promise<void>; 
  	patchRoutingSettingsTranscription(body: Models.TranscriptionSettings): Promise<Models.TranscriptionSettings>; 
  	patchRoutingSkillgroup(skillGroupId: string, body: Models.SkillGroup): Promise<Models.SkillGroup>; 
  	patchUserQueue(queueId: string, userId: string, body: Models.UserQueue): Promise<Models.UserQueue>; 
  	patchUserQueues(userId: string, body: Array<Models.UserQueue>, opts?: RoutingApi.patchUserQueuesOptions): Promise<Models.UserQueueEntityListing>; 
  	patchUserRoutinglanguage(userId: string, languageId: string, body: Models.UserRoutingLanguage): Promise<Models.UserRoutingLanguage>; 
  	patchUserRoutinglanguagesBulk(userId: string, body: Array<Models.UserRoutingLanguagePost>): Promise<Models.UserLanguageEntityListing>; 
  	patchUserRoutingskillsBulk(userId: string, body: Array<Models.UserRoutingSkillPost>): Promise<Models.UserSkillEntityListing>; 
  	postAnalyticsQueuesObservationsQuery(body: Models.QueueObservationQuery): Promise<Models.QueueObservationQueryResponse>; 
  	postAnalyticsRoutingActivityQuery(body: Models.RoutingActivityQuery, opts?: RoutingApi.postAnalyticsRoutingActivityQueryOptions): Promise<Models.RoutingActivityResponse>; 
  	postRoutingAssessments(opts?: RoutingApi.postRoutingAssessmentsOptions): Promise<Models.BenefitAssessment>; 
  	postRoutingAssessmentsJobs(opts?: RoutingApi.postRoutingAssessmentsJobsOptions): Promise<Models.BenefitAssessmentJob>; 
  	postRoutingEmailDomainRoutes(domainName: string, body: Models.InboundRoute): Promise<Models.InboundRoute>; 
  	postRoutingEmailDomainTestconnection(domainId: string, opts?: RoutingApi.postRoutingEmailDomainTestconnectionOptions): Promise<Models.TestMessage>; 
  	postRoutingEmailDomains(body: Models.InboundDomain): Promise<Models.InboundDomain>; 
  	postRoutingEmailOutboundDomains(body: Models.OutboundDomain): Promise<Models.EmailOutboundDomainResult>; 
  	postRoutingEmailOutboundDomainsSimulated(body: Models.OutboundDomain): Promise<Models.EmailOutboundDomainResult>; 
  	postRoutingLanguages(body: Models.Language): Promise<Models.Language>; 
  	postRoutingPredictors(opts?: RoutingApi.postRoutingPredictorsOptions): Promise<Models.Predictor>; 
  	postRoutingQueueMembers(queueId: string, body: Array<Models.WritableEntity>, opts?: RoutingApi.postRoutingQueueMembersOptions): Promise<void>; 
  	postRoutingQueueUsers(queueId: string, body: Array<Models.WritableEntity>, opts?: RoutingApi.postRoutingQueueUsersOptions): Promise<void>; 
  	postRoutingQueueWrapupcodes(queueId: string, body: Array<Models.WrapUpCodeReference>): Promise<Array<Models.WrapupCode>>; 
  	postRoutingQueues(body: Models.CreateQueueRequest): Promise<Models.Queue>; 
  	postRoutingSkillgroupMembersDivisions(skillGroupId: string, opts?: RoutingApi.postRoutingSkillgroupMembersDivisionsOptions): Promise<void>; 
  	postRoutingSkillgroups(body: Models.SkillGroupWithMemberDivisions): Promise<Models.SkillGroupWithMemberDivisions>; 
  	postRoutingSkills(body: Models.RoutingSkill): Promise<Models.RoutingSkill>; 
  	postRoutingSmsAddresses(body: Models.SmsAddressProvision): Promise<Models.SmsAddress>; 
  	postRoutingSmsPhonenumbers(body: Models.SmsPhoneNumberProvision): Promise<Models.SmsPhoneNumber>; 
  	postRoutingSmsPhonenumbersAlphanumeric(body: Models.SmsAlphanumericProvision): Promise<Models.SmsPhoneNumber>; 
  	postRoutingSmsPhonenumbersImport(body: Models.SmsPhoneNumberImport): Promise<Models.SmsPhoneNumber>; 
  	postRoutingUtilizationLabels(body: Models.CreateUtilizationLabelRequest): Promise<Models.UtilizationLabel>; 
  	postRoutingUtilizationTags(body: Models.CreateUtilizationTagRequest): Promise<Models.UtilizationTag>; 
  	postRoutingWrapupcodes(body: Models.WrapupCodeRequest): Promise<Models.WrapupCode>; 
  	postUserRoutinglanguages(userId: string, body: Models.UserRoutingLanguagePost): Promise<Models.UserRoutingLanguage>; 
  	postUserRoutingskills(userId: string, body: Models.UserRoutingSkillPost): Promise<Models.UserRoutingSkill>; 
  	putRoutingEmailDomainRoute(domainName: string, routeId: string, body: Models.InboundRoute): Promise<Models.InboundRoute>; 
  	putRoutingEmailOutboundDomainActivation(domainId: string): Promise<Models.EmailOutboundDomainResult>; 
  	putRoutingMessageRecipient(recipientId: string, body: Models.RecipientRequest): Promise<Models.Recipient>; 
  	putRoutingQueue(queueId: string, body: Models.QueueRequest): Promise<Models.Queue>; 
  	putRoutingSettings(body: Models.RoutingSettings): Promise<Models.RoutingSettings>; 
  	putRoutingSettingsTranscription(body: Models.TranscriptionSettings): Promise<Models.TranscriptionSettings>; 
  	putRoutingSmsPhonenumber(addressId: string, body: Models.SmsPhoneNumber): Promise<Models.SmsPhoneNumber>; 
  	putRoutingUserUtilization(userId: string, body: Models.UtilizationRequest): Promise<Models.AgentMaxUtilizationResponse>; 
  	putRoutingUtilization(body: Models.UtilizationRequest): Promise<Models.UtilizationResponse>; 
  	putRoutingUtilizationLabel(labelId: string, body: Models.UpdateUtilizationLabelRequest): Promise<Models.UtilizationLabel>; 
  	putRoutingWrapupcode(codeId: string, body: Models.WrapupCodeRequest): Promise<Models.WrapupCode>; 
  	putUserRoutingskill(userId: string, skillId: string, body: Models.UserRoutingSkill): Promise<Models.UserRoutingSkill>; 
  	putUserRoutingskillsBulk(userId: string, body: Array<Models.UserRoutingSkillPost>): Promise<Models.UserSkillEntityListing>;
}

declare namespace RoutingApi { 
	export interface deleteRoutingQueueOptions { 
		"forceDelete"?: boolean;
	}
	export interface deleteRoutingUtilizationLabelOptions { 
		"forceDelete"?: boolean;
	}
	export interface deleteRoutingUtilizationTagOptions { 
		"forceDelete"?: boolean;
	}
	export interface getRoutingAssessmentsOptions { 
		"before"?: string;
		"after"?: string;
		"limit"?: string;
		"pageSize"?: string;
		"queueId"?: Array<string>;
	}
	export interface getRoutingAssessmentsJobsOptions { 
		"divisionId"?: Array<string>;
	}
	export interface getRoutingEmailDomainRoutesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"pattern"?: string;
	}
	export interface getRoutingEmailDomainsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"excludeStatus"?: boolean;
		"filter"?: string;
	}
	export interface getRoutingEmailOutboundDomainsOptions { 
		"filter"?: string;
	}
	export interface getRoutingLanguagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"name"?: string;
		"id"?: Array<string>;
	}
	export interface getRoutingMessageRecipientsOptions { 
		"messengerType"?: string;
		"name"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getRoutingPredictorsOptions { 
		"before"?: string;
		"after"?: string;
		"limit"?: string;
		"pageSize"?: string;
		"queueId"?: Array<string>;
	}
	export interface getRoutingPredictorsKeyperformanceindicatorsOptions { 
		"kpiGroup"?: string;
		"expand"?: Array<string>;
	}
	export interface getRoutingQueueEstimatedwaittimeOptions { 
		"conversationId"?: string;
	}
	export interface getRoutingQueueMembersOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortOrder"?: string;
		"expand"?: Array<string>;
		"name"?: string;
		"profileSkills"?: Array<string>;
		"skills"?: Array<string>;
		"languages"?: Array<string>;
		"routingStatus"?: Array<string>;
		"presence"?: Array<string>;
		"memberBy"?: string;
		"joined"?: boolean;
	}
	export interface getRoutingQueueUsersOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortOrder"?: string;
		"expand"?: Array<string>;
		"joined"?: boolean;
		"name"?: string;
		"profileSkills"?: Array<string>;
		"skills"?: Array<string>;
		"languages"?: Array<string>;
		"routingStatus"?: Array<string>;
		"presence"?: Array<string>;
	}
	export interface getRoutingQueueWrapupcodesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getRoutingQueuesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortOrder"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"divisionId"?: Array<string>;
		"peerId"?: Array<string>;
		"cannedResponseLibraryId"?: string;
		"hasPeer"?: boolean;
	}
	export interface getRoutingQueuesDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"divisionId"?: Array<string>;
	}
	export interface getRoutingQueuesDivisionviewsAllOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getRoutingQueuesMeOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"joined"?: boolean;
		"sortOrder"?: string;
	}
	export interface getRoutingSkillgroupMembersOptions { 
		"pageSize"?: number;
		"after"?: string;
		"before"?: string;
		"expand"?: string;
	}
	export interface getRoutingSkillgroupMembersDivisionsOptions { 
		"expand"?: string;
	}
	export interface getRoutingSkillgroupsOptions { 
		"pageSize"?: number;
		"name"?: string;
		"after"?: string;
		"before"?: string;
	}
	export interface getRoutingSkillsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"id"?: Array<string>;
	}
	export interface getRoutingSmsAddressesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getRoutingSmsAvailablephonenumbersOptions { 
		"region"?: string;
		"city"?: string;
		"areaCode"?: string;
		"pattern"?: string;
		"addressRequirement"?: string;
	}
	export interface getRoutingSmsPhonenumberOptions { 
		"expand"?: string;
	}
	export interface getRoutingSmsPhonenumbersOptions { 
		"phoneNumber"?: string;
		"phoneNumberType"?: Array<string>;
		"phoneNumberStatus"?: Array<string>;
		"countryCode"?: Array<string>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"language"?: string;
		"integrationId"?: string;
	}
	export interface getRoutingUtilizationLabelsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"name"?: string;
	}
	export interface getRoutingUtilizationTagsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"name"?: string;
	}
	export interface getRoutingWrapupcodesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"id"?: Array<string>;
		"divisionId"?: Array<string>;
	}
	export interface getRoutingWrapupcodesDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"id"?: Array<string>;
		"divisionId"?: Array<string>;
		"includeState"?: string;
	}
	export interface getUserQueuesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"joined"?: boolean;
		"divisionId"?: Array<string>;
	}
	export interface getUserRoutinglanguagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getUserRoutingskillsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getUserSkillgroupsOptions { 
		"pageSize"?: number;
		"after"?: string;
		"before"?: string;
	}
	export interface patchRoutingPredictorOptions { 
		"body"?: Models.PatchPredictorRequest;
	}
	export interface patchUserQueuesOptions { 
		"divisionId"?: Array<string>;
	}
	export interface postAnalyticsRoutingActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postRoutingAssessmentsOptions { 
		"body"?: Models.CreateBenefitAssessmentRequest;
	}
	export interface postRoutingAssessmentsJobsOptions { 
		"body"?: Models.CreateBenefitAssessmentJobRequest;
	}
	export interface postRoutingEmailDomainTestconnectionOptions { 
		"body"?: Models.TestMessage;
	}
	export interface postRoutingPredictorsOptions { 
		"body"?: Models.CreatePredictorRequest;
	}
	export interface postRoutingQueueMembersOptions { 
		"_delete"?: boolean;
	}
	export interface postRoutingQueueUsersOptions { 
		"_delete"?: boolean;
	}
	export interface postRoutingSkillgroupMembersDivisionsOptions { 
		"body"?: Models.SkillGroupMemberDivisions;
	}
}

declare class SCIMApi {  
  	deleteScimUser(userId: string, opts?: SCIMApi.deleteScimUserOptions): Promise<object>; 
  	deleteScimV2User(userId: string, opts?: SCIMApi.deleteScimV2UserOptions): Promise<object>; 
  	getScimGroup(groupId: string, opts?: SCIMApi.getScimGroupOptions): Promise<Models.ScimV2Group>; 
  	getScimGroups(opts?: SCIMApi.getScimGroupsOptions): Promise<Models.ScimGroupListResponse>; 
  	getScimResourcetype(resourceType: string): Promise<Models.ScimConfigResourceType>; 
  	getScimResourcetypes(): Promise<Models.ScimConfigResourceTypesListResponse>; 
  	getScimSchema(schemaId: string): Promise<Models.ScimV2SchemaDefinition>; 
  	getScimSchemas(opts?: SCIMApi.getScimSchemasOptions): Promise<Models.ScimV2SchemaListResponse>; 
  	getScimServiceproviderconfig(opts?: SCIMApi.getScimServiceproviderconfigOptions): Promise<Models.ScimServiceProviderConfig>; 
  	getScimUser(userId: string, opts?: SCIMApi.getScimUserOptions): Promise<Models.ScimV2User>; 
  	getScimUsers(opts?: SCIMApi.getScimUsersOptions): Promise<Models.ScimUserListResponse>; 
  	getScimV2Group(groupId: string, opts?: SCIMApi.getScimV2GroupOptions): Promise<Models.ScimV2Group>; 
  	getScimV2Groups(filter: string, opts?: SCIMApi.getScimV2GroupsOptions): Promise<Models.ScimGroupListResponse>; 
  	getScimV2Resourcetype(resourceType: string): Promise<Models.ScimConfigResourceType>; 
  	getScimV2Resourcetypes(): Promise<Models.ScimConfigResourceTypesListResponse>; 
  	getScimV2Schema(schemaId: string): Promise<Models.ScimV2SchemaDefinition>; 
  	getScimV2Schemas(opts?: SCIMApi.getScimV2SchemasOptions): Promise<Models.ScimV2SchemaListResponse>; 
  	getScimV2Serviceproviderconfig(opts?: SCIMApi.getScimV2ServiceproviderconfigOptions): Promise<Models.ScimServiceProviderConfig>; 
  	getScimV2User(userId: string, opts?: SCIMApi.getScimV2UserOptions): Promise<Models.ScimV2User>; 
  	getScimV2Users(opts?: SCIMApi.getScimV2UsersOptions): Promise<Models.ScimUserListResponse>; 
  	patchScimGroup(groupId: string, body: Models.ScimV2PatchRequest, opts?: SCIMApi.patchScimGroupOptions): Promise<Models.ScimV2Group>; 
  	patchScimUser(userId: string, body: Models.ScimV2PatchRequest, opts?: SCIMApi.patchScimUserOptions): Promise<Models.ScimV2User>; 
  	patchScimV2Group(groupId: string, body: Models.ScimV2PatchRequest, opts?: SCIMApi.patchScimV2GroupOptions): Promise<Models.ScimV2Group>; 
  	patchScimV2User(userId: string, body: Models.ScimV2PatchRequest, opts?: SCIMApi.patchScimV2UserOptions): Promise<Models.ScimV2User>; 
  	postScimUsers(body: Models.ScimV2CreateUser): Promise<Models.ScimV2User>; 
  	postScimV2Users(body: Models.ScimV2CreateUser): Promise<Models.ScimV2User>; 
  	putScimGroup(groupId: string, body: Models.ScimV2Group, opts?: SCIMApi.putScimGroupOptions): Promise<Models.ScimV2Group>; 
  	putScimUser(userId: string, body: Models.ScimV2User, opts?: SCIMApi.putScimUserOptions): Promise<Models.ScimV2User>; 
  	putScimV2Group(groupId: string, body: Models.ScimV2Group, opts?: SCIMApi.putScimV2GroupOptions): Promise<Models.ScimV2Group>; 
  	putScimV2User(userId: string, body: Models.ScimV2User, opts?: SCIMApi.putScimV2UserOptions): Promise<Models.ScimV2User>;
}

declare namespace SCIMApi { 
	export interface deleteScimUserOptions { 
		"ifMatch"?: string;
	}
	export interface deleteScimV2UserOptions { 
		"ifMatch"?: string;
	}
	export interface getScimGroupOptions { 
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"ifNoneMatch"?: string;
	}
	export interface getScimGroupsOptions { 
		"startIndex"?: number;
		"count"?: number;
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"filter"?: string;
	}
	export interface getScimSchemasOptions { 
		"filter"?: string;
	}
	export interface getScimServiceproviderconfigOptions { 
		"ifNoneMatch"?: string;
	}
	export interface getScimUserOptions { 
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"ifNoneMatch"?: string;
	}
	export interface getScimUsersOptions { 
		"startIndex"?: number;
		"count"?: number;
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"filter"?: string;
	}
	export interface getScimV2GroupOptions { 
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"ifNoneMatch"?: string;
	}
	export interface getScimV2GroupsOptions { 
		"startIndex"?: number;
		"count"?: number;
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
	}
	export interface getScimV2SchemasOptions { 
		"filter"?: string;
	}
	export interface getScimV2ServiceproviderconfigOptions { 
		"ifNoneMatch"?: string;
	}
	export interface getScimV2UserOptions { 
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"ifNoneMatch"?: string;
	}
	export interface getScimV2UsersOptions { 
		"startIndex"?: number;
		"count"?: number;
		"attributes"?: Array<string>;
		"excludedAttributes"?: Array<string>;
		"filter"?: string;
	}
	export interface patchScimGroupOptions { 
		"ifMatch"?: string;
	}
	export interface patchScimUserOptions { 
		"ifMatch"?: string;
	}
	export interface patchScimV2GroupOptions { 
		"ifMatch"?: string;
	}
	export interface patchScimV2UserOptions { 
		"ifMatch"?: string;
	}
	export interface putScimGroupOptions { 
		"ifMatch"?: string;
	}
	export interface putScimUserOptions { 
		"ifMatch"?: string;
	}
	export interface putScimV2GroupOptions { 
		"ifMatch"?: string;
	}
	export interface putScimV2UserOptions { 
		"ifMatch"?: string;
	}
}

declare class ScreenRecordingApi {  
  	postScreenrecordingToken(opts?: ScreenRecordingApi.postScreenrecordingTokenOptions): Promise<Models.SignedData>;
}

declare namespace ScreenRecordingApi { 
	export interface postScreenrecordingTokenOptions { 
		"body"?: Models.ScreenRecordingUserAuthenticatedInfo;
	}
}

declare class ScriptsApi {  
  	getScript(scriptId: string): Promise<Models.Script>; 
  	getScriptPage(scriptId: string, pageId: string, opts?: ScriptsApi.getScriptPageOptions): Promise<Models.Page>; 
  	getScriptPages(scriptId: string, opts?: ScriptsApi.getScriptPagesOptions): Promise<Array<Models.Page>>; 
  	getScripts(opts?: ScriptsApi.getScriptsOptions): Promise<Models.ScriptEntityListing>; 
  	getScriptsDivisionviews(opts?: ScriptsApi.getScriptsDivisionviewsOptions): Promise<Models.ScriptEntityListing>; 
  	getScriptsPublished(opts?: ScriptsApi.getScriptsPublishedOptions): Promise<Models.ScriptEntityListing>; 
  	getScriptsPublishedDivisionviews(opts?: ScriptsApi.getScriptsPublishedDivisionviewsOptions): Promise<Models.ScriptEntityListing>; 
  	getScriptsPublishedScriptId(scriptId: string, opts?: ScriptsApi.getScriptsPublishedScriptIdOptions): Promise<Models.Script>; 
  	getScriptsPublishedScriptIdPage(scriptId: string, pageId: string, opts?: ScriptsApi.getScriptsPublishedScriptIdPageOptions): Promise<Models.Page>; 
  	getScriptsPublishedScriptIdPages(scriptId: string, opts?: ScriptsApi.getScriptsPublishedScriptIdPagesOptions): Promise<Array<Models.Page>>; 
  	getScriptsPublishedScriptIdVariables(scriptId: string, opts?: ScriptsApi.getScriptsPublishedScriptIdVariablesOptions): Promise<object>; 
  	getScriptsUploadStatus(uploadId: string, opts?: ScriptsApi.getScriptsUploadStatusOptions): Promise<Models.ImportScriptStatusResponse>; 
  	postScriptExport(scriptId: string, opts?: ScriptsApi.postScriptExportOptions): Promise<Models.ExportScriptResponse>; 
  	postScriptsPublished(opts?: ScriptsApi.postScriptsPublishedOptions): Promise<Models.Script>;
}

declare namespace ScriptsApi { 
	export interface getScriptPageOptions { 
		"scriptDataVersion"?: string;
	}
	export interface getScriptPagesOptions { 
		"scriptDataVersion"?: string;
	}
	export interface getScriptsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"name"?: string;
		"feature"?: string;
		"flowId"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"scriptDataVersion"?: string;
		"divisionIds"?: string;
	}
	export interface getScriptsDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"name"?: string;
		"feature"?: string;
		"flowId"?: string;
		"sortBy"?: string;
		"sortOrder"?: string;
		"scriptDataVersion"?: string;
		"divisionIds"?: string;
	}
	export interface getScriptsPublishedOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"name"?: string;
		"feature"?: string;
		"flowId"?: string;
		"scriptDataVersion"?: string;
		"divisionIds"?: string;
	}
	export interface getScriptsPublishedDivisionviewsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"name"?: string;
		"feature"?: string;
		"flowId"?: string;
		"scriptDataVersion"?: string;
		"divisionIds"?: string;
	}
	export interface getScriptsPublishedScriptIdOptions { 
		"scriptDataVersion"?: string;
	}
	export interface getScriptsPublishedScriptIdPageOptions { 
		"scriptDataVersion"?: string;
	}
	export interface getScriptsPublishedScriptIdPagesOptions { 
		"scriptDataVersion"?: string;
	}
	export interface getScriptsPublishedScriptIdVariablesOptions { 
		"input"?: string;
		"output"?: string;
		"type"?: string;
		"scriptDataVersion"?: string;
	}
	export interface getScriptsUploadStatusOptions { 
		"longPoll"?: boolean;
	}
	export interface postScriptExportOptions { 
		"body"?: Models.ExportScriptRequest;
	}
	export interface postScriptsPublishedOptions { 
		"scriptDataVersion"?: string;
		"body"?: Models.PublishScriptRequestData;
	}
}

declare class SearchApi {  
  	getDocumentationGknSearch(q64: string): Promise<Models.GKNDocumentationSearchResponse>; 
  	getDocumentationSearch(q64: string): Promise<Models.DocumentationSearchResponse>; 
  	getGroupsSearch(q64: string, opts?: SearchApi.getGroupsSearchOptions): Promise<Models.GroupsSearchResponse>; 
  	getLocationsSearch(q64: string, opts?: SearchApi.getLocationsSearchOptions): Promise<Models.LocationsSearchResponse>; 
  	getSearch(q64: string, opts?: SearchApi.getSearchOptions): Promise<Models.JsonNodeSearchResponse>; 
  	getSearchSuggest(q64: string, opts?: SearchApi.getSearchSuggestOptions): Promise<Models.JsonNodeSearchResponse>; 
  	getUsersSearch(q64: string, opts?: SearchApi.getUsersSearchOptions): Promise<Models.UsersSearchResponse>; 
  	getVoicemailSearch(q64: string, opts?: SearchApi.getVoicemailSearchOptions): Promise<Models.VoicemailsSearchResponse>; 
  	postAnalyticsConversationsTranscriptsQuery(body: Models.TranscriptConversationDetailSearchRequest): Promise<Models.AnalyticsConversationWithoutAttributesMultiGetResponse>; 
  	postConversationsParticipantsAttributesSearch(body: Models.ConversationParticipantSearchRequest): Promise<Models.JsonCursorSearchResponse>; 
  	postDocumentationAllSearch(body: Models.DocumentationV2SearchRequest): Promise<Models.JsonNodeSearchResponse>; 
  	postDocumentationGknSearch(body: Models.GKNDocumentationSearchRequest): Promise<Models.GKNDocumentationSearchResponse>; 
  	postDocumentationSearch(body: Models.DocumentationSearchRequest): Promise<Models.DocumentationSearchResponse>; 
  	postGroupsSearch(body: Models.GroupSearchRequest): Promise<Models.GroupsSearchResponse>; 
  	postKnowledgeKnowledgebaseSearch(knowledgeBaseId: string, opts?: SearchApi.postKnowledgeKnowledgebaseSearchOptions): Promise<Models.KnowledgeSearchResponse>; 
  	postLocationsSearch(body: Models.LocationSearchRequest): Promise<Models.LocationsSearchResponse>; 
  	postSearch(body: Models.SearchRequest, opts?: SearchApi.postSearchOptions): Promise<Models.JsonNodeSearchResponse>; 
  	postSearchSuggest(body: Models.SuggestSearchRequest, opts?: SearchApi.postSearchSuggestOptions): Promise<Models.JsonNodeSearchResponse>; 
  	postSpeechandtextanalyticsTranscriptsSearch(body: Models.TranscriptSearchRequest): Promise<Models.JsonSearchResponse>; 
  	postTeamsSearch(body: Models.TeamSearchRequest): Promise<Models.TeamsSearchResponse>; 
  	postUsersSearch(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postUsersSearchConversationTarget(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postUsersSearchQueuemembersManage(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postUsersSearchTeamsAssign(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postVoicemailSearch(body: Models.VoicemailSearchRequest): Promise<Models.VoicemailsSearchResponse>;
}

declare namespace SearchApi { 
	export interface getGroupsSearchOptions { 
		"expand"?: Array<string>;
	}
	export interface getLocationsSearchOptions { 
		"expand"?: Array<string>;
	}
	export interface getSearchOptions { 
		"expand"?: Array<string>;
		"profile"?: boolean;
	}
	export interface getSearchSuggestOptions { 
		"expand"?: Array<string>;
		"profile"?: boolean;
	}
	export interface getUsersSearchOptions { 
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
	}
	export interface getVoicemailSearchOptions { 
		"expand"?: Array<string>;
	}
	export interface postKnowledgeKnowledgebaseSearchOptions { 
		"body"?: Models.KnowledgeSearchRequest;
	}
	export interface postSearchOptions { 
		"profile"?: boolean;
	}
	export interface postSearchSuggestOptions { 
		"profile"?: boolean;
	}
}

declare class SettingsApi {  
  	getEmailsSettings(): Promise<Models.EmailSettings>; 
  	getSettingsExecutiondata(): Promise<Models.ExecutionDataGlobalSettingsResponse>; 
  	patchEmailsSettings(opts?: SettingsApi.patchEmailsSettingsOptions): Promise<Models.EmailSettings>; 
  	patchSettingsExecutiondata(body: Models.ExecutionDataSettingsRequest): Promise<Models.ExecutionDataGlobalSettingsResponse>;
}

declare namespace SettingsApi { 
	export interface patchEmailsSettingsOptions { 
		"body"?: Models.EmailSettings;
	}
}

declare class SpeechTextAnalyticsApi {  
  	deleteSpeechandtextanalyticsDictionaryfeedbackDictionaryFeedbackId(dictionaryFeedbackId: string): Promise<void>; 
  	deleteSpeechandtextanalyticsProgram(programId: string, opts?: SpeechTextAnalyticsApi.deleteSpeechandtextanalyticsProgramOptions): Promise<void>; 
  	deleteSpeechandtextanalyticsSentimentfeedback(): Promise<void>; 
  	deleteSpeechandtextanalyticsSentimentfeedbackSentimentFeedbackId(sentimentFeedbackId: string): Promise<void>; 
  	deleteSpeechandtextanalyticsTopic(topicId: string): Promise<void>; 
  	getSpeechandtextanalyticsConversation(conversationId: string): Promise<Models.ConversationMetrics>; 
  	getSpeechandtextanalyticsConversationCommunicationTranscripturl(conversationId: string, communicationId: string): Promise<Models.TranscriptUrl>; 
  	getSpeechandtextanalyticsConversationCommunicationTranscripturls(conversationId: string, communicationId: string): Promise<Models.TranscriptUrls>; 
  	getSpeechandtextanalyticsDictionaryfeedback(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsDictionaryfeedbackOptions): Promise<Models.DictionaryFeedbackEntityListing>; 
  	getSpeechandtextanalyticsDictionaryfeedbackDictionaryFeedbackId(dictionaryFeedbackId: string): Promise<Models.DictionaryFeedback>; 
  	getSpeechandtextanalyticsProgram(programId: string): Promise<Models.Program>; 
  	getSpeechandtextanalyticsProgramMappings(programId: string): Promise<Models.ProgramMappings>; 
  	getSpeechandtextanalyticsProgramTranscriptionengines(programId: string): Promise<Models.ProgramTranscriptionEngines>; 
  	getSpeechandtextanalyticsPrograms(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsProgramsOptions): Promise<Models.ProgramsEntityListing>; 
  	getSpeechandtextanalyticsProgramsGeneralJob(jobId: string): Promise<Models.GeneralProgramJob>; 
  	getSpeechandtextanalyticsProgramsMappings(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsProgramsMappingsOptions): Promise<Models.ProgramsMappingsEntityListing>; 
  	getSpeechandtextanalyticsProgramsPublishjob(jobId: string): Promise<Models.ProgramJob>; 
  	getSpeechandtextanalyticsProgramsTranscriptionenginesDialects(): Promise<Models.SupportedDialectsEntityListing>; 
  	getSpeechandtextanalyticsProgramsUnpublished(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsProgramsUnpublishedOptions): Promise<Models.UnpublishedProgramsEntityListing>; 
  	getSpeechandtextanalyticsSentimentDialects(): Promise<Models.EntityListing>; 
  	getSpeechandtextanalyticsSentimentfeedback(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsSentimentfeedbackOptions): Promise<Models.SentimentFeedbackEntityListing>; 
  	getSpeechandtextanalyticsSettings(): Promise<Models.SpeechTextAnalyticsSettingsResponse>; 
  	getSpeechandtextanalyticsTopic(topicId: string): Promise<Models.Topic>; 
  	getSpeechandtextanalyticsTopics(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsTopicsOptions): Promise<Models.TopicsEntityListing>; 
  	getSpeechandtextanalyticsTopicsDialects(): Promise<Models.EntityListing>; 
  	getSpeechandtextanalyticsTopicsGeneral(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsTopicsGeneralOptions): Promise<Models.GeneralTopicsEntityListing>; 
  	getSpeechandtextanalyticsTopicsGeneralStatus(opts?: SpeechTextAnalyticsApi.getSpeechandtextanalyticsTopicsGeneralStatusOptions): Promise<Models.UnifiedGeneralTopicEntityListing>; 
  	getSpeechandtextanalyticsTopicsPublishjob(jobId: string): Promise<Models.TopicJob>; 
  	patchSpeechandtextanalyticsSettings(body: Models.SpeechTextAnalyticsSettingsRequest): Promise<Models.SpeechTextAnalyticsSettingsResponse>; 
  	postSpeechandtextanalyticsDictionaryfeedback(body: Models.DictionaryFeedback): Promise<Models.DictionaryFeedback>; 
  	postSpeechandtextanalyticsPrograms(body: Models.ProgramRequest): Promise<Models.Program>; 
  	postSpeechandtextanalyticsProgramsGeneralJobs(body: Models.GeneralProgramJobRequest): Promise<Models.GeneralProgramJob>; 
  	postSpeechandtextanalyticsProgramsPublishjobs(body: Models.ProgramJobRequest): Promise<Models.ProgramJob>; 
  	postSpeechandtextanalyticsSentimentfeedback(body: Models.SentimentFeedback): Promise<Models.SentimentFeedback>; 
  	postSpeechandtextanalyticsTopics(body: Models.TopicRequest): Promise<Models.Topic>; 
  	postSpeechandtextanalyticsTopicsPublishjobs(body: Models.TopicJobRequest): Promise<Models.TopicJob>; 
  	postSpeechandtextanalyticsTranscriptsSearch(body: Models.TranscriptSearchRequest): Promise<Models.JsonSearchResponse>; 
  	putSpeechandtextanalyticsDictionaryfeedbackDictionaryFeedbackId(dictionaryFeedbackId: string, opts?: SpeechTextAnalyticsApi.putSpeechandtextanalyticsDictionaryfeedbackDictionaryFeedbackIdOptions): Promise<Models.DictionaryFeedback>; 
  	putSpeechandtextanalyticsProgram(programId: string, body: Models.ProgramRequest): Promise<Models.Program>; 
  	putSpeechandtextanalyticsProgramMappings(programId: string, body: Models.ProgramMappingsRequest): Promise<Models.ProgramMappings>; 
  	putSpeechandtextanalyticsProgramTranscriptionengines(programId: string, body: Models.TranscriptionEnginesRequest): Promise<Models.ProgramTranscriptionEngines>; 
  	putSpeechandtextanalyticsSettings(body: Models.SpeechTextAnalyticsSettingsRequest): Promise<Models.SpeechTextAnalyticsSettingsResponse>; 
  	putSpeechandtextanalyticsTopic(topicId: string, body: Models.TopicRequest): Promise<Models.Topic>;
}

declare namespace SpeechTextAnalyticsApi { 
	export interface deleteSpeechandtextanalyticsProgramOptions { 
		"forceDelete"?: boolean;
	}
	export interface getSpeechandtextanalyticsDictionaryfeedbackOptions { 
		"dialect"?: string;
		"nextPage"?: string;
		"pageSize"?: number;
	}
	export interface getSpeechandtextanalyticsProgramsOptions { 
		"nextPage"?: string;
		"pageSize"?: number;
		"state"?: string;
	}
	export interface getSpeechandtextanalyticsProgramsMappingsOptions { 
		"nextPage"?: string;
		"pageSize"?: number;
	}
	export interface getSpeechandtextanalyticsProgramsUnpublishedOptions { 
		"nextPage"?: string;
		"pageSize"?: number;
	}
	export interface getSpeechandtextanalyticsSentimentfeedbackOptions { 
		"dialect"?: string;
	}
	export interface getSpeechandtextanalyticsTopicsOptions { 
		"nextPage"?: string;
		"pageSize"?: number;
		"state"?: string;
		"name"?: string;
		"ids"?: Array<string>;
		"dialects"?: Array<string>;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	export interface getSpeechandtextanalyticsTopicsGeneralOptions { 
		"dialect"?: string;
	}
	export interface getSpeechandtextanalyticsTopicsGeneralStatusOptions { 
		"dialect"?: string;
	}
	export interface putSpeechandtextanalyticsDictionaryfeedbackDictionaryFeedbackIdOptions { 
		"body"?: Models.DictionaryFeedback;
	}
}

declare class StationsApi {  
  	deleteStationAssociateduser(stationId: string): Promise<void>; 
  	getStation(stationId: string): Promise<Models.Station>; 
  	getStations(opts?: StationsApi.getStationsOptions): Promise<Models.StationEntityListing>;
}

declare namespace StationsApi { 
	export interface getStationsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"name"?: string;
		"userSelectable"?: string;
		"webRtcUserId"?: string;
		"id"?: string;
		"lineAppearanceId"?: string;
	}
}

declare class SuggestApi {  
  	getSearch(q64: string, opts?: SuggestApi.getSearchOptions): Promise<Models.JsonNodeSearchResponse>; 
  	getSearchSuggest(q64: string, opts?: SuggestApi.getSearchSuggestOptions): Promise<Models.JsonNodeSearchResponse>; 
  	postSearch(body: Models.SearchRequest, opts?: SuggestApi.postSearchOptions): Promise<Models.JsonNodeSearchResponse>; 
  	postSearchSuggest(body: Models.SuggestSearchRequest, opts?: SuggestApi.postSearchSuggestOptions): Promise<Models.JsonNodeSearchResponse>;
}

declare namespace SuggestApi { 
	export interface getSearchOptions { 
		"expand"?: Array<string>;
		"profile"?: boolean;
	}
	export interface getSearchSuggestOptions { 
		"expand"?: Array<string>;
		"profile"?: boolean;
	}
	export interface postSearchOptions { 
		"profile"?: boolean;
	}
	export interface postSearchSuggestOptions { 
		"profile"?: boolean;
	}
}

declare class TaskManagementApi {  
  	deleteTaskmanagementWorkbin(workbinId: string): Promise<void>; 
  	deleteTaskmanagementWorkitem(workitemId: string): Promise<void>; 
  	deleteTaskmanagementWorkitemsSchema(schemaId: string): Promise<void>; 
  	deleteTaskmanagementWorktype(worktypeId: string): Promise<void>; 
  	deleteTaskmanagementWorktypeStatus(worktypeId: string, statusId: string): Promise<void>; 
  	getTaskmanagementWorkbin(workbinId: string): Promise<Models.Workbin>; 
  	getTaskmanagementWorkbinHistory(workbinId: string, opts?: TaskManagementApi.getTaskmanagementWorkbinHistoryOptions): Promise<Models.WorkbinChangeListing>; 
  	getTaskmanagementWorkbinVersion(workbinId: string, entityVersion: number): Promise<Models.WorkbinVersion>; 
  	getTaskmanagementWorkbinVersions(workbinId: string, opts?: TaskManagementApi.getTaskmanagementWorkbinVersionsOptions): Promise<Models.WorkbinVersionListing>; 
  	getTaskmanagementWorkitem(workitemId: string, opts?: TaskManagementApi.getTaskmanagementWorkitemOptions): Promise<Models.Workitem>; 
  	getTaskmanagementWorkitemHistory(workitemId: string, opts?: TaskManagementApi.getTaskmanagementWorkitemHistoryOptions): Promise<Models.WorkitemChangeListing>; 
  	getTaskmanagementWorkitemUserWrapups(workitemId: string, userId: string, opts?: TaskManagementApi.getTaskmanagementWorkitemUserWrapupsOptions): Promise<Models.WorkitemWrapup>; 
  	getTaskmanagementWorkitemVersion(workitemId: string, entityVersion: number): Promise<Models.WorkitemVersion>; 
  	getTaskmanagementWorkitemVersions(workitemId: string, opts?: TaskManagementApi.getTaskmanagementWorkitemVersionsOptions): Promise<Models.WorkitemVersionListing>; 
  	getTaskmanagementWorkitemWrapups(workitemId: string, opts?: TaskManagementApi.getTaskmanagementWorkitemWrapupsOptions): Promise<Models.WorkitemWrapupEntityListing>; 
  	getTaskmanagementWorkitemsQueryJob(jobId: string): Promise<Models.WorkitemQueryJobResponse>; 
  	getTaskmanagementWorkitemsQueryJobResults(jobId: string): Promise<Models.WorkitemPagedEntityListing>; 
  	getTaskmanagementWorkitemsSchema(schemaId: string): Promise<Models.DataSchema>; 
  	getTaskmanagementWorkitemsSchemaVersion(schemaId: string, versionId: string): Promise<Models.DataSchema>; 
  	getTaskmanagementWorkitemsSchemaVersions(schemaId: string): Promise<Models.DataSchema>; 
  	getTaskmanagementWorkitemsSchemas(): Promise<Models.DataSchemaListing>; 
  	getTaskmanagementWorktype(worktypeId: string, opts?: TaskManagementApi.getTaskmanagementWorktypeOptions): Promise<Models.Worktype>; 
  	getTaskmanagementWorktypeHistory(worktypeId: string, opts?: TaskManagementApi.getTaskmanagementWorktypeHistoryOptions): Promise<Models.WorktypeChangeListing>; 
  	getTaskmanagementWorktypeStatus(worktypeId: string, statusId: string): Promise<Models.WorkitemStatus>; 
  	getTaskmanagementWorktypeStatuses(worktypeId: string): Promise<Models.WorkitemStatusListing>; 
  	getTaskmanagementWorktypeVersion(worktypeId: string, entityVersion: number): Promise<Models.WorktypeVersion>; 
  	getTaskmanagementWorktypeVersions(worktypeId: string, opts?: TaskManagementApi.getTaskmanagementWorktypeVersionsOptions): Promise<Models.WorktypeVersionListing>; 
  	patchTaskmanagementWorkbin(workbinId: string, body: Models.WorkbinUpdate): Promise<Models.Workbin>; 
  	patchTaskmanagementWorkitem(workitemId: string, body: Models.WorkitemUpdate): Promise<Models.Workitem>; 
  	patchTaskmanagementWorkitemAssignment(workitemId: string, body: Models.WorkitemManualAssign): Promise<void>; 
  	patchTaskmanagementWorkitemUserWrapups(workitemId: string, userId: string, body: Models.WorkitemWrapupUpdate): Promise<Models.WorkitemWrapup>; 
  	patchTaskmanagementWorkitemUsersMeWrapups(workitemId: string, body: Models.WorkitemWrapupUpdate): Promise<Models.WorkitemWrapup>; 
  	patchTaskmanagementWorktype(worktypeId: string, opts?: TaskManagementApi.patchTaskmanagementWorktypeOptions): Promise<Models.Worktype>; 
  	patchTaskmanagementWorktypeStatus(worktypeId: string, statusId: string, opts?: TaskManagementApi.patchTaskmanagementWorktypeStatusOptions): Promise<Models.WorkitemStatus>; 
  	postTaskmanagementWorkbins(opts?: TaskManagementApi.postTaskmanagementWorkbinsOptions): Promise<Models.Workbin>; 
  	postTaskmanagementWorkbinsQuery(body: Models.WorkbinQueryRequest): Promise<Models.WorkbinQueryEntityListing>; 
  	postTaskmanagementWorkitemAcdCancel(workitemId: string): Promise<Models.Workitem>; 
  	postTaskmanagementWorkitemDisconnect(workitemId: string): Promise<Models.Workitem>; 
  	postTaskmanagementWorkitemTerminate(workitemId: string, opts?: TaskManagementApi.postTaskmanagementWorkitemTerminateOptions): Promise<Models.Workitem>; 
  	postTaskmanagementWorkitems(body: Models.WorkitemCreate): Promise<Models.Workitem>; 
  	postTaskmanagementWorkitemsQuery(body: Models.WorkitemQueryPostRequest): Promise<Models.WorkitemPostQueryEntityListing>; 
  	postTaskmanagementWorkitemsQueryJobs(body: Models.WorkitemQueryJobCreate): Promise<Models.WorkitemQueryJobResponse>; 
  	postTaskmanagementWorkitemsSchemas(body: Models.DataSchema): Promise<Models.DataSchema>; 
  	postTaskmanagementWorktypeStatuses(worktypeId: string, opts?: TaskManagementApi.postTaskmanagementWorktypeStatusesOptions): Promise<Models.WorkitemStatus>; 
  	postTaskmanagementWorktypes(opts?: TaskManagementApi.postTaskmanagementWorktypesOptions): Promise<Models.Worktype>; 
  	postTaskmanagementWorktypesQuery(body: Models.WorktypeQueryRequest): Promise<Models.WorktypeQueryEntityListing>; 
  	putTaskmanagementWorkitemsSchema(schemaId: string, body: Models.DataSchema): Promise<Models.DataSchema>;
}

declare namespace TaskManagementApi { 
	export interface getTaskmanagementWorkbinHistoryOptions { 
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorkbinVersionsOptions { 
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorkitemOptions { 
		"expands"?: string;
	}
	export interface getTaskmanagementWorkitemHistoryOptions { 
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorkitemUserWrapupsOptions { 
		"expands"?: string;
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorkitemVersionsOptions { 
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorkitemWrapupsOptions { 
		"expands"?: string;
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorktypeOptions { 
		"expands"?: Array<string>;
	}
	export interface getTaskmanagementWorktypeHistoryOptions { 
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface getTaskmanagementWorktypeVersionsOptions { 
		"after"?: string;
		"pageSize"?: number;
		"sortOrder"?: string;
	}
	export interface patchTaskmanagementWorktypeOptions { 
		"body"?: Models.WorktypeUpdate;
	}
	export interface patchTaskmanagementWorktypeStatusOptions { 
		"body"?: Models.WorkitemStatusUpdate;
	}
	export interface postTaskmanagementWorkbinsOptions { 
		"body"?: Models.WorkbinCreate;
	}
	export interface postTaskmanagementWorkitemTerminateOptions { 
		"body"?: Models.WorkitemTerminate;
	}
	export interface postTaskmanagementWorktypeStatusesOptions { 
		"body"?: Models.WorkitemStatusCreate;
	}
	export interface postTaskmanagementWorktypesOptions { 
		"body"?: Models.WorktypeCreate;
	}
}

declare class TeamsApi {  
  	deleteTeam(teamId: string): Promise<void>; 
  	deleteTeamMembers(teamId: string, id: string): Promise<void>; 
  	getTeam(teamId: string): Promise<Models.Team>; 
  	getTeamMembers(teamId: string, opts?: TeamsApi.getTeamMembersOptions): Promise<Models.TeamMemberEntityListing>; 
  	getTeams(opts?: TeamsApi.getTeamsOptions): Promise<Models.TeamEntityListing>; 
  	patchTeam(teamId: string, body: Models.Team): Promise<Models.Team>; 
  	postAnalyticsTeamsActivityQuery(body: Models.TeamActivityQuery, opts?: TeamsApi.postAnalyticsTeamsActivityQueryOptions): Promise<Models.TeamActivityResponse>; 
  	postTeamMembers(teamId: string, body: Models.TeamMembers): Promise<Models.TeamMemberAddListingResponse>; 
  	postTeams(body: Models.Team): Promise<Models.Team>; 
  	postTeamsSearch(body: Models.TeamSearchRequest): Promise<Models.TeamsSearchResponse>;
}

declare namespace TeamsApi { 
	export interface getTeamMembersOptions { 
		"pageSize"?: number;
		"before"?: string;
		"after"?: string;
		"expand"?: string;
	}
	export interface getTeamsOptions { 
		"pageSize"?: number;
		"name"?: string;
		"after"?: string;
		"before"?: string;
		"expand"?: string;
	}
	export interface postAnalyticsTeamsActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class TelephonyApi {  
  	getTelephonyMediaregions(): Promise<Models.MediaRegions>; 
  	getTelephonySipmessagesConversation(conversationId: string): Promise<Models.Callmessage>; 
  	getTelephonySipmessagesConversationHeaders(conversationId: string, opts?: TelephonyApi.getTelephonySipmessagesConversationHeadersOptions): Promise<Models.Callheader>; 
  	getTelephonySiptraces(dateStart: string, dateEnd: string, opts?: TelephonyApi.getTelephonySiptracesOptions): Promise<Models.SipSearchResult>; 
  	getTelephonySiptracesDownloadDownloadId(downloadId: string): Promise<Models.SignedUrlResponse>; 
  	postTelephonySiptracesDownload(sIPSearchPublicRequest: Models.SIPSearchPublicRequest): Promise<Models.SipDownloadResponse>;
}

declare namespace TelephonyApi { 
	export interface getTelephonySipmessagesConversationHeadersOptions { 
		"keys"?: Array<string>;
	}
	export interface getTelephonySiptracesOptions { 
		"callId"?: string;
		"toUser"?: string;
		"fromUser"?: string;
		"conversationId"?: string;
	}
}

declare class TelephonyProvidersEdgeApi {  
  	deleteTelephonyProvidersEdge(edgeId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgeLogicalinterface(edgeId: string, interfaceId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgeSoftwareupdate(edgeId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesCertificateauthority(certificateId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesDidpool(didPoolId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesEdgegroup(edgeGroupId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesExtensionpool(extensionPoolId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesPhone(phoneId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesPhonebasesetting(phoneBaseId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesSite(siteId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesSiteOutboundroute(siteId: string, outboundRouteId: string): Promise<void>; 
  	deleteTelephonyProvidersEdgesTrunkbasesetting(trunkBaseSettingsId: string): Promise<void>; 
  	getTelephonyProvidersEdge(edgeId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgeOptions): Promise<Models.Edge>; 
  	getTelephonyProvidersEdgeDiagnosticNslookup(edgeId: string): Promise<Models.EdgeNetworkDiagnosticResponse>; 
  	getTelephonyProvidersEdgeDiagnosticPing(edgeId: string): Promise<Models.EdgeNetworkDiagnosticResponse>; 
  	getTelephonyProvidersEdgeDiagnosticRoute(edgeId: string): Promise<Models.EdgeNetworkDiagnosticResponse>; 
  	getTelephonyProvidersEdgeDiagnosticTracepath(edgeId: string): Promise<Models.EdgeNetworkDiagnosticResponse>; 
  	getTelephonyProvidersEdgeLogicalinterface(edgeId: string, interfaceId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgeLogicalinterfaceOptions): Promise<Models.DomainLogicalInterface>; 
  	getTelephonyProvidersEdgeLogicalinterfaces(edgeId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgeLogicalinterfacesOptions): Promise<Models.LogicalInterfaceEntityListing>; 
  	getTelephonyProvidersEdgeLogsJob(edgeId: string, jobId: string): Promise<Models.EdgeLogsJob>; 
  	getTelephonyProvidersEdgeMetrics(edgeId: string): Promise<Models.EdgeMetrics>; 
  	getTelephonyProvidersEdgePhysicalinterface(edgeId: string, interfaceId: string): Promise<Models.DomainPhysicalInterface>; 
  	getTelephonyProvidersEdgePhysicalinterfaces(edgeId: string): Promise<Models.PhysicalInterfaceEntityListing>; 
  	getTelephonyProvidersEdgeSetuppackage(edgeId: string): Promise<Models.VmPairingInfo>; 
  	getTelephonyProvidersEdgeSoftwareupdate(edgeId: string): Promise<Models.DomainEdgeSoftwareUpdateDto>; 
  	getTelephonyProvidersEdgeSoftwareversions(edgeId: string): Promise<Models.DomainEdgeSoftwareVersionDtoEntityListing>; 
  	getTelephonyProvidersEdgeTrunks(edgeId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgeTrunksOptions): Promise<Models.TrunkEntityListing>; 
  	getTelephonyProvidersEdges(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesOptions): Promise<Models.EdgeEntityListing>; 
  	getTelephonyProvidersEdgesCertificateauthorities(): Promise<Models.CertificateAuthorityEntityListing>; 
  	getTelephonyProvidersEdgesCertificateauthority(certificateId: string): Promise<Models.DomainCertificateAuthority>; 
  	getTelephonyProvidersEdgesDid(didId: string): Promise<Models.DID>; 
  	getTelephonyProvidersEdgesDidpool(didPoolId: string): Promise<Models.DIDPool>; 
  	getTelephonyProvidersEdgesDidpools(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesDidpoolsOptions): Promise<Models.DIDPoolEntityListing>; 
  	getTelephonyProvidersEdgesDidpoolsDids(type: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesDidpoolsDidsOptions): Promise<Models.DIDNumberEntityListing>; 
  	getTelephonyProvidersEdgesDids(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesDidsOptions): Promise<Models.DIDEntityListing>; 
  	getTelephonyProvidersEdgesEdgegroup(edgeGroupId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesEdgegroupOptions): Promise<Models.EdgeGroup>; 
  	getTelephonyProvidersEdgesEdgegroupEdgetrunkbase(edgegroupId: string, edgetrunkbaseId: string): Promise<Models.EdgeTrunkBase>; 
  	getTelephonyProvidersEdgesEdgegroups(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesEdgegroupsOptions): Promise<Models.EdgeGroupEntityListing>; 
  	getTelephonyProvidersEdgesEdgeversionreport(): Promise<Models.EdgeVersionReport>; 
  	getTelephonyProvidersEdgesExpired(): Promise<Models.ExpiredEdgeListing>; 
  	getTelephonyProvidersEdgesExtension(extensionId: string): Promise<Models.Extension>; 
  	getTelephonyProvidersEdgesExtensionpool(extensionPoolId: string): Promise<Models.ExtensionPool>; 
  	getTelephonyProvidersEdgesExtensionpools(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesExtensionpoolsOptions): Promise<Models.ExtensionPoolEntityListing>; 
  	getTelephonyProvidersEdgesExtensionpoolsDivisionviews(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesExtensionpoolsDivisionviewsOptions): Promise<Models.ExtensionPoolDivisionViewEntityListing>; 
  	getTelephonyProvidersEdgesExtensions(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesExtensionsOptions): Promise<Models.ExtensionEntityListing>; 
  	getTelephonyProvidersEdgesLine(lineId: string): Promise<Models.Line>; 
  	getTelephonyProvidersEdgesLinebasesetting(lineBaseId: string): Promise<Models.LineBase>; 
  	getTelephonyProvidersEdgesLinebasesettings(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesLinebasesettingsOptions): Promise<Models.LineBaseEntityListing>; 
  	getTelephonyProvidersEdgesLines(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesLinesOptions): Promise<Models.LineEntityListing>; 
  	getTelephonyProvidersEdgesLinesTemplate(lineBaseSettingsId: string): Promise<Models.Line>; 
  	getTelephonyProvidersEdgesLogicalinterfaces(edgeIds: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesLogicalinterfacesOptions): Promise<Models.LogicalInterfaceEntityListing>; 
  	getTelephonyProvidersEdgesMediastatisticsConversation(conversationId: string): Promise<Models.MediaStatisticsListing>; 
  	getTelephonyProvidersEdgesMediastatisticsConversationCommunication(conversationId: string, communicationId: string): Promise<Models.MediaStatistics>; 
  	getTelephonyProvidersEdgesMetrics(edgeIds: string): Promise<Array<Models.EdgeMetrics>>; 
  	getTelephonyProvidersEdgesOutboundroutes(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesOutboundroutesOptions): Promise<Models.OutboundRouteEntityListing>; 
  	getTelephonyProvidersEdgesPhone(phoneId: string): Promise<Models.Phone>; 
  	getTelephonyProvidersEdgesPhonebasesetting(phoneBaseId: string): Promise<Models.PhoneBase>; 
  	getTelephonyProvidersEdgesPhonebasesettings(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesPhonebasesettingsOptions): Promise<Models.PhoneBaseEntityListing>; 
  	getTelephonyProvidersEdgesPhonebasesettingsAvailablemetabases(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesPhonebasesettingsAvailablemetabasesOptions): Promise<Models.PhoneMetaBaseEntityListing>; 
  	getTelephonyProvidersEdgesPhonebasesettingsTemplate(phoneMetabaseId: string): Promise<Models.PhoneBase>; 
  	getTelephonyProvidersEdgesPhones(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesPhonesOptions): Promise<Models.PhoneEntityListing>; 
  	getTelephonyProvidersEdgesPhonesTemplate(phoneBaseSettingsId: string): Promise<Models.Phone>; 
  	getTelephonyProvidersEdgesPhysicalinterfaces(edgeIds: string): Promise<Models.PhysicalInterfaceEntityListing>; 
  	getTelephonyProvidersEdgesSite(siteId: string): Promise<Models.Site>; 
  	getTelephonyProvidersEdgesSiteNumberplan(siteId: string, numberPlanId: string): Promise<Models.NumberPlan>; 
  	getTelephonyProvidersEdgesSiteNumberplans(siteId: string): Promise<Array<Models.NumberPlan>>; 
  	getTelephonyProvidersEdgesSiteNumberplansClassifications(siteId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesSiteNumberplansClassificationsOptions): Promise<Array<string>>; 
  	getTelephonyProvidersEdgesSiteOutboundroute(siteId: string, outboundRouteId: string): Promise<Models.OutboundRouteBase>; 
  	getTelephonyProvidersEdgesSiteOutboundroutes(siteId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesSiteOutboundroutesOptions): Promise<Models.OutboundRouteBaseEntityListing>; 
  	getTelephonyProvidersEdgesSiteSiteconnections(siteId: string): Promise<Models.SiteConnections>; 
  	getTelephonyProvidersEdgesSites(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesSitesOptions): Promise<Models.SiteEntityListing>; 
  	getTelephonyProvidersEdgesTimezones(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesTimezonesOptions): Promise<Models.TimeZoneEntityListing>; 
  	getTelephonyProvidersEdgesTrunk(trunkId: string): Promise<Models.Trunk>; 
  	getTelephonyProvidersEdgesTrunkMetrics(trunkId: string): Promise<Models.TrunkMetrics>; 
  	getTelephonyProvidersEdgesTrunkbasesetting(trunkBaseSettingsId: string, opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesTrunkbasesettingOptions): Promise<Models.TrunkBase>; 
  	getTelephonyProvidersEdgesTrunkbasesettings(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesTrunkbasesettingsOptions): Promise<Models.TrunkBaseEntityListing>; 
  	getTelephonyProvidersEdgesTrunkbasesettingsAvailablemetabases(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesTrunkbasesettingsAvailablemetabasesOptions): Promise<Models.TrunkMetabaseEntityListing>; 
  	getTelephonyProvidersEdgesTrunkbasesettingsTemplate(trunkMetabaseId: string): Promise<Models.TrunkBase>; 
  	getTelephonyProvidersEdgesTrunks(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesTrunksOptions): Promise<Models.TrunkEntityListing>; 
  	getTelephonyProvidersEdgesTrunksMetrics(trunkIds: string): Promise<Array<Models.TrunkMetrics>>; 
  	getTelephonyProvidersEdgesTrunkswithrecording(opts?: TelephonyProvidersEdgeApi.getTelephonyProvidersEdgesTrunkswithrecordingOptions): Promise<Models.TrunkRecordingEnabledCount>; 
  	patchTelephonyProvidersEdgesSiteSiteconnections(siteId: string, body: Models.DisableSiteConnectionsRequest): Promise<Models.SiteConnections>; 
  	postTelephonyProvidersEdgeDiagnosticNslookup(edgeId: string, body: Models.EdgeNetworkDiagnosticRequest): Promise<Models.EdgeNetworkDiagnostic>; 
  	postTelephonyProvidersEdgeDiagnosticPing(edgeId: string, body: Models.EdgeNetworkDiagnosticRequest): Promise<Models.EdgeNetworkDiagnostic>; 
  	postTelephonyProvidersEdgeDiagnosticRoute(edgeId: string, body: Models.EdgeNetworkDiagnosticRequest): Promise<Models.EdgeNetworkDiagnostic>; 
  	postTelephonyProvidersEdgeDiagnosticTracepath(edgeId: string, body: Models.EdgeNetworkDiagnosticRequest): Promise<Models.EdgeNetworkDiagnostic>; 
  	postTelephonyProvidersEdgeLogicalinterfaces(edgeId: string, body: Models.DomainLogicalInterface): Promise<Models.DomainLogicalInterface>; 
  	postTelephonyProvidersEdgeLogsJobUpload(edgeId: string, jobId: string, body: Models.EdgeLogsJobUploadRequest): Promise<void>; 
  	postTelephonyProvidersEdgeLogsJobs(edgeId: string, body: Models.EdgeLogsJobRequest): Promise<Models.EdgeLogsJobResponse>; 
  	postTelephonyProvidersEdgeReboot(edgeId: string, opts?: TelephonyProvidersEdgeApi.postTelephonyProvidersEdgeRebootOptions): Promise<string>; 
  	postTelephonyProvidersEdgeSoftwareupdate(edgeId: string, body: Models.DomainEdgeSoftwareUpdateDto): Promise<Models.DomainEdgeSoftwareUpdateDto>; 
  	postTelephonyProvidersEdgeStatuscode(edgeId: string, opts?: TelephonyProvidersEdgeApi.postTelephonyProvidersEdgeStatuscodeOptions): Promise<string>; 
  	postTelephonyProvidersEdgeUnpair(edgeId: string): Promise<string>; 
  	postTelephonyProvidersEdges(body: Models.Edge): Promise<Models.Edge>; 
  	postTelephonyProvidersEdgesAddressvalidation(body: Models.ValidateAddressRequest): Promise<Models.ValidateAddressResponse>; 
  	postTelephonyProvidersEdgesCertificateauthorities(body: Models.DomainCertificateAuthority): Promise<Models.DomainCertificateAuthority>; 
  	postTelephonyProvidersEdgesDidpools(body: Models.DIDPool): Promise<Models.DIDPool>; 
  	postTelephonyProvidersEdgesEdgegroups(body: Models.EdgeGroup): Promise<Models.EdgeGroup>; 
  	postTelephonyProvidersEdgesExtensionpools(body: Models.ExtensionPool): Promise<Models.ExtensionPool>; 
  	postTelephonyProvidersEdgesPhoneReboot(phoneId: string): Promise<void>; 
  	postTelephonyProvidersEdgesPhonebasesettings(body: Models.PhoneBase): Promise<Models.PhoneBase>; 
  	postTelephonyProvidersEdgesPhones(body: Models.Phone): Promise<Models.Phone>; 
  	postTelephonyProvidersEdgesPhonesReboot(body: Models.PhonesReboot): Promise<void>; 
  	postTelephonyProvidersEdgesSiteOutboundroutes(siteId: string, body: Models.OutboundRouteBase): Promise<Models.OutboundRouteBase>; 
  	postTelephonyProvidersEdgesSites(body: Models.Site): Promise<Models.Site>; 
  	postTelephonyProvidersEdgesTrunkbasesettings(body: Models.TrunkBase): Promise<Models.TrunkBase>; 
  	putTelephonyProvidersEdge(edgeId: string, body: Models.Edge): Promise<Models.Edge>; 
  	putTelephonyProvidersEdgeLogicalinterface(edgeId: string, interfaceId: string, body: Models.DomainLogicalInterface): Promise<Models.DomainLogicalInterface>; 
  	putTelephonyProvidersEdgesCertificateauthority(certificateId: string, body: Models.DomainCertificateAuthority): Promise<Models.DomainCertificateAuthority>; 
  	putTelephonyProvidersEdgesDidpool(didPoolId: string, body: Models.DIDPool): Promise<Models.DIDPool>; 
  	putTelephonyProvidersEdgesEdgegroup(edgeGroupId: string, body: Models.EdgeGroup): Promise<Models.EdgeGroup>; 
  	putTelephonyProvidersEdgesEdgegroupEdgetrunkbase(edgegroupId: string, edgetrunkbaseId: string, body: Models.EdgeTrunkBase): Promise<Models.EdgeTrunkBase>; 
  	putTelephonyProvidersEdgesExtensionpool(extensionPoolId: string, body: Models.ExtensionPool): Promise<Models.ExtensionPool>; 
  	putTelephonyProvidersEdgesPhone(phoneId: string, body: Models.Phone): Promise<Models.Phone>; 
  	putTelephonyProvidersEdgesPhonebasesetting(phoneBaseId: string, body: Models.PhoneBase): Promise<Models.PhoneBase>; 
  	putTelephonyProvidersEdgesSite(siteId: string, body: Models.Site): Promise<Models.Site>; 
  	putTelephonyProvidersEdgesSiteNumberplans(siteId: string, body: Array<Models.NumberPlan>): Promise<Array<Models.NumberPlan>>; 
  	putTelephonyProvidersEdgesSiteOutboundroute(siteId: string, outboundRouteId: string, body: Models.OutboundRouteBase): Promise<Models.OutboundRouteBase>; 
  	putTelephonyProvidersEdgesSiteSiteconnections(siteId: string, body: Models.SiteConnections): Promise<Models.SiteConnections>; 
  	putTelephonyProvidersEdgesTrunkbasesetting(trunkBaseSettingsId: string, body: Models.TrunkBase): Promise<Models.TrunkBase>;
}

declare namespace TelephonyProvidersEdgeApi { 
	export interface getTelephonyProvidersEdgeOptions { 
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgeLogicalinterfaceOptions { 
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgeLogicalinterfacesOptions { 
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgeTrunksOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"trunkBaseId"?: string;
		"trunkType"?: string;
	}
	export interface getTelephonyProvidersEdgesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"siteId"?: string;
		"edgeGroupId"?: string;
		"sortBy"?: string;
		"managed"?: boolean;
		"showCloudMedia"?: boolean;
	}
	export interface getTelephonyProvidersEdgesDidpoolsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"id"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesDidpoolsDidsOptions { 
		"id"?: Array<string>;
		"numberMatch"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getTelephonyProvidersEdgesDidsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"phoneNumber"?: string;
		"ownerId"?: string;
		"didPoolId"?: string;
		"id"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesEdgegroupOptions { 
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesEdgegroupsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"sortBy"?: string;
		"managed"?: boolean;
	}
	export interface getTelephonyProvidersEdgesExtensionpoolsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"_number"?: string;
	}
	export interface getTelephonyProvidersEdgesExtensionpoolsDivisionviewsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"id"?: Array<string>;
		"name"?: string;
		"divisionId"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesExtensionsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"_number"?: string;
	}
	export interface getTelephonyProvidersEdgesLinebasesettingsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesLinesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"sortBy"?: string;
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesLogicalinterfacesOptions { 
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesOutboundroutesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"siteId"?: string;
		"externalTrunkBasesIds"?: string;
		"sortBy"?: string;
	}
	export interface getTelephonyProvidersEdgesPhonebasesettingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"expand"?: Array<string>;
		"name"?: string;
	}
	export interface getTelephonyProvidersEdgesPhonebasesettingsAvailablemetabasesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getTelephonyProvidersEdgesPhonesOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"siteId"?: string;
		"webRtcUserId"?: string;
		"phoneBaseSettingsId"?: string;
		"linesLoggedInUserId"?: string;
		"linesDefaultForUserId"?: string;
		"phoneHardwareId"?: string;
		"linesId"?: string;
		"linesName"?: string;
		"name"?: string;
		"statusOperationalStatus"?: string;
		"secondaryStatusOperationalStatus"?: string;
		"expand"?: Array<string>;
		"fields"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesSiteNumberplansClassificationsOptions { 
		"classification"?: string;
	}
	export interface getTelephonyProvidersEdgesSiteOutboundroutesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"name"?: string;
		"externalTrunkBasesIds"?: string;
		"sortBy"?: string;
	}
	export interface getTelephonyProvidersEdgesSitesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"name"?: string;
		"locationId"?: string;
		"managed"?: boolean;
		"expand"?: Array<string>;
	}
	export interface getTelephonyProvidersEdgesTimezonesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getTelephonyProvidersEdgesTrunkbasesettingOptions { 
		"ignoreHidden"?: boolean;
	}
	export interface getTelephonyProvidersEdgesTrunkbasesettingsOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"recordingEnabled"?: boolean;
		"ignoreHidden"?: boolean;
		"managed"?: boolean;
		"expand"?: Array<string>;
		"name"?: string;
	}
	export interface getTelephonyProvidersEdgesTrunkbasesettingsAvailablemetabasesOptions { 
		"type"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getTelephonyProvidersEdgesTrunksOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"edgeId"?: string;
		"trunkBaseId"?: string;
		"trunkType"?: string;
	}
	export interface getTelephonyProvidersEdgesTrunkswithrecordingOptions { 
		"trunkType"?: string;
	}
	export interface postTelephonyProvidersEdgeRebootOptions { 
		"body"?: Models.EdgeRebootParameters;
	}
	export interface postTelephonyProvidersEdgeStatuscodeOptions { 
		"body"?: Models.EdgeServiceStateRequest;
	}
}

declare class TextbotsApi {  
  	getTextbotsBotsSearch(opts?: TextbotsApi.getTextbotsBotsSearchOptions): Promise<Models.BotSearchResponseEntityListing>; 
  	postTextbotsBotflowsSessionTurns(sessionId: string, turnRequest: Models.TextBotFlowTurnRequest): Promise<Models.TextBotFlowTurnResponse>; 
  	postTextbotsBotflowsSessions(launchRequest: Models.TextBotFlowLaunchRequest): Promise<Models.TextBotFlowLaunchResponse>; 
  	postTextbotsBotsExecute(postTextRequest: Models.PostTextRequest): Promise<Models.PostTextResponse>;
}

declare namespace TextbotsApi { 
	export interface getTextbotsBotsSearchOptions { 
		"botType"?: Array<string>;
		"botName"?: string;
		"botId"?: Array<string>;
		"pageSize"?: number;
	}
}

declare class TokensApi {  
  	deleteToken(userId: string): Promise<void>; 
  	deleteTokensMe(): Promise<void>; 
  	getTokensMe(opts?: TokensApi.getTokensMeOptions): Promise<Models.TokenInfo>; 
  	getTokensTimeout(): Promise<Models.IdleTokenTimeout>; 
  	headTokensMe(): Promise<void>; 
  	putTokensTimeout(opts?: TokensApi.putTokensTimeoutOptions): Promise<Models.IdleTokenTimeout>;
}

declare namespace TokensApi { 
	export interface getTokensMeOptions { 
		"preserveIdleTTL"?: boolean;
	}
	export interface putTokensTimeoutOptions { 
		"body"?: Models.IdleTokenTimeout;
	}
}

declare class UploadsApi {  
  	getKnowledgeKnowledgebaseUploadsUrlsJob(knowledgeBaseId: string, jobId: string): Promise<Models.GetUploadSourceUrlJobStatusResponse>; 
  	postIntegrationsActionDraftFunctionUpload(actionId: string, body: Models.FunctionUploadRequest): Promise<Models.FunctionUploadResponse>; 
  	postKnowledgeDocumentuploads(body: Models.UploadUrlRequest): Promise<Models.UploadUrlResponse>; 
  	postKnowledgeKnowledgebaseUploadsUrlsJobs(knowledgeBaseId: string, body: Models.CreateUploadSourceUrlJobRequest): Promise<Models.CreateUploadSourceUrlJobResponse>; 
  	postLanguageunderstandingMinerUploads(minerId: string, body: object): Promise<Models.UploadUrlResponse>; 
  	postUploadsLearningCoverart(body: Models.LearningCoverArtUploadUrlRequest): Promise<Models.UploadUrlResponse>; 
  	postUploadsPublicassetsImages(body: Models.UploadUrlRequest): Promise<Models.UploadUrlResponse>; 
  	postUploadsRecordings(body: Models.UploadUrlRequest): Promise<Models.UploadUrlResponse>; 
  	postUploadsWorkforcemanagementHistoricaldataCsv(body: Models.UploadUrlRequest): Promise<Models.UploadUrlResponse>;
}

declare namespace UploadsApi { 
}

declare class UsageApi {  
  	getOauthClientUsageQueryResult(executionId: string, clientId: string): Promise<Models.ApiUsageQueryResult>; 
  	getOauthClientUsageSummary(clientId: string, opts?: UsageApi.getOauthClientUsageSummaryOptions): Promise<Models.UsageExecutionResult>; 
  	getUsageQueryExecutionIdResults(executionId: string): Promise<Models.ApiUsageQueryResult>; 
  	getUsageSimplesearchExecutionIdResults(executionId: string, opts?: UsageApi.getUsageSimplesearchExecutionIdResultsOptions): Promise<Models.ApiUsageQueryResult>; 
  	postOauthClientUsageQuery(clientId: string, body: Models.ApiUsageClientQuery): Promise<Models.UsageExecutionResult>; 
  	postUsageQuery(body: Models.ApiUsageOrganizationQuery): Promise<Models.UsageExecutionResult>; 
  	postUsageSimplesearch(body: Models.ApiUsageSimpleSearch): Promise<Models.UsageExecutionResult>;
}

declare namespace UsageApi { 
	export interface getOauthClientUsageSummaryOptions { 
		"days"?: string;
	}
	export interface getUsageSimplesearchExecutionIdResultsOptions { 
		"after"?: string;
		"pageSize"?: number;
	}
}

declare class UserRecordingsApi {  
  	deleteUserrecording(recordingId: string): Promise<void>; 
  	getUserrecording(recordingId: string, opts?: UserRecordingsApi.getUserrecordingOptions): Promise<Models.UserRecording>; 
  	getUserrecordingMedia(recordingId: string, opts?: UserRecordingsApi.getUserrecordingMediaOptions): Promise<Models.DownloadResponse>; 
  	getUserrecordings(opts?: UserRecordingsApi.getUserrecordingsOptions): Promise<Models.UserRecordingEntityListing>; 
  	getUserrecordingsSummary(): Promise<Models.FaxSummary>; 
  	putUserrecording(recordingId: string, body: Models.UserRecording, opts?: UserRecordingsApi.putUserrecordingOptions): Promise<Models.UserRecording>;
}

declare namespace UserRecordingsApi { 
	export interface getUserrecordingOptions { 
		"expand"?: Array<string>;
	}
	export interface getUserrecordingMediaOptions { 
		"formatId"?: string;
		"async"?: boolean;
	}
	export interface getUserrecordingsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: Array<string>;
	}
	export interface putUserrecordingOptions { 
		"expand"?: Array<string>;
	}
}

declare class UsersApi {  
  	deleteAnalyticsUsersDetailsJob(jobId: string): Promise<void>; 
  	deleteAuthorizationSubjectDivisionRole(subjectId: string, divisionId: string, roleId: string): Promise<void>; 
  	deleteRoutingUserUtilization(userId: string): Promise<void>; 
  	deleteUser(userId: string): Promise<object>; 
  	deleteUserRoutinglanguage(userId: string, languageId: string): Promise<void>; 
  	deleteUserRoutingskill(userId: string, skillId: string): Promise<void>; 
  	deleteUserStationAssociatedstation(userId: string): Promise<void>; 
  	deleteUserStationDefaultstation(userId: string): Promise<void>; 
  	deleteUserVerifier(userId: string, verifierId: string): Promise<void>; 
  	getAnalyticsUsersAggregatesJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsUsersAggregatesJobResults(jobId: string, opts?: UsersApi.getAnalyticsUsersAggregatesJobResultsOptions): Promise<Models.UserAsyncAggregateQueryResponse>; 
  	getAnalyticsUsersDetailsJob(jobId: string): Promise<Models.AsyncQueryStatus>; 
  	getAnalyticsUsersDetailsJobResults(jobId: string, opts?: UsersApi.getAnalyticsUsersDetailsJobResultsOptions): Promise<Models.AnalyticsUserDetailsAsyncQueryResponse>; 
  	getAnalyticsUsersDetailsJobsAvailability(): Promise<Models.DataAvailabilityResponse>; 
  	getAuthorizationDivisionspermittedMe(permission: string, opts?: UsersApi.getAuthorizationDivisionspermittedMeOptions): Promise<Array<Models.AuthzDivision>>; 
  	getAuthorizationDivisionspermittedPagedMe(permission: string, opts?: UsersApi.getAuthorizationDivisionspermittedPagedMeOptions): Promise<Models.DivsPermittedEntityListing>; 
  	getAuthorizationDivisionspermittedPagedSubjectId(subjectId: string, permission: string, opts?: UsersApi.getAuthorizationDivisionspermittedPagedSubjectIdOptions): Promise<Models.DivsPermittedEntityListing>; 
  	getAuthorizationSubject(subjectId: string, opts?: UsersApi.getAuthorizationSubjectOptions): Promise<Models.AuthzSubject>; 
  	getAuthorizationSubjectsMe(opts?: UsersApi.getAuthorizationSubjectsMeOptions): Promise<Models.AuthzSubject>; 
  	getFieldconfig(type: string): Promise<Models.FieldConfig>; 
  	getProfilesUsers(opts?: UsersApi.getProfilesUsersOptions): Promise<Models.UserProfileEntityListing>; 
  	getRoutingUserUtilization(userId: string): Promise<Models.AgentMaxUtilizationResponse>; 
  	getUser(userId: string, opts?: UsersApi.getUserOptions): Promise<Models.User>; 
  	getUserAdjacents(userId: string, opts?: UsersApi.getUserAdjacentsOptions): Promise<Models.Adjacents>; 
  	getUserCallforwarding(userId: string): Promise<Models.CallForwarding>; 
  	getUserDirectreports(userId: string, opts?: UsersApi.getUserDirectreportsOptions): Promise<Array<Models.User>>; 
  	getUserFavorites(userId: string, opts?: UsersApi.getUserFavoritesOptions): Promise<Models.UserEntityListing>; 
  	getUserGeolocation(userId: string, clientId: string): Promise<Models.Geolocation>; 
  	getUserOutofoffice(userId: string): Promise<Models.OutOfOffice>; 
  	getUserProfile(userId: string, opts?: UsersApi.getUserProfileOptions): Promise<Models.UserProfile>; 
  	getUserProfileskills(userId: string): Promise<Array<string>>; 
  	getUserQueues(userId: string, opts?: UsersApi.getUserQueuesOptions): Promise<Models.UserQueueEntityListing>; 
  	getUserRoles(subjectId: string): Promise<Models.UserAuthorization>; 
  	getUserRoutinglanguages(userId: string, opts?: UsersApi.getUserRoutinglanguagesOptions): Promise<Models.UserLanguageEntityListing>; 
  	getUserRoutingskills(userId: string, opts?: UsersApi.getUserRoutingskillsOptions): Promise<Models.UserSkillEntityListing>; 
  	getUserRoutingstatus(userId: string): Promise<Models.RoutingStatus>; 
  	getUserSkillgroups(userId: string, opts?: UsersApi.getUserSkillgroupsOptions): Promise<Models.UserSkillGroupEntityListing>; 
  	getUserState(userId: string): Promise<Models.UserState>; 
  	getUserStation(userId: string): Promise<Models.UserStations>; 
  	getUserSuperiors(userId: string, opts?: UsersApi.getUserSuperiorsOptions): Promise<Array<Models.User>>; 
  	getUserTrustors(userId: string, opts?: UsersApi.getUserTrustorsOptions): Promise<Models.TrustorEntityListing>; 
  	getUserVerifiers(userId: string): Promise<Models.VerifierEntityListing>; 
  	getUsers(opts?: UsersApi.getUsersOptions): Promise<Models.UserEntityListing>; 
  	getUsersDevelopmentActivities(opts?: UsersApi.getUsersDevelopmentActivitiesOptions): Promise<Models.DevelopmentActivityListing>; 
  	getUsersDevelopmentActivitiesMe(opts?: UsersApi.getUsersDevelopmentActivitiesMeOptions): Promise<Models.DevelopmentActivityListing>; 
  	getUsersDevelopmentActivity(activityId: string, type: string): Promise<Models.DevelopmentActivity>; 
  	getUsersMe(opts?: UsersApi.getUsersMeOptions): Promise<Models.UserMe>; 
  	getUsersSearch(q64: string, opts?: UsersApi.getUsersSearchOptions): Promise<Models.UsersSearchResponse>; 
  	patchUser(userId: string, body: Models.UpdateUser): Promise<Models.User>; 
  	patchUserCallforwarding(userId: string, body: Models.CallForwarding): Promise<Models.CallForwarding>; 
  	patchUserGeolocation(userId: string, clientId: string, body: Models.Geolocation): Promise<Models.Geolocation>; 
  	patchUserQueue(queueId: string, userId: string, body: Models.UserQueue): Promise<Models.UserQueue>; 
  	patchUserQueues(userId: string, body: Array<Models.UserQueue>, opts?: UsersApi.patchUserQueuesOptions): Promise<Models.UserQueueEntityListing>; 
  	patchUserRoutinglanguage(userId: string, languageId: string, body: Models.UserRoutingLanguage): Promise<Models.UserRoutingLanguage>; 
  	patchUserRoutinglanguagesBulk(userId: string, body: Array<Models.UserRoutingLanguagePost>): Promise<Models.UserLanguageEntityListing>; 
  	patchUserRoutingskillsBulk(userId: string, body: Array<Models.UserRoutingSkillPost>): Promise<Models.UserSkillEntityListing>; 
  	patchUsersBulk(body: Array<Models.PatchUser>): Promise<Models.UserEntityListing>; 
  	postAnalyticsUsersActivityQuery(body: Models.UserActivityQuery, opts?: UsersApi.postAnalyticsUsersActivityQueryOptions): Promise<Models.UserActivityResponse>; 
  	postAnalyticsUsersAggregatesJobs(body: Models.UserAsyncAggregationQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsUsersAggregatesQuery(body: Models.UserAggregationQuery): Promise<Models.UserAggregateQueryResponse>; 
  	postAnalyticsUsersDetailsJobs(body: Models.AsyncUserDetailsQuery): Promise<Models.AsyncQueryResponse>; 
  	postAnalyticsUsersDetailsQuery(body: Models.UserDetailsQuery): Promise<Models.AnalyticsUserDetailsQueryResponse>; 
  	postAnalyticsUsersObservationsQuery(body: Models.UserObservationQuery): Promise<Models.UserObservationQueryResponse>; 
  	postAuthorizationSubjectBulkadd(subjectId: string, body: Models.RoleDivisionGrants, opts?: UsersApi.postAuthorizationSubjectBulkaddOptions): Promise<void>; 
  	postAuthorizationSubjectBulkremove(subjectId: string, body: Models.RoleDivisionGrants): Promise<void>; 
  	postAuthorizationSubjectBulkreplace(subjectId: string, body: Models.RoleDivisionGrants, opts?: UsersApi.postAuthorizationSubjectBulkreplaceOptions): Promise<void>; 
  	postAuthorizationSubjectDivisionRole(subjectId: string, divisionId: string, roleId: string, opts?: UsersApi.postAuthorizationSubjectDivisionRoleOptions): Promise<void>; 
  	postUserExternalid(userId: string, body: Models.UserExternalIdentifier): Promise<Array<Models.UserExternalIdentifier>>; 
  	postUserInvite(userId: string, opts?: UsersApi.postUserInviteOptions): Promise<void>; 
  	postUserPassword(userId: string, body: Models.ChangePasswordRequest): Promise<void>; 
  	postUserRoutinglanguages(userId: string, body: Models.UserRoutingLanguagePost): Promise<Models.UserRoutingLanguage>; 
  	postUserRoutingskills(userId: string, body: Models.UserRoutingSkillPost): Promise<Models.UserRoutingSkill>; 
  	postUsers(body: Models.CreateUser): Promise<Models.User>; 
  	postUsersDevelopmentActivitiesAggregatesQuery(body: Models.DevelopmentActivityAggregateParam): Promise<Models.DevelopmentActivityAggregateResponse>; 
  	postUsersMePassword(body: Models.ChangeMyPasswordRequest): Promise<void>; 
  	postUsersSearch(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postUsersSearchConversationTarget(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postUsersSearchQueuemembersManage(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	postUsersSearchTeamsAssign(body: Models.UserSearchRequest): Promise<Models.UsersSearchResponse>; 
  	putRoutingUserUtilization(userId: string, body: Models.UtilizationRequest): Promise<Models.AgentMaxUtilizationResponse>; 
  	putUserCallforwarding(userId: string, body: Models.CallForwarding): Promise<Models.CallForwarding>; 
  	putUserOutofoffice(userId: string, body: Models.OutOfOffice): Promise<Models.OutOfOffice>; 
  	putUserProfileskills(userId: string, body: Array<string>): Promise<Array<string>>; 
  	putUserRoles(subjectId: string, body: Array<string>): Promise<Models.UserAuthorization>; 
  	putUserRoutingskill(userId: string, skillId: string, body: Models.UserRoutingSkill): Promise<Models.UserRoutingSkill>; 
  	putUserRoutingskillsBulk(userId: string, body: Array<Models.UserRoutingSkillPost>): Promise<Models.UserSkillEntityListing>; 
  	putUserRoutingstatus(userId: string, body: Models.RoutingStatus): Promise<Models.RoutingStatus>; 
  	putUserState(userId: string, body: Models.UserState): Promise<Models.UserState>; 
  	putUserStationAssociatedstationStationId(userId: string, stationId: string): Promise<void>; 
  	putUserStationDefaultstationStationId(userId: string, stationId: string): Promise<void>; 
  	putUserVerifier(userId: string, verifierId: string, body: Models.UpdateVerifierRequest): Promise<Models.Verifier>;
}

declare namespace UsersApi { 
	export interface getAnalyticsUsersAggregatesJobResultsOptions { 
		"cursor"?: string;
	}
	export interface getAnalyticsUsersDetailsJobResultsOptions { 
		"cursor"?: string;
		"pageSize"?: number;
	}
	export interface getAuthorizationDivisionspermittedMeOptions { 
		"name"?: string;
	}
	export interface getAuthorizationDivisionspermittedPagedMeOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAuthorizationDivisionspermittedPagedSubjectIdOptions { 
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	export interface getAuthorizationSubjectOptions { 
		"includeDuplicates"?: boolean;
	}
	export interface getAuthorizationSubjectsMeOptions { 
		"includeDuplicates"?: boolean;
	}
	export interface getProfilesUsersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"jid"?: Array<string>;
		"sortOrder"?: string;
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
	}
	export interface getUserOptions { 
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
		"state"?: string;
	}
	export interface getUserAdjacentsOptions { 
		"expand"?: Array<string>;
	}
	export interface getUserDirectreportsOptions { 
		"expand"?: Array<string>;
	}
	export interface getUserFavoritesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"expand"?: Array<string>;
	}
	export interface getUserProfileOptions { 
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
	}
	export interface getUserQueuesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"joined"?: boolean;
		"divisionId"?: Array<string>;
	}
	export interface getUserRoutinglanguagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getUserRoutingskillsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
	}
	export interface getUserSkillgroupsOptions { 
		"pageSize"?: number;
		"after"?: string;
		"before"?: string;
	}
	export interface getUserSuperiorsOptions { 
		"expand"?: Array<string>;
	}
	export interface getUserTrustorsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getUsersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"id"?: Array<string>;
		"jabberId"?: Array<string>;
		"sortOrder"?: string;
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
		"state"?: string;
	}
	export interface getUsersDevelopmentActivitiesOptions { 
		"userId"?: Array<string>;
		"moduleId"?: string;
		"interval"?: string;
		"completionInterval"?: string;
		"overdue"?: string;
		"pass"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"types"?: Array<string>;
		"statuses"?: Array<string>;
		"relationship"?: Array<string>;
	}
	export interface getUsersDevelopmentActivitiesMeOptions { 
		"moduleId"?: string;
		"interval"?: string;
		"completionInterval"?: string;
		"overdue"?: string;
		"pass"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"types"?: Array<string>;
		"statuses"?: Array<string>;
		"relationship"?: Array<string>;
	}
	export interface getUsersMeOptions { 
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
	}
	export interface getUsersSearchOptions { 
		"expand"?: Array<string>;
		"integrationPresenceSource"?: string;
	}
	export interface patchUserQueuesOptions { 
		"divisionId"?: Array<string>;
	}
	export interface postAnalyticsUsersActivityQueryOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface postAuthorizationSubjectBulkaddOptions { 
		"subjectType"?: string;
	}
	export interface postAuthorizationSubjectBulkreplaceOptions { 
		"subjectType"?: string;
	}
	export interface postAuthorizationSubjectDivisionRoleOptions { 
		"subjectType"?: string;
	}
	export interface postUserInviteOptions { 
		"force"?: boolean;
	}
}

declare class UtilitiesApi {  
  	getDate(): Promise<Models.ServerDate>; 
  	getIpranges(): Promise<Models.IpAddressRangeListing>; 
  	getTimezones(opts?: UtilitiesApi.getTimezonesOptions): Promise<Models.TimeZoneEntityListing>; 
  	postCertificateDetails(body: Models.Certificate): Promise<Models.ParsedCertificate>;
}

declare namespace UtilitiesApi { 
	export interface getTimezonesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class VoicemailApi {  
  	deleteVoicemailMessage(messageId: string): Promise<void>; 
  	deleteVoicemailMessages(): Promise<void>; 
  	getVoicemailGroupMailbox(groupId: string): Promise<Models.VoicemailMailboxInfo>; 
  	getVoicemailGroupMessages(groupId: string, opts?: VoicemailApi.getVoicemailGroupMessagesOptions): Promise<Models.VoicemailMessageEntityListing>; 
  	getVoicemailGroupPolicy(groupId: string): Promise<Models.VoicemailGroupPolicy>; 
  	getVoicemailMailbox(): Promise<Models.VoicemailMailboxInfo>; 
  	getVoicemailMeMailbox(): Promise<Models.VoicemailMailboxInfo>; 
  	getVoicemailMeMessages(opts?: VoicemailApi.getVoicemailMeMessagesOptions): Promise<Models.VoicemailMessageEntityListing>; 
  	getVoicemailMePolicy(): Promise<Models.VoicemailUserPolicy>; 
  	getVoicemailMessage(messageId: string, opts?: VoicemailApi.getVoicemailMessageOptions): Promise<Models.VoicemailMessage>; 
  	getVoicemailMessageMedia(messageId: string, opts?: VoicemailApi.getVoicemailMessageMediaOptions): Promise<Models.VoicemailMediaInfo>; 
  	getVoicemailMessages(opts?: VoicemailApi.getVoicemailMessagesOptions): Promise<Models.VoicemailMessageEntityListing>; 
  	getVoicemailPolicy(): Promise<Models.VoicemailOrganizationPolicy>; 
  	getVoicemailQueueMessages(queueId: string, opts?: VoicemailApi.getVoicemailQueueMessagesOptions): Promise<Models.VoicemailMessageEntityListing>; 
  	getVoicemailSearch(q64: string, opts?: VoicemailApi.getVoicemailSearchOptions): Promise<Models.VoicemailsSearchResponse>; 
  	getVoicemailUserpolicy(userId: string): Promise<Models.VoicemailUserPolicy>; 
  	patchVoicemailGroupPolicy(groupId: string, body: Models.VoicemailGroupPolicy): Promise<Models.VoicemailGroupPolicy>; 
  	patchVoicemailMePolicy(body: Models.VoicemailUserPolicy): Promise<Models.VoicemailUserPolicy>; 
  	patchVoicemailMessage(messageId: string, body: Models.VoicemailMessage): Promise<Models.VoicemailMessage>; 
  	patchVoicemailUserpolicy(userId: string, body: Models.VoicemailUserPolicy): Promise<Models.VoicemailUserPolicy>; 
  	postVoicemailMessages(opts?: VoicemailApi.postVoicemailMessagesOptions): Promise<Models.VoicemailMessage>; 
  	postVoicemailSearch(body: Models.VoicemailSearchRequest): Promise<Models.VoicemailsSearchResponse>; 
  	putVoicemailMessage(messageId: string, body: Models.VoicemailMessage): Promise<Models.VoicemailMessage>; 
  	putVoicemailPolicy(body: Models.VoicemailOrganizationPolicy): Promise<Models.VoicemailOrganizationPolicy>; 
  	putVoicemailUserpolicy(userId: string, body: Models.VoicemailUserPolicy): Promise<Models.VoicemailUserPolicy>;
}

declare namespace VoicemailApi { 
	export interface getVoicemailGroupMessagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getVoicemailMeMessagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getVoicemailMessageOptions { 
		"expand"?: Array<string>;
	}
	export interface getVoicemailMessageMediaOptions { 
		"formatId"?: string;
	}
	export interface getVoicemailMessagesOptions { 
		"ids"?: string;
		"expand"?: Array<string>;
	}
	export interface getVoicemailQueueMessagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	export interface getVoicemailSearchOptions { 
		"expand"?: Array<string>;
	}
	export interface postVoicemailMessagesOptions { 
		"body"?: Models.CopyVoicemailMessage;
	}
}

declare class WebChatApi {  
  	deleteWebchatDeployment(deploymentId: string): Promise<void>; 
  	deleteWebchatGuestConversationMember(conversationId: string, memberId: string): Promise<void>; 
  	deleteWebchatSettings(): Promise<void>; 
  	getWebchatDeployment(deploymentId: string): Promise<Models.WebChatDeployment>; 
  	getWebchatDeployments(): Promise<Models.WebChatDeploymentEntityListing>; 
  	getWebchatGuestConversationMediarequest(conversationId: string, mediaRequestId: string): Promise<Models.WebChatGuestMediaRequest>; 
  	getWebchatGuestConversationMediarequests(conversationId: string): Promise<Models.WebChatGuestMediaRequestEntityList>; 
  	getWebchatGuestConversationMember(conversationId: string, memberId: string): Promise<Models.WebChatMemberInfo>; 
  	getWebchatGuestConversationMembers(conversationId: string, opts?: WebChatApi.getWebchatGuestConversationMembersOptions): Promise<Models.WebChatMemberInfoEntityList>; 
  	getWebchatGuestConversationMessage(conversationId: string, messageId: string): Promise<Models.WebChatMessage>; 
  	getWebchatGuestConversationMessages(conversationId: string, opts?: WebChatApi.getWebchatGuestConversationMessagesOptions): Promise<Models.WebChatMessageEntityList>; 
  	getWebchatSettings(): Promise<Models.WebChatSettings>; 
  	patchWebchatGuestConversationMediarequest(conversationId: string, mediaRequestId: string, body: Models.WebChatGuestMediaRequest): Promise<Models.WebChatGuestMediaRequest>; 
  	postWebchatDeployments(body: Models.WebChatDeployment): Promise<Models.WebChatDeployment>; 
  	postWebchatGuestConversationMemberMessages(conversationId: string, memberId: string, body: Models.CreateWebChatMessageRequest): Promise<Models.WebChatMessage>; 
  	postWebchatGuestConversationMemberTyping(conversationId: string, memberId: string): Promise<Models.WebChatTyping>; 
  	postWebchatGuestConversations(body: Models.CreateWebChatConversationRequest): Promise<Models.CreateWebChatConversationResponse>; 
  	putWebchatDeployment(deploymentId: string, body: Models.WebChatDeployment): Promise<Models.WebChatDeployment>; 
  	putWebchatSettings(body: Models.WebChatSettings): Promise<Models.WebChatSettings>;
}

declare namespace WebChatApi { 
	export interface getWebchatGuestConversationMembersOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"excludeDisconnectedMembers"?: boolean;
	}
	export interface getWebchatGuestConversationMessagesOptions { 
		"after"?: string;
		"before"?: string;
		"sortOrder"?: string;
		"maxResults"?: number;
	}
}

declare class WebDeploymentsApi {  
  	deleteWebdeploymentsConfiguration(configurationId: string): Promise<void>; 
  	deleteWebdeploymentsDeployment(deploymentId: string): Promise<void>; 
  	deleteWebdeploymentsDeploymentCobrowseSessionId(deploymentId: string, sessionId: string): Promise<object>; 
  	deleteWebdeploymentsTokenRevoke(opts?: WebDeploymentsApi.deleteWebdeploymentsTokenRevokeOptions): Promise<void>; 
  	getWebdeploymentsConfigurationVersion(configurationId: string, versionId: string): Promise<Models.WebDeploymentConfigurationVersion>; 
  	getWebdeploymentsConfigurationVersions(configurationId: string): Promise<Models.WebDeploymentConfigurationVersionEntityListing>; 
  	getWebdeploymentsConfigurationVersionsDraft(configurationId: string): Promise<Models.WebDeploymentConfigurationVersion>; 
  	getWebdeploymentsConfigurations(opts?: WebDeploymentsApi.getWebdeploymentsConfigurationsOptions): Promise<Models.WebDeploymentConfigurationVersionEntityListing>; 
  	getWebdeploymentsDeployment(deploymentId: string, opts?: WebDeploymentsApi.getWebdeploymentsDeploymentOptions): Promise<Models.WebDeployment>; 
  	getWebdeploymentsDeploymentCobrowseSessionId(deploymentId: string, sessionId: string): Promise<Models.CobrowseWebMessagingSession>; 
  	getWebdeploymentsDeploymentConfigurations(deploymentId: string, opts?: WebDeploymentsApi.getWebdeploymentsDeploymentConfigurationsOptions): Promise<Models.WebDeploymentActiveConfigurationOnDeployment>; 
  	getWebdeploymentsDeployments(opts?: WebDeploymentsApi.getWebdeploymentsDeploymentsOptions): Promise<Models.ExpandableWebDeploymentEntityListing>; 
  	postWebdeploymentsConfigurationVersionsDraftPublish(configurationId: string): Promise<Models.WebDeploymentConfigurationVersion>; 
  	postWebdeploymentsConfigurations(configurationVersion: Models.WebDeploymentConfigurationVersion): Promise<Models.WebDeploymentConfigurationVersion>; 
  	postWebdeploymentsDeployments(deployment: Models.WebDeployment): Promise<Models.WebDeployment>; 
  	postWebdeploymentsTokenOauthcodegrantjwtexchange(body: Models.WebDeploymentsOAuthExchangeRequest): Promise<Models.WebDeploymentsAuthorizationResponse>; 
  	postWebdeploymentsTokenRefresh(opts?: WebDeploymentsApi.postWebdeploymentsTokenRefreshOptions): Promise<Models.SignedData>; 
  	putWebdeploymentsConfigurationVersionsDraft(configurationId: string, configurationVersion: Models.WebDeploymentConfigurationVersion): Promise<Models.WebDeploymentConfigurationVersion>; 
  	putWebdeploymentsDeployment(deploymentId: string, deployment: Models.WebDeployment): Promise<Models.WebDeployment>;
}

declare namespace WebDeploymentsApi { 
	export interface deleteWebdeploymentsTokenRevokeOptions { 
		"xJourneySessionId"?: string;
		"xJourneySessionType"?: string;
	}
	export interface getWebdeploymentsConfigurationsOptions { 
		"showOnlyPublished"?: boolean;
	}
	export interface getWebdeploymentsDeploymentOptions { 
		"expand"?: Array<string>;
	}
	export interface getWebdeploymentsDeploymentConfigurationsOptions { 
		"type"?: string;
		"expand"?: Array<string>;
	}
	export interface getWebdeploymentsDeploymentsOptions { 
		"expand"?: Array<string>;
	}
	export interface postWebdeploymentsTokenRefreshOptions { 
		"body"?: Models.WebDeploymentsRefreshJWTRequest;
	}
}

declare class WebMessagingApi {  
  	getWebmessagingMessages(opts?: WebMessagingApi.getWebmessagingMessagesOptions): Promise<Models.WebMessagingMessageEntityList>;
}

declare namespace WebMessagingApi { 
	export interface getWebmessagingMessagesOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
	}
}

declare class WidgetsApi {  
  	deleteWidgetsDeployment(deploymentId: string): Promise<void>; 
  	getWidgetsDeployment(deploymentId: string): Promise<Models.WidgetDeployment>; 
  	getWidgetsDeployments(): Promise<Models.WidgetDeploymentEntityListing>; 
  	postWidgetsDeployments(body: Models.WidgetDeployment): Promise<Models.WidgetDeployment>; 
  	putWidgetsDeployment(deploymentId: string, body: Models.WidgetDeployment): Promise<Models.WidgetDeployment>;
}

declare namespace WidgetsApi { 
}

declare class WorkforceManagementApi {  
  	deleteWorkforcemanagementBusinessunit(businessUnitId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitActivitycode(businessUnitId: string, activityCodeId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitPlanninggroup(businessUnitId: string, planningGroupId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitSchedulingRun(businessUnitId: string, runId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitServicegoaltemplate(businessUnitId: string, serviceGoalTemplateId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitStaffinggroup(businessUnitId: string, staffingGroupId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitTimeofflimit(businessUnitId: string, timeOffLimitId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitTimeoffplan(businessUnitId: string, timeOffPlanId: string): Promise<void>; 
  	deleteWorkforcemanagementBusinessunitWeekSchedule(businessUnitId: string, weekId: string, scheduleId: string): Promise<Models.BuAsyncScheduleResponse>; 
  	deleteWorkforcemanagementBusinessunitWeekShorttermforecast(businessUnitId: string, weekDateId: string, forecastId: string): Promise<void>; 
  	deleteWorkforcemanagementCalendarUrlIcs(): Promise<void>; 
  	deleteWorkforcemanagementManagementunit(managementUnitId: string): Promise<void>; 
  	deleteWorkforcemanagementManagementunitTimeofflimit(managementUnitId: string, timeOffLimitId: string): Promise<void>; 
  	deleteWorkforcemanagementManagementunitTimeoffplan(managementUnitId: string, timeOffPlanId: string): Promise<void>; 
  	deleteWorkforcemanagementManagementunitWorkplan(managementUnitId: string, workPlanId: string): Promise<void>; 
  	deleteWorkforcemanagementManagementunitWorkplanrotation(managementUnitId: string, workPlanRotationId: string): Promise<void>; 
  	getWorkforcemanagementAdherence(userId: Array<string>): Promise<Array<Models.UserScheduleAdherence>>; 
  	getWorkforcemanagementAdherenceExplanation(explanationId: string): Promise<Models.AdherenceExplanationResponse>; 
  	getWorkforcemanagementAdherenceExplanationsJob(jobId: string): Promise<Models.AdherenceExplanationJob>; 
  	getWorkforcemanagementAdherenceHistoricalBulkJob(jobId: string): Promise<Models.WfmHistoricalAdherenceBulkResponse>; 
  	getWorkforcemanagementAdherenceHistoricalJob(jobId: string): Promise<Models.WfmHistoricalAdherenceResponse>; 
  	getWorkforcemanagementAdhocmodelingjob(jobId: string): Promise<Models.ModelingStatusResponse>; 
  	getWorkforcemanagementAgentAdherenceExplanation(agentId: string, explanationId: string): Promise<Models.AdherenceExplanationResponse>; 
  	getWorkforcemanagementAgentManagementunit(agentId: string): Promise<Models.AgentManagementUnitReference>; 
  	getWorkforcemanagementAgentsMeManagementunit(): Promise<Models.AgentManagementUnitReference>; 
  	getWorkforcemanagementBusinessunit(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitOptions): Promise<Models.BusinessUnitResponse>; 
  	getWorkforcemanagementBusinessunitActivitycode(businessUnitId: string, activityCodeId: string): Promise<Models.BusinessUnitActivityCode>; 
  	getWorkforcemanagementBusinessunitActivitycodes(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitActivitycodesOptions): Promise<Models.BusinessUnitActivityCodeListing>; 
  	getWorkforcemanagementBusinessunitIntradayPlanninggroups(businessUnitId: string, _date: string): Promise<Models.WfmIntradayPlanningGroupListing>; 
  	getWorkforcemanagementBusinessunitManagementunits(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitManagementunitsOptions): Promise<Models.ManagementUnitListing>; 
  	getWorkforcemanagementBusinessunitPlanninggroup(businessUnitId: string, planningGroupId: string): Promise<Models.PlanningGroup>; 
  	getWorkforcemanagementBusinessunitPlanninggroups(businessUnitId: string): Promise<Models.PlanningGroupList>; 
  	getWorkforcemanagementBusinessunitSchedulingRun(businessUnitId: string, runId: string): Promise<Models.BuScheduleRun>; 
  	getWorkforcemanagementBusinessunitSchedulingRunResult(businessUnitId: string, runId: string, managementUnitIds: Array<string>, expand: Array<string>): Promise<Models.BuRescheduleResult>; 
  	getWorkforcemanagementBusinessunitSchedulingRuns(businessUnitId: string): Promise<Models.BuScheduleRunListing>; 
  	getWorkforcemanagementBusinessunitServicegoaltemplate(businessUnitId: string, serviceGoalTemplateId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitServicegoaltemplateOptions): Promise<Models.ServiceGoalTemplate>; 
  	getWorkforcemanagementBusinessunitServicegoaltemplates(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitServicegoaltemplatesOptions): Promise<Models.ServiceGoalTemplateList>; 
  	getWorkforcemanagementBusinessunitStaffinggroup(businessUnitId: string, staffingGroupId: string): Promise<Models.StaffingGroupResponse>; 
  	getWorkforcemanagementBusinessunitStaffinggroups(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitStaffinggroupsOptions): Promise<Models.StaffingGroupListing>; 
  	getWorkforcemanagementBusinessunitTimeofflimit(businessUnitId: string, timeOffLimitId: string): Promise<Models.BuTimeOffLimitResponse>; 
  	getWorkforcemanagementBusinessunitTimeofflimits(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitTimeofflimitsOptions): Promise<Models.BuTimeOffLimitListing>; 
  	getWorkforcemanagementBusinessunitTimeoffplan(businessUnitId: string, timeOffPlanId: string): Promise<Models.BuTimeOffPlanResponse>; 
  	getWorkforcemanagementBusinessunitTimeoffplans(businessUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitTimeoffplansOptions): Promise<Models.BuTimeOffPlanListing>; 
  	getWorkforcemanagementBusinessunitWeekSchedule(businessUnitId: string, weekId: string, scheduleId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekScheduleOptions): Promise<Models.BuScheduleMetadata>; 
  	getWorkforcemanagementBusinessunitWeekScheduleGenerationresults(businessUnitId: string, weekId: string, scheduleId: string): Promise<Models.ScheduleGenerationResult>; 
  	getWorkforcemanagementBusinessunitWeekScheduleHeadcountforecast(businessUnitId: string, weekId: string, scheduleId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekScheduleHeadcountforecastOptions): Promise<Models.BuHeadcountForecastResponse>; 
  	getWorkforcemanagementBusinessunitWeekScheduleHistoryAgent(businessUnitId: string, weekId: string, scheduleId: string, agentId: string): Promise<Models.BuAgentScheduleHistoryResponse>; 
  	getWorkforcemanagementBusinessunitWeekSchedulePerformancepredictions(businessUnitId: string, weekId: string, scheduleId: string): Promise<Models.PerformancePredictionResponse>; 
  	getWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculation(businessUnitId: string, weekId: string, scheduleId: string, recalculationId: string): Promise<Models.PerformancePredictionRecalculationResponse>; 
  	getWorkforcemanagementBusinessunitWeekSchedules(businessUnitId: string, weekId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekSchedulesOptions): Promise<Models.BuScheduleListing>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecast(businessUnitId: string, weekDateId: string, forecastId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekShorttermforecastOptions): Promise<Models.BuShortTermForecast>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecastData(businessUnitId: string, weekDateId: string, forecastId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekShorttermforecastDataOptions): Promise<Models.BuForecastResultResponse>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecastGenerationresults(businessUnitId: string, weekDateId: string, forecastId: string): Promise<Models.BuForecastGenerationResult>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecastLongtermforecastdata(businessUnitId: string, weekDateId: string, forecastId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekShorttermforecastLongtermforecastdataOptions): Promise<Models.LongTermForecastResultResponse>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecastPlanninggroups(businessUnitId: string, weekDateId: string, forecastId: string): Promise<Models.ForecastPlanningGroupsResponse>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecastStaffingrequirement(businessUnitId: string, weekDateId: string, forecastId: string, opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitWeekShorttermforecastStaffingrequirementOptions): Promise<Models.BuForecastStaffingRequirementsResultResponse>; 
  	getWorkforcemanagementBusinessunitWeekShorttermforecasts(businessUnitId: string, weekDateId: string): Promise<Models.BuShortTermForecastListing>; 
  	getWorkforcemanagementBusinessunits(opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitsOptions): Promise<Models.BusinessUnitListing>; 
  	getWorkforcemanagementBusinessunitsDivisionviews(opts?: WorkforceManagementApi.getWorkforcemanagementBusinessunitsDivisionviewsOptions): Promise<Models.BusinessUnitListing>; 
  	getWorkforcemanagementCalendarDataIcs(calendarId: string): Promise<string>; 
  	getWorkforcemanagementCalendarUrlIcs(): Promise<Models.CalendarUrlResponse>; 
  	getWorkforcemanagementHistoricaldataDeletejob(): Promise<Models.HistoricalImportDeleteJobResponse>; 
  	getWorkforcemanagementHistoricaldataImportstatus(): Promise<Models.HistoricalImportStatusListing>; 
  	getWorkforcemanagementIntegrationsHris(): Promise<Models.WfmIntegrationListing>; 
  	getWorkforcemanagementIntegrationsHrisTimeofftypesJob(jobId: string): Promise<Models.HrisTimeOffTypesJobResponse>; 
  	getWorkforcemanagementManagementunit(managementUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitOptions): Promise<Models.ManagementUnit>; 
  	getWorkforcemanagementManagementunitActivitycodes(managementUnitId: string): Promise<Models.ActivityCodeContainer>; 
  	getWorkforcemanagementManagementunitAdherence(managementUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitAdherenceOptions): Promise<Models.UserScheduleAdherenceListing>; 
  	getWorkforcemanagementManagementunitAgent(managementUnitId: string, agentId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitAgentOptions): Promise<Models.WfmAgent>; 
  	getWorkforcemanagementManagementunitAgentShifttrades(managementUnitId: string, agentId: string): Promise<Models.ShiftTradeListResponse>; 
  	getWorkforcemanagementManagementunitShifttradesMatched(managementUnitId: string): Promise<Models.ShiftTradeMatchesSummaryResponse>; 
  	getWorkforcemanagementManagementunitShifttradesUsers(managementUnitId: string): Promise<Models.WfmUserEntityListing>; 
  	getWorkforcemanagementManagementunitTimeofflimit(managementUnitId: string, timeOffLimitId: string): Promise<Models.TimeOffLimit>; 
  	getWorkforcemanagementManagementunitTimeofflimits(managementUnitId: string): Promise<Models.TimeOffLimitListing>; 
  	getWorkforcemanagementManagementunitTimeoffplan(managementUnitId: string, timeOffPlanId: string): Promise<Models.TimeOffPlan>; 
  	getWorkforcemanagementManagementunitTimeoffplans(managementUnitId: string): Promise<Models.TimeOffPlanListing>; 
  	getWorkforcemanagementManagementunitUserTimeoffrequest(managementUnitId: string, userId: string, timeOffRequestId: string): Promise<Models.TimeOffRequestResponse>; 
  	getWorkforcemanagementManagementunitUserTimeoffrequestTimeofflimits(managementUnitId: string, userId: string, timeOffRequestId: string): Promise<Models.QueryTimeOffLimitValuesResponse>; 
  	getWorkforcemanagementManagementunitUserTimeoffrequests(managementUnitId: string, userId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitUserTimeoffrequestsOptions): Promise<Models.TimeOffRequestList>; 
  	getWorkforcemanagementManagementunitUsers(managementUnitId: string): Promise<Models.WfmUserEntityListing>; 
  	getWorkforcemanagementManagementunitWeekSchedule(managementUnitId: string, weekId: string, scheduleId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitWeekScheduleOptions): Promise<Models.WeekScheduleResponse>; 
  	getWorkforcemanagementManagementunitWeekSchedules(managementUnitId: string, weekId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitWeekSchedulesOptions): Promise<Models.WeekScheduleListResponse>; 
  	getWorkforcemanagementManagementunitWeekShifttrades(managementUnitId: string, weekDateId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitWeekShifttradesOptions): Promise<Models.WeekShiftTradeListResponse>; 
  	getWorkforcemanagementManagementunitWorkplan(managementUnitId: string, workPlanId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitWorkplanOptions): Promise<Models.WorkPlan>; 
  	getWorkforcemanagementManagementunitWorkplanrotation(managementUnitId: string, workPlanRotationId: string): Promise<Models.WorkPlanRotationResponse>; 
  	getWorkforcemanagementManagementunitWorkplanrotations(managementUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitWorkplanrotationsOptions): Promise<Models.WorkPlanRotationListResponse>; 
  	getWorkforcemanagementManagementunitWorkplans(managementUnitId: string, opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitWorkplansOptions): Promise<Models.WorkPlanListResponse>; 
  	getWorkforcemanagementManagementunits(opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitsOptions): Promise<Models.ManagementUnitListing>; 
  	getWorkforcemanagementManagementunitsDivisionviews(opts?: WorkforceManagementApi.getWorkforcemanagementManagementunitsDivisionviewsOptions): Promise<Models.ManagementUnitListing>; 
  	getWorkforcemanagementNotifications(): Promise<Models.NotificationsResponse>; 
  	getWorkforcemanagementSchedulingjob(jobId: string): Promise<Models.SchedulingStatusResponse>; 
  	getWorkforcemanagementShifttrades(): Promise<Models.ShiftTradeListResponse>; 
  	getWorkforcemanagementShrinkageJob(jobId: string): Promise<Models.WfmHistoricalShrinkageResponse>; 
  	getWorkforcemanagementTimeoffbalanceJob(jobId: string): Promise<Models.TimeOffBalanceJobResponse>; 
  	getWorkforcemanagementTimeoffrequest(timeOffRequestId: string): Promise<Models.TimeOffRequestResponse>; 
  	getWorkforcemanagementTimeoffrequestWaitlistpositions(timeOffRequestId: string): Promise<Models.WaitlistPositionListing>; 
  	getWorkforcemanagementTimeoffrequests(opts?: WorkforceManagementApi.getWorkforcemanagementTimeoffrequestsOptions): Promise<Models.TimeOffRequestList>; 
  	patchWorkforcemanagementAgentAdherenceExplanation(agentId: string, explanationId: string, body: Models.UpdateAdherenceExplanationStatusRequest): Promise<Models.AdherenceExplanationAsyncResponse>; 
  	patchWorkforcemanagementBusinessunit(businessUnitId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitOptions): Promise<Models.BusinessUnitResponse>; 
  	patchWorkforcemanagementBusinessunitActivitycode(businessUnitId: string, activityCodeId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitActivitycodeOptions): Promise<Models.BusinessUnitActivityCode>; 
  	patchWorkforcemanagementBusinessunitPlanninggroup(businessUnitId: string, planningGroupId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitPlanninggroupOptions): Promise<Models.PlanningGroup>; 
  	patchWorkforcemanagementBusinessunitSchedulingRun(businessUnitId: string, runId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitSchedulingRunOptions): Promise<void>; 
  	patchWorkforcemanagementBusinessunitServicegoaltemplate(businessUnitId: string, serviceGoalTemplateId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitServicegoaltemplateOptions): Promise<Models.ServiceGoalTemplate>; 
  	patchWorkforcemanagementBusinessunitStaffinggroup(businessUnitId: string, staffingGroupId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitStaffinggroupOptions): Promise<Models.StaffingGroupResponse>; 
  	patchWorkforcemanagementBusinessunitTimeoffplan(businessUnitId: string, timeOffPlanId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementBusinessunitTimeoffplanOptions): Promise<Models.BuTimeOffPlanResponse>; 
  	patchWorkforcemanagementManagementunit(managementUnitId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitOptions): Promise<Models.ManagementUnit>; 
  	patchWorkforcemanagementManagementunitAgents(managementUnitId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitAgentsOptions): Promise<void>; 
  	patchWorkforcemanagementManagementunitTimeofflimit(managementUnitId: string, timeOffLimitId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitTimeofflimitOptions): Promise<Models.TimeOffLimit>; 
  	patchWorkforcemanagementManagementunitTimeoffplan(managementUnitId: string, timeOffPlanId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitTimeoffplanOptions): Promise<Models.TimeOffPlan>; 
  	patchWorkforcemanagementManagementunitTimeoffrequestUserIntegrationstatus(managementUnitId: string, timeOffRequestId: string, userId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitTimeoffrequestUserIntegrationstatusOptions): Promise<Models.UserTimeOffIntegrationStatusResponse>; 
  	patchWorkforcemanagementManagementunitUserTimeoffrequest(managementUnitId: string, userId: string, timeOffRequestId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitUserTimeoffrequestOptions): Promise<Models.TimeOffRequestResponse>; 
  	patchWorkforcemanagementManagementunitWeekShifttrade(managementUnitId: string, weekDateId: string, tradeId: string, body: Models.PatchShiftTradeRequest): Promise<Models.ShiftTradeResponse>; 
  	patchWorkforcemanagementManagementunitWorkplan(managementUnitId: string, workPlanId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitWorkplanOptions): Promise<Models.WorkPlan>; 
  	patchWorkforcemanagementManagementunitWorkplanrotation(managementUnitId: string, workPlanRotationId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementManagementunitWorkplanrotationOptions): Promise<Models.WorkPlanRotationResponse>; 
  	patchWorkforcemanagementTimeoffrequest(timeOffRequestId: string, opts?: WorkforceManagementApi.patchWorkforcemanagementTimeoffrequestOptions): Promise<Models.TimeOffRequestResponse>; 
  	postWorkforcemanagementAdherenceExplanations(body: Models.AddAdherenceExplanationAgentRequest): Promise<Models.AdherenceExplanationAsyncResponse>; 
  	postWorkforcemanagementAdherenceExplanationsQuery(body: Models.AgentQueryAdherenceExplanationsRequest, opts?: WorkforceManagementApi.postWorkforcemanagementAdherenceExplanationsQueryOptions): Promise<Models.QueryAdherenceExplanationsResponse>; 
  	postWorkforcemanagementAdherenceHistorical(opts?: WorkforceManagementApi.postWorkforcemanagementAdherenceHistoricalOptions): Promise<Models.WfmHistoricalAdherenceResponse>; 
  	postWorkforcemanagementAdherenceHistoricalBulk(opts?: WorkforceManagementApi.postWorkforcemanagementAdherenceHistoricalBulkOptions): Promise<Models.WfmHistoricalAdherenceBulkResponse>; 
  	postWorkforcemanagementAgentAdherenceExplanations(agentId: string, body: Models.AddAdherenceExplanationAdminRequest): Promise<Models.AdherenceExplanationAsyncResponse>; 
  	postWorkforcemanagementAgentAdherenceExplanationsQuery(agentId: string, body: Models.AgentQueryAdherenceExplanationsRequest, opts?: WorkforceManagementApi.postWorkforcemanagementAgentAdherenceExplanationsQueryOptions): Promise<Models.AgentQueryAdherenceExplanationsResponse>; 
  	postWorkforcemanagementAgents(opts?: WorkforceManagementApi.postWorkforcemanagementAgentsOptions): Promise<Models.MoveAgentsResponse>; 
  	postWorkforcemanagementAgentsIntegrationsHrisQuery(opts?: WorkforceManagementApi.postWorkforcemanagementAgentsIntegrationsHrisQueryOptions): Promise<Models.AgentsIntegrationsListing>; 
  	postWorkforcemanagementAgentsMePossibleworkshifts(body: Models.AgentPossibleWorkShiftsRequest): Promise<Models.AgentPossibleWorkShiftsResponse>; 
  	postWorkforcemanagementAgentschedulesMine(opts?: WorkforceManagementApi.postWorkforcemanagementAgentschedulesMineOptions): Promise<Models.BuCurrentAgentScheduleSearchResponse>; 
  	postWorkforcemanagementBusinessunitActivitycodes(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitActivitycodesOptions): Promise<Models.BusinessUnitActivityCode>; 
  	postWorkforcemanagementBusinessunitAdherenceExplanationsQuery(businessUnitId: string, body: Models.BuQueryAdherenceExplanationsRequest, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitAdherenceExplanationsQueryOptions): Promise<Models.BuQueryAdherenceExplanationsResponse>; 
  	postWorkforcemanagementBusinessunitAgentschedulesSearch(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitAgentschedulesSearchOptions): Promise<Models.BuAsyncAgentSchedulesSearchResponse>; 
  	postWorkforcemanagementBusinessunitIntraday(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitIntradayOptions): Promise<Models.AsyncIntradayResponse>; 
  	postWorkforcemanagementBusinessunitPlanninggroups(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitPlanninggroupsOptions): Promise<Models.PlanningGroup>; 
  	postWorkforcemanagementBusinessunitServicegoaltemplates(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitServicegoaltemplatesOptions): Promise<Models.ServiceGoalTemplate>; 
  	postWorkforcemanagementBusinessunitStaffinggroups(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitStaffinggroupsOptions): Promise<Models.StaffingGroupResponse>; 
  	postWorkforcemanagementBusinessunitStaffinggroupsQuery(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitStaffinggroupsQueryOptions): Promise<Models.UserStaffingGroupListing>; 
  	postWorkforcemanagementBusinessunitTimeofflimits(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitTimeofflimitsOptions): Promise<Models.BuTimeOffLimitResponse>; 
  	postWorkforcemanagementBusinessunitTimeofflimitsValuesQuery(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitTimeofflimitsValuesQueryOptions): Promise<Models.BuTimeOffLimitValuesResponse>; 
  	postWorkforcemanagementBusinessunitTimeoffplans(businessUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitTimeoffplansOptions): Promise<Models.BuTimeOffPlanResponse>; 
  	postWorkforcemanagementBusinessunitWeekScheduleAgentschedulesQuery(businessUnitId: string, weekId: string, scheduleId: string, body: Models.BuQueryAgentSchedulesRequest, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitWeekScheduleAgentschedulesQueryOptions): Promise<Models.BuAsyncAgentSchedulesQueryResponse>; 
  	postWorkforcemanagementBusinessunitWeekScheduleCopy(businessUnitId: string, weekId: string, scheduleId: string, body: Models.BuCopyScheduleRequest): Promise<Models.BuAsyncScheduleResponse>; 
  	postWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculations(businessUnitId: string, weekId: string, scheduleId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculationsOptions): Promise<Models.PerformancePredictionRecalculationResponse>; 
  	postWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculationsUploadurl(businessUnitId: string, weekId: string, scheduleId: string, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculationsUploadurlOptions): Promise<Models.PerformancePredictionRecalculationUploadResponse>; 
  	postWorkforcemanagementBusinessunitWeekScheduleReschedule(businessUnitId: string, weekId: string, scheduleId: string, body: Models.BuRescheduleRequest): Promise<Models.BuAsyncScheduleRunResponse>; 
  	postWorkforcemanagementBusinessunitWeekScheduleUpdate(businessUnitId: string, weekId: string, scheduleId: string, body: Models.ProcessScheduleUpdateUploadRequest): Promise<Models.BuAsyncScheduleResponse>; 
  	postWorkforcemanagementBusinessunitWeekScheduleUpdateUploadurl(businessUnitId: string, weekId: string, scheduleId: string, body: Models.UploadUrlRequestBody): Promise<Models.UpdateScheduleUploadResponse>; 
  	postWorkforcemanagementBusinessunitWeekSchedules(businessUnitId: string, weekId: string, body: Models.BuCreateBlankScheduleRequest): Promise<Models.BuScheduleMetadata>; 
  	postWorkforcemanagementBusinessunitWeekSchedulesGenerate(businessUnitId: string, weekId: string, body: Models.BuGenerateScheduleRequest): Promise<Models.BuAsyncScheduleRunResponse>; 
  	postWorkforcemanagementBusinessunitWeekSchedulesImport(businessUnitId: string, weekId: string, body: Models.WfmProcessUploadRequest): Promise<Models.ScheduleUploadProcessingResponse>; 
  	postWorkforcemanagementBusinessunitWeekSchedulesImportUploadurl(businessUnitId: string, weekId: string, body: Models.UploadUrlRequestBody): Promise<Models.ImportScheduleUploadResponse>; 
  	postWorkforcemanagementBusinessunitWeekShorttermforecastCopy(businessUnitId: string, weekDateId: string, forecastId: string, body: Models.CopyBuForecastRequest, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitWeekShorttermforecastCopyOptions): Promise<Models.AsyncForecastOperationResult>; 
  	postWorkforcemanagementBusinessunitWeekShorttermforecastsGenerate(businessUnitId: string, weekDateId: string, body: Models.GenerateBuForecastRequest, opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitWeekShorttermforecastsGenerateOptions): Promise<Models.AsyncForecastOperationResult>; 
  	postWorkforcemanagementBusinessunitWeekShorttermforecastsImport(businessUnitId: string, weekDateId: string, body: Models.WfmProcessUploadRequest): Promise<Models.ImportForecastResponse>; 
  	postWorkforcemanagementBusinessunitWeekShorttermforecastsImportUploadurl(businessUnitId: string, weekDateId: string, body: Models.UploadUrlRequestBody): Promise<Models.ImportForecastUploadResponse>; 
  	postWorkforcemanagementBusinessunits(opts?: WorkforceManagementApi.postWorkforcemanagementBusinessunitsOptions): Promise<Models.BusinessUnitResponse>; 
  	postWorkforcemanagementCalendarUrlIcs(opts?: WorkforceManagementApi.postWorkforcemanagementCalendarUrlIcsOptions): Promise<Models.CalendarUrlResponse>; 
  	postWorkforcemanagementHistoricaldataDeletejob(): Promise<Models.HistoricalImportDeleteJobResponse>; 
  	postWorkforcemanagementHistoricaldataValidate(opts?: WorkforceManagementApi.postWorkforcemanagementHistoricaldataValidateOptions): Promise<void>; 
  	postWorkforcemanagementIntegrationsHriTimeofftypesJobs(hrisIntegrationId: string): Promise<Models.HrisTimeOffTypesResponse>; 
  	postWorkforcemanagementManagementunitAgentschedulesSearch(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitAgentschedulesSearchOptions): Promise<Models.BuAsyncAgentSchedulesSearchResponse>; 
  	postWorkforcemanagementManagementunitHistoricaladherencequery(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitHistoricaladherencequeryOptions): Promise<Models.WfmHistoricalAdherenceResponse>; 
  	postWorkforcemanagementManagementunitMove(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitMoveOptions): Promise<Models.MoveManagementUnitResponse>; 
  	postWorkforcemanagementManagementunitSchedulesSearch(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitSchedulesSearchOptions): Promise<Models.UserScheduleContainer>; 
  	postWorkforcemanagementManagementunitShrinkageJobs(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitShrinkageJobsOptions): Promise<Models.WfmHistoricalShrinkageResponse>; 
  	postWorkforcemanagementManagementunitTimeofflimits(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeofflimitsOptions): Promise<Models.TimeOffLimit>; 
  	postWorkforcemanagementManagementunitTimeofflimitsValuesQuery(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeofflimitsValuesQueryOptions): Promise<Models.QueryTimeOffLimitValuesResponse>; 
  	postWorkforcemanagementManagementunitTimeoffplans(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeoffplansOptions): Promise<Models.TimeOffPlan>; 
  	postWorkforcemanagementManagementunitTimeoffrequests(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeoffrequestsOptions): Promise<Models.TimeOffRequestList>; 
  	postWorkforcemanagementManagementunitTimeoffrequestsIntegrationstatusQuery(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeoffrequestsIntegrationstatusQueryOptions): Promise<Models.UserTimeOffIntegrationStatusResponseListing>; 
  	postWorkforcemanagementManagementunitTimeoffrequestsQuery(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeoffrequestsQueryOptions): Promise<Models.TimeOffRequestListing>; 
  	postWorkforcemanagementManagementunitTimeoffrequestsWaitlistpositionsQuery(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitTimeoffrequestsWaitlistpositionsQueryOptions): Promise<Models.WaitlistPositionListing>; 
  	postWorkforcemanagementManagementunitUserTimeoffbalanceJobs(managementUnitId: string, userId: string, body: Models.TimeOffBalanceRequest): Promise<Models.TimeOffBalancesResponse>; 
  	postWorkforcemanagementManagementunitUserTimeoffrequestTimeoffbalanceJobs(managementUnitId: string, userId: string, timeOffRequestId: string): Promise<Models.TimeOffBalancesResponse>; 
  	postWorkforcemanagementManagementunitUserTimeoffrequestsEstimate(managementUnitId: string, userId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitUserTimeoffrequestsEstimateOptions): Promise<Models.EstimateAvailableTimeOffResponse>; 
  	postWorkforcemanagementManagementunitWeekShifttradeMatch(managementUnitId: string, weekDateId: string, tradeId: string, body: Models.MatchShiftTradeRequest): Promise<Models.MatchShiftTradeResponse>; 
  	postWorkforcemanagementManagementunitWeekShifttrades(managementUnitId: string, weekDateId: string, body: Models.AddShiftTradeRequest): Promise<Models.ShiftTradeResponse>; 
  	postWorkforcemanagementManagementunitWeekShifttradesSearch(managementUnitId: string, weekDateId: string, body: Models.SearchShiftTradesRequest, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWeekShifttradesSearchOptions): Promise<Models.SearchShiftTradesResponse>; 
  	postWorkforcemanagementManagementunitWeekShifttradesStateBulk(managementUnitId: string, weekDateId: string, body: Models.BulkShiftTradeStateUpdateRequest, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWeekShifttradesStateBulkOptions): Promise<Models.BulkUpdateShiftTradeStateResponse>; 
  	postWorkforcemanagementManagementunitWorkplanCopy(managementUnitId: string, workPlanId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWorkplanCopyOptions): Promise<Models.WorkPlan>; 
  	postWorkforcemanagementManagementunitWorkplanValidate(managementUnitId: string, workPlanId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWorkplanValidateOptions): Promise<Models.ValidateWorkPlanResponse>; 
  	postWorkforcemanagementManagementunitWorkplanrotationCopy(managementUnitId: string, workPlanRotationId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWorkplanrotationCopyOptions): Promise<Models.WorkPlanRotationResponse>; 
  	postWorkforcemanagementManagementunitWorkplanrotations(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWorkplanrotationsOptions): Promise<Models.WorkPlanRotationResponse>; 
  	postWorkforcemanagementManagementunitWorkplans(managementUnitId: string, opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitWorkplansOptions): Promise<Models.WorkPlan>; 
  	postWorkforcemanagementManagementunits(opts?: WorkforceManagementApi.postWorkforcemanagementManagementunitsOptions): Promise<Models.ManagementUnit>; 
  	postWorkforcemanagementNotificationsUpdate(opts?: WorkforceManagementApi.postWorkforcemanagementNotificationsUpdateOptions): Promise<Models.UpdateNotificationsResponse>; 
  	postWorkforcemanagementSchedules(opts?: WorkforceManagementApi.postWorkforcemanagementSchedulesOptions): Promise<Models.UserScheduleContainer>; 
  	postWorkforcemanagementTeamAdherenceHistorical(teamId: string, opts?: WorkforceManagementApi.postWorkforcemanagementTeamAdherenceHistoricalOptions): Promise<Models.WfmHistoricalAdherenceResponse>; 
  	postWorkforcemanagementTeamShrinkageJobs(teamId: string, opts?: WorkforceManagementApi.postWorkforcemanagementTeamShrinkageJobsOptions): Promise<Models.WfmHistoricalShrinkageResponse>; 
  	postWorkforcemanagementTimeoffbalanceJobs(body: Models.TimeOffBalanceRequest): Promise<Models.TimeOffBalancesResponse>; 
  	postWorkforcemanagementTimeofflimitsAvailableQuery(opts?: WorkforceManagementApi.postWorkforcemanagementTimeofflimitsAvailableQueryOptions): Promise<Models.AvailableTimeOffResponse>; 
  	postWorkforcemanagementTimeoffrequests(opts?: WorkforceManagementApi.postWorkforcemanagementTimeoffrequestsOptions): Promise<Models.TimeOffRequestResponse>; 
  	postWorkforcemanagementTimeoffrequestsEstimate(opts?: WorkforceManagementApi.postWorkforcemanagementTimeoffrequestsEstimateOptions): Promise<Models.EstimateAvailableTimeOffResponse>; 
  	postWorkforcemanagementTimeoffrequestsIntegrationstatusQuery(opts?: WorkforceManagementApi.postWorkforcemanagementTimeoffrequestsIntegrationstatusQueryOptions): Promise<Models.TimeOffIntegrationStatusResponseListing>; 
  	putWorkforcemanagementAgentIntegrationsHris(agentId: string, body: Models.AgentIntegrationsRequest): Promise<Models.AgentIntegrationsResponse>; 
  	putWorkforcemanagementBusinessunitTimeofflimitValues(businessUnitId: string, timeOffLimitId: string, opts?: WorkforceManagementApi.putWorkforcemanagementBusinessunitTimeofflimitValuesOptions): Promise<Models.BuTimeOffLimitResponse>; 
  	putWorkforcemanagementManagementunitTimeofflimitValues(managementUnitId: string, timeOffLimitId: string, opts?: WorkforceManagementApi.putWorkforcemanagementManagementunitTimeofflimitValuesOptions): Promise<Models.TimeOffLimit>;
}

declare namespace WorkforceManagementApi { 
	export interface getWorkforcemanagementBusinessunitOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementBusinessunitActivitycodesOptions { 
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementBusinessunitManagementunitsOptions { 
		"feature"?: string;
		"divisionId"?: string;
	}
	export interface getWorkforcemanagementBusinessunitServicegoaltemplateOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementBusinessunitServicegoaltemplatesOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementBusinessunitStaffinggroupsOptions { 
		"managementUnitId"?: string;
	}
	export interface getWorkforcemanagementBusinessunitTimeofflimitsOptions { 
		"managementUnitId"?: string;
	}
	export interface getWorkforcemanagementBusinessunitTimeoffplansOptions { 
		"managementUnitId"?: string;
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementBusinessunitWeekScheduleOptions { 
		"expand"?: string;
	}
	export interface getWorkforcemanagementBusinessunitWeekScheduleHeadcountforecastOptions { 
		"forceDownload"?: boolean;
	}
	export interface getWorkforcemanagementBusinessunitWeekSchedulesOptions { 
		"includeOnlyPublished"?: boolean;
		"expand"?: string;
	}
	export interface getWorkforcemanagementBusinessunitWeekShorttermforecastOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementBusinessunitWeekShorttermforecastDataOptions { 
		"weekNumber"?: number;
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementBusinessunitWeekShorttermforecastLongtermforecastdataOptions { 
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementBusinessunitWeekShorttermforecastStaffingrequirementOptions { 
		"weekNumbers"?: Array<string>;
	}
	export interface getWorkforcemanagementBusinessunitsOptions { 
		"feature"?: string;
		"divisionId"?: string;
	}
	export interface getWorkforcemanagementBusinessunitsDivisionviewsOptions { 
		"divisionId"?: Array<string>;
	}
	export interface getWorkforcemanagementManagementunitOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementManagementunitAdherenceOptions { 
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementManagementunitAgentOptions { 
		"excludeCapabilities"?: boolean;
	}
	export interface getWorkforcemanagementManagementunitUserTimeoffrequestsOptions { 
		"recentlyReviewed"?: boolean;
	}
	export interface getWorkforcemanagementManagementunitWeekScheduleOptions { 
		"expand"?: string;
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementManagementunitWeekSchedulesOptions { 
		"includeOnlyPublished"?: boolean;
		"earliestWeekDate"?: string;
		"latestWeekDate"?: string;
	}
	export interface getWorkforcemanagementManagementunitWeekShifttradesOptions { 
		"evaluateMatches"?: boolean;
		"forceDownloadService"?: boolean;
	}
	export interface getWorkforcemanagementManagementunitWorkplanOptions { 
		"includeOnly"?: Array<string>;
	}
	export interface getWorkforcemanagementManagementunitWorkplanrotationsOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementManagementunitWorkplansOptions { 
		"expand"?: Array<string>;
	}
	export interface getWorkforcemanagementManagementunitsOptions { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"expand"?: string;
		"feature"?: string;
		"divisionId"?: string;
	}
	export interface getWorkforcemanagementManagementunitsDivisionviewsOptions { 
		"divisionId"?: Array<string>;
	}
	export interface getWorkforcemanagementTimeoffrequestsOptions { 
		"recentlyReviewed"?: boolean;
	}
	export interface patchWorkforcemanagementBusinessunitOptions { 
		"body"?: Models.UpdateBusinessUnitRequest;
	}
	export interface patchWorkforcemanagementBusinessunitActivitycodeOptions { 
		"body"?: Models.UpdateActivityCodeRequest;
	}
	export interface patchWorkforcemanagementBusinessunitPlanninggroupOptions { 
		"body"?: Models.UpdatePlanningGroupRequest;
	}
	export interface patchWorkforcemanagementBusinessunitSchedulingRunOptions { 
		"body"?: Models.PatchBuScheduleRunRequest;
	}
	export interface patchWorkforcemanagementBusinessunitServicegoaltemplateOptions { 
		"body"?: Models.UpdateServiceGoalTemplate;
	}
	export interface patchWorkforcemanagementBusinessunitStaffinggroupOptions { 
		"body"?: Models.UpdateStaffingGroupRequest;
	}
	export interface patchWorkforcemanagementBusinessunitTimeoffplanOptions { 
		"body"?: Models.BuUpdateTimeOffPlanRequest;
	}
	export interface patchWorkforcemanagementManagementunitOptions { 
		"body"?: Models.UpdateManagementUnitRequest;
	}
	export interface patchWorkforcemanagementManagementunitAgentsOptions { 
		"body"?: Models.UpdateMuAgentsRequest;
	}
	export interface patchWorkforcemanagementManagementunitTimeofflimitOptions { 
		"body"?: Models.UpdateTimeOffLimitRequest;
	}
	export interface patchWorkforcemanagementManagementunitTimeoffplanOptions { 
		"body"?: Models.UpdateTimeOffPlanRequest;
	}
	export interface patchWorkforcemanagementManagementunitTimeoffrequestUserIntegrationstatusOptions { 
		"body"?: Models.SetTimeOffIntegrationStatusRequest;
	}
	export interface patchWorkforcemanagementManagementunitUserTimeoffrequestOptions { 
		"body"?: Models.AdminTimeOffRequestPatch;
	}
	export interface patchWorkforcemanagementManagementunitWorkplanOptions { 
		"validationMode"?: string;
		"body"?: Models.WorkPlan;
	}
	export interface patchWorkforcemanagementManagementunitWorkplanrotationOptions { 
		"body"?: Models.UpdateWorkPlanRotationRequest;
	}
	export interface patchWorkforcemanagementTimeoffrequestOptions { 
		"body"?: Models.AgentTimeOffRequestPatch;
	}
	export interface postWorkforcemanagementAdherenceExplanationsQueryOptions { 
		"forceAsync"?: boolean;
		"forceDownloadService"?: boolean;
	}
	export interface postWorkforcemanagementAdherenceHistoricalOptions { 
		"body"?: Models.WfmHistoricalAdherenceQueryForUsers;
	}
	export interface postWorkforcemanagementAdherenceHistoricalBulkOptions { 
		"body"?: Models.WfmHistoricalAdherenceBulkQuery;
	}
	export interface postWorkforcemanagementAgentAdherenceExplanationsQueryOptions { 
		"forceAsync"?: boolean;
		"forceDownloadService"?: boolean;
	}
	export interface postWorkforcemanagementAgentsOptions { 
		"body"?: Models.MoveAgentsRequest;
	}
	export interface postWorkforcemanagementAgentsIntegrationsHrisQueryOptions { 
		"body"?: Models.QueryAgentsIntegrationsRequest;
	}
	export interface postWorkforcemanagementAgentschedulesMineOptions { 
		"body"?: Models.BuGetCurrentAgentScheduleRequest;
	}
	export interface postWorkforcemanagementBusinessunitActivitycodesOptions { 
		"body"?: Models.CreateActivityCodeRequest;
	}
	export interface postWorkforcemanagementBusinessunitAdherenceExplanationsQueryOptions { 
		"forceAsync"?: boolean;
		"forceDownloadService"?: boolean;
	}
	export interface postWorkforcemanagementBusinessunitAgentschedulesSearchOptions { 
		"forceAsync"?: boolean;
		"forceDownloadService"?: boolean;
		"body"?: Models.BuSearchAgentSchedulesRequest;
	}
	export interface postWorkforcemanagementBusinessunitIntradayOptions { 
		"forceAsync"?: boolean;
		"body"?: Models.IntradayPlanningGroupRequest;
	}
	export interface postWorkforcemanagementBusinessunitPlanninggroupsOptions { 
		"body"?: Models.CreatePlanningGroupRequest;
	}
	export interface postWorkforcemanagementBusinessunitServicegoaltemplatesOptions { 
		"body"?: Models.CreateServiceGoalTemplate;
	}
	export interface postWorkforcemanagementBusinessunitStaffinggroupsOptions { 
		"body"?: Models.CreateStaffingGroupRequest;
	}
	export interface postWorkforcemanagementBusinessunitStaffinggroupsQueryOptions { 
		"body"?: Models.QueryUserStaffingGroupListRequest;
	}
	export interface postWorkforcemanagementBusinessunitTimeofflimitsOptions { 
		"body"?: Models.BuCreateTimeOffLimitRequest;
	}
	export interface postWorkforcemanagementBusinessunitTimeofflimitsValuesQueryOptions { 
		"body"?: Models.QueryTimeOffLimitValuesRequest;
	}
	export interface postWorkforcemanagementBusinessunitTimeoffplansOptions { 
		"body"?: Models.BuCreateTimeOffPlanRequest;
	}
	export interface postWorkforcemanagementBusinessunitWeekScheduleAgentschedulesQueryOptions { 
		"forceAsync"?: boolean;
		"forceDownloadService"?: boolean;
	}
	export interface postWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculationsOptions { 
		"body"?: Models.WfmProcessUploadRequest;
	}
	export interface postWorkforcemanagementBusinessunitWeekSchedulePerformancepredictionsRecalculationsUploadurlOptions { 
		"body"?: Models.UploadUrlRequestBody;
	}
	export interface postWorkforcemanagementBusinessunitWeekShorttermforecastCopyOptions { 
		"forceAsync"?: boolean;
	}
	export interface postWorkforcemanagementBusinessunitWeekShorttermforecastsGenerateOptions { 
		"forceAsync"?: boolean;
	}
	export interface postWorkforcemanagementBusinessunitsOptions { 
		"body"?: Models.CreateBusinessUnitRequest;
	}
	export interface postWorkforcemanagementCalendarUrlIcsOptions { 
		"language"?: string;
	}
	export interface postWorkforcemanagementHistoricaldataValidateOptions { 
		"body"?: Models.ValidationServiceRequest;
	}
	export interface postWorkforcemanagementManagementunitAgentschedulesSearchOptions { 
		"forceAsync"?: boolean;
		"forceDownloadService"?: boolean;
		"body"?: Models.BuSearchAgentSchedulesRequest;
	}
	export interface postWorkforcemanagementManagementunitHistoricaladherencequeryOptions { 
		"body"?: Models.WfmHistoricalAdherenceQuery;
	}
	export interface postWorkforcemanagementManagementunitMoveOptions { 
		"body"?: Models.MoveManagementUnitRequest;
	}
	export interface postWorkforcemanagementManagementunitSchedulesSearchOptions { 
		"body"?: Models.UserListScheduleRequestBody;
	}
	export interface postWorkforcemanagementManagementunitShrinkageJobsOptions { 
		"body"?: Models.WfmHistoricalShrinkageRequest;
	}
	export interface postWorkforcemanagementManagementunitTimeofflimitsOptions { 
		"body"?: Models.CreateTimeOffLimitRequest;
	}
	export interface postWorkforcemanagementManagementunitTimeofflimitsValuesQueryOptions { 
		"body"?: Models.QueryTimeOffLimitValuesRequest;
	}
	export interface postWorkforcemanagementManagementunitTimeoffplansOptions { 
		"body"?: Models.CreateTimeOffPlanRequest;
	}
	export interface postWorkforcemanagementManagementunitTimeoffrequestsOptions { 
		"body"?: Models.CreateAdminTimeOffRequest;
	}
	export interface postWorkforcemanagementManagementunitTimeoffrequestsIntegrationstatusQueryOptions { 
		"body"?: Models.QueryTimeOffIntegrationStatusRequest;
	}
	export interface postWorkforcemanagementManagementunitTimeoffrequestsQueryOptions { 
		"forceDownloadService"?: boolean;
		"body"?: Models.TimeOffRequestQueryBody;
	}
	export interface postWorkforcemanagementManagementunitTimeoffrequestsWaitlistpositionsQueryOptions { 
		"body"?: Models.QueryWaitlistPositionsRequest;
	}
	export interface postWorkforcemanagementManagementunitUserTimeoffrequestsEstimateOptions { 
		"body"?: Models.EstimateAvailableTimeOffRequest;
	}
	export interface postWorkforcemanagementManagementunitWeekShifttradesSearchOptions { 
		"forceDownloadService"?: boolean;
	}
	export interface postWorkforcemanagementManagementunitWeekShifttradesStateBulkOptions { 
		"forceAsync"?: boolean;
	}
	export interface postWorkforcemanagementManagementunitWorkplanCopyOptions { 
		"body"?: Models.CopyWorkPlan;
	}
	export interface postWorkforcemanagementManagementunitWorkplanValidateOptions { 
		"expand"?: Array<string>;
		"body"?: Models.WorkPlanValidationRequest;
	}
	export interface postWorkforcemanagementManagementunitWorkplanrotationCopyOptions { 
		"body"?: Models.CopyWorkPlanRotationRequest;
	}
	export interface postWorkforcemanagementManagementunitWorkplanrotationsOptions { 
		"body"?: Models.AddWorkPlanRotationRequest;
	}
	export interface postWorkforcemanagementManagementunitWorkplansOptions { 
		"validationMode"?: string;
		"body"?: Models.CreateWorkPlan;
	}
	export interface postWorkforcemanagementManagementunitsOptions { 
		"body"?: Models.CreateManagementUnitApiRequest;
	}
	export interface postWorkforcemanagementNotificationsUpdateOptions { 
		"body"?: Models.UpdateNotificationsRequest;
	}
	export interface postWorkforcemanagementSchedulesOptions { 
		"body"?: Models.CurrentUserScheduleRequestBody;
	}
	export interface postWorkforcemanagementTeamAdherenceHistoricalOptions { 
		"body"?: Models.WfmHistoricalAdherenceQueryForTeams;
	}
	export interface postWorkforcemanagementTeamShrinkageJobsOptions { 
		"body"?: Models.WfmHistoricalShrinkageTeamsRequest;
	}
	export interface postWorkforcemanagementTimeofflimitsAvailableQueryOptions { 
		"body"?: Models.AvailableTimeOffRequest;
	}
	export interface postWorkforcemanagementTimeoffrequestsOptions { 
		"body"?: Models.CreateAgentTimeOffRequest;
	}
	export interface postWorkforcemanagementTimeoffrequestsEstimateOptions { 
		"body"?: Models.EstimateAvailableTimeOffRequest;
	}
	export interface postWorkforcemanagementTimeoffrequestsIntegrationstatusQueryOptions { 
		"body"?: Models.CurrentUserTimeOffIntegrationStatusRequest;
	}
	export interface putWorkforcemanagementBusinessunitTimeofflimitValuesOptions { 
		"body"?: Models.BuSetTimeOffLimitValuesRequest;
	}
	export interface putWorkforcemanagementManagementunitTimeofflimitValuesOptions { 
		"body"?: Models.SetTimeOffLimitValuesRequest;
	}
}

declare namespace Models { 
	export interface ADFS { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface AcceleratorInput { 
		"dryRun"?: boolean;
		"acceleratorId": string;
		"parameters"?: Array<Models.AcceleratorParameter>;
	}
	
	export interface AcceleratorList { 
		"entities"?: Array<Models.AcceleratorMetadata>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AcceleratorMetadata { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"origin"?: string;
		"type"?: string;
		"classification"?: string;
		"tags"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface AcceleratorParameter { 
		"name": string;
		"value": string;
	}
	
	export interface AcceleratorSpecification { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"origin"?: string;
		"type"?: string;
		"classification"?: string;
		"tags"?: Array<string>;
		"permissions"?: Array<string>;
		"products"?: Array<string>;
		"documentation"?: Array<Models.MetadataDocumentation>;
		"presentation"?: Array<Models.MetadataPresentation>;
		"results"?: Models.MetadataResults;
		"selfUri"?: string;
	}
	
	export interface AcdEndDetailEventTopicAcdEndEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"disconnectType"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"queueId"?: string;
		"divisionId"?: string;
		"acdOutcome"?: string;
		"answeredUserId"?: string;
		"requestedRoutings"?: Array<string>;
		"usedRouting"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedLanguageId"?: string;
		"requestedRoutingUserIds"?: Array<string>;
		"routingPriority"?: number;
		"connectedDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface AcdStartDetailEventTopicAcdStartEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"queueId"?: string;
		"divisionId"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface AchievedOutcome { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface AcknowledgeScreenRecordingRequest { 
		"participantJid"?: string;
		"roomId"?: string;
		"conversationId"?: string;
	}
	
	export interface Action { 
		"id"?: string;
		"name"?: string;
		"integrationId"?: string;
		"category"?: string;
		"contract"?: Models.ActionContract;
		"version"?: number;
		"secure"?: boolean;
		"config"?: Models.ActionConfig;
		"selfUri"?: string;
	}
	
	export interface ActionAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface ActionAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.ActionAggregateQueryPredicate>;
	}
	
	export interface ActionAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.ActionAggregateQueryClause>;
		"predicates"?: Array<Models.ActionAggregateQueryPredicate>;
	}
	
	export interface ActionAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface ActionAggregateQueryResponse { 
		"results"?: Array<Models.ActionAggregateDataContainer>;
	}
	
	export interface ActionAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.ActionAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.ActionAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface ActionAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface ActionAsyncAggregateQueryResponse { 
		"results"?: Array<Models.ActionAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface ActionAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.ActionAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.ActionAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface ActionCertificate { 
		"signingAuthority"?: string;
		"certificate"?: string;
		"status"?: string;
		"type"?: string;
	}
	
	export interface ActionCertificateListing { 
		"entities"?: Array<Models.ActionCertificate>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ActionConfig { 
		"timeoutSeconds"?: number;
		"request"?: Models.RequestConfig;
		"response"?: Models.ResponseConfig;
	}
	
	export interface ActionContract { 
		"output"?: Models.ActionOutput;
		"input"?: Models.ActionInput;
	}
	
	export interface ActionContractInput { 
		"input": Models.PostInputContract;
		"output": Models.PostOutputContract;
	}
	
	export interface ActionEntityListing { 
		"entities"?: Array<Models.Action>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ActionEventActionMap { 
		"id": string;
		"selfUri"?: string;
		"version": number;
		"displayName": string;
	}
	
	export interface ActionEventRequest { 
		"id"?: string;
		"sessionId": string;
		"actionId": string;
		"actionState": string;
		"errorCode"?: string;
		"errorMessage"?: string;
		"selfUri"?: string;
	}
	
	export interface ActionInput { 
		"inputSchema"?: Models.JsonSchemaDocument;
		"inputSchemaFlattened"?: Models.JsonSchemaDocument;
		"inputSchemaUri"?: string;
	}
	
	export interface ActionMap { 
		"id"?: string;
		"version"?: number;
		"isActive"?: boolean;
		"displayName": string;
		"triggerWithSegments": Array<string>;
		"triggerWithEventConditions"?: Array<Models.EventCondition>;
		"triggerWithOutcomeProbabilityConditions"?: Array<Models.OutcomeProbabilityCondition>;
		"triggerWithOutcomePercentileConditions"?: Array<Models.OutcomePercentileCondition>;
		"triggerWithOutcomeQuantileConditions"?: Array<Models.OutcomeQuantileCondition>;
		"pageUrlConditions": Array<Models.UrlCondition>;
		"activation"?: Models.Activation;
		"weight"?: number;
		"action"?: Models.ActionMapAction;
		"actionMapScheduleGroups"?: Models.ActionMapScheduleGroups;
		"ignoreFrequencyCap"?: boolean;
		"selfUri"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"startDate"?: string;
		"endDate"?: string;
	}
	
	export interface ActionMapAction { 
		"actionTemplate"?: Models.ActionMapActionTemplate;
		"mediaType"?: string;
		"actionTargetId"?: string;
		"isPacingEnabled"?: boolean;
		"props"?: Models.ActionProperties;
		"architectFlowFields"?: Models.ArchitectFlowFields;
		"webMessagingOfferFields"?: Models.WebMessagingOfferFields;
		"openActionFields"?: Models.OpenActionFields;
	}
	
	export interface ActionMapActionTemplate { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ActionMapEstimateOutcomeCriteria { 
		"outcomeId": string;
		"maxProbability"?: number;
		"probability"?: number;
		"quantile"?: number;
		"maxQuantile"?: number;
	}
	
	export interface ActionMapEstimateRequest { 
		"segmentIds"?: Array<string>;
		"outcomeCriteria"?: Models.ActionMapEstimateOutcomeCriteria;
	}
	
	export interface ActionMapEstimateResult { 
		"qualifiedSessionCount"?: number;
		"totalSessionCount"?: number;
		"perSegmentCounts"?: Array<Models.SegmentEstimateCount>;
		"outcomesScoresCount"?: number;
	}
	
	export interface ActionMapListing { 
		"entities"?: Array<Models.ActionMap>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ActionMapScheduleGroup { 
		"id": string;
	}
	
	export interface ActionMapScheduleGroups { 
		"actionMapScheduleGroup": Models.ActionMapScheduleGroup;
		"emergencyActionMapScheduleGroup"?: Models.ActionMapScheduleGroup;
	}
	
	export interface ActionOutput { 
		"successSchema"?: Models.JsonSchemaDocument;
		"successSchemaUri"?: string;
		"errorSchema"?: Models.JsonSchemaDocument;
		"errorSchemaUri"?: string;
		"successSchemaFlattened"?: Models.JsonSchemaDocument;
		"errorSchemaFlattened"?: object;
	}
	
	export interface ActionProperties { 
		"webchatPrompt"?: string;
		"webchatTitleText"?: string;
		"webchatAcceptText"?: string;
		"webchatDeclineText"?: string;
		"webchatSurvey"?: Models.ActionSurvey;
	}
	
	export interface ActionSurvey { 
		"questions": Array<Models.JourneySurveyQuestion>;
	}
	
	export interface ActionTarget { 
		"id"?: string;
		"name"?: string;
		"userData"?: Array<Models.KeyValue>;
		"supportedMediaTypes"?: Array<string>;
		"state"?: string;
		"description"?: string;
		"serviceLevel"?: Models.ServiceLevel;
		"shortAbandonThreshold"?: number;
		"selfUri"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
	}
	
	export interface ActionTargetListing { 
		"entities"?: Array<Models.ActionTarget>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ActionTemplate { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"version"?: number;
		"mediaType": string;
		"state": string;
		"contentOffer"?: Models.ContentOffer;
		"selfUri"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
	}
	
	export interface ActionTemplateListing { 
		"entities"?: Array<Models.ActionTemplate>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Actions { 
		"skillsToRemove"?: Array<Models.SkillsToRemove>;
	}
	
	export interface Activation { 
		"type": string;
		"delayInSeconds"?: number;
	}
	
	export interface ActiveAlertCount { 
		"count"?: number;
	}
	
	export interface ActivityCode { 
		"id"?: string;
		"selfUri"?: string;
		"name"?: string;
		"isActive"?: boolean;
		"isDefault"?: boolean;
		"category"?: string;
		"lengthInMinutes"?: number;
		"countsAsPaidTime"?: boolean;
		"countsAsWorkTime"?: boolean;
		"agentTimeOffSelectable"?: boolean;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface ActivityCodeContainer { 
		"activityCodes"?: { [key: string]: Models.ActivityCode; };
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface ActivityCodeReference { 
		"id": string;
		"name"?: string;
		"secondaryPresences"?: Array<Models.SecondaryPresence>;
		"selfUri"?: string;
	}
	
	export interface AcwDetailEventTopicAfterCallWorkEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"userId"?: string;
		"queueId"?: string;
		"wrapupCode"?: string;
		"wrapupNotes"?: string;
		"wrapupDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface AcwSettings { 
		"wrapupPrompt"?: string;
		"timeoutMs"?: number;
	}
	
	export interface AddAdherenceExplanationAdminRequest { 
		"type": string;
		"startDate": string;
		"lengthMinutes": number;
		"notes"?: string;
		"status"?: string;
	}
	
	export interface AddAdherenceExplanationAgentRequest { 
		"type": string;
		"startDate": string;
		"lengthMinutes": number;
		"notes"?: string;
	}
	
	export interface AddConversationRequest { 
		"conversationId": string;
	}
	
	export interface AddConversationResponse { 
		"conversation"?: Models.ConversationReference;
		"appointment"?: Models.CoachingAppointmentReference;
	}
	
	export interface AddShiftTradeRequest { 
		"scheduleId": string;
		"initiatingShiftId": string;
		"receivingUserId"?: string;
		"expiration"?: string;
		"acceptableIntervals"?: Array<string>;
	}
	
	export interface AddWorkPlanRotationAgentRequest { 
		"userId": string;
		"dateRange": Models.DateRangeWithOptionalEnd;
		"position": number;
	}
	
	export interface AddWorkPlanRotationRequest { 
		"name": string;
		"dateRange": Models.DateRangeWithOptionalEnd;
		"agents"?: Array<Models.AddWorkPlanRotationAgentRequest>;
		"pattern": Models.WorkPlanPatternRequest;
	}
	
	export interface AdditionalLanguagesIntent { 
		"id"?: string;
		"utterances"?: Array<Models.NluUtterance>;
	}
	
	export interface AdditionalLanguagesSynonyms { 
		"synonyms"?: Array<string>;
	}
	
	export interface AdditionalMessage { 
		"textBody": string;
		"mediaIds"?: Array<string>;
		"stickerIds"?: Array<string>;
		"messagingTemplate"?: Models.MessagingTemplateRequest;
	}
	
	export interface Address { 
		"name"?: string;
		"nameRaw"?: string;
		"addressNormalized"?: string;
		"addressRaw"?: string;
		"addressDisplayable"?: string;
	}
	
	export interface AddressableEntity { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface AddressableEntityListing { 
		"entities"?: Array<Models.AddressableEntity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AddressableEntityRef { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface AddressableLicenseDefinition { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface AdherenceExplanationAsyncResponse { 
		"job"?: Models.AdherenceExplanationJobReference;
	}
	
	export interface AdherenceExplanationJob { 
		"id"?: string;
		"type"?: string;
		"status"?: string;
		"adherenceExplanation"?: Models.AdherenceExplanationResponse;
		"downloadUrl"?: string;
		"error"?: Models.ErrorBody;
		"agentQueryResponseTemplate"?: Models.AdherenceExplanationListingAgentQueryResponse;
		"buQueryResponseTemplate"?: Models.AdherenceExplanationListingBuQueryResponse;
		"selfUri"?: string;
	}
	
	export interface AdherenceExplanationJobReference { 
		"id"?: string;
		"type"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface AdherenceExplanationListing { 
		"entities"?: Array<Models.AdherenceExplanationResponse>;
	}
	
	export interface AdherenceExplanationListingAgentQueryResponse { 
		"entities"?: Array<Models.AdherenceExplanationResponse>;
	}
	
	export interface AdherenceExplanationListingBuQueryResponse { 
		"entities"?: Array<Models.AdherenceExplanationResponse>;
	}
	
	export interface AdherenceExplanationNotification { 
		"id"?: string;
		"agent"?: Models.UserReference;
		"managementUnit"?: Models.ManagementUnitReference;
		"businessUnit"?: Models.BusinessUnitReference;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"status"?: string;
		"type"?: string;
		"notes"?: string;
		"selfUri"?: string;
	}
	
	export interface AdherenceExplanationResponse { 
		"id"?: string;
		"agent": Models.UserReference;
		"managementUnit": Models.ManagementUnitReference;
		"businessUnit": Models.BusinessUnitReference;
		"type": string;
		"status": string;
		"startDate": string;
		"lengthMinutes": number;
		"notes"?: string;
		"reviewedBy"?: Models.UserReference;
		"reviewedDate"?: string;
		"selfUri"?: string;
	}
	
	export interface AdherenceSettings { 
		"severeAlertThresholdMinutes"?: number;
		"adherenceTargetPercent"?: number;
		"adherenceExceptionThresholdSeconds"?: number;
		"nonOnQueueActivitiesEquivalent"?: boolean;
		"trackOnQueueActivity"?: boolean;
		"ignoredActivityCategories"?: Models.IgnoredActivityCategories;
	}
	
	export interface AdhocRecordingTopicConversationData { 
		"id"?: string;
	}
	
	export interface AdhocRecordingTopicLockData { 
		"lockedBy"?: Models.AdhocRecordingTopicUserData;
		"dateCreated"?: string;
		"dateExpires"?: string;
	}
	
	export interface AdhocRecordingTopicRecordingDataV2 { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"workspace"?: Models.AdhocRecordingTopicWorkspaceData;
		"createdBy"?: Models.AdhocRecordingTopicUserData;
		"contentType"?: string;
		"contentLength"?: number;
		"filename"?: string;
		"changeNumber"?: number;
		"dateUploaded"?: string;
		"uploadedBy"?: Models.AdhocRecordingTopicUserData;
		"lockInfo"?: Models.AdhocRecordingTopicLockData;
		"selfUri"?: string;
		"durationMillieconds"?: number;
		"conversation"?: Models.AdhocRecordingTopicConversationData;
		"read"?: boolean;
	}
	
	export interface AdhocRecordingTopicUserData { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface AdhocRecordingTopicWorkspaceData { 
		"id"?: string;
	}
	
	export interface Adjacents { 
		"superiors"?: Array<Models.User>;
		"siblings"?: Array<Models.User>;
		"directReports"?: Array<Models.User>;
	}
	
	export interface AdjustableLiveSpeakerDetection { 
		"mode"?: string;
		"preconnectDuration"?: string;
		"eventName"?: string;
		"isPersonLikely"?: boolean;
		"totalRingbacks"?: number;
		"lineConnected"?: boolean;
	}
	
	export interface AdminTimeOffRequestPatch { 
		"status"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"notes"?: string;
		"fullDayManagementUnitDates"?: Array<string>;
		"partialDayStartDateTimes"?: Array<string>;
		"dailyDurationMinutes"?: number;
		"durationMinutes"?: Array<number>;
		"payableMinutes"?: Array<number>;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface AfterCallWork { 
		"startTime"?: string;
		"endTime"?: string;
		"state"?: string;
	}
	
	export interface AfterCallWorkUpdate { 
		"afterCallWorkRequired": boolean;
	}
	
	export interface Agent { 
		"stage"?: string;
	}
	
	export interface AgentActivity { 
		"id"?: string;
		"name"?: string;
		"agent"?: Models.User;
		"numEvaluations"?: number;
		"averageEvaluationScore"?: number;
		"numCriticalEvaluations"?: number;
		"averageCriticalScore"?: number;
		"highestEvaluationScore"?: number;
		"lowestEvaluationScore"?: number;
		"highestCriticalScore"?: number;
		"lowestCriticalScore"?: number;
		"agentEvaluatorActivityList"?: Array<Models.AgentEvaluatorActivity>;
		"numEvaluationsWithoutViewPermission"?: number;
		"selfUri"?: string;
	}
	
	export interface AgentActivityChangedTopicAgentActivity { 
		"id"?: string;
		"routingStatus"?: Models.AgentActivityChangedTopicRoutingStatus;
		"presence"?: Models.AgentActivityChangedTopicPresence;
		"outOfOffice"?: Models.AgentActivityChangedTopicOutOfOffice;
		"activeQueueIds"?: Array<string>;
		"dateActiveQueuesChanged"?: string;
	}
	
	export interface AgentActivityChangedTopicOrganizationPresence { 
		"id"?: string;
		"systemPresence"?: string;
	}
	
	export interface AgentActivityChangedTopicOutOfOffice { 
		"active"?: boolean;
		"modifiedDate"?: string;
	}
	
	export interface AgentActivityChangedTopicPresence { 
		"presenceDefinition"?: Models.AgentActivityChangedTopicOrganizationPresence;
		"presenceMessage"?: string;
		"modifiedDate"?: string;
	}
	
	export interface AgentActivityChangedTopicRoutingStatus { 
		"status"?: string;
		"startTime"?: string;
	}
	
	export interface AgentActivityEntityListing { 
		"entities"?: Array<Models.AgentActivity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AgentEvaluatorActivity { 
		"id"?: string;
		"name"?: string;
		"agent"?: Models.User;
		"evaluator"?: Models.User;
		"numEvaluations"?: number;
		"averageEvaluationScore"?: number;
		"numEvaluationsWithoutViewPermission"?: number;
		"selfUri"?: string;
	}
	
	export interface AgentIntegrationAssociationRequest { 
		"agentExternalId": string;
		"integrationId": string;
		"locked": boolean;
	}
	
	export interface AgentIntegrationAssociationResponse { 
		"agentExternalId": string;
		"integration": Models.WfmIntegrationReference;
		"locked": boolean;
	}
	
	export interface AgentIntegrationsRequest { 
		"selectedIntegrationId"?: string;
		"associatedIntegrations": Array<Models.AgentIntegrationAssociationRequest>;
	}
	
	export interface AgentIntegrationsResponse { 
		"agent": Models.UserReference;
		"selectedIntegration"?: Models.WfmIntegrationReference;
		"userSelected"?: boolean;
		"associatedIntegrations": Array<Models.AgentIntegrationAssociationResponse>;
	}
	
	export interface AgentManagementUnitReference { 
		"user"?: Models.UserReference;
		"managementUnit"?: Models.ManagementUnitReference;
		"businessUnit"?: Models.BusinessUnitReference;
	}
	
	export interface AgentMaxUtilizationResponse { 
		"utilization"?: { [key: string]: Models.MediaUtilization; };
		"level"?: string;
	}
	
	export interface AgentOwnedMappingPreview { 
		"agentOwnedColumn"?: string;
		"email"?: string;
		"userId"?: string;
		"exists"?: boolean;
		"isQueueMember"?: boolean;
		"recordCount"?: number;
	}
	
	export interface AgentOwnedMappingPreviewListing { 
		"entities"?: Array<Models.AgentOwnedMappingPreview>;
	}
	
	export interface AgentOwnedRouting { 
		"enableAgentOwnedCallbacks"?: boolean;
		"maxOwnedCallbackHours"?: number;
		"maxOwnedCallbackDelayHours"?: number;
	}
	
	export interface AgentPossibleWorkShiftsRequest { 
		"weekStartDate": string;
		"weekCount": number;
	}
	
	export interface AgentPossibleWorkShiftsResponse { 
		"weekStartDate"?: string;
		"pattern"?: Array<number>;
		"weeklyPossibleWorkShifts"?: Array<Models.PossibleWorkShiftsForWeek>;
		"schedulerIntervalLengthMinutes"?: number;
		"timeZone"?: string;
	}
	
	export interface AgentQueryAdherenceExplanationsRequest { 
		"startDate": string;
		"endDate": string;
	}
	
	export interface AgentQueryAdherenceExplanationsResponse { 
		"job"?: Models.AdherenceExplanationJobReference;
		"result"?: Models.AdherenceExplanationListingAgentQueryResponse;
		"downloadUrl"?: string;
	}
	
	export interface AgentQueueTimeRequest { 
		"agentId": string;
		"startOffsetMinutes": Array<number>;
		"onQueueLengthMinutesPerInterval": Array<number>;
	}
	
	export interface AgentTimeOffRequestPatch { 
		"markedAsRead"?: boolean;
		"status"?: string;
		"notes"?: string;
	}
	
	export interface AgentVideoSettings { 
		"allowCamera"?: boolean;
		"allowScreenShare"?: boolean;
		"background"?: string;
		"backgroundImage"?: Models.BackgroundImageSettings;
	}
	
	export interface AgentlessEmailSendRequestDto { 
		"senderType": string;
		"conversationId"?: string;
		"fromAddress": Models.EmailAddress;
		"toAddresses": Array<Models.EmailAddress>;
		"replyToAddress"?: Models.EmailAddress;
		"subject"?: string;
		"textBody"?: string;
		"htmlBody"?: string;
	}
	
	export interface AgentlessEmailSendResponseDto { 
		"id"?: string;
		"conversationId": string;
		"senderType": string;
		"fromAddress": Models.EmailAddress;
		"toAddresses": Array<Models.EmailAddress>;
		"replyToAddress"?: Models.EmailAddress;
		"subject"?: string;
		"dateCreated": string;
		"selfUri"?: string;
	}
	
	export interface AgentsIntegrationsListing { 
		"entities"?: Array<Models.AgentIntegrationsResponse>;
	}
	
	export interface AggregateMetricData { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: Models.StatisticalSummary;
	}
	
	export interface AggregateViewData { 
		"name"?: string;
		"stats"?: Models.StatisticalSummary;
	}
	
	export interface AggregationRange { 
		"gte"?: number;
		"lt"?: number;
	}
	
	export interface AggregationResult { 
		"type"?: string;
		"dimension"?: string;
		"metric"?: string;
		"count"?: number;
		"results"?: Array<Models.AggregationResultEntry>;
	}
	
	export interface AggregationResultEntry { 
		"count"?: number;
		"value"?: string;
		"gte"?: number;
		"lt"?: number;
	}
	
	export interface AlertListing { 
		"entities"?: Array<Models.CommonAlert>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AlertNotification { 
		"recipient": string;
		"notificationTypes": Array<string>;
		"locale"?: string;
	}
	
	export interface AlertRequest { 
		"type": string;
		"dateStart"?: string;
		"dateEnd"?: string;
		"unread"?: Models.UnreadFields;
		"validRequest"?: boolean;
	}
	
	export interface AlertRuleProperties { 
		"id"?: string;
		"name"?: string;
		"type": string;
	}
	
	export interface AlertSummary { 
		"entities": Array<Models.AlertSummaryEntity>;
		"conversation"?: Models.AddressableEntityRef;
		"metricType": string;
		"entitiesAreTeamMembers": boolean;
	}
	
	export interface AlertSummaryEntity { 
		"entityType": string;
		"user"?: Models.AddressableEntityRef;
		"group"?: Models.AddressableEntityRef;
		"queue"?: Models.AddressableEntityRef;
		"team"?: Models.AddressableEntityRef;
		"alerting": boolean;
	}
	
	export interface AlertingUnreadStatus { 
		"unread": boolean;
	}
	
	export interface AllTimePoints { 
		"user"?: Models.UserReference;
		"dateEndWorkday"?: string;
		"allTimePoints"?: number;
	}
	
	export interface Alteration { 
		"type"?: string;
		"start"?: string;
		"end"?: string;
	}
	
	export interface AlternativeShiftNotification { 
		"id"?: string;
		"weekDate": string;
		"granularity": string;
		"newState"?: string;
		"initiatingUser": Models.UserReference;
		"initiatingShiftDate": string;
		"receivingUser"?: Models.UserReference;
		"receivingShiftDate"?: string;
		"selfUri"?: string;
	}
	
	export interface AmazonLexRequest { 
		"requestAttributes"?: { [key: string]: string; };
		"sessionAttributes"?: { [key: string]: string; };
	}
	
	export interface AnalyticsAgentGroup { 
		"agentGroupId"?: string;
		"agentGroupType"?: string;
	}
	
	export interface AnalyticsConversation { 
		"conferenceStart"?: string;
		"conversationEnd"?: string;
		"conversationId"?: string;
		"conversationInitiator"?: string;
		"conversationStart"?: string;
		"customerParticipation"?: boolean;
		"divisionIds"?: Array<string>;
		"externalTag"?: string;
		"knowledgeBaseIds"?: Array<string>;
		"mediaStatsMinConversationMos"?: number;
		"mediaStatsMinConversationRFactor"?: number;
		"originatingDirection"?: string;
		"selfServed"?: boolean;
		"evaluations"?: Array<Models.AnalyticsEvaluation>;
		"surveys"?: Array<Models.AnalyticsSurvey>;
		"resolutions"?: Array<Models.AnalyticsResolution>;
		"participants"?: Array<Models.AnalyticsParticipant>;
	}
	
	export interface AnalyticsConversationAsyncQueryResponse { 
		"conversations"?: Array<Models.AnalyticsConversation>;
		"cursor"?: string;
		"dataAvailabilityDate"?: string;
	}
	
	export interface AnalyticsConversationQueryResponse { 
		"conversations"?: Array<Models.AnalyticsConversationWithoutAttributes>;
		"aggregations"?: Array<Models.AggregationResult>;
		"totalHits"?: number;
	}
	
	export interface AnalyticsConversationSegment { 
		"audioMuted"?: boolean;
		"conference"?: boolean;
		"destinationConversationId"?: string;
		"destinationSessionId"?: string;
		"disconnectType"?: string;
		"errorCode"?: string;
		"groupId"?: string;
		"q850ResponseCodes"?: Array<number>;
		"queueId"?: string;
		"requestedLanguageId"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedRoutingUserIds"?: Array<string>;
		"segmentEnd"?: string;
		"segmentStart"?: string;
		"segmentType"?: string;
		"sipResponseCodes"?: Array<number>;
		"sourceConversationId"?: string;
		"sourceSessionId"?: string;
		"subject"?: string;
		"videoMuted"?: boolean;
		"wrapUpCode"?: string;
		"wrapUpNote"?: string;
		"wrapUpTags"?: Array<string>;
		"scoredAgents"?: Array<Models.AnalyticsScoredAgent>;
		"properties"?: Array<Models.AnalyticsProperty>;
	}
	
	export interface AnalyticsConversationWithoutAttributes { 
		"conferenceStart"?: string;
		"conversationEnd"?: string;
		"conversationId"?: string;
		"conversationInitiator"?: string;
		"conversationStart"?: string;
		"customerParticipation"?: boolean;
		"divisionIds"?: Array<string>;
		"externalTag"?: string;
		"knowledgeBaseIds"?: Array<string>;
		"mediaStatsMinConversationMos"?: number;
		"mediaStatsMinConversationRFactor"?: number;
		"originatingDirection"?: string;
		"selfServed"?: boolean;
		"evaluations"?: Array<Models.AnalyticsEvaluation>;
		"surveys"?: Array<Models.AnalyticsSurvey>;
		"resolutions"?: Array<Models.AnalyticsResolution>;
		"participants"?: Array<Models.AnalyticsParticipantWithoutAttributes>;
	}
	
	export interface AnalyticsConversationWithoutAttributesMultiGetResponse { 
		"conversations"?: Array<Models.AnalyticsConversationWithoutAttributes>;
	}
	
	export interface AnalyticsDataRetentionResponse { 
		"retentionDays"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
	}
	
	export interface AnalyticsEvaluation { 
		"assigneeApplicable"?: boolean;
		"assigneeId"?: string;
		"calibrationId"?: string;
		"contextId"?: string;
		"deleted"?: boolean;
		"evaluationId"?: string;
		"evaluationStatus"?: string;
		"evaluatorId"?: string;
		"eventTime"?: string;
		"formId"?: string;
		"formName"?: string;
		"queueId"?: string;
		"released"?: boolean;
		"rescored"?: boolean;
		"userId"?: string;
		"oTotalCriticalScore"?: number;
		"oTotalScore"?: number;
	}
	
	export interface AnalyticsFlow { 
		"endingLanguage"?: string;
		"entryReason"?: string;
		"entryType"?: string;
		"exitReason"?: string;
		"flowId"?: string;
		"flowName"?: string;
		"flowType"?: string;
		"flowVersion"?: string;
		"issuedCallback"?: boolean;
		"recognitionFailureReason"?: string;
		"startingLanguage"?: string;
		"transferTargetAddress"?: string;
		"transferTargetName"?: string;
		"transferType"?: string;
		"outcomes"?: Array<Models.AnalyticsFlowOutcome>;
	}
	
	export interface AnalyticsFlowOutcome { 
		"flowOutcome"?: string;
		"flowOutcomeEndTimestamp"?: string;
		"flowOutcomeId"?: string;
		"flowOutcomeStartTimestamp"?: string;
		"flowOutcomeValue"?: string;
	}
	
	export interface AnalyticsMediaEndpointStat { 
		"codecs"?: Array<string>;
		"discardedPackets"?: number;
		"duplicatePackets"?: number;
		"eventTime"?: string;
		"invalidPackets"?: number;
		"maxLatencyMs"?: number;
		"minMos"?: number;
		"minRFactor"?: number;
		"overrunPackets"?: number;
		"receivedPackets"?: number;
		"underrunPackets"?: number;
	}
	
	export interface AnalyticsParticipant { 
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"flaggedReason"?: string;
		"participantId"?: string;
		"participantName"?: string;
		"purpose"?: string;
		"teamId"?: string;
		"userId"?: string;
		"sessions"?: Array<Models.AnalyticsSession>;
		"attributes"?: { [key: string]: string; };
	}
	
	export interface AnalyticsParticipantWithoutAttributes { 
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"flaggedReason"?: string;
		"participantId"?: string;
		"participantName"?: string;
		"purpose"?: string;
		"teamId"?: string;
		"userId"?: string;
		"sessions"?: Array<Models.AnalyticsSession>;
	}
	
	export interface AnalyticsProperty { 
		"property"?: string;
		"propertyType"?: string;
		"value"?: string;
	}
	
	export interface AnalyticsProposedAgent { 
		"agentRank"?: number;
		"proposedAgentId"?: string;
	}
	
	export interface AnalyticsQueryAggregation { 
		"type"?: string;
		"dimension"?: string;
		"metric"?: string;
		"size"?: number;
		"ranges"?: Array<Models.AggregationRange>;
	}
	
	export interface AnalyticsReportingSettings { 
		"piiMaskingEnabled"?: boolean;
		"queueAgentAccessObfuscation"?: boolean;
		"myInteractionsPiiMaskingEnabled"?: boolean;
	}
	
	export interface AnalyticsResolution { 
		"eventTime"?: string;
		"queueId"?: string;
		"userId"?: string;
		"nNextContactAvoided"?: number;
	}
	
	export interface AnalyticsRoutingStatusRecord { 
		"startTime"?: string;
		"endTime"?: string;
		"routingStatus"?: string;
	}
	
	export interface AnalyticsScoredAgent { 
		"agentScore"?: number;
		"scoredAgentId"?: string;
	}
	
	export interface AnalyticsSession { 
		"activeSkillIds"?: Array<string>;
		"acwSkipped"?: boolean;
		"addressFrom"?: string;
		"addressOther"?: string;
		"addressSelf"?: string;
		"addressTo"?: string;
		"agentAssistantId"?: string;
		"agentBullseyeRing"?: number;
		"agentOwned"?: boolean;
		"ani"?: string;
		"assignerId"?: string;
		"authenticated"?: boolean;
		"bargedParticipantId"?: string;
		"bcc"?: Array<string>;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: string;
		"callbackUserName"?: string;
		"cc"?: Array<string>;
		"cleared"?: boolean;
		"coachedParticipantId"?: string;
		"cobrowseRole"?: string;
		"cobrowseRoomId"?: string;
		"deliveryStatus"?: string;
		"deliveryStatusChangeDate"?: string;
		"destinationAddresses"?: Array<string>;
		"direction"?: string;
		"dispositionAnalyzer"?: string;
		"dispositionName"?: string;
		"dnis"?: string;
		"edgeId"?: string;
		"eligibleAgentCounts"?: Array<number>;
		"extendedDeliveryStatus"?: string;
		"flowInType"?: string;
		"flowOutType"?: string;
		"journeyActionId"?: string;
		"journeyActionMapId"?: string;
		"journeyActionMapVersion"?: number;
		"journeyCustomerId"?: string;
		"journeyCustomerIdType"?: string;
		"journeyCustomerSessionId"?: string;
		"journeyCustomerSessionIdType"?: string;
		"mediaBridgeId"?: string;
		"mediaCount"?: number;
		"mediaType"?: string;
		"messageType"?: string;
		"monitoredParticipantId"?: string;
		"outboundCampaignId"?: string;
		"outboundContactId"?: string;
		"outboundContactListId"?: string;
		"peerId"?: string;
		"protocolCallId"?: string;
		"provider"?: string;
		"recording"?: boolean;
		"remote"?: string;
		"remoteNameDisplayable"?: string;
		"removedSkillIds"?: Array<string>;
		"requestedRoutings"?: Array<string>;
		"roomId"?: string;
		"routingRing"?: number;
		"routingRule"?: string;
		"routingRuleType"?: string;
		"screenShareAddressSelf"?: string;
		"screenShareRoomId"?: string;
		"scriptId"?: string;
		"selectedAgentId"?: string;
		"selectedAgentRank"?: number;
		"sessionDnis"?: string;
		"sessionId"?: string;
		"sharingScreen"?: boolean;
		"skipEnabled"?: boolean;
		"timeoutSeconds"?: number;
		"usedRouting"?: string;
		"videoAddressSelf"?: string;
		"videoRoomId"?: string;
		"waitingInteractionCounts"?: Array<number>;
		"agentGroups"?: Array<Models.AnalyticsAgentGroup>;
		"proposedAgents"?: Array<Models.AnalyticsProposedAgent>;
		"mediaEndpointStats"?: Array<Models.AnalyticsMediaEndpointStat>;
		"flow"?: Models.AnalyticsFlow;
		"metrics"?: Array<Models.AnalyticsSessionMetric>;
		"segments"?: Array<Models.AnalyticsConversationSegment>;
	}
	
	export interface AnalyticsSessionMetric { 
		"emitDate"?: string;
		"name"?: string;
		"value"?: number;
	}
	
	export interface AnalyticsSurvey { 
		"eventTime"?: string;
		"queueId"?: string;
		"surveyCompletedDate"?: string;
		"surveyFormContextId"?: string;
		"surveyFormId"?: string;
		"surveyFormName"?: string;
		"surveyId"?: string;
		"surveyPartialResponse"?: boolean;
		"surveyPromoterScore"?: number;
		"surveyStatus"?: string;
		"surveyType"?: string;
		"userId"?: string;
		"oSurveyTotalScore"?: number;
	}
	
	export interface AnalyticsUserDetail { 
		"userId"?: string;
		"primaryPresence"?: Array<Models.AnalyticsUserPresenceRecord>;
		"routingStatus"?: Array<Models.AnalyticsRoutingStatusRecord>;
	}
	
	export interface AnalyticsUserDetailsAsyncQueryResponse { 
		"userDetails"?: Array<Models.AnalyticsUserDetail>;
		"cursor"?: string;
		"dataAvailabilityDate"?: string;
	}
	
	export interface AnalyticsUserDetailsQueryResponse { 
		"userDetails"?: Array<Models.AnalyticsUserDetail>;
		"aggregations"?: Array<Models.AggregationResult>;
		"totalHits"?: number;
	}
	
	export interface AnalyticsUserPresenceRecord { 
		"startTime"?: string;
		"endTime"?: string;
		"systemPresence"?: string;
		"organizationPresenceId"?: string;
	}
	
	export interface Annotation { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"location"?: number;
		"durationMs"?: number;
		"absoluteLocation"?: number;
		"absoluteDurationMs"?: number;
		"recordingLocation"?: number;
		"recordingDurationMs"?: number;
		"user"?: Models.User;
		"description"?: string;
		"reason"?: string;
		"annotations"?: Array<Models.Annotation>;
		"realtimeLocation"?: number;
		"selfUri"?: string;
	}
	
	export interface AnswerOption { 
		"id"?: string;
		"text"?: string;
		"value"?: number;
		"assistanceConditions"?: Array<Models.AssistanceCondition>;
	}
	
	export interface ApiUsageClientQuery { 
		"interval": string;
		"granularity"?: string;
		"metrics"?: Array<string>;
		"groupBy"?: Array<string>;
	}
	
	export interface ApiUsageOrganizationQuery { 
		"interval": string;
		"granularity"?: string;
		"metrics"?: Array<string>;
		"groupBy"?: Array<string>;
	}
	
	export interface ApiUsageQueryResult { 
		"results"?: Array<Models.ApiUsageRow>;
		"queryStatus"?: string;
		"cursors"?: Models.Cursors;
	}
	
	export interface ApiUsageRow { 
		"clientId"?: string;
		"clientName"?: string;
		"organizationId"?: string;
		"userId"?: string;
		"templateUri"?: string;
		"httpMethod"?: string;
		"status200"?: number;
		"status300"?: number;
		"status400"?: number;
		"status500"?: number;
		"status429"?: number;
		"requests"?: number;
		"date"?: string;
	}
	
	export interface ApiUsageSimpleSearch { 
		"interval": string;
		"metrics"?: Array<string>;
		"oauthClientNames"?: Array<string>;
		"httpMethods"?: Array<string>;
		"templateUris"?: Array<string>;
	}
	
	export interface AppEvent { 
		"eventName": string;
		"screenName": string;
		"app": Models.JourneyApp;
		"device": Models.Device;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"geolocation"?: Models.JourneyGeolocation;
		"sdkLibrary"?: Models.SdkLibrary;
		"networkConnectivity"?: Models.NetworkConnectivity;
		"mktCampaign"?: Models.JourneyCampaign;
		"searchQuery"?: string;
		"attributes": { [key: string]: Models.CustomEventAttribute; };
		"traits": { [key: string]: Models.CustomEventAttribute; };
	}
	
	export interface AppEventRequest { 
		"eventName": string;
		"screenName": string;
		"app": Models.JourneyApp;
		"device": Models.RequestDevice;
		"sdkLibrary"?: Models.SdkLibrary;
		"networkConnectivity"?: Models.NetworkConnectivity;
		"referrerUrl"?: string;
		"searchQuery"?: string;
		"attributes"?: { [key: string]: Models.CustomEventAttribute; };
		"traits"?: { [key: string]: Models.CustomEventAttribute; };
		"customerCookieId": string;
		"createdDate": string;
	}
	
	export interface AppEventResponse { 
		"id": string;
		"customerId": string;
		"customerIdType": string;
		"eventName": string;
		"screenName": string;
		"app": Models.JourneyApp;
		"device": Models.Device;
		"ipOrganization"?: string;
		"geolocation"?: Models.JourneyGeolocation;
		"sdkLibrary"?: Models.SdkLibrary;
		"networkConnectivity"?: Models.NetworkConnectivity;
		"mktCampaign"?: Models.JourneyCampaign;
		"session": Models.AppEventResponseSession;
		"searchQuery"?: string;
		"attributes": { [key: string]: Models.CustomEventAttribute; };
		"traits": { [key: string]: Models.CustomEventAttribute; };
		"createdDate": string;
	}
	
	export interface AppEventResponseSession { 
		"id": string;
		"durationInSeconds": number;
		"eventCount": number;
		"screenviewCount": number;
		"referrer"?: Models.Referrer;
		"selfUri"?: string;
		"createdDate": string;
	}
	
	export interface AppendToDncActionSettings { 
		"expire": boolean;
		"expirationDuration"?: string;
		"listType"?: string;
	}
	
	export interface ApprovalNamespace { 
		"namespace"?: string;
		"status"?: string;
		"type"?: string;
	}
	
	export interface ArchitectDependencyTrackingBuildNotificationClient { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ArchitectDependencyTrackingBuildNotificationDependencyTrackingBuildNotification { 
		"status"?: string;
		"user"?: Models.ArchitectDependencyTrackingBuildNotificationUser;
		"client"?: Models.ArchitectDependencyTrackingBuildNotificationClient;
		"startTime"?: string;
	}
	
	export interface ArchitectDependencyTrackingBuildNotificationHomeOrganization { 
		"id"?: string;
		"name"?: string;
		"thirdPartyOrgName"?: string;
	}
	
	export interface ArchitectDependencyTrackingBuildNotificationUser { 
		"id"?: string;
		"name"?: string;
		"homeOrg"?: Models.ArchitectDependencyTrackingBuildNotificationHomeOrganization;
	}
	
	export interface ArchitectFlowFields { 
		"architectFlow"?: Models.AddressableEntityRef;
		"flowRequestMappings"?: Array<Models.RequestMapping>;
	}
	
	export interface ArchitectFlowNotificationArchitectOperation { 
		"id"?: string;
		"complete"?: boolean;
		"user"?: Models.ArchitectFlowNotificationUser;
		"client"?: Models.ArchitectFlowNotificationClient;
		"actionName"?: string;
		"actionStatus"?: string;
		"errorMessage"?: string;
		"errorCode"?: string;
		"errorMessageParams"?: Models.ArchitectFlowNotificationErrorMessageParams;
		"errorDetails"?: Array<Models.ArchitectFlowNotificationErrorDetail>;
	}
	
	export interface ArchitectFlowNotificationClient { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ArchitectFlowNotificationErrorDetail { 
		"errorCode"?: string;
		"entityId"?: string;
		"entityName"?: string;
		"fieldName"?: string;
	}
	
	export interface ArchitectFlowNotificationErrorMessageParams { 
		"additionalProperties"?: { [key: string]: string; };
	}
	
	export interface ArchitectFlowNotificationFlowNotification { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"deleted"?: boolean;
		"checkedInVersion"?: Models.ArchitectFlowNotificationFlowVersion;
		"savedVersion"?: Models.ArchitectFlowNotificationFlowVersion;
		"publishedVersion"?: Models.ArchitectFlowNotificationFlowVersion;
		"currentOperation"?: Models.ArchitectFlowNotificationArchitectOperation;
	}
	
	export interface ArchitectFlowNotificationFlowVersion { 
		"id"?: string;
	}
	
	export interface ArchitectFlowNotificationHomeOrganization { 
		"id"?: string;
		"name"?: string;
		"thirdPartyOrgName"?: string;
	}
	
	export interface ArchitectFlowNotificationUser { 
		"id"?: string;
		"name"?: string;
		"homeOrg"?: Models.ArchitectFlowNotificationHomeOrganization;
	}
	
	export interface ArchitectFlowOutcomeNotificationArchitectOperation { 
		"id"?: string;
		"complete"?: boolean;
		"user"?: Models.ArchitectFlowOutcomeNotificationUser;
		"client"?: Models.ArchitectFlowOutcomeNotificationClient;
		"actionName"?: string;
		"actionStatus"?: string;
		"errorMessage"?: string;
		"errorCode"?: string;
		"errorMessageParams"?: Models.ArchitectFlowOutcomeNotificationErrorMessageParams;
		"errorDetails"?: Array<Models.ArchitectFlowOutcomeNotificationErrorDetail>;
	}
	
	export interface ArchitectFlowOutcomeNotificationClient { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ArchitectFlowOutcomeNotificationErrorDetail { 
		"errorCode"?: string;
		"entityId"?: string;
		"entityName"?: string;
		"fieldName"?: string;
	}
	
	export interface ArchitectFlowOutcomeNotificationErrorMessageParams { 
		"additionalProperties"?: { [key: string]: string; };
	}
	
	export interface ArchitectFlowOutcomeNotificationFlowOutcomeNotification { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"currentOperation"?: Models.ArchitectFlowOutcomeNotificationArchitectOperation;
	}
	
	export interface ArchitectFlowOutcomeNotificationHomeOrganization { 
		"id"?: string;
		"name"?: string;
		"thirdPartyOrgName"?: string;
	}
	
	export interface ArchitectFlowOutcomeNotificationUser { 
		"id"?: string;
		"name"?: string;
		"homeOrg"?: Models.ArchitectFlowOutcomeNotificationHomeOrganization;
	}
	
	export interface ArchitectJobMessage { 
		"dateTime"?: string;
		"type"?: string;
		"text"?: string;
	}
	
	export interface ArchitectJobStateResponse { 
		"id"?: string;
		"flow"?: Models.AddressableEntityRef;
		"status"?: string;
		"command"?: string;
		"messages"?: Array<Models.ArchitectJobMessage>;
		"selfUri"?: string;
	}
	
	export interface ArchitectPromptNotificationArchitectOperation { 
		"id"?: string;
		"complete"?: boolean;
		"user"?: Models.ArchitectPromptNotificationUser;
		"client"?: Models.ArchitectPromptNotificationClient;
		"actionName"?: string;
		"actionStatus"?: string;
		"errorMessage"?: string;
		"errorCode"?: string;
		"errorMessageParams"?: Models.ArchitectPromptNotificationErrorMessageParams;
		"errorDetails"?: Array<Models.ArchitectPromptNotificationErrorDetail>;
	}
	
	export interface ArchitectPromptNotificationClient { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ArchitectPromptNotificationErrorDetail { 
		"errorCode"?: string;
		"entityId"?: string;
		"entityName"?: string;
		"fieldName"?: string;
	}
	
	export interface ArchitectPromptNotificationErrorMessageParams { 
		"additionalProperties"?: { [key: string]: string; };
	}
	
	export interface ArchitectPromptNotificationHomeOrganization { 
		"id"?: string;
		"name"?: string;
		"thirdPartyOrgName"?: string;
	}
	
	export interface ArchitectPromptNotificationPromptNotification { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"currentOperation"?: Models.ArchitectPromptNotificationArchitectOperation;
	}
	
	export interface ArchitectPromptNotificationUser { 
		"id"?: string;
		"name"?: string;
		"homeOrg"?: Models.ArchitectPromptNotificationHomeOrganization;
	}
	
	export interface ArchitectPromptResourceNotificationPromptResourceNotification { 
		"promptId"?: string;
		"id"?: string;
		"language"?: string;
		"mediaUri"?: string;
		"uploadStatus"?: string;
		"durationSeconds"?: number;
	}
	
	export interface ArchitectSystemPromptResourceNotificationSystemPromptResourceNotification { 
		"promptId"?: string;
		"id"?: string;
		"language"?: string;
		"mediaUri"?: string;
		"uploadStatus"?: string;
		"durationSeconds"?: number;
	}
	
	export interface ArchiveRetention { 
		"days"?: number;
		"storageMedium"?: string;
	}
	
	export interface ArrayNode { 
	}
	
	export interface ArticleContent { 
		"body"?: Models.ArticleContentBody;
	}
	
	export interface ArticleContentBody { 
		"locationUrl"?: string;
	}
	
	export interface AssessmentForm { 
		"id"?: string;
		"dateModified"?: string;
		"contextId"?: string;
		"selfUri"?: string;
		"published"?: boolean;
		"passPercent": number;
		"questionGroups": Array<Models.AssessmentFormQuestionGroup>;
	}
	
	export interface AssessmentFormQuestion { 
		"id"?: string;
		"type"?: string;
		"text": string;
		"helpText"?: string;
		"naEnabled"?: boolean;
		"commentsRequired"?: boolean;
		"visibilityCondition"?: Models.VisibilityCondition;
		"answerOptions"?: Array<Models.AnswerOption>;
		"maxResponseCharacters"?: number;
		"isKill"?: boolean;
		"isCritical"?: boolean;
	}
	
	export interface AssessmentFormQuestionGroup { 
		"id"?: string;
		"name": string;
		"type": string;
		"defaultAnswersToHighest"?: boolean;
		"defaultAnswersToNA"?: boolean;
		"naEnabled"?: boolean;
		"weight"?: number;
		"manualWeight"?: boolean;
		"questions": Array<Models.AssessmentFormQuestion>;
		"visibilityCondition"?: Models.VisibilityCondition;
		"selfUri"?: string;
	}
	
	export interface AssessmentJobListing { 
		"total"?: number;
		"entities"?: Array<Models.BenefitAssessmentJob>;
		"selfUri"?: string;
	}
	
	export interface AssessmentListing { 
		"entities"?: Array<Models.BenefitAssessment>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface AssessmentQuestionGroupScore { 
		"questionGroupId": string;
		"totalScore"?: number;
		"maxTotalScore"?: number;
		"markedNA"?: boolean;
		"systemMarkedNA"?: boolean;
		"totalCriticalScore"?: number;
		"maxTotalCriticalScore"?: number;
		"totalNonCriticalScore"?: number;
		"maxTotalNonCriticalScore"?: number;
		"totalScoreUnweighted"?: number;
		"maxTotalScoreUnweighted"?: number;
		"totalCriticalScoreUnweighted"?: number;
		"maxTotalCriticalScoreUnweighted"?: number;
		"totalNonCriticalScoreUnweighted"?: number;
		"maxTotalNonCriticalScoreUnweighted"?: number;
		"questionScores"?: Array<Models.AssessmentQuestionScore>;
	}
	
	export interface AssessmentQuestionScore { 
		"failedKillQuestion"?: boolean;
		"comments"?: string;
		"questionId": string;
		"answerId"?: string;
		"score"?: number;
		"markedNA"?: boolean;
		"systemMarkedNA"?: boolean;
		"freeTextAnswer"?: string;
	}
	
	export interface AssessmentScoringSet { 
		"totalScore"?: number;
		"totalCriticalScore"?: number;
		"totalNonCriticalScore"?: number;
		"questionGroupScores": Array<Models.AssessmentQuestionGroupScore>;
		"failureReasons"?: Array<string>;
		"comments"?: string;
		"agentComments"?: string;
		"isPassed"?: boolean;
	}
	
	export interface AssignUsers { 
		"membersToAssign": Array<string>;
		"membersToRemove": Array<string>;
	}
	
	export interface AssignedLearningModule { 
		"id"?: string;
		"name": string;
		"excludedFromCatalog"?: boolean;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"modifiedBy"?: Models.UserReference;
		"dateModified"?: string;
		"version"?: number;
		"externalId"?: string;
		"source"?: string;
		"rule"?: Models.LearningModuleRule;
		"currentAssignments"?: Array<Models.LearningAssignment>;
		"selfUri"?: string;
		"isArchived"?: boolean;
		"isPublished"?: boolean;
		"description"?: string;
		"completionTimeInDays": number;
		"type"?: string;
		"informSteps"?: Array<Models.LearningModuleInformStep>;
		"assessmentForm"?: Models.AssessmentForm;
		"summaryData"?: Models.LearningModuleSummary;
		"reassignSummaryData"?: Models.LearningModuleReassignSummary;
		"coverArt"?: Models.LearningModuleCoverArtResponse;
		"lengthInMinutes"?: number;
		"archivalMode"?: string;
	}
	
	export interface AssignedLearningModuleDomainEntityListing { 
		"entities"?: Array<Models.AssignedLearningModule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AssignedSegment { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface AssignedWrapupCode { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface Assignment { 
		"assignedMembers"?: Array<Models.UserReference>;
		"removedMembers"?: Array<Models.UserReference>;
		"assignmentErrors"?: Array<Models.AssignmentError>;
	}
	
	export interface AssignmentError { 
		"user"?: Models.UserReference;
		"message"?: string;
	}
	
	export interface AssignmentValidation { 
		"membersNotAssigned"?: Array<Models.UserReference>;
		"membersAlreadyAssigned"?: Array<Models.UserReference>;
		"membersAlreadyAssignedToOther"?: Array<Models.OtherProfileAssignment>;
		"invalidMemberAssignments"?: Array<Models.InvalidAssignment>;
	}
	
	export interface AssistanceCondition { 
		"operator"?: string;
		"topicIds"?: Array<string>;
	}
	
	export interface AssociatedValueField { 
		"dataType": string;
		"name": string;
	}
	
	export interface AsyncConversationQuery { 
		"conversationFilters"?: Array<Models.ConversationDetailQueryFilter>;
		"segmentFilters"?: Array<Models.SegmentDetailQueryFilter>;
		"evaluationFilters"?: Array<Models.EvaluationDetailQueryFilter>;
		"surveyFilters"?: Array<Models.SurveyDetailQueryFilter>;
		"resolutionFilters"?: Array<Models.ResolutionDetailQueryFilter>;
		"order"?: string;
		"orderBy"?: string;
		"interval": string;
		"limit"?: number;
		"startOfDayIntervalMatching"?: boolean;
	}
	
	export interface AsyncForecastOperationResult { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuShortTermForecast;
		"progress"?: number;
	}
	
	export interface AsyncIntradayResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuIntradayResponse;
	}
	
	export interface AsyncJob { 
		"id"?: string;
		"selfUri"?: string;
		"state"?: string;
	}
	
	export interface AsyncQueryResponse { 
		"jobId"?: string;
	}
	
	export interface AsyncQueryStatus { 
		"state"?: string;
		"errorMessage"?: string;
		"expirationDate"?: string;
		"submissionDate"?: string;
		"completionDate"?: string;
	}
	
	export interface AsyncUserDetailsQuery { 
		"interval": string;
		"userFilters"?: Array<Models.UserDetailQueryFilter>;
		"presenceFilters"?: Array<Models.PresenceDetailQueryFilter>;
		"routingStatusFilters"?: Array<Models.RoutingStatusDetailQueryFilter>;
		"order"?: string;
		"limit"?: number;
	}
	
	export interface Attachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
		"inlineImage"?: boolean;
	}
	
	export interface AttemptLimits { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"maxAttemptsPerContact"?: number;
		"maxAttemptsPerNumber"?: number;
		"timeZoneId"?: string;
		"resetPeriod"?: string;
		"recallEntries"?: { [key: string]: Models.RecallEntry; };
		"selfUri"?: string;
	}
	
	export interface AttemptLimitsEntityListing { 
		"entities"?: Array<Models.AttemptLimits>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AttendanceStatus { 
		"dateWorkday"?: string;
		"attendanceStatusType"?: string;
		"hasEvaluation"?: string;
	}
	
	export interface AttendanceStatusListing { 
		"entities"?: Array<Models.AttendanceStatus>;
	}
	
	export interface Attribute { 
		"id"?: string;
		"name": string;
		"version"?: number;
		"description"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"modifiedBy"?: Models.DomainEntityRef;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface AttributeDetailEventTopicAttributeUpdateEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"attributes"?: { [key: string]: string; };
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
		"communications"?: Array<Models.AttributeDetailEventTopicCommunication>;
	}
	
	export interface AttributeDetailEventTopicCommunication { 
		"id"?: string;
		"mediaType"?: string;
	}
	
	export interface AttributeFilterItem { 
		"id"?: string;
		"operator"?: string;
		"values"?: Array<string>;
	}
	
	export interface AtzmTimeSlot { 
		"earliestCallableTime"?: string;
		"latestCallableTime"?: string;
	}
	
	export interface AtzmTimeSlotWithTimeZone { 
		"earliestCallableTime"?: string;
		"latestCallableTime"?: string;
		"timeZoneId"?: string;
	}
	
	export interface AudioState { 
		"canHear"?: boolean;
		"canSpeak"?: boolean;
	}
	
	export interface AudioUpdatedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"audioState": Models.AudioState;
	}
	
	export interface AuditEntity { 
		"type": string;
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface AuditFacet { 
		"name": string;
		"type": string;
	}
	
	export interface AuditFilter { 
		"name": string;
		"type": string;
		"operator": string;
		"values": Array<string>;
	}
	
	export interface AuditLogMessage { 
		"id"?: string;
		"userHomeOrgId"?: string;
		"user"?: Models.DomainEntityRef;
		"client"?: Models.AddressableEntityRef;
		"remoteIp"?: Array<string>;
		"serviceName"?: string;
		"level"?: string;
		"eventDate"?: string;
		"message"?: Models.MessageInfo;
		"action"?: string;
		"entity"?: Models.DomainEntityRef;
		"entityType"?: string;
		"status"?: string;
		"application"?: string;
		"initiatingAction"?: Models.InitiatingAction;
		"transactionInitiator"?: boolean;
		"propertyChanges"?: Array<Models.PropertyChange>;
		"context"?: { [key: string]: string; };
		"entityChanges"?: Array<Models.EntityChange>;
	}
	
	export interface AuditMessage { 
		"id": string;
		"user"?: Models.AuditUser;
		"correlationId"?: string;
		"transactionId"?: string;
		"transactionInitiator"?: boolean;
		"application"?: string;
		"serviceName": string;
		"level": string;
		"timestamp"?: string;
		"receivedTimestamp": string;
		"status": string;
		"actionContext"?: string;
		"action"?: string;
		"changes"?: Array<Models.Change>;
		"entity"?: Models.AuditEntity;
		"serviceContext"?: Models.ServiceContext;
	}
	
	export interface AuditQueryEntity { 
		"name"?: string;
		"actions"?: Array<string>;
	}
	
	export interface AuditQueryExecutionResultsResponse { 
		"id"?: string;
		"pageSize"?: number;
		"cursor"?: string;
		"entities"?: Array<Models.AuditLogMessage>;
	}
	
	export interface AuditQueryExecutionStatusResponse { 
		"id"?: string;
		"state"?: string;
		"startDate"?: string;
		"interval"?: string;
		"serviceName"?: string;
		"filters"?: Array<Models.AuditQueryFilter>;
		"sort"?: Array<Models.AuditQuerySort>;
	}
	
	export interface AuditQueryFilter { 
		"property": string;
		"value": string;
	}
	
	export interface AuditQueryRequest { 
		"interval": string;
		"serviceName": string;
		"filters"?: Array<Models.AuditQueryFilter>;
		"sort"?: Array<Models.AuditQuerySort>;
	}
	
	export interface AuditQueryResponse { 
	}
	
	export interface AuditQueryService { 
		"name"?: string;
		"entities"?: Array<Models.AuditQueryEntity>;
	}
	
	export interface AuditQueryServiceMapping { 
		"services"?: Array<Models.AuditQueryService>;
	}
	
	export interface AuditQuerySort { 
		"name": string;
		"sortOrder": string;
	}
	
	export interface AuditRealtimeQueryRequest { 
		"interval": string;
		"serviceName"?: string;
		"filters"?: Array<Models.AuditQueryFilter>;
		"sort"?: Array<Models.AuditQuerySort>;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	
	export interface AuditRealtimeQueryResultsResponse { 
		"entities"?: Array<Models.AuditLogMessage>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface AuditSearchResult { 
		"pageNumber"?: number;
		"pageSize"?: number;
		"total"?: number;
		"pageCount"?: number;
		"facetInfo"?: Array<Models.FacetInfo>;
		"auditMessages"?: Array<Models.AuditMessage>;
	}
	
	export interface AuditTopicAddressableEntityRef { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface AuditTopicAuditLogMessage { 
		"id"?: string;
		"userId"?: string;
		"userHomeOrgId"?: string;
		"username"?: Models.AuditTopicDomainEntityRef;
		"userDisplay"?: string;
		"clientId"?: Models.AuditTopicAddressableEntityRef;
		"remoteIp"?: Array<string>;
		"serviceName"?: string;
		"level"?: string;
		"eventTime"?: string;
		"message"?: Models.AuditTopicMessageInfo;
		"action"?: string;
		"entityType"?: string;
		"entity"?: Models.AuditTopicDomainEntityRef;
		"propertyChanges"?: Array<Models.AuditTopicPropertyChange>;
		"context"?: { [key: string]: string; };
	}
	
	export interface AuditTopicDomainEntityRef { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface AuditTopicMessageInfo { 
		"localizableMessageCode"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface AuditTopicPropertyChange { 
		"property"?: string;
		"oldValues"?: Array<string>;
		"newValues"?: Array<string>;
	}
	
	export interface AuditUser { 
		"id": string;
		"name"?: string;
		"display"?: string;
	}
	
	export interface AuthenticationSettings { 
		"enabled": boolean;
		"integrationId": string;
		"allowSessionUpgrade"?: boolean;
	}
	
	export interface AuthorizationSettings { 
		"id"?: string;
		"analysisEnabled"?: boolean;
		"analysisDays"?: number;
		"dateLastCalculated"?: string;
		"dateLastActive"?: string;
		"selfUri"?: string;
	}
	
	export interface AuthzDivision { 
		"id"?: string;
		"name"?: string;
		"description": string;
		"homeDivision"?: boolean;
		"objectCounts"?: { [key: string]: number; };
		"selfUri"?: string;
	}
	
	export interface AuthzDivisionEntityListing { 
		"entities"?: Array<Models.AuthzDivision>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface AuthzDivisionGrantEntityListing { 
		"entities"?: Array<Models.AuthzGrant>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface AuthzGrant { 
		"subjectId"?: string;
		"division"?: Models.AuthzDivision;
		"role"?: Models.AuthzGrantRole;
		"grantMadeAt"?: string;
	}
	
	export interface AuthzGrantPolicy { 
		"actions"?: Array<string>;
		"condition"?: string;
		"domain"?: string;
		"entityName"?: string;
	}
	
	export interface AuthzGrantRole { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"policies"?: Array<Models.AuthzGrantPolicy>;
		"default"?: boolean;
		"selfUri"?: string;
	}
	
	export interface AuthzSubject { 
		"id"?: string;
		"name"?: string;
		"grants"?: Array<Models.AuthzGrant>;
		"version"?: number;
		"selfUri"?: string;
	}
	
	export interface AutoStart { 
		"enabled"?: boolean;
	}
	
	export interface AutoStatusTransitionDetail { 
		"nextStatus"?: Models.WorkitemStatusReference;
		"dateOfTransition"?: string;
		"errorDetails"?: Models.TaskManagementErrorDetails;
	}
	
	export interface AutomaticTimeZoneMappingSettings { 
		"callableWindows"?: Array<Models.CallableWindow>;
		"supportedCountries"?: Array<string>;
	}
	
	export interface AvailableMediaType { 
		"mediaType"?: string;
		"availableSubTypes"?: Array<string>;
	}
	
	export interface AvailableMediaTypeEntityListing { 
		"entities"?: Array<Models.AvailableMediaType>;
	}
	
	export interface AvailableTime { 
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"isPaid"?: boolean;
		"activityCategory"?: string;
		"wfmSchedule"?: Models.WfmScheduleReference;
	}
	
	export interface AvailableTimeOffRange { 
		"timeOffLimit"?: Models.TimeOffLimitReference;
		"startDate"?: string;
		"granularity"?: string;
		"availableMinutesPerInterval"?: Array<number>;
		"waitlistedRequestsPerInterval"?: Array<number>;
		"waitlistEnabled"?: boolean;
	}
	
	export interface AvailableTimeOffRequest { 
		"activityCodeId": string;
		"dateRanges"?: Array<Models.LocalDateRange>;
	}
	
	export interface AvailableTimeOffResponse { 
		"values"?: Array<Models.AvailableTimeOffRange>;
	}
	
	export interface AvailableTopic { 
		"description"?: string;
		"id"?: string;
		"permissionDetails"?: Array<Models.PermissionDetails>;
		"requiresPermissions"?: Array<string>;
		"requiresDivisionPermissions"?: boolean;
		"requiresAnyValidator"?: boolean;
		"enforced"?: boolean;
		"visibility"?: string;
		"schema"?: { [key: string]: object; };
		"requiresCurrentUser"?: boolean;
		"requiresCurrentUserOrPermission"?: boolean;
		"transports"?: Array<string>;
		"publicApiTemplateUriPaths"?: Array<string>;
		"topicParameters"?: Array<string>;
	}
	
	export interface AvailableTopicEntityListing { 
		"entities"?: Array<Models.AvailableTopic>;
	}
	
	export interface AvailableTranslations { 
		"orgSpecific"?: Array<string>;
		"builtin"?: Array<string>;
	}
	
	export interface BackgroundImageSettings { 
		"url"?: string;
	}
	
	export interface BaseMediaSettings { 
		"enableAutoAnswer"?: boolean;
	}
	
	export interface BaseProgramEntity { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface BaseTopicEntitiy { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface BatchConversationEventRequest { 
		"endTransferEvents"?: Array<Models.EndTransferEvent>;
		"phoneTransferEvents"?: Array<Models.PhoneTransferEvent>;
		"progressTransferEvents"?: Array<Models.ProgressTransferEvent>;
		"routingTransferEvents"?: Array<Models.RoutingTransferEvent>;
		"userTransferEvents"?: Array<Models.UserTransferEvent>;
		"communicationAnsweredEvents"?: Array<Models.CommunicationAnsweredEvent>;
		"communicationDispositionAppliedEvents"?: Array<Models.CommunicationDispositionAppliedEvent>;
		"holdUpdatedEvents"?: Array<Models.HoldUpdatedEvent>;
		"externalEstablishedEvents"?: Array<Models.ExternalEstablishedEvent>;
		"ivrEstablishedEvents"?: Array<Models.IvrEstablishedEvent>;
		"phoneEstablishedEvents"?: Array<Models.PhoneEstablishedEvent>;
		"routingEstablishedEvents"?: Array<Models.RoutingEstablishedEvent>;
		"userEstablishedEvents"?: Array<Models.UserEstablishedEvent>;
		"audioUpdatedEvents"?: Array<Models.AudioUpdatedEvent>;
		"communicationEndedEvents"?: Array<Models.CommunicationEndedEvent>;
		"consultTransferEvents"?: Array<Models.ConsultTransferEvent>;
		"progressConsultTransferEvents"?: Array<Models.ProgressConsultTransferEvent>;
		"endConsultTransferEvents"?: Array<Models.EndConsultTransferEvent>;
	}
	
	export interface BatchDownloadJobResult { 
		"id"?: string;
		"name"?: string;
		"conversationId"?: string;
		"recordingId"?: string;
		"resultUrl"?: string;
		"contentType"?: string;
		"errorMsg"?: string;
		"selfUri"?: string;
	}
	
	export interface BatchDownloadJobStatusResult { 
		"id"?: string;
		"jobId"?: string;
		"expectedResultCount"?: number;
		"resultCount"?: number;
		"errorCount"?: number;
		"results"?: Array<Models.BatchDownloadJobResult>;
		"selfUri"?: string;
	}
	
	export interface BatchDownloadJobSubmission { 
		"batchDownloadRequestList": Array<Models.BatchDownloadRequest>;
	}
	
	export interface BatchDownloadJobSubmissionResult { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface BatchDownloadRequest { 
		"conversationId"?: string;
		"recordingId"?: string;
	}
	
	export interface BatchEventResponse { 
		"errors"?: Array<Models.EventError>;
	}
	
	export interface BatchUserPresenceEventRequest { 
		"userPresenceEvents"?: Array<Models.UserPresenceEvent>;
	}
	
	export interface BatchUserRoutingStatusEventRequest { 
		"userRoutingStatusEvents"?: Array<Models.UserRoutingStatusEvent>;
	}
	
	export interface BenefitAssessment { 
		"id"?: string;
		"queues"?: Array<Models.AddressableEntityRef>;
		"kpiAssessments"?: Array<Models.KeyPerformanceIndicatorAssessment>;
		"state"?: string;
		"jobId"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface BenefitAssessmentJob { 
		"id"?: string;
		"state"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface BillingUsage { 
		"name": string;
		"totalUsage": string;
		"resources": Array<Models.BillingUsageResource>;
	}
	
	export interface BillingUsageReport { 
		"id"?: string;
		"name"?: string;
		"startDate": string;
		"endDate": string;
		"status"?: string;
		"usages": Array<Models.BillingUsage>;
		"selfUri"?: string;
	}
	
	export interface BillingUsageResource { 
		"name": string;
		"date": string;
	}
	
	export interface Biography { 
		"biography"?: string;
		"interests"?: Array<string>;
		"hobbies"?: Array<string>;
		"spouse"?: string;
		"education"?: Array<Models.Education>;
	}
	
	export interface BotAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface BotAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.BotAggregateQueryPredicate>;
	}
	
	export interface BotAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.BotAggregateQueryClause>;
		"predicates"?: Array<Models.BotAggregateQueryPredicate>;
	}
	
	export interface BotAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface BotAggregateQueryResponse { 
		"results"?: Array<Models.BotAggregateDataContainer>;
	}
	
	export interface BotAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.BotAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.BotAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface BotAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface BotAsyncAggregateQueryResponse { 
		"results"?: Array<Models.BotAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface BotAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.BotAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.BotAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface BotChannel { 
		"name": string;
		"inputModes": Array<string>;
		"outputModes": Array<string>;
		"userAgent": Models.TextBotUserAgent;
	}
	
	export interface BotConnectorBot { 
		"id": string;
		"name"?: string;
		"description"?: string;
		"versions": Array<Models.BotConnectorBotVersion>;
		"botCompositeTag"?: string;
		"selfUri"?: string;
	}
	
	export interface BotConnectorBotSummaryEntityListing { 
		"entities"?: Array<Models.BotSummary>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface BotConnectorBotVersion { 
		"version": string;
		"supportedLanguages": Array<string>;
		"intents": Array<Models.BotIntent>;
	}
	
	export interface BotConnectorBotVersionSummaryEntityListing { 
		"entities"?: Array<Models.BotVersionSummary>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface BotExecutionConfiguration { 
		"botId": string;
		"executionHost": string;
		"botCredentials": Models.NuanceBotCredentials;
	}
	
	export interface BotFlowSession { 
		"id"?: string;
		"flow"?: Models.Entity;
		"channel"?: Models.BotChannel;
		"language"?: string;
		"endLanguage"?: string;
		"botResult"?: string;
		"botResultCategory"?: string;
		"dateCreated"?: string;
		"conversation"?: Models.AddressableEntityRef;
	}
	
	export interface BotIntent { 
		"name": string;
		"slots"?: { [key: string]: Models.BotSlot; };
	}
	
	export interface BotList { 
		"chatBots": Array<Models.BotConnectorBot>;
	}
	
	export interface BotMessengerProfile { 
		"name"?: string;
		"avatarUrl"?: string;
	}
	
	export interface BotSearchResponse { 
		"id": string;
		"name": string;
		"botType": string;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface BotSearchResponseEntityListing { 
		"entities"?: Array<Models.BotSearchResponse>;
	}
	
	export interface BotSlot { 
		"name": string;
		"type": string;
	}
	
	export interface BotSummary { 
		"name": string;
		"id": string;
		"description"?: string;
		"botCompositeTag"?: string;
	}
	
	export interface BotVersionSummary { 
		"name": string;
		"id": string;
		"description"?: string;
		"botCompositeTag"?: string;
		"version": string;
	}
	
	export interface Browser { 
		"family": string;
		"version": string;
		"lang"?: string;
		"fingerprint"?: string;
		"isMobile"?: boolean;
		"viewHeight"?: number;
		"viewWidth"?: number;
		"featuresFlash": boolean;
		"featuresJava": boolean;
		"featuresPdf": boolean;
		"featuresWebrtc": boolean;
	}
	
	export interface BuAbandonRate { 
		"include": boolean;
		"percent"?: number;
	}
	
	export interface BuAgentScheduleActivity { 
		"startDate"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"payableMinutes"?: number;
		"timeOffRequestId"?: string;
		"timeOffRequestSyncVersion"?: number;
		"externalActivityId"?: string;
		"externalActivityType"?: string;
	}
	
	export interface BuAgentScheduleHistoryChange { 
		"metadata"?: Models.BuAgentScheduleHistoryChangeMetadata;
		"shifts"?: Array<Models.BuAgentScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.BuFullDayTimeOffMarker>;
		"deletes"?: Models.BuAgentScheduleHistoryDeletedChange;
	}
	
	export interface BuAgentScheduleHistoryChangeMetadata { 
		"dateModified"?: string;
		"modifiedBy"?: Models.UserReference;
	}
	
	export interface BuAgentScheduleHistoryDeletedChange { 
		"shiftIds"?: Array<string>;
		"fullDayTimeOffMarkerDates"?: Array<string>;
		"agentSchedule"?: boolean;
	}
	
	export interface BuAgentScheduleHistoryDroppedChange { 
		"metadata"?: Models.BuAgentScheduleHistoryChangeMetadata;
		"shiftIds"?: Array<string>;
		"fullDayTimeOffMarkerDates"?: Array<string>;
		"deletes"?: Models.BuAgentScheduleHistoryDeletedChange;
	}
	
	export interface BuAgentScheduleHistoryResponse { 
		"priorPublishedSchedules"?: Array<Models.BuScheduleReference>;
		"basePublishedSchedule"?: Models.BuAgentScheduleHistoryChange;
		"droppedChanges"?: Array<Models.BuAgentScheduleHistoryDroppedChange>;
		"changes"?: Array<Models.BuAgentScheduleHistoryChange>;
	}
	
	export interface BuAgentSchedulePublishedScheduleReference { 
		"id"?: string;
		"weekDate"?: string;
		"weekCount"?: number;
		"selfUri"?: string;
	}
	
	export interface BuAgentScheduleQueryResponse { 
		"user"?: Models.UserReference;
		"shifts"?: Array<Models.BuAgentScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.BuFullDayTimeOffMarker>;
		"workPlan"?: Models.WorkPlanReference;
		"workPlansPerWeek"?: Array<Models.WorkPlanReference>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface BuAgentScheduleRescheduleResponse { 
		"user"?: Models.UserReference;
		"shifts"?: Array<Models.BuAgentScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.BuFullDayTimeOffMarker>;
		"workPlan"?: Models.WorkPlanReference;
		"workPlansPerWeek"?: Array<Models.WorkPlanReference>;
	}
	
	export interface BuAgentScheduleSearchResponse { 
		"user"?: Models.UserReference;
		"shifts"?: Array<Models.BuAgentScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.BuFullDayTimeOffMarker>;
	}
	
	export interface BuAgentScheduleShift { 
		"id"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"activities"?: Array<Models.BuAgentScheduleActivity>;
		"manuallyEdited"?: boolean;
		"schedule"?: Models.BuScheduleReference;
	}
	
	export interface BuAgentScheduleUpdate { 
		"type"?: string;
		"shiftStartDates"?: Array<string>;
	}
	
	export interface BuAgentSchedulesQueryResponse { 
		"agentSchedules"?: Array<Models.BuAgentScheduleQueryResponse>;
		"businessUnitTimeZone"?: string;
	}
	
	export interface BuAgentSchedulesSearchResponse { 
		"agentSchedules"?: Array<Models.BuAgentScheduleSearchResponse>;
		"businessUnitTimeZone"?: string;
		"publishedSchedules"?: Array<Models.BuAgentSchedulePublishedScheduleReference>;
	}
	
	export interface BuAsyncAgentSchedulesQueryResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuAgentSchedulesQueryResponse;
		"progress"?: number;
		"downloadUrl"?: string;
	}
	
	export interface BuAsyncAgentSchedulesSearchResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuAgentSchedulesSearchResponse;
		"progress"?: number;
		"downloadUrl"?: string;
	}
	
	export interface BuAsyncScheduleResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuScheduleMetadata;
	}
	
	export interface BuAsyncScheduleRunResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuScheduleRun;
	}
	
	export interface BuAverageSpeedOfAnswer { 
		"include": boolean;
		"seconds"?: number;
	}
	
	export interface BuCopyScheduleRequest { 
		"description": string;
		"weekDate": string;
	}
	
	export interface BuCreateBlankScheduleRequest { 
		"description": string;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"weekCount": number;
	}
	
	export interface BuCreateTimeOffLimitRequest { 
		"staffingGroupId"?: string;
		"managementUnitId"?: string;
	}
	
	export interface BuCreateTimeOffPlanRequest { 
		"name": string;
		"activityCodeIds"?: Array<string>;
		"autoApprovalRule"?: string;
		"daysBeforeStartToExpireFromWaitlist"?: number;
		"hrisTimeOffType"?: Models.HrisTimeOffType;
		"enabled"?: boolean;
		"countAgainstTimeOffLimits"?: boolean;
		"businessUnitAssociation"?: Models.CreateTimeOffPlanBusinessUnitAssociation;
		"managementUnitAssociation"?: Models.CreateTimeOffPlanManagementUnitAssociation;
	}
	
	export interface BuCurrentAgentScheduleSearchResponse { 
		"agentSchedules"?: Array<Models.BuAgentScheduleSearchResponse>;
		"businessUnitTimeZone"?: string;
		"publishedSchedules"?: Array<Models.BuAgentSchedulePublishedScheduleReference>;
		"startDate"?: string;
		"endDate"?: string;
		"updates"?: Array<Models.BuAgentScheduleUpdate>;
	}
	
	export interface BuForecastGenerationPlanningGroupResult { 
		"planningGroupId"?: string;
		"metricResults"?: Array<Models.BuForecastTimeSeriesResult>;
	}
	
	export interface BuForecastGenerationResult { 
		"planningGroupResults"?: Array<Models.BuForecastGenerationPlanningGroupResult>;
	}
	
	export interface BuForecastModificationResponse { 
		"type": string;
		"startIntervalIndex"?: number;
		"endIntervalIndex"?: number;
		"metric": string;
		"legacyMetric"?: string;
		"value"?: number;
		"values": Array<Models.WfmForecastModificationIntervalOffsetValue>;
		"secondaryValues"?: Array<Models.WfmForecastModificationIntervalOffsetValue>;
		"displayGranularity": string;
		"granularity": string;
		"secondaryGranularity"?: string;
		"enabled": boolean;
		"planningGroupIds": Array<string>;
	}
	
	export interface BuForecastResult { 
		"referenceStartDate"?: string;
		"planningGroups"?: Array<Models.ForecastPlanningGroupData>;
		"weekNumber"?: number;
		"weekCount"?: number;
	}
	
	export interface BuForecastResultResponse { 
		"result"?: Models.BuForecastResult;
		"downloadUrl"?: string;
	}
	
	export interface BuForecastStaffingRequirementsResult { 
		"weekNumber": number;
		"downloadUrl": string;
		"downloadUrlExpirationDate": string;
		"planningGroupStaffingRequirements"?: Array<Models.StaffingRequirementsPlanningGroupData>;
	}
	
	export interface BuForecastStaffingRequirementsResultResponse { 
		"businessUnitId": string;
		"forecast": Models.BuShortTermForecastReference;
		"referenceStartDate": string;
		"weekCount": number;
		"intervalLengthMinutes": number;
		"state": string;
		"results"?: Array<Models.BuForecastStaffingRequirementsResult>;
	}
	
	export interface BuForecastTimeSeriesResult { 
		"metric"?: string;
		"forecastingMethod"?: string;
		"forecastType"?: string;
	}
	
	export interface BuFullDayTimeOffMarker { 
		"businessUnitDate"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"payableMinutes"?: number;
		"timeOffRequestId"?: string;
		"timeOffRequestSyncVersion"?: number;
	}
	
	export interface BuGenerateScheduleRequest { 
		"description": string;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"weekCount": number;
		"options"?: Models.SchedulingOptionsRequest;
	}
	
	export interface BuGetCurrentAgentScheduleRequest { 
		"startDate": string;
		"endDate": string;
	}
	
	export interface BuHeadcountForecast { 
		"entities"?: Array<Models.BuPlanningGroupHeadcountForecast>;
		"referenceStartDate"?: string;
	}
	
	export interface BuHeadcountForecastResponse { 
		"result"?: Models.BuHeadcountForecast;
		"downloadUrl"?: string;
	}
	
	export interface BuImportAgentScheduleUploadSchema { 
		"userId": string;
		"workPlanId"?: Models.ValueWrapperString;
		"workPlanIdsPerWeek"?: Models.ListWrapperString;
		"shifts"?: Array<Models.BuAgentScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.BuFullDayTimeOffMarker>;
	}
	
	export interface BuImportShortTermForecastSchema { 
		"description": string;
		"weekCount": number;
		"planningGroups": Array<Models.ForecastPlanningGroupData>;
		"longTermPlanningGroups"?: Array<Models.LongTermForecastPlanningGroupData>;
		"canUseForScheduling"?: boolean;
	}
	
	export interface BuIntradayDataGroup { 
		"mediaType"?: string;
		"forecastDataSummary"?: Models.BuIntradayForecastData;
		"forecastDataPerInterval"?: Array<Models.BuIntradayForecastData>;
		"scheduleDataSummary"?: Models.BuIntradayScheduleData;
		"scheduleDataPerInterval"?: Array<Models.BuIntradayScheduleData>;
		"performancePredictionDataSummary"?: Models.IntradayPerformancePredictionData;
		"performancePredictionDataPerInterval"?: Array<Models.IntradayPerformancePredictionData>;
	}
	
	export interface BuIntradayForecastData { 
		"offered"?: number;
		"averageHandleTimeSeconds"?: number;
	}
	
	export interface BuIntradayResponse { 
		"startDate"?: string;
		"endDate"?: string;
		"intervalLengthMinutes"?: number;
		"noDataReason"?: string;
		"categories"?: Array<string>;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"schedule"?: Models.BuScheduleReference;
		"intradayDataGroupings"?: Array<Models.BuIntradayDataGroup>;
	}
	
	export interface BuIntradayScheduleData { 
		"onQueueTimeSeconds"?: number;
	}
	
	export interface BuManagementUnitScheduleSummary { 
		"managementUnit"?: Models.ManagementUnitReference;
		"agentCount"?: number;
		"startDate"?: string;
		"endDate"?: string;
		"agents"?: Array<Models.UserReference>;
	}
	
	export interface BuPlanningGroupHeadcountForecast { 
		"planningGroup"?: Models.PlanningGroupReference;
		"requiredPerInterval"?: Array<number>;
		"requiredWithoutShrinkagePerInterval"?: Array<number>;
	}
	
	export interface BuQueryAdherenceExplanationsRequest { 
		"startDate": string;
		"endDate": string;
		"managementUnitIds"?: Array<string>;
		"agentIds"?: Array<string>;
	}
	
	export interface BuQueryAdherenceExplanationsResponse { 
		"job"?: Models.AdherenceExplanationJobReference;
		"result"?: Models.AdherenceExplanationListingBuQueryResponse;
		"downloadUrl"?: string;
	}
	
	export interface BuQueryAgentSchedulesRequest { 
		"managementUnitId": string;
		"userIds"?: Array<string>;
		"teamIds"?: Array<string>;
	}
	
	export interface BuRescheduleAgentScheduleResult { 
		"managementUnit"?: Models.ManagementUnitReference;
		"downloadResult"?: Models.MuRescheduleResultWrapper;
		"downloadUrl"?: string;
	}
	
	export interface BuRescheduleRequest { 
		"startDate"?: string;
		"endDate"?: string;
		"agentIds"?: Array<string>;
		"activityCodeIds"?: Array<string>;
		"managementUnitIds": Array<string>;
		"doNotChangeWeeklyPaidTime": boolean;
		"doNotChangeDailyPaidTime": boolean;
		"doNotChangeShiftStartTimes": boolean;
		"doNotChangeManuallyEditedShifts": boolean;
	}
	
	export interface BuRescheduleResult { 
		"generationResults"?: Models.ScheduleGenerationResult;
		"generationResultsDownloadUrl"?: string;
		"headcountForecast"?: Models.BuHeadcountForecast;
		"headcountForecastDownloadUrl"?: string;
		"agentSchedules"?: Array<Models.BuRescheduleAgentScheduleResult>;
	}
	
	export interface BuScheduleListItem { 
		"id"?: string;
		"weekDate"?: string;
		"weekCount"?: number;
		"description"?: string;
		"published"?: boolean;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"generationResults"?: Models.ScheduleGenerationResultSummary;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface BuScheduleListing { 
		"entities"?: Array<Models.BuScheduleListItem>;
	}
	
	export interface BuScheduleMetadata { 
		"id"?: string;
		"weekDate"?: string;
		"weekCount"?: number;
		"description"?: string;
		"published"?: boolean;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"generationResults"?: Models.ScheduleGenerationResultSummary;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"managementUnits"?: Array<Models.BuManagementUnitScheduleSummary>;
		"selfUri"?: string;
	}
	
	export interface BuScheduleReference { 
		"id"?: string;
		"weekDate"?: string;
		"selfUri"?: string;
	}
	
	export interface BuScheduleReferenceForMuRoute { 
		"id"?: string;
		"weekDate"?: string;
		"businessUnit"?: Models.BusinessUnitReference;
		"selfUri"?: string;
	}
	
	export interface BuScheduleRun { 
		"id"?: string;
		"schedulerRunId"?: string;
		"intradayRescheduling"?: boolean;
		"state"?: string;
		"weekCount"?: number;
		"percentComplete"?: number;
		"targetWeek"?: string;
		"schedule"?: Models.BuScheduleReference;
		"scheduleDescription"?: string;
		"schedulingStartTime"?: string;
		"schedulingStartedBy"?: Models.UserReference;
		"schedulingCanceledBy"?: Models.UserReference;
		"schedulingCompletedTime"?: string;
		"messageCount"?: number;
		"messageSeverityCounts"?: Array<Models.SchedulerMessageSeverityCount>;
		"reschedulingOptions"?: Models.ReschedulingOptionsRunResponse;
		"reschedulingResultExpiration"?: string;
		"selfUri"?: string;
	}
	
	export interface BuScheduleRunListing { 
		"entities"?: Array<Models.BuScheduleRun>;
	}
	
	export interface BuSchedulingSettingsRequest { 
		"messageSeverities"?: Array<Models.SchedulerMessageTypeSeverity>;
		"syncTimeOffProperties"?: Models.SetWrapperSyncTimeOffProperty;
		"serviceGoalImpact"?: Models.WfmServiceGoalImpactSettings;
		"allowWorkPlanPerMinuteGranularity"?: boolean;
	}
	
	export interface BuSchedulingSettingsResponse { 
		"messageSeverities"?: Array<Models.SchedulerMessageTypeSeverity>;
		"syncTimeOffProperties"?: Array<string>;
		"serviceGoalImpact"?: Models.WfmServiceGoalImpactSettings;
		"allowWorkPlanPerMinuteGranularity"?: boolean;
	}
	
	export interface BuSearchAgentSchedulesRequest { 
		"startDate": string;
		"endDate": string;
		"userIds"?: Array<string>;
	}
	
	export interface BuServiceLevel { 
		"include": boolean;
		"percent"?: number;
		"seconds"?: number;
	}
	
	export interface BuSetTimeOffLimitValuesRequest { 
		"values"?: Array<Models.BuTimeOffLimitRange>;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface BuShortTermForecast { 
		"id"?: string;
		"weekDate"?: string;
		"weekCount"?: number;
		"creationMethod"?: string;
		"description"?: string;
		"legacy"?: boolean;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"canUseForScheduling"?: boolean;
		"referenceStartDate"?: string;
		"sourceDays"?: Array<Models.ForecastSourceDayPointer>;
		"modifications"?: Array<Models.BuForecastModificationResponse>;
		"generationResults"?: Models.BuForecastGenerationResult;
		"timeZone"?: string;
		"planningGroupsVersion"?: number;
		"planningGroups"?: Models.ForecastPlanningGroupsResponse;
		"selfUri"?: string;
	}
	
	export interface BuShortTermForecastListItem { 
		"id"?: string;
		"weekDate"?: string;
		"weekCount"?: number;
		"creationMethod"?: string;
		"description"?: string;
		"legacy"?: boolean;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"canUseForScheduling"?: boolean;
		"selfUri"?: string;
	}
	
	export interface BuShortTermForecastListing { 
		"entities"?: Array<Models.BuShortTermForecastListItem>;
	}
	
	export interface BuShortTermForecastReference { 
		"id"?: string;
		"weekDate": string;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface BuShortTermForecastingSettings { 
		"defaultHistoryWeeks"?: number;
	}
	
	export interface BuTimeOffLimitListing { 
		"entities"?: Array<Models.BuTimeOffLimitResponse>;
	}
	
	export interface BuTimeOffLimitRange { 
		"startDate": string;
		"limitMinutesPerDay": Array<number>;
	}
	
	export interface BuTimeOffLimitReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface BuTimeOffLimitResponse { 
		"id"?: string;
		"staffingGroup"?: Models.StaffingGroupReference;
		"managementUnit"?: Models.ManagementUnitReference;
		"metadata": Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface BuTimeOffLimitValueRange { 
		"id"?: string;
		"timeOffLimit": Models.BuTimeOffLimitReference;
		"startDate": string;
		"granularity": string;
		"limitMinutesPerInterval": Array<number>;
		"allocatedMinutesPerInterval": Array<number>;
		"waitlistedMinutesPerInterval": Array<number>;
		"waitlistedRequestsPerInterval": Array<number>;
		"metadata": Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface BuTimeOffLimitValuesResponse { 
		"values"?: Array<Models.BuTimeOffLimitValueRange>;
	}
	
	export interface BuTimeOffPlanListing { 
		"entities"?: Array<Models.BuTimeOffPlanResponse>;
		"downloadUrl"?: string;
	}
	
	export interface BuTimeOffPlanResponse { 
		"id"?: string;
		"name": string;
		"activityCodeIds": Array<string>;
		"timeOffLimits"?: Array<Models.BuTimeOffLimitReference>;
		"autoApprovalRule": string;
		"daysBeforeStartToExpireFromWaitlist": number;
		"hrisTimeOffType"?: Models.HrisTimeOffType;
		"enabled": boolean;
		"countAgainstTimeOffLimits": boolean;
		"businessUnitAssociation"?: Models.TimeOffPlanBusinessUnitAssociation;
		"managementUnitAssociation"?: Models.TimeOffPlanManagementUnitAssociation;
		"metadata": Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface BuUpdateAgentScheduleShift { 
		"id"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"activities"?: Array<Models.BuAgentScheduleActivity>;
		"manuallyEdited"?: boolean;
		"schedule"?: Models.BuScheduleReference;
		"delete"?: boolean;
	}
	
	export interface BuUpdateAgentScheduleUploadSchema { 
		"userId": string;
		"workPlanId"?: Models.ValueWrapperString;
		"workPlanIdsPerWeek"?: Models.ListWrapperString;
		"shifts"?: Array<Models.BuUpdateAgentScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.BuFullDayTimeOffMarker>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"delete"?: boolean;
	}
	
	export interface BuUpdateTimeOffPlanRequest { 
		"name"?: string;
		"activityCodeIds"?: Models.SetWrapperString;
		"autoApprovalRule"?: string;
		"daysBeforeStartToExpireFromWaitlist"?: number;
		"hrisTimeOffType"?: Models.ValueWrapperHrisTimeOffType;
		"enabled"?: boolean;
		"countAgainstTimeOffLimits"?: boolean;
		"businessUnitAssociation"?: Models.UpdateTimeOffPlanBusinessUnitAssociation;
		"managementUnitAssociation"?: Models.UpdateTimeOffPlanManagementUnitAssociation;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface BulkCallbackDisconnectRequest { 
		"callbackDisconnectIdentifiers": Array<Models.CallbackDisconnectIdentifier>;
	}
	
	export interface BulkCallbackPatchRequest { 
		"patchCallbackRequests": Array<Models.PatchCallbackRequest>;
	}
	
	export interface BulkCallbackPatchResponse { 
		"results"?: Array<Models.BulkResult>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkContactsRequest { 
		"entities"?: Array<Models.ExternalContact>;
	}
	
	export interface BulkContactsResponse { 
		"results"?: Array<Models.BulkResponseResultExternalContactExternalContact>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkDeleteResponse { 
		"results"?: Array<Models.BulkResponseResultVoidEntity>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkError { 
		"message"?: string;
		"code"?: string;
	}
	
	export interface BulkErrorDetail { 
		"fieldName"?: string;
		"value"?: string;
		"message"?: string;
	}
	
	export interface BulkErrorEntity { 
		"code"?: string;
		"message"?: string;
		"status"?: number;
		"retryable"?: boolean;
		"entity"?: Models.Entity;
		"details"?: Array<Models.BulkErrorDetail>;
	}
	
	export interface BulkErrorExternalContact { 
		"code"?: string;
		"message"?: string;
		"status"?: number;
		"retryable"?: boolean;
		"entity"?: Models.ExternalContact;
		"details"?: Array<Models.BulkErrorDetail>;
	}
	
	export interface BulkErrorExternalOrganization { 
		"code"?: string;
		"message"?: string;
		"status"?: number;
		"retryable"?: boolean;
		"entity"?: Models.ExternalOrganization;
		"details"?: Array<Models.BulkErrorDetail>;
	}
	
	export interface BulkErrorNote { 
		"code"?: string;
		"message"?: string;
		"status"?: number;
		"retryable"?: boolean;
		"entity"?: Models.Note;
		"details"?: Array<Models.BulkErrorDetail>;
	}
	
	export interface BulkErrorRelationship { 
		"code"?: string;
		"message"?: string;
		"status"?: number;
		"retryable"?: boolean;
		"entity"?: Models.Relationship;
		"details"?: Array<Models.BulkErrorDetail>;
	}
	
	export interface BulkFetchContactsResponse { 
		"results"?: Array<Models.BulkResponseResultExternalContactEntity>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkFetchNotesResponse { 
		"results"?: Array<Models.BulkResponseResultNoteEntity>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkFetchOrganizationsResponse { 
		"results"?: Array<Models.BulkResponseResultExternalOrganizationEntity>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkFetchRelationshipsResponse { 
		"results"?: Array<Models.BulkResponseResultRelationshipEntity>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkIdsRequest { 
		"entities"?: Array<Models.ExternalContactsEntity>;
	}
	
	export interface BulkNotesRequest { 
		"entities"?: Array<Models.Note>;
	}
	
	export interface BulkNotesResponse { 
		"results"?: Array<Models.BulkResponseResultNoteNote>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkOrganizationsRequest { 
		"entities"?: Array<Models.ExternalOrganization>;
	}
	
	export interface BulkOrganizationsResponse { 
		"results"?: Array<Models.BulkResponseResultExternalOrganizationExternalOrganization>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkRelationshipsRequest { 
		"entities"?: Array<Models.Relationship>;
	}
	
	export interface BulkRelationshipsResponse { 
		"results"?: Array<Models.BulkResponseResultRelationshipRelationship>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkResponse { 
		"results"?: Array<Models.BulkResult>;
		"errorCount"?: number;
		"errorIndexes"?: Array<number>;
	}
	
	export interface BulkResponseResultExternalContactEntity { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.ExternalContact;
		"error"?: Models.BulkErrorEntity;
	}
	
	export interface BulkResponseResultExternalContactExternalContact { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.ExternalContact;
		"error"?: Models.BulkErrorExternalContact;
	}
	
	export interface BulkResponseResultExternalOrganizationEntity { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.ExternalOrganization;
		"error"?: Models.BulkErrorEntity;
	}
	
	export interface BulkResponseResultExternalOrganizationExternalOrganization { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.ExternalOrganization;
		"error"?: Models.BulkErrorExternalOrganization;
	}
	
	export interface BulkResponseResultNoteEntity { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.Note;
		"error"?: Models.BulkErrorEntity;
	}
	
	export interface BulkResponseResultNoteNote { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.Note;
		"error"?: Models.BulkErrorNote;
	}
	
	export interface BulkResponseResultRelationshipEntity { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.Relationship;
		"error"?: Models.BulkErrorEntity;
	}
	
	export interface BulkResponseResultRelationshipRelationship { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: Models.Relationship;
		"error"?: Models.BulkErrorRelationship;
	}
	
	export interface BulkResponseResultVoidEntity { 
		"id"?: string;
		"success"?: boolean;
		"entity"?: object;
		"error"?: Models.BulkErrorEntity;
	}
	
	export interface BulkResult { 
		"error"?: Models.BulkError;
		"entity"?: object;
	}
	
	export interface BulkShiftTradeStateUpdateRequest { 
		"entities": Array<Models.BulkUpdateShiftTradeStateRequestItem>;
	}
	
	export interface BulkUpdateShiftTradeStateRequestItem { 
		"id"?: string;
		"state": string;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface BulkUpdateShiftTradeStateResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BulkUpdateShiftTradeStateResult;
	}
	
	export interface BulkUpdateShiftTradeStateResult { 
		"entities"?: Array<Models.BulkUpdateShiftTradeStateResultItem>;
	}
	
	export interface BulkUpdateShiftTradeStateResultItem { 
		"id"?: string;
		"state"?: string;
		"reviewedBy"?: Models.UserReference;
		"reviewedDate"?: string;
		"failureReason"?: string;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface Bullseye { 
		"rings"?: Array<Models.Ring>;
	}
	
	export interface BusinessUnitActivityCode { 
		"id"?: string;
		"name"?: string;
		"active"?: boolean;
		"defaultCode"?: boolean;
		"category"?: string;
		"lengthInMinutes"?: number;
		"countsAsPaidTime"?: boolean;
		"countsAsWorkTime"?: boolean;
		"agentTimeOffSelectable"?: boolean;
		"countsTowardShrinkage"?: boolean;
		"plannedShrinkage"?: boolean;
		"interruptible"?: boolean;
		"secondaryPresences"?: Array<Models.SecondaryPresence>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface BusinessUnitActivityCodeListing { 
		"entities"?: Array<Models.BusinessUnitActivityCode>;
		"downloadUrl"?: string;
	}
	
	export interface BusinessUnitListItem { 
		"id"?: string;
		"name"?: string;
		"authorized"?: boolean;
		"division"?: Models.DivisionReference;
		"selfUri"?: string;
	}
	
	export interface BusinessUnitListing { 
		"entities"?: Array<Models.BusinessUnitListItem>;
	}
	
	export interface BusinessUnitReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface BusinessUnitResponse { 
		"id"?: string;
		"name"?: string;
		"settings"?: Models.BusinessUnitSettingsResponse;
		"division"?: Models.DivisionReference;
		"selfUri"?: string;
	}
	
	export interface BusinessUnitSettingsResponse { 
		"startDayOfWeek": string;
		"timeZone": string;
		"shortTermForecasting"?: Models.BuShortTermForecastingSettings;
		"scheduling"?: Models.BuSchedulingSettingsResponse;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface ButtonComponent { 
		"title"?: string;
		"actions"?: Models.ContentActions;
	}
	
	export interface ButtonResponse { 
		"type"?: string;
		"text"?: string;
		"payload"?: string;
		"messageType"?: string;
	}
	
	export interface CachedMediaItem { 
		"id"?: string;
		"url"?: string;
		"downloadUrl"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"dateCreated"?: string;
		"dateExpires"?: string;
		"selfUri"?: string;
	}
	
	export interface CachedMediaItemEntityListing { 
		"entities"?: Array<Models.CachedMediaItem>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CalendarUrlResponse { 
		"calendarUrl"?: string;
		"selfUri"?: string;
	}
	
	export interface Calibration { 
		"id"?: string;
		"name"?: string;
		"calibrator"?: Models.User;
		"agent"?: Models.User;
		"conversation"?: Models.ConversationReference;
		"evaluationForm"?: Models.EvaluationForm;
		"contextId"?: string;
		"averageScore"?: number;
		"highScore"?: number;
		"lowScore"?: number;
		"createdDate"?: string;
		"evaluations"?: Array<Models.Evaluation>;
		"evaluators"?: Array<Models.User>;
		"scoringIndex"?: Models.Evaluation;
		"expertEvaluator"?: Models.User;
		"selfUri"?: string;
	}
	
	export interface CalibrationAssignment { 
		"calibrator"?: Models.User;
		"evaluators"?: Array<Models.User>;
		"evaluationForm"?: Models.EvaluationForm;
		"expertEvaluator"?: Models.User;
	}
	
	export interface CalibrationCreate { 
		"id"?: string;
		"name"?: string;
		"calibrator"?: Models.User;
		"agent"?: Models.User;
		"conversation": Models.ConversationReference;
		"evaluationForm"?: Models.EvaluationForm;
		"contextId"?: string;
		"averageScore"?: number;
		"highScore"?: number;
		"lowScore"?: number;
		"createdDate"?: string;
		"evaluations"?: Array<Models.Evaluation>;
		"evaluators"?: Array<Models.User>;
		"scoringIndex"?: Models.Evaluation;
		"expertEvaluator"?: Models.User;
		"selfUri"?: string;
	}
	
	export interface CalibrationEntityListing { 
		"entities"?: Array<Models.Calibration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Call { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"direction"?: string;
		"recording"?: boolean;
		"recordingState"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"securePause"?: boolean;
		"recordingId"?: string;
		"segments"?: Array<Models.Segment>;
		"errorInfo"?: Models.ErrorInfo;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"documentId"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"disconnectReasons"?: Array<Models.DisconnectReason>;
		"faxStatus"?: Models.FaxStatus;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"uuiData"?: string;
		"self"?: Models.Address;
		"other"?: Models.Address;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
		"disposition"?: Models.Disposition;
	}
	
	export interface CallBasic { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"direction"?: string;
		"recording"?: boolean;
		"recordingState"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"securePause"?: boolean;
		"recordingId"?: string;
		"segments"?: Array<Models.Segment>;
		"errorInfo"?: Models.ErrorInfo;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"documentId"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"disconnectReasons"?: Array<Models.DisconnectReason>;
		"faxStatus"?: Models.FaxStatus;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"uuiData"?: string;
		"self"?: Models.Address;
		"other"?: Models.Address;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
		"disposition"?: Models.Disposition;
	}
	
	export interface CallCommand { 
		"callNumber": string;
		"phoneColumn"?: string;
	}
	
	export interface CallConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.CallMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"utilizationLabelId"?: string;
		"recordingState"?: string;
		"maxParticipants"?: number;
		"securePause"?: boolean;
		"selfUri"?: string;
	}
	
	export interface CallConversationEntityListing { 
		"entities"?: Array<Models.CallConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CallForwarding { 
		"id"?: string;
		"name"?: string;
		"user"?: Models.User;
		"enabled"?: boolean;
		"phoneNumber"?: string;
		"calls"?: Array<Models.CallRoute>;
		"voicemail"?: string;
		"modifiedDate"?: string;
		"selfUri"?: string;
	}
	
	export interface CallForwardingEventCall { 
		"targets"?: Array<Models.CallForwardingEventTarget>;
	}
	
	export interface CallForwardingEventCallForwarding { 
		"user"?: Models.CallForwardingEventUser;
		"enabled"?: boolean;
		"calls"?: Array<Models.CallForwardingEventCall>;
		"voicemail"?: string;
		"modifiedDate"?: string;
	}
	
	export interface CallForwardingEventTarget { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface CallForwardingEventUser { 
		"id"?: string;
	}
	
	export interface CallHistoryConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.CallHistoryParticipant>;
		"direction"?: string;
		"wentToVoicemail"?: boolean;
		"missedCall"?: boolean;
		"startTime"?: string;
		"wasConference"?: boolean;
		"wasCallback"?: boolean;
		"hadScreenShare"?: boolean;
		"hadCobrowse"?: boolean;
		"wasOutboundCampaign"?: boolean;
		"selfUri"?: string;
	}
	
	export interface CallHistoryConversationEntityListing { 
		"entities"?: Array<Models.CallHistoryConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CallHistoryParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"purpose"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"user"?: Models.User;
		"queue"?: Models.Queue;
		"group"?: Models.Group;
		"disconnectType"?: string;
		"externalContact"?: Models.ExternalContact;
		"externalOrganization"?: Models.ExternalOrganization;
		"didInteract"?: boolean;
		"sipResponseCodes"?: Array<number>;
		"flaggedReason"?: string;
		"outboundCampaign"?: Models.Campaign;
	}
	
	export interface CallMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"mediaRoles"?: Array<string>;
		"user"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"team"?: Models.DomainEntityRef;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ErrorInfo;
		"script"?: Models.DomainEntityRef;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.DomainEntityRef;
		"externalOrganization"?: Models.DomainEntityRef;
		"wrapup"?: Models.Wrapup;
		"peer"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.JourneyContext;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"recording"?: boolean;
		"recordingState"?: string;
		"group"?: Models.DomainEntityRef;
		"ani"?: string;
		"dnis"?: string;
		"documentId"?: string;
		"faxStatus"?: Models.FaxStatus;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"consultParticipantId"?: string;
		"uuiData"?: string;
		"bargedTime"?: string;
		"securePause"?: boolean;
		"disposition"?: Models.Disposition;
	}
	
	export interface CallMediaPolicy { 
		"actions"?: Models.PolicyActions;
		"conditions"?: Models.CallMediaPolicyConditions;
	}
	
	export interface CallMediaPolicyConditions { 
		"forUsers"?: Array<Models.User>;
		"dateRanges"?: Array<string>;
		"forQueues"?: Array<Models.Queue>;
		"wrapupCodes"?: Array<Models.WrapupCode>;
		"languages"?: Array<Models.Language>;
		"timeAllowed"?: Models.TimeAllowed;
		"teams"?: Array<Models.Team>;
		"directions"?: Array<string>;
		"duration"?: Models.DurationCondition;
	}
	
	export interface CallRecord { 
		"lastAttempt"?: string;
		"lastResult"?: string;
	}
	
	export interface CallRoute { 
		"targets"?: Array<Models.CallTarget>;
	}
	
	export interface CallTarget { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface CallToAction { 
		"text"?: string;
		"url": string;
		"target"?: string;
	}
	
	export interface CallableContactsDiagnostic { 
		"attemptLimits"?: Models.DomainEntityRef;
		"dncLists"?: Array<Models.DomainEntityRef>;
		"callableTimeSet"?: Models.DomainEntityRef;
		"ruleSets"?: Array<Models.DomainEntityRef>;
	}
	
	export interface CallableTime { 
		"timeSlots": Array<Models.CampaignTimeSlot>;
		"timeZoneId": string;
	}
	
	export interface CallableTimeSet { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"callableTimes": Array<Models.CallableTime>;
		"selfUri"?: string;
	}
	
	export interface CallableTimeSetEntityListing { 
		"entities"?: Array<Models.CallableTimeSet>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CallableWindow { 
		"mapped"?: Models.AtzmTimeSlot;
		"unmapped"?: Models.AtzmTimeSlotWithTimeZone;
	}
	
	export interface Callback { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"segments"?: Array<Models.Segment>;
		"direction"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"dialerPreview"?: Models.DialerPreview;
		"voicemail"?: Models.Voicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"scriptId"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"timeoutSeconds"?: number;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
		"provider"?: string;
		"peerId"?: string;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"callerId"?: string;
		"callerIdName"?: string;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
	}
	
	export interface CallbackBasic { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"segments"?: Array<Models.Segment>;
		"direction"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"dialerPreview"?: Models.DialerPreview;
		"voicemail"?: Models.Voicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"scriptId"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"timeoutSeconds"?: number;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
		"provider"?: string;
		"peerId"?: string;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"callerId"?: string;
		"callerIdName"?: string;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
	}
	
	export interface CallbackConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.CallbackMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
	}
	
	export interface CallbackConversationEntityListing { 
		"entities"?: Array<Models.CallbackConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CallbackDisconnectIdentifier { 
		"conversationId": string;
		"callbackId": string;
	}
	
	export interface CallbackIdentifier { 
		"type": string;
		"id": string;
	}
	
	export interface CallbackMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"mediaRoles"?: Array<string>;
		"user"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"team"?: Models.DomainEntityRef;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ErrorInfo;
		"script"?: Models.DomainEntityRef;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.DomainEntityRef;
		"externalOrganization"?: Models.DomainEntityRef;
		"wrapup"?: Models.Wrapup;
		"peer"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.JourneyContext;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"outboundPreview"?: Models.DialerPreview;
		"voicemail"?: Models.Voicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"timeoutSeconds"?: number;
		"automatedCallbackConfigId"?: string;
		"callbackScheduledTime"?: string;
	}
	
	export interface CallbackMediaSettings { 
		"enableAutoAnswer"?: boolean;
		"alertingTimeoutSeconds"?: number;
		"serviceLevel"?: Models.ServiceLevel;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"subTypeSettings"?: { [key: string]: Models.BaseMediaSettings; };
		"enableAutoDialAndEnd"?: boolean;
		"autoDialDelaySeconds"?: number;
		"autoEndDelaySeconds"?: number;
	}
	
	export interface Callheader { 
		"id"?: string;
		"name"?: string;
		"headers"?: { [key: string]: Array<string>; };
		"selfUri"?: string;
	}
	
	export interface Callmessage { 
		"id"?: string;
		"name"?: string;
		"message"?: string;
		"selfUri"?: string;
	}
	
	export interface Campaign { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"contactList": Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"dialingMode": string;
		"script"?: Models.DomainEntityRef;
		"edgeGroup"?: Models.DomainEntityRef;
		"site"?: Models.DomainEntityRef;
		"campaignStatus"?: string;
		"phoneColumns": Array<Models.PhoneColumn>;
		"abandonRate"?: number;
		"dncLists"?: Array<Models.DomainEntityRef>;
		"callableTimeSet"?: Models.DomainEntityRef;
		"callAnalysisResponseSet"?: Models.DomainEntityRef;
		"errors"?: Array<Models.RestErrorDetail>;
		"callerName": string;
		"callerAddress": string;
		"outboundLineCount"?: number;
		"ruleSets"?: Array<Models.DomainEntityRef>;
		"skipPreviewDisabled"?: boolean;
		"previewTimeOutSeconds"?: number;
		"alwaysRunning"?: boolean;
		"contactSort"?: Models.ContactSort;
		"contactSorts"?: Array<Models.ContactSort>;
		"noAnswerTimeout"?: number;
		"callAnalysisLanguage"?: string;
		"priority"?: number;
		"contactListFilters"?: Array<Models.DomainEntityRef>;
		"division"?: Models.DomainEntityRef;
		"dynamicContactQueueingSettings"?: Models.DynamicContactQueueingSettings;
		"maxCallsPerAgent"?: number;
		"callbackAutoAnswer"?: boolean;
		"selfUri"?: string;
	}
	
	export interface CampaignDiagnostics { 
		"callableContacts"?: Models.CallableContactsDiagnostic;
		"queueUtilizationDiagnostic"?: Models.QueueUtilizationDiagnostic;
		"ruleSetDiagnostics"?: Array<Models.RuleSetDiagnostic>;
		"outstandingInteractionsCount"?: number;
		"scheduledInteractionsCount"?: number;
		"timeZoneRescheduledCallsCount"?: number;
		"campaignSkillStatistics"?: Models.CampaignSkillStatistics;
	}
	
	export interface CampaignDivisionView { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"selfUri"?: string;
	}
	
	export interface CampaignDivisionViewListing { 
		"entities"?: Array<Models.CampaignDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CampaignEntityListing { 
		"entities"?: Array<Models.Campaign>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CampaignInteraction { 
		"id"?: string;
		"campaign"?: Models.DomainEntityRef;
		"agent"?: Models.DomainEntityRef;
		"contact"?: Models.DomainEntityRef;
		"destinationAddress"?: string;
		"activePreviewCall"?: boolean;
		"lastActivePreviewWrapupTime"?: string;
		"creationTime"?: string;
		"callPlacedTime"?: string;
		"callRoutedTime"?: string;
		"previewConnectedTime"?: string;
		"queue"?: Models.DomainEntityRef;
		"script"?: Models.DomainEntityRef;
		"disposition"?: string;
		"callerName"?: string;
		"callerAddress"?: string;
		"previewPopDeliveredTime"?: string;
		"conversation"?: Models.ConversationBasic;
		"dialerSystemParticipantId"?: string;
		"dialingMode"?: string;
		"skills"?: Array<Models.DomainEntityRef>;
	}
	
	export interface CampaignInteractions { 
		"campaign"?: Models.DomainEntityRef;
		"pendingInteractions"?: Array<Models.CampaignInteraction>;
		"proceedingInteractions"?: Array<Models.CampaignInteraction>;
		"previewingInteractions"?: Array<Models.CampaignInteraction>;
		"interactingInteractions"?: Array<Models.CampaignInteraction>;
		"scheduledInteractions"?: Array<Models.CampaignInteraction>;
	}
	
	export interface CampaignLinesUtilization { 
		"assignedOutboundLines"?: number;
		"totalAvailableOutboundLines"?: number;
	}
	
	export interface CampaignProgress { 
		"campaign": Models.DomainEntityRef;
		"contactList": Models.DomainEntityRef;
		"numberOfContactsCalled"?: number;
		"numberOfContactsMessaged"?: number;
		"totalNumberOfContacts"?: number;
		"percentage"?: number;
		"numberOfContactsSkipped"?: { [key: string]: number; };
	}
	
	export interface CampaignRule { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"campaignRuleEntities": Models.CampaignRuleEntities;
		"campaignRuleConditions": Array<Models.CampaignRuleCondition>;
		"campaignRuleActions": Array<Models.CampaignRuleAction>;
		"matchAnyConditions"?: boolean;
		"enabled"?: boolean;
		"selfUri"?: string;
	}
	
	export interface CampaignRuleAction { 
		"id"?: string;
		"parameters"?: Models.CampaignRuleParameters;
		"actionType": string;
		"campaignRuleActionEntities": Models.CampaignRuleActionEntities;
	}
	
	export interface CampaignRuleActionEntities { 
		"campaigns"?: Array<Models.DomainEntityRef>;
		"sequences"?: Array<Models.DomainEntityRef>;
		"useTriggeringEntity"?: boolean;
	}
	
	export interface CampaignRuleCondition { 
		"id"?: string;
		"parameters": Models.CampaignRuleParameters;
		"conditionType": string;
	}
	
	export interface CampaignRuleEntities { 
		"campaigns"?: Array<Models.DomainEntityRef>;
		"sequences"?: Array<Models.DomainEntityRef>;
	}
	
	export interface CampaignRuleEntityListing { 
		"entities"?: Array<Models.CampaignRule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CampaignRuleParameters { 
		"operator"?: string;
		"value"?: string;
		"priority"?: string;
		"dialingMode"?: string;
	}
	
	export interface CampaignSchedule { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"intervals": Array<Models.ScheduleInterval>;
		"timeZone": string;
		"campaign": Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface CampaignSequence { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"campaigns": Array<Models.DomainEntityRef>;
		"currentCampaign": number;
		"status": string;
		"stopMessage"?: string;
		"repeat"?: boolean;
		"selfUri"?: string;
	}
	
	export interface CampaignSequenceEntityListing { 
		"entities"?: Array<Models.CampaignSequence>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CampaignSkillStatistics { 
		"skillCombinations"?: number;
		"eligibleSkilledAgents"?: number;
	}
	
	export interface CampaignStats { 
		"contactRate"?: Models.ConnectRate;
		"idleAgents"?: number;
		"effectiveIdleAgents"?: number;
		"adjustedCallsPerAgent"?: number;
		"outstandingCalls"?: number;
		"scheduledCalls"?: number;
		"timeZoneRescheduledCalls"?: number;
	}
	
	export interface CampaignTimeSlot { 
		"startTime": string;
		"stopTime": string;
		"day": number;
	}
	
	export interface CannedResponseLibraries { 
		"libraryIds"?: Array<string>;
		"mode"?: string;
	}
	
	export interface Card { 
		"title"?: string;
		"description"?: string;
		"url"?: string;
		"defaultAction"?: Models.CardAction;
		"actions"?: Array<Models.CardAction>;
	}
	
	export interface CardAction { 
		"type"?: string;
		"text"?: string;
		"payload"?: string;
		"url"?: string;
		"isSelected"?: boolean;
	}
	
	export interface Category { 
		"name"?: string;
	}
	
	export interface CategoryCreateRequest { 
		"id"?: string;
		"name": string;
		"parentCategoryId"?: string;
		"description"?: string;
		"externalId"?: string;
		"selfUri"?: string;
	}
	
	export interface CategoryEntityListing { 
		"entities"?: Array<Models.Category>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface CategoryListing { 
		"entities"?: Array<Models.KnowledgeCategory>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface CategoryReference { 
		"id": string;
		"name"?: string;
		"parentCategory"?: Models.CategoryReference;
		"selfUri"?: string;
	}
	
	export interface CategoryResponse { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"externalId"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"parentCategory"?: Models.CategoryReference;
		"documentCount"?: number;
		"knowledgeBase"?: Models.KnowledgeBaseReference;
		"selfUri"?: string;
	}
	
	export interface CategoryResponseListing { 
		"entities"?: Array<Models.CategoryResponse>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface CategoryUpdateRequest { 
		"id"?: string;
		"name"?: string;
		"parentCategoryId"?: string;
		"description"?: string;
		"externalId"?: string;
		"selfUri"?: string;
	}
	
	export interface Certificate { 
		"certificate": string;
	}
	
	export interface CertificateAuthorityEntityListing { 
		"entities"?: Array<Models.DomainCertificateAuthority>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CertificateDetails { 
		"issuer"?: string;
		"subject"?: string;
		"expirationDate"?: string;
		"issueDate"?: string;
		"expired"?: boolean;
		"valid"?: boolean;
		"signatureValid"?: boolean;
	}
	
	export interface Change { 
		"entity"?: Models.AuditEntity;
		"property"?: string;
		"oldValues"?: Array<string>;
		"newValues"?: Array<string>;
	}
	
	export interface ChangeMyPasswordRequest { 
		"newPassword": string;
		"oldPassword": string;
	}
	
	export interface ChangePasswordRequest { 
		"newPassword": string;
	}
	
	export interface Channel { 
		"connectUri"?: string;
		"id"?: string;
		"expires"?: string;
	}
	
	export interface ChannelEntityListing { 
		"entities"?: Array<Models.Channel>;
	}
	
	export interface ChannelTopic { 
		"id"?: string;
		"state"?: string;
		"rejectionReason"?: string;
		"selfUri"?: string;
	}
	
	export interface ChannelTopicEntityListing { 
		"entities"?: Array<Models.ChannelTopic>;
	}
	
	export interface Chat { 
		"jabberId"?: string;
	}
	
	export interface ChatBadgeTopicBadgeEntity { 
		"jabberId"?: string;
	}
	
	export interface ChatBadgeTopicChatBadge { 
		"entity"?: Models.ChatBadgeTopicBadgeEntity;
		"unreadCount"?: number;
		"lastUnreadNotificationDate"?: string;
	}
	
	export interface ChatConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ChatMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
	}
	
	export interface ChatConversationEntityListing { 
		"entities"?: Array<Models.ChatConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ChatMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"mediaRoles"?: Array<string>;
		"user"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"team"?: Models.DomainEntityRef;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ErrorInfo;
		"script"?: Models.DomainEntityRef;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.DomainEntityRef;
		"externalOrganization"?: Models.DomainEntityRef;
		"wrapup"?: Models.Wrapup;
		"peer"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.JourneyContext;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"roomId"?: string;
		"avatarImageUrl"?: string;
	}
	
	export interface ChatMediaPolicy { 
		"actions"?: Models.PolicyActions;
		"conditions"?: Models.ChatMediaPolicyConditions;
	}
	
	export interface ChatMediaPolicyConditions { 
		"forUsers"?: Array<Models.User>;
		"dateRanges"?: Array<string>;
		"forQueues"?: Array<Models.Queue>;
		"wrapupCodes"?: Array<Models.WrapupCode>;
		"languages"?: Array<Models.Language>;
		"timeAllowed"?: Models.TimeAllowed;
		"teams"?: Array<Models.Team>;
		"duration"?: Models.DurationCondition;
	}
	
	export interface ChatMessage { 
		"body"?: string;
		"id"?: string;
		"to"?: string;
		"from"?: string;
		"utc"?: string;
		"chat"?: string;
		"message"?: string;
		"type"?: string;
		"bodyType"?: string;
		"senderCommunicationId"?: string;
		"participantPurpose"?: string;
		"user"?: Models.ChatMessageUser;
	}
	
	export interface ChatMessageEntityListing { 
		"entities"?: Array<Models.ChatMessageResponse>;
	}
	
	export interface ChatMessageResponse { 
		"id": string;
		"dateCreated": string;
		"dateModified"?: string;
		"toJid": string;
		"jid": string;
		"body": string;
		"mentions"?: { [key: string]: string; };
		"edited"?: boolean;
		"attachmentDeleted"?: boolean;
		"fileUri"?: string;
		"thread": Models.Entity;
		"parentThread"?: Models.Entity;
		"user"?: Models.AddressableEntityRef;
		"toUser"?: Models.AddressableEntityRef;
		"reactions"?: Array<Models.ChatReaction>;
	}
	
	export interface ChatMessageUser { 
		"id"?: string;
		"name"?: string;
		"displayName"?: string;
		"username"?: string;
		"images"?: Array<Models.UserImage>;
	}
	
	export interface ChatReaction { 
		"emoji": string;
		"users": Array<Models.AddressableEntityRef>;
	}
	
	export interface ChatReactionUpdate { 
		"reactions": Array<string>;
	}
	
	export interface ChatSendMessageResponse { 
		"id": string;
	}
	
	export interface ChatSettings { 
		"messageRetentionPeriodDays"?: number;
	}
	
	export interface ChatUserSettings { 
		"mobile": Models.MobileSettings;
	}
	
	export interface Check { 
		"result"?: string;
		"type"?: string;
	}
	
	export interface ClientApp { 
		"id"?: string;
		"name"?: string;
		"integrationType"?: Models.IntegrationType;
		"notes"?: string;
		"intendedState": string;
		"config"?: Models.ClientAppConfigurationInfo;
		"reportedState"?: Models.IntegrationStatusInfo;
		"attributes"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface ClientAppConfigurationInfo { 
		"current"?: Models.IntegrationConfiguration;
		"effective"?: Models.EffectiveConfiguration;
	}
	
	export interface ClientAppEntityListing { 
		"entities"?: Array<Models.ClientApp>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ClonedUser { 
		"id"?: string;
		"name"?: string;
		"trustor"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface ClonedUserEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.ClonedUser>;
		"selfUri"?: string;
	}
	
	export interface CloseButtonStyleProperties { 
		"color"?: string;
		"opacity"?: number;
	}
	
	export interface CoachingAnnotation { 
		"id"?: string;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"modifiedBy"?: Models.UserReference;
		"dateModified"?: string;
		"text": string;
		"isDeleted"?: boolean;
		"accessType"?: string;
		"selfUri"?: string;
	}
	
	export interface CoachingAnnotationCreateRequest { 
		"text": string;
		"accessType": string;
	}
	
	export interface CoachingAnnotationList { 
		"entities"?: Array<Models.CoachingAnnotation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CoachingAppointmentAggregateRequest { 
		"interval": string;
		"metrics"?: Array<string>;
		"groupBy"?: Array<string>;
		"filter": Models.QueryRequestFilter;
	}
	
	export interface CoachingAppointmentAggregateResponse { 
		"results"?: Array<Models.QueryResponseGroupedData>;
	}
	
	export interface CoachingAppointmentReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface CoachingAppointmentResponse { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"status"?: string;
		"facilitator"?: Models.UserReference;
		"attendees"?: Array<Models.UserReference>;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"modifiedBy"?: Models.UserReference;
		"dateModified"?: string;
		"conversations"?: Array<Models.ConversationReference>;
		"documents"?: Array<Models.DocumentReference>;
		"isOverdue"?: boolean;
		"wfmSchedule"?: Models.WfmScheduleReference;
		"dateCompleted"?: string;
		"externalLinks"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface CoachingAppointmentResponseList { 
		"entities"?: Array<Models.CoachingAppointmentResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CoachingAppointmentStatusRequest { 
		"status": string;
	}
	
	export interface CoachingAppointmentStatusResponse { 
		"appointment"?: Models.CoachingAppointmentReference;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"status"?: string;
	}
	
	export interface CoachingAppointmentStatusResponseList { 
		"entities"?: Array<Models.CoachingAppointmentStatusResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface CoachingNotification { 
		"id"?: string;
		"name"?: string;
		"markedAsRead"?: boolean;
		"actionType"?: string;
		"relationship"?: string;
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"status"?: string;
		"user"?: Models.UserReference;
		"appointment"?: Models.CoachingAppointmentResponse;
		"selfUri"?: string;
	}
	
	export interface CoachingNotificationList { 
		"entities"?: Array<Models.CoachingNotification>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CoachingSlot { 
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"staffingDifference"?: number;
		"differenceRating"?: string;
		"wfmSchedule"?: Models.WfmScheduleReference;
	}
	
	export interface CoachingSlotsRequest { 
		"interval": string;
		"lengthInMinutes": number;
		"attendeeIds": Array<string>;
		"facilitatorIds"?: Array<string>;
		"interruptibleAppointmentIds"?: Array<string>;
	}
	
	export interface CoachingSlotsResponse { 
		"suggestedSlots"?: Array<Models.CoachingSlot>;
		"attendeeSchedules"?: Array<Models.UserAvailableTimes>;
		"facilitatorSchedules"?: Array<Models.UserAvailableTimes>;
		"wfmScheduleActivities"?: Array<Models.WfmScheduleActivity>;
	}
	
	export interface CobrowseConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.CobrowseMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
	}
	
	export interface CobrowseConversationEntityListing { 
		"entities"?: Array<Models.CobrowseConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CobrowseMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"mediaRoles"?: Array<string>;
		"user"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"team"?: Models.DomainEntityRef;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ErrorInfo;
		"script"?: Models.DomainEntityRef;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.DomainEntityRef;
		"externalOrganization"?: Models.DomainEntityRef;
		"wrapup"?: Models.Wrapup;
		"peer"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.JourneyContext;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"controlling"?: Array<string>;
		"viewerUrl"?: string;
		"providerEventTime"?: string;
	}
	
	export interface CobrowseSettings { 
		"enabled"?: boolean;
		"allowAgentControl"?: boolean;
		"maskSelectors"?: Array<string>;
		"channels"?: Array<string>;
		"readonlySelectors"?: Array<string>;
	}
	
	export interface CobrowseWebMessagingSession { 
		"id"?: string;
		"name"?: string;
		"joinCode"?: string;
		"websocketUrl"?: string;
		"dateOfferEnds"?: string;
		"communicationType"?: string;
		"selfUri"?: string;
	}
	
	export interface Cobrowsesession { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"disconnectType"?: string;
		"self"?: Models.Address;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"controlling"?: Array<string>;
		"viewerUrl"?: string;
		"providerEventTime"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"provider"?: string;
		"peerId"?: string;
		"segments"?: Array<Models.Segment>;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface Column { 
		"columnName"?: string;
		"columnNumber"?: number;
		"startPosition"?: number;
		"length"?: number;
	}
	
	export interface ColumnDataTypeSpecification { 
		"columnName"?: string;
		"columnDataType"?: string;
		"min"?: number;
		"max"?: number;
		"maxLength"?: number;
	}
	
	export interface ColumnStatus { 
		"contactable"?: boolean;
	}
	
	export interface CommandStatus { 
		"id"?: string;
		"name"?: string;
		"expiration"?: string;
		"userId"?: string;
		"statusCode"?: string;
		"commandType"?: string;
		"document"?: Models.Document;
		"selfUri"?: string;
	}
	
	export interface CommandStatusEntityListing { 
		"entities"?: Array<Models.CommandStatus>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CommonAlert { 
		"id"?: string;
		"name"?: string;
		"user": Models.UserReference;
		"rule": Models.AlertRuleProperties;
		"notifications": Array<Models.AlertNotification>;
		"dateStart": string;
		"dateEnd"?: string;
		"active": boolean;
		"unread": boolean;
		"waitBetweenNotificationMs": number;
		"muted": boolean;
		"snoozed": boolean;
		"dateMutedUntil": string;
		"dateSnoozedUntil": string;
		"conditions": Models.CommonRuleConditions;
		"conversationId"?: string;
		"alertSummary"?: Models.AlertSummary;
		"ruleUri"?: string;
		"selfUri"?: string;
	}
	
	export interface CommonAlertBulkUpdateRequest { 
		"type": string;
		"alertIds": Array<string>;
		"muteSnooze"?: Models.MuteSnoozeFields;
		"unread"?: Models.UnreadFields;
	}
	
	export interface CommonCampaign { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"mediaType"?: string;
		"selfUri"?: string;
	}
	
	export interface CommonCampaignDivisionView { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"mediaType"?: string;
		"selfUri"?: string;
	}
	
	export interface CommonCampaignDivisionViewEntityListing { 
		"entities"?: Array<Models.CommonCampaignDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CommonCampaignEntityListing { 
		"entities"?: Array<Models.CommonCampaign>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CommonRule { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"enabled"?: boolean;
		"notifications"?: Array<Models.AlertNotification>;
		"sendExitingAlarmNotifications"?: boolean;
		"waitBetweenNotificationMs"?: number;
		"conditions"?: Models.CommonRuleConditions;
		"type": string;
		"inAlarm"?: boolean;
		"user"?: Models.UserReference;
		"version"?: number;
		"dateCreated"?: string;
		"dateLastModified"?: string;
		"selfUri"?: string;
	}
	
	export interface CommonRuleBulkDeleteRequest { 
		"ruleIds": Array<string>;
	}
	
	export interface CommonRuleBulkUpdateNotificationsRequest { 
		"ruleIds": Array<string>;
		"properties"?: Models.ModifiableRuleProperties;
		"typesToAdd"?: Array<string>;
		"typesToRemove"?: Array<string>;
	}
	
	export interface CommonRuleConditions { 
		"clauses"?: Array<Models.CommonRuleConditions>;
		"predicates": Array<Models.CommonRulePredicate>;
		"type": string;
		"id"?: string;
	}
	
	export interface CommonRuleContainer { 
		"entities"?: Array<Models.CommonRule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CommonRulePredicate { 
		"metricType": string;
		"metricValueType": string;
		"comparisonOperator": string;
		"value": number;
		"status"?: string;
		"entity": Models.CommonRulePredicateEntity;
		"mediaType"?: string;
		"metric": string;
	}
	
	export interface CommonRulePredicateEntity { 
		"entityType": string;
		"user"?: Models.AddressableEntityRef;
		"group"?: Models.AddressableEntityRef;
		"queue"?: Models.AddressableEntityRef;
		"team"?: Models.AddressableEntityRef;
	}
	
	export interface CommunicationAnsweredEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
	}
	
	export interface CommunicationDispositionAppliedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
	}
	
	export interface CommunicationEndedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"disconnectType": string;
		"destinationConversationId"?: string;
	}
	
	export interface ComparisonPeriod { 
		"id"?: string;
		"kpi"?: string;
		"dateStarted"?: string;
		"dateEnded"?: string;
		"percentageBenefit"?: number;
		"kpiResults"?: Array<Models.KpiResult>;
		"selfUri"?: string;
	}
	
	export interface ComparisonPeriodListing { 
		"total"?: number;
		"entities"?: Array<Models.ComparisonPeriod>;
		"selfUri"?: string;
	}
	
	export interface ComplexVariableInfo { 
		"id": string;
		"name": string;
	}
	
	export interface Compliance { 
		"stopSettings": Array<Models.StopSettings>;
		"optInSettings": Array<Models.OptInSettings>;
		"helpSettings": Array<Models.HelpSettings>;
	}
	
	export interface ComplianceResponse { 
		"message": string;
	}
	
	export interface Condition { 
		"type"?: string;
		"inverted"?: boolean;
		"attributeName"?: string;
		"value"?: string;
		"valueType"?: string;
		"operator"?: string;
		"codes"?: Array<string>;
		"property"?: string;
		"propertyType"?: string;
		"dataAction"?: Models.DomainEntityRef;
		"dataNotFoundResolution"?: boolean;
		"contactIdField"?: string;
		"callAnalysisResultField"?: string;
		"agentWrapupField"?: string;
		"contactColumnToDataActionFieldMappings"?: Array<Models.ContactColumnToDataActionFieldMapping>;
		"predicates"?: Array<Models.DataActionConditionPredicate>;
	}
	
	export interface ConditionalGroupRouting { 
		"rules"?: Array<Models.ConditionalGroupRoutingRule>;
	}
	
	export interface ConditionalGroupRoutingCondition { 
		"queue"?: Models.DomainEntityRef;
		"metric"?: string;
		"operator"?: string;
		"value"?: number;
	}
	
	export interface ConditionalGroupRoutingRule { 
		"queue"?: Models.DomainEntityRef;
		"metric"?: string;
		"operator"?: string;
		"conditionValue"?: number;
		"groups"?: Array<Models.MemberGroup>;
		"waitSeconds"?: number;
	}
	
	export interface ConfigurationOverrides { 
		"priority"?: boolean;
	}
	
	export interface ConfusionDetails { 
		"intents"?: Array<Models.ConfusionIntentDetails>;
	}
	
	export interface ConfusionInfo { 
		"intents"?: Array<Models.ConfusionIntentInfo>;
	}
	
	export interface ConfusionIntentDetails { 
		"id"?: string;
		"name"?: string;
		"utteranceCount"?: number;
		"utterances"?: Array<Models.ConfusionUtterance>;
		"selfUri"?: string;
	}
	
	export interface ConfusionIntentInfo { 
		"id"?: string;
		"name"?: string;
		"utteranceCount"?: number;
	}
	
	export interface ConfusionUtterance { 
		"id"?: string;
		"text"?: string;
		"similarity"?: number;
	}
	
	export interface ConnectRate { 
		"attempts"?: number;
		"connects"?: number;
		"connectRatio"?: number;
	}
	
	export interface ConnectedEdge { 
		"id"?: string;
		"name"?: string;
		"interfaceName"?: string;
		"interfaceIpAddress"?: string;
		"edgeConnectionList"?: Array<Models.EdgeConnectionInfo>;
		"selfUri"?: string;
	}
	
	export interface ConnectedQueue { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ConnectedUser { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ConstraintConflictMessage { 
		"message"?: Models.WorkPlanConstraintConflictMessage;
		"conflictedConstraintMessages"?: Array<Models.WorkPlanConstraintMessage>;
	}
	
	export interface ConsultTransfer { 
		"speakTo": string;
		"consultingUserId"?: string;
		"destination": Models.Destination;
	}
	
	export interface ConsultTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"initiatingCommunicationId": string;
		"destinationCommunicationId": string;
		"objectCommunicationId": string;
	}
	
	export interface ConsultTransferResponse { 
		"destinationParticipantId": string;
	}
	
	export interface ConsultTransferToAgent { 
		"speakTo": string;
		"consultingUserId"?: string;
		"userId"?: string;
		"userDisplayName"?: string;
	}
	
	export interface ConsultTransferToExternal { 
		"speakTo": string;
		"consultingUserId"?: string;
		"address"?: string;
	}
	
	export interface ConsultTransferToQueue { 
		"speakTo": string;
		"consultingUserId"?: string;
		"queueId"?: string;
		"queueName"?: string;
	}
	
	export interface ConsultTransferUpdate { 
		"speakTo": string;
		"consultingUserId"?: string;
	}
	
	export interface ConsumedResourcesEntityListing { 
		"entities"?: Array<Models.Dependency>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ConsumingResourcesEntityListing { 
		"entities"?: Array<Models.Dependency>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Contact { 
		"address"?: string;
		"display"?: string;
		"mediaType"?: string;
		"type"?: string;
		"extension"?: string;
		"countryCode"?: string;
		"integration"?: string;
	}
	
	export interface ContactAddress { 
		"address1"?: string;
		"address2"?: string;
		"city"?: string;
		"state"?: string;
		"postalCode"?: string;
		"countryCode"?: string;
	}
	
	export interface ContactAddressConditionSettings { 
		"operator": string;
		"value": string;
	}
	
	export interface ContactAddressTypeConditionSettings { 
		"operator": string;
		"value": string;
	}
	
	export interface ContactAddressableEntityRef { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ContactBulkSearchCriteria { 
		"clauses"?: Array<Models.ContactListFilterClause>;
		"filterType"?: string;
	}
	
	export interface ContactCallbackRequest { 
		"campaignId": string;
		"contactListId": string;
		"contactId": string;
		"phoneColumn": string;
		"schedule": string;
	}
	
	export interface ContactCenterSettings { 
		"removeSkillsFromBlindTransfer"?: boolean;
	}
	
	export interface ContactColumnConditionSettings { 
		"columnName": string;
		"operator": string;
		"value": string;
		"valueType": string;
	}
	
	export interface ContactColumnTimeZone { 
		"timeZone"?: string;
		"columnType"?: string;
	}
	
	export interface ContactColumnToDataActionFieldMapping { 
		"contactColumnName": string;
		"dataActionField": string;
	}
	
	export interface ContactDetailEventTopicContactUpdateEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"externalOrganizationId"?: string;
		"externalContactId"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface ContactIdentifier { 
		"id"?: string;
		"type": string;
		"value": string;
		"dateCreated"?: string;
		"selfUri"?: string;
	}
	
	export interface ContactList { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"division"?: Models.DomainEntityRef;
		"columnNames": Array<string>;
		"phoneColumns"?: Array<Models.ContactPhoneNumberColumn>;
		"emailColumns"?: Array<Models.EmailColumn>;
		"importStatus"?: Models.ImportStatus;
		"previewModeColumnName"?: string;
		"previewModeAcceptedValues"?: Array<string>;
		"size"?: number;
		"attemptLimits"?: Models.DomainEntityRef;
		"automaticTimeZoneMapping"?: boolean;
		"zipCodeColumnName"?: string;
		"columnDataTypeSpecifications"?: Array<Models.ColumnDataTypeSpecification>;
		"trimWhitespace"?: boolean;
		"selfUri"?: string;
	}
	
	export interface ContactListDivisionView { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"columnNames": Array<string>;
		"phoneColumns"?: Array<Models.ContactPhoneNumberColumn>;
		"emailColumns"?: Array<Models.EmailColumn>;
		"importStatus"?: Models.ImportStatus;
		"size"?: number;
		"selfUri"?: string;
	}
	
	export interface ContactListDivisionViewListing { 
		"entities"?: Array<Models.ContactListDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ContactListEntityListing { 
		"entities"?: Array<Models.ContactList>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ContactListFilter { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"contactList"?: Models.DomainEntityRef;
		"contactListTemplate"?: Models.DomainEntityRef;
		"sourceType"?: string;
		"clauses"?: Array<Models.ContactListFilterClause>;
		"filterType"?: string;
		"selfUri"?: string;
	}
	
	export interface ContactListFilterBulkRetrieveBody { 
		"ids": Array<string>;
	}
	
	export interface ContactListFilterClause { 
		"filterType"?: string;
		"predicates"?: Array<Models.ContactListFilterPredicate>;
	}
	
	export interface ContactListFilterEntityListing { 
		"entities"?: Array<Models.ContactListFilter>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ContactListFilterPredicate { 
		"column"?: string;
		"columnType"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.ContactListFilterRange;
		"inverted"?: boolean;
	}
	
	export interface ContactListFilterRange { 
		"min"?: string;
		"max"?: string;
		"minInclusive"?: boolean;
		"maxInclusive"?: boolean;
		"inSet"?: Array<string>;
	}
	
	export interface ContactListTemplate { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"columnNames": Array<string>;
		"phoneColumns"?: Array<Models.ContactPhoneNumberColumn>;
		"emailColumns"?: Array<Models.EmailColumn>;
		"previewModeColumnName"?: string;
		"previewModeAcceptedValues"?: Array<string>;
		"attemptLimits"?: Models.DomainEntityRef;
		"automaticTimeZoneMapping"?: boolean;
		"zipCodeColumnName"?: string;
		"columnDataTypeSpecifications"?: Array<Models.ColumnDataTypeSpecification>;
		"trimWhitespace"?: boolean;
		"selfUri"?: string;
	}
	
	export interface ContactListTemplateBulkRetrieveBody { 
		"ids": Array<string>;
	}
	
	export interface ContactListTemplateEntityListing { 
		"entities"?: Array<Models.ContactListTemplate>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ContactListing { 
		"entities"?: Array<Models.ExternalContact>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"partialResults"?: boolean;
		"nextUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"lastUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ContactPhoneNumberColumn { 
		"columnName": string;
		"type": string;
		"callableTimeColumn"?: string;
	}
	
	export interface ContactSort { 
		"fieldName"?: string;
		"direction"?: string;
		"numeric"?: boolean;
	}
	
	export interface ContactableStatus { 
		"contactable"?: boolean;
		"columnStatus"?: { [key: string]: Models.ColumnStatus; };
	}
	
	export interface ContactlistDownloadReadyExportUri { 
		"uri"?: string;
		"exportTimestamp"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface ContactlistDownloadReadyObject { 
	}
	
	export interface ContactlistImportStatusImportStatus { 
		"importState"?: string;
		"totalRecords"?: number;
		"completedRecords"?: number;
		"percentageComplete"?: number;
		"failureReason"?: string;
		"targetContactListIds"?: Array<string>;
		"listNamePrefix"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface ContactlistImportStatusObject { 
	}
	
	export interface ContactsExportRequest { 
		"contactListFilterId"?: string;
		"criteria"?: Models.ContactBulkSearchCriteria;
		"contactIds"?: Array<string>;
	}
	
	export interface ContentActions { 
		"url"?: string;
		"urlTarget"?: string;
		"textback"?: string;
	}
	
	export interface ContentAttachment { 
		"id"?: string;
		"mediaType": string;
		"url"?: string;
		"mime"?: string;
		"text"?: string;
		"sha256"?: string;
		"filename"?: string;
	}
	
	export interface ContentButtonResponse { 
		"id"?: string;
		"type": string;
		"text": string;
		"payload": string;
	}
	
	export interface ContentCard { 
		"title": string;
		"description"?: string;
		"image"?: string;
		"video"?: string;
		"defaultAction"?: Models.ContentCardAction;
		"actions": Array<Models.ContentCardAction>;
	}
	
	export interface ContentCardAction { 
		"type"?: string;
		"text"?: string;
		"payload"?: string;
		"url"?: string;
	}
	
	export interface ContentCarousel { 
		"cards": Array<Models.ContentCard>;
	}
	
	export interface ContentFilterItem { 
		"name"?: string;
		"type"?: string;
		"operator"?: string;
		"values"?: Array<string>;
	}
	
	export interface ContentGeneric { 
		"title"?: string;
		"description"?: string;
		"image"?: string;
		"video"?: string;
		"actions"?: Models.ContentActions;
		"components"?: Array<Models.ButtonComponent>;
	}
	
	export interface ContentList { 
		"id"?: string;
		"listType"?: string;
		"title"?: string;
		"description"?: string;
		"submitLabel"?: string;
		"actions"?: Models.ContentActions;
		"components"?: Array<Models.ListItemComponent>;
	}
	
	export interface ContentLocation { 
		"url"?: string;
		"address"?: string;
		"text"?: string;
		"latitude"?: number;
		"longitude"?: number;
	}
	
	export interface ContentManagementSingleDocumentTopicDocumentDataV2 { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"workspace"?: Models.ContentManagementSingleDocumentTopicWorkspaceData;
		"createdBy"?: Models.ContentManagementSingleDocumentTopicUserData;
		"contentType"?: string;
		"contentLength"?: number;
		"filename"?: string;
		"changeNumber"?: number;
		"dateUploaded"?: string;
		"uploadedBy"?: Models.ContentManagementSingleDocumentTopicUserData;
		"lockInfo"?: Models.ContentManagementSingleDocumentTopicLockData;
		"selfUri"?: string;
	}
	
	export interface ContentManagementSingleDocumentTopicLockData { 
		"lockedBy"?: Models.ContentManagementSingleDocumentTopicUserData;
		"dateCreated"?: string;
		"dateExpires"?: string;
	}
	
	export interface ContentManagementSingleDocumentTopicUserData { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ContentManagementSingleDocumentTopicWorkspaceData { 
		"id"?: string;
	}
	
	export interface ContentManagementWorkspaceDocumentsTopicDocumentDataV2 { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"workspace"?: Models.ContentManagementWorkspaceDocumentsTopicWorkspaceData;
		"createdBy"?: Models.ContentManagementWorkspaceDocumentsTopicUserData;
		"contentType"?: string;
		"contentLength"?: number;
		"filename"?: string;
		"changeNumber"?: number;
		"dateUploaded"?: string;
		"uploadedBy"?: Models.ContentManagementWorkspaceDocumentsTopicUserData;
		"lockInfo"?: Models.ContentManagementWorkspaceDocumentsTopicLockData;
		"selfUri"?: string;
	}
	
	export interface ContentManagementWorkspaceDocumentsTopicLockData { 
		"lockedBy"?: Models.ContentManagementWorkspaceDocumentsTopicUserData;
		"dateCreated"?: string;
		"dateExpires"?: string;
	}
	
	export interface ContentManagementWorkspaceDocumentsTopicUserData { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ContentManagementWorkspaceDocumentsTopicWorkspaceData { 
		"id"?: string;
	}
	
	export interface ContentNotificationTemplate { 
		"id"?: string;
		"language"?: string;
		"header"?: Models.NotificationTemplateHeader;
		"body": Models.NotificationTemplateBody;
		"footer"?: Models.NotificationTemplateFooter;
	}
	
	export interface ContentOffer { 
		"imageUrl"?: string;
		"displayMode": string;
		"layoutMode": string;
		"title"?: string;
		"headline"?: string;
		"body"?: string;
		"callToAction"?: Models.CallToAction;
		"style"?: Models.ContentOfferStylingConfiguration;
	}
	
	export interface ContentOfferStyleProperties { 
		"padding"?: string;
		"color"?: string;
		"backgroundColor"?: string;
	}
	
	export interface ContentOfferStylingConfiguration { 
		"position"?: Models.ContentPositionProperties;
		"offer"?: Models.ContentOfferStyleProperties;
		"closeButton"?: Models.CloseButtonStyleProperties;
		"ctaButton"?: Models.CtaButtonStyleProperties;
		"title"?: Models.TextStyleProperties;
		"headline"?: Models.TextStyleProperties;
		"body"?: Models.TextStyleProperties;
	}
	
	export interface ContentPositionProperties { 
		"top"?: string;
		"bottom"?: string;
		"left"?: string;
		"right"?: string;
	}
	
	export interface ContentPostback { 
		"id"?: string;
		"text"?: string;
		"payload": string;
	}
	
	export interface ContentQuickReply { 
		"id"?: string;
		"text": string;
		"payload": string;
		"image"?: string;
		"action"?: string;
	}
	
	export interface ContentQuickReplyV2 { 
		"title": string;
		"actions": Array<Models.ContentQuickReply>;
	}
	
	export interface ContentReaction { 
		"reactionType": string;
		"count": number;
	}
	
	export interface ContentSetting { 
		"story"?: Models.StorySetting;
	}
	
	export interface ContentStory { 
		"type": string;
		"url": string;
		"replyToId"?: string;
	}
	
	export interface ContentText { 
		"type"?: string;
		"body": string;
	}
	
	export interface Context { 
		"patterns": Array<Models.ContextPattern>;
	}
	
	export interface ContextEntity { 
		"name": string;
	}
	
	export interface ContextIntent { 
		"name": string;
	}
	
	export interface ContextPattern { 
		"criteria": Array<Models.EntityTypeCriteria>;
	}
	
	export interface Conversation { 
		"id"?: string;
		"name"?: string;
		"externalTag"?: string;
		"startTime": string;
		"endTime"?: string;
		"address"?: string;
		"participants": Array<Models.Participant>;
		"conversationIds"?: Array<string>;
		"maxParticipants"?: number;
		"recordingState"?: string;
		"state"?: string;
		"divisions"?: Array<Models.ConversationDivisionMembership>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"securePause"?: boolean;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
	}
	
	export interface ConversationActivityData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.ConversationActivityMetricValue>;
		"truncated"?: boolean;
		"entities"?: Array<Models.ConversationActivityEntityData>;
	}
	
	export interface ConversationActivityEntityData { 
		"activityDate": string;
		"metric"?: string;
		"activeRouting"?: string;
		"addressFrom"?: string;
		"addressTo"?: string;
		"ani"?: string;
		"conversationId"?: string;
		"convertedFrom"?: string;
		"convertedTo"?: string;
		"direction"?: string;
		"dnis"?: string;
		"mediaType"?: string;
		"participantName"?: string;
		"queueId"?: string;
		"requestedLanguageId"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedRoutings"?: Array<string>;
		"routingPriority"?: number;
		"sessionId"?: string;
		"teamId"?: string;
		"usedRouting"?: string;
		"userId"?: string;
		"scoredAgents"?: Array<Models.ConversationActivityScoredAgent>;
	}
	
	export interface ConversationActivityMetricValue { 
		"metric"?: string;
		"count"?: number;
	}
	
	export interface ConversationActivityQuery { 
		"metrics": Array<Models.ConversationActivityQueryMetric>;
		"groupBy": Array<string>;
		"filter"?: Models.ConversationActivityQueryFilter;
		"order"?: string;
	}
	
	export interface ConversationActivityQueryClause { 
		"type": string;
		"predicates": Array<Models.ConversationActivityQueryPredicate>;
	}
	
	export interface ConversationActivityQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.ConversationActivityQueryClause>;
		"predicates"?: Array<Models.ConversationActivityQueryPredicate>;
	}
	
	export interface ConversationActivityQueryMetric { 
		"metric": string;
		"details"?: boolean;
	}
	
	export interface ConversationActivityQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
	}
	
	export interface ConversationActivityResponse { 
		"results"?: Array<Models.ConversationActivityData>;
		"entityIdDimension"?: string;
	}
	
	export interface ConversationActivityScoredAgent { 
		"agentScore"?: number;
		"scoredAgentId"?: string;
	}
	
	export interface ConversationAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface ConversationAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.ConversationAggregateQueryPredicate>;
	}
	
	export interface ConversationAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.ConversationAggregateQueryClause>;
		"predicates"?: Array<Models.ConversationAggregateQueryPredicate>;
	}
	
	export interface ConversationAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface ConversationAggregateQueryResponse { 
		"results"?: Array<Models.ConversationAggregateDataContainer>;
	}
	
	export interface ConversationAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.ConversationAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.ConversationAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface ConversationAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface ConversationAppSettings { 
		"enabled"?: boolean;
		"showAgentTypingIndicator"?: boolean;
		"showUserTypingIndicator"?: boolean;
		"autoStart"?: Models.AutoStart;
		"markdown"?: Models.Markdown;
		"conversationDisconnect"?: Models.ConversationDisconnectSettings;
		"conversationClear"?: Models.ConversationClearSettings;
		"humanize"?: Models.Humanize;
	}
	
	export interface ConversationAssociation { 
		"externalContactId"?: string;
		"conversationId": string;
		"communicationId": string;
		"mediaType": string;
	}
	
	export interface ConversationAsyncAggregateQueryResponse { 
		"results"?: Array<Models.ConversationAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface ConversationAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.ConversationAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.ConversationAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface ConversationBasic { 
		"id"?: string;
		"name"?: string;
		"externalTag"?: string;
		"startTime": string;
		"endTime"?: string;
		"divisions"?: Array<Models.ConversationDivisionMembership>;
		"securePause"?: boolean;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
		"participants"?: Array<Models.ParticipantBasic>;
	}
	
	export interface ConversationCallEventTopicCallConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationCallEventTopicCallMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
		"recordingState"?: string;
		"securePause"?: boolean;
		"maxParticipants"?: number;
	}
	
	export interface ConversationCallEventTopicCallMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationCallEventTopicUriReference;
		"queue"?: Models.ConversationCallEventTopicUriReference;
		"team"?: Models.ConversationCallEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationCallEventTopicErrorBody;
		"script"?: Models.ConversationCallEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationCallEventTopicUriReference;
		"externalOrganization"?: Models.ConversationCallEventTopicUriReference;
		"wrapup"?: Models.ConversationCallEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationCallEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationCallEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationCallEventTopicQueueMediaSettings;
		"muted"?: boolean;
		"confined"?: boolean;
		"recording"?: boolean;
		"recordingState"?: string;
		"securePause"?: boolean;
		"group"?: Models.ConversationCallEventTopicUriReference;
		"ani"?: string;
		"dnis"?: string;
		"documentId"?: string;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"bargedTime"?: string;
		"consultParticipantId"?: string;
		"faxStatus"?: Models.ConversationCallEventTopicFaxStatus;
	}
	
	export interface ConversationCallEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationCallEventTopicUriReference;
		"language"?: Models.ConversationCallEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationCallEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationCallEventTopicScoredAgent>;
	}
	
	export interface ConversationCallEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationCallEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationCallEventTopicDetail>;
		"errors"?: Array<Models.ConversationCallEventTopicErrorBody>;
	}
	
	export interface ConversationCallEventTopicFaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"dataRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface ConversationCallEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationCallEventTopicJourneyActionMap;
	}
	
	export interface ConversationCallEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationCallEventTopicJourneyContext { 
		"customer"?: Models.ConversationCallEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationCallEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationCallEventTopicJourneyAction;
	}
	
	export interface ConversationCallEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationCallEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationCallEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationCallEventTopicScoredAgent { 
		"agent"?: Models.ConversationCallEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationCallEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationCallEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationCallbackEventTopicCallbackConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationCallbackEventTopicCallbackMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationCallbackEventTopicCallbackMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationCallbackEventTopicUriReference;
		"queue"?: Models.ConversationCallbackEventTopicUriReference;
		"team"?: Models.ConversationCallbackEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationCallbackEventTopicErrorBody;
		"script"?: Models.ConversationCallbackEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationCallbackEventTopicUriReference;
		"externalOrganization"?: Models.ConversationCallbackEventTopicUriReference;
		"wrapup"?: Models.ConversationCallbackEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationCallbackEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationCallbackEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationCallbackEventTopicQueueMediaSettings;
		"outboundPreview"?: Models.ConversationCallbackEventTopicDialerPreview;
		"voicemail"?: Models.ConversationCallbackEventTopicVoicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"skipEnabled"?: boolean;
		"externalCampaign"?: boolean;
		"timeoutSeconds"?: number;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
	}
	
	export interface ConversationCallbackEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationCallbackEventTopicUriReference;
		"language"?: Models.ConversationCallbackEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationCallbackEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationCallbackEventTopicScoredAgent>;
	}
	
	export interface ConversationCallbackEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationCallbackEventTopicDialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.ConversationCallbackEventTopicPhoneNumberColumn>;
	}
	
	export interface ConversationCallbackEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationCallbackEventTopicDetail>;
		"errors"?: Array<Models.ConversationCallbackEventTopicErrorBody>;
	}
	
	export interface ConversationCallbackEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationCallbackEventTopicJourneyActionMap;
	}
	
	export interface ConversationCallbackEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationCallbackEventTopicJourneyContext { 
		"customer"?: Models.ConversationCallbackEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationCallbackEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationCallbackEventTopicJourneyAction;
	}
	
	export interface ConversationCallbackEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationCallbackEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationCallbackEventTopicPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface ConversationCallbackEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationCallbackEventTopicScoredAgent { 
		"agent"?: Models.ConversationCallbackEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationCallbackEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationCallbackEventTopicVoicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface ConversationCallbackEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationChannel { 
		"type": string;
		"messageType"?: string;
		"platform"?: string;
	}
	
	export interface ConversationChannelMetadata { 
	}
	
	export interface ConversationChat { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"roomId"?: string;
		"recordingId"?: string;
		"segments"?: Array<Models.Segment>;
		"held"?: boolean;
		"direction"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"avatarImageUrl"?: string;
		"journeyContext"?: Models.JourneyContext;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
	}
	
	export interface ConversationChatEventTopicChatConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationChatEventTopicChatMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationChatEventTopicChatMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationChatEventTopicUriReference;
		"queue"?: Models.ConversationChatEventTopicUriReference;
		"team"?: Models.ConversationChatEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationChatEventTopicErrorBody;
		"script"?: Models.ConversationChatEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationChatEventTopicUriReference;
		"externalOrganization"?: Models.ConversationChatEventTopicUriReference;
		"wrapup"?: Models.ConversationChatEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationChatEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationChatEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationChatEventTopicQueueMediaSettings;
		"roomId"?: string;
		"avatarImageUrl"?: string;
	}
	
	export interface ConversationChatEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationChatEventTopicUriReference;
		"language"?: Models.ConversationChatEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationChatEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationChatEventTopicScoredAgent>;
	}
	
	export interface ConversationChatEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationChatEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationChatEventTopicDetail>;
		"errors"?: Array<Models.ConversationChatEventTopicErrorBody>;
	}
	
	export interface ConversationChatEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationChatEventTopicJourneyActionMap;
	}
	
	export interface ConversationChatEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationChatEventTopicJourneyContext { 
		"customer"?: Models.ConversationChatEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationChatEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationChatEventTopicJourneyAction;
	}
	
	export interface ConversationChatEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationChatEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationChatEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationChatEventTopicScoredAgent { 
		"agent"?: Models.ConversationChatEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationChatEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationChatEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationClearSettings { 
		"enabled"?: boolean;
	}
	
	export interface ConversationCobrowseEventTopicCobrowseConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationCobrowseEventTopicCobrowseMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationCobrowseEventTopicCobrowseMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationCobrowseEventTopicUriReference;
		"queue"?: Models.ConversationCobrowseEventTopicUriReference;
		"team"?: Models.ConversationCobrowseEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationCobrowseEventTopicErrorBody;
		"script"?: Models.ConversationCobrowseEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationCobrowseEventTopicUriReference;
		"externalOrganization"?: Models.ConversationCobrowseEventTopicUriReference;
		"wrapup"?: Models.ConversationCobrowseEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationCobrowseEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationCobrowseEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationCobrowseEventTopicQueueMediaSettings;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"viewerUrl"?: string;
		"providerEventTime"?: string;
		"controlling"?: Array<string>;
	}
	
	export interface ConversationCobrowseEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationCobrowseEventTopicUriReference;
		"language"?: Models.ConversationCobrowseEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationCobrowseEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationCobrowseEventTopicScoredAgent>;
	}
	
	export interface ConversationCobrowseEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationCobrowseEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationCobrowseEventTopicDetail>;
		"errors"?: Array<Models.ConversationCobrowseEventTopicErrorBody>;
	}
	
	export interface ConversationCobrowseEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationCobrowseEventTopicJourneyActionMap;
	}
	
	export interface ConversationCobrowseEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationCobrowseEventTopicJourneyContext { 
		"customer"?: Models.ConversationCobrowseEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationCobrowseEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationCobrowseEventTopicJourneyAction;
	}
	
	export interface ConversationCobrowseEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationCobrowseEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationCobrowseEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationCobrowseEventTopicScoredAgent { 
		"agent"?: Models.ConversationCobrowseEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationCobrowseEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationCobrowseEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationContentAttachment { 
		"id"?: string;
		"mediaType": string;
		"url"?: string;
		"mime"?: string;
		"text"?: string;
		"sha256"?: string;
		"filename"?: string;
		"contentSizeBytes"?: number;
	}
	
	export interface ConversationContentButtonResponse { 
		"type"?: string;
		"text": string;
		"payload": string;
	}
	
	export interface ConversationContentCard { 
		"title": string;
		"description"?: string;
		"image"?: string;
		"video"?: string;
		"defaultAction"?: Models.ConversationContentCardAction;
		"actions": Array<Models.ConversationContentCardAction>;
	}
	
	export interface ConversationContentCardAction { 
		"type"?: string;
		"text"?: string;
		"payload"?: string;
		"url"?: string;
	}
	
	export interface ConversationContentCarousel { 
		"cards": Array<Models.ConversationContentCard>;
	}
	
	export interface ConversationContentLocation { 
		"url"?: string;
		"address"?: string;
		"text"?: string;
		"latitude"?: number;
		"longitude"?: number;
	}
	
	export interface ConversationContentNotificationTemplate { 
		"id"?: string;
		"language"?: string;
		"header"?: Models.ConversationNotificationTemplateHeader;
		"body": Models.ConversationNotificationTemplateBody;
		"footer"?: Models.ConversationNotificationTemplateFooter;
	}
	
	export interface ConversationContentQuickReply { 
		"text": string;
		"payload": string;
		"image"?: string;
		"action"?: string;
	}
	
	export interface ConversationContentQuickReplyV2 { 
		"title": string;
		"actions": Array<Models.ConversationContentQuickReply>;
	}
	
	export interface ConversationContentStory { 
		"type"?: string;
		"url"?: string;
		"replyToId"?: string;
	}
	
	export interface ConversationContentText { 
		"type"?: string;
		"body": string;
	}
	
	export interface ConversationDeletionProtectionQuery { 
		"conversationIds": Array<string>;
	}
	
	export interface ConversationDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.ConversationDetailQueryPredicate>;
	}
	
	export interface ConversationDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.ConversationDetailQueryClause>;
		"predicates"?: Array<Models.ConversationDetailQueryPredicate>;
	}
	
	export interface ConversationDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"metric"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface ConversationDetailsDatalakeAvailabilityTopicDataAvailabilityChangeNotification { 
		"dataAvailabilityDate"?: string;
	}
	
	export interface ConversationDisconnectSettings { 
		"enabled"?: boolean;
		"type"?: string;
	}
	
	export interface ConversationDivisionMembership { 
		"division"?: Models.DomainEntityRef;
		"entities"?: Array<Models.DomainEntityRef>;
	}
	
	export interface ConversationEmailEventTopicAttachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
	}
	
	export interface ConversationEmailEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationEmailEventTopicUriReference;
		"language"?: Models.ConversationEmailEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationEmailEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationEmailEventTopicScoredAgent>;
	}
	
	export interface ConversationEmailEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationEmailEventTopicEmailConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationEmailEventTopicEmailMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationEmailEventTopicEmailMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationEmailEventTopicUriReference;
		"queue"?: Models.ConversationEmailEventTopicUriReference;
		"team"?: Models.ConversationEmailEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationEmailEventTopicErrorBody;
		"script"?: Models.ConversationEmailEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationEmailEventTopicUriReference;
		"externalOrganization"?: Models.ConversationEmailEventTopicUriReference;
		"wrapup"?: Models.ConversationEmailEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationEmailEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationEmailEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationEmailEventTopicQueueMediaSettings;
		"subject"?: string;
		"messagesSent"?: number;
		"autoGenerated"?: boolean;
		"messageId"?: string;
		"draftAttachments"?: Array<Models.ConversationEmailEventTopicAttachment>;
		"spam"?: boolean;
	}
	
	export interface ConversationEmailEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationEmailEventTopicDetail>;
		"errors"?: Array<Models.ConversationEmailEventTopicErrorBody>;
	}
	
	export interface ConversationEmailEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationEmailEventTopicJourneyActionMap;
	}
	
	export interface ConversationEmailEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationEmailEventTopicJourneyContext { 
		"customer"?: Models.ConversationEmailEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationEmailEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationEmailEventTopicJourneyAction;
	}
	
	export interface ConversationEmailEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationEmailEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationEmailEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationEmailEventTopicScoredAgent { 
		"agent"?: Models.ConversationEmailEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationEmailEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationEmailEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationEncryptionConfiguration { 
		"id"?: string;
		"url": string;
		"keyConfigurationType": string;
		"lastError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface ConversationEncryptionConfigurationListing { 
		"total"?: number;
		"entities"?: Array<Models.ConversationEncryptionConfiguration>;
		"selfUri"?: string;
	}
	
	export interface ConversationEntityListing { 
		"entities"?: Array<Models.Conversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ConversationEventCoBrowse { 
		"type": string;
		"sessionId"?: string;
		"sessionJoinToken"?: string;
	}
	
	export interface ConversationEventPresence { 
		"type": string;
	}
	
	export interface ConversationEventTopicAddress { 
		"name"?: string;
		"nameRaw"?: string;
		"addressNormalized"?: string;
		"addressRaw"?: string;
		"addressDisplayable"?: string;
	}
	
	export interface ConversationEventTopicAfterCallWork { 
		"state"?: string;
		"startTime"?: string;
		"endTime"?: string;
	}
	
	export interface ConversationEventTopicAttachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
	}
	
	export interface ConversationEventTopicCall { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"recording"?: boolean;
		"recordingState"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"securePause"?: boolean;
		"errorInfo"?: Models.ConversationEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"direction"?: string;
		"documentId"?: string;
		"self"?: Models.ConversationEventTopicAddress;
		"other"?: Models.ConversationEventTopicAddress;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"disconnectReasons"?: Array<Models.ConversationEventTopicDisconnectReason>;
		"faxStatus"?: Models.ConversationEventTopicFaxStatus;
		"uuiData"?: string;
		"bargedTime"?: string;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicCallback { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"direction"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"dialerPreview"?: Models.ConversationEventTopicDialerPreview;
		"voicemail"?: Models.ConversationEventTopicVoicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"provider"?: string;
		"timeoutSeconds"?: number;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"callerId"?: string;
		"callerIdName"?: string;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicChat { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"roomId"?: string;
		"avatarImageUrl"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"journeyContext"?: Models.ConversationEventTopicJourneyContext;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicCobrowse { 
		"state"?: string;
		"initialState"?: string;
		"disconnectType"?: string;
		"id"?: string;
		"self"?: Models.ConversationEventTopicAddress;
		"roomId"?: string;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"controlling"?: Array<string>;
		"viewerUrl"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"providerEventTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicConversation { 
		"id"?: string;
		"maxParticipants"?: number;
		"participants"?: Array<Models.ConversationEventTopicParticipant>;
		"recentTransfers"?: Array<Models.ConversationEventTopicRecentTransfer>;
		"recordingState"?: string;
		"address"?: string;
		"externalTag"?: string;
		"utilizationLabelId"?: string;
		"securePause"?: boolean;
	}
	
	export interface ConversationEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationEventTopicUriReference;
		"language"?: Models.ConversationEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationEventTopicScoredAgent>;
	}
	
	export interface ConversationEventTopicDestination { 
		"userId"?: string;
		"address"?: string;
	}
	
	export interface ConversationEventTopicDialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.ConversationEventTopicPhoneNumberColumn>;
	}
	
	export interface ConversationEventTopicDisconnectReason { 
		"type"?: string;
		"code"?: number;
		"phrase"?: string;
	}
	
	export interface ConversationEventTopicEmail { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"held"?: boolean;
		"autoGenerated"?: boolean;
		"subject"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"messagesSent"?: number;
		"errorInfo"?: Models.ConversationEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"messageId"?: string;
		"direction"?: string;
		"draftAttachments"?: Array<Models.ConversationEventTopicAttachment>;
		"spam"?: boolean;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
		"resumeTime"?: string;
	}
	
	export interface ConversationEventTopicErrorDetails { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"uri"?: string;
	}
	
	export interface ConversationEventTopicFaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"baudRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface ConversationEventTopicInitiator { 
		"userId"?: string;
	}
	
	export interface ConversationEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationEventTopicJourneyActionMap;
	}
	
	export interface ConversationEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationEventTopicJourneyContext { 
		"customer"?: Models.ConversationEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationEventTopicJourneyAction;
	}
	
	export interface ConversationEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationEventTopicMessage { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"held"?: boolean;
		"errorInfo"?: Models.ConversationEventTopicErrorDetails;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"toAddress"?: Models.ConversationEventTopicAddress;
		"fromAddress"?: Models.ConversationEventTopicAddress;
		"messages"?: Array<Models.ConversationEventTopicMessageDetails>;
		"messagesTranscriptUri"?: string;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"journeyContext"?: Models.ConversationEventTopicJourneyContext;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"byoSmsIntegrationId"?: string;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicMessageDetails { 
		"messageId"?: string;
		"messageTime"?: string;
		"messageStatus"?: string;
		"messageSegmentCount"?: number;
		"media"?: Array<Models.ConversationEventTopicMessageMedia>;
		"errorInfo"?: Models.ConversationEventTopicErrorDetails;
		"stickers"?: Array<Models.ConversationEventTopicMessageSticker>;
		"messageMetadata"?: Models.ConversationEventTopicMessageMetadata;
	}
	
	export interface ConversationEventTopicMessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface ConversationEventTopicMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.ConversationEventTopicMessageMetadataEvent>;
		"content"?: Array<Models.ConversationEventTopicMessageMetadataContent>;
	}
	
	export interface ConversationEventTopicMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface ConversationEventTopicMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface ConversationEventTopicMessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface ConversationEventTopicModifiedBy { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ConversationEventTopicObject { 
	}
	
	export interface ConversationEventTopicParticipant { 
		"id"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"name"?: string;
		"queueId"?: string;
		"groupId"?: string;
		"teamId"?: string;
		"purpose"?: string;
		"consultParticipantId"?: string;
		"address"?: string;
		"wrapupRequired"?: boolean;
		"wrapupExpected"?: boolean;
		"wrapupPrompt"?: string;
		"wrapupTimeoutMs"?: number;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"conversationRoutingData"?: Models.ConversationEventTopicConversationRoutingData;
		"alertingTimeoutMs"?: number;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"mediaRoles"?: Array<string>;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"attributes"?: { [key: string]: string; };
		"calls"?: Array<Models.ConversationEventTopicCall>;
		"callbacks"?: Array<Models.ConversationEventTopicCallback>;
		"chats"?: Array<Models.ConversationEventTopicChat>;
		"cobrowsesessions"?: Array<Models.ConversationEventTopicCobrowse>;
		"emails"?: Array<Models.ConversationEventTopicEmail>;
		"messages"?: Array<Models.ConversationEventTopicMessage>;
		"screenshares"?: Array<Models.ConversationEventTopicScreenshare>;
		"socialExpressions"?: Array<Models.ConversationEventTopicSocialExpression>;
		"videos"?: Array<Models.ConversationEventTopicVideo>;
		"workflow"?: Models.ConversationEventTopicWorkflow;
	}
	
	export interface ConversationEventTopicPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface ConversationEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationEventTopicRecentTransfer { 
		"id"?: string;
		"state"?: string;
		"dateIssued"?: string;
		"initiator"?: Models.ConversationEventTopicInitiator;
		"modifiedBy"?: Models.ConversationEventTopicModifiedBy;
		"destination"?: Models.ConversationEventTopicDestination;
		"transferType"?: string;
	}
	
	export interface ConversationEventTopicScoredAgent { 
		"agent"?: Models.ConversationEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationEventTopicScreenshare { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.ConversationEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"sharing"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"peerCount"?: object;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicSocialExpression { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"socialMediaId"?: string;
		"socialMediaHub"?: string;
		"socialUserName"?: string;
		"previewText"?: string;
		"recordingId"?: string;
		"held"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface ConversationEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationEventTopicVideo { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.ConversationEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"audioMuted"?: boolean;
		"videoMuted"?: boolean;
		"sharingScreen"?: boolean;
		"peerCount"?: object;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"msids"?: Array<string>;
		"wrapup"?: Models.ConversationEventTopicWrapup;
		"afterCallWork"?: Models.ConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationEventTopicQueueMediaSettings;
	}
	
	export interface ConversationEventTopicVoicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface ConversationEventTopicWorkflow { 
		"workflowId"?: string;
	}
	
	export interface ConversationEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationEventTyping { 
		"type": string;
		"duration"?: number;
	}
	
	export interface ConversationMessageContent { 
		"contentType": string;
		"location"?: Models.ConversationContentLocation;
		"attachment"?: Models.ConversationContentAttachment;
		"quickReply"?: Models.ConversationContentQuickReply;
		"buttonResponse"?: Models.ConversationContentButtonResponse;
		"template"?: Models.ConversationContentNotificationTemplate;
		"story"?: Models.ConversationContentStory;
		"card"?: Models.ConversationContentCard;
		"carousel"?: Models.ConversationContentCarousel;
		"text"?: Models.ConversationContentText;
		"quickReplyV2"?: Models.ConversationContentQuickReplyV2;
	}
	
	export interface ConversationMessageEvent { 
		"eventType": string;
		"coBrowse"?: Models.ConversationEventCoBrowse;
		"typing"?: Models.ConversationEventTyping;
		"presence"?: Models.ConversationEventPresence;
	}
	
	export interface ConversationMessageEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationMessageEventTopicUriReference;
		"language"?: Models.ConversationMessageEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationMessageEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationMessageEventTopicScoredAgent>;
	}
	
	export interface ConversationMessageEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationMessageEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationMessageEventTopicDetail>;
		"errors"?: Array<Models.ConversationMessageEventTopicErrorBody>;
	}
	
	export interface ConversationMessageEventTopicErrorDetails { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"uri"?: string;
	}
	
	export interface ConversationMessageEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationMessageEventTopicJourneyActionMap;
	}
	
	export interface ConversationMessageEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationMessageEventTopicJourneyContext { 
		"customer"?: Models.ConversationMessageEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationMessageEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationMessageEventTopicJourneyAction;
	}
	
	export interface ConversationMessageEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationMessageEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationMessageEventTopicMessageConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationMessageEventTopicMessageMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationMessageEventTopicMessageDetails { 
		"message"?: Models.ConversationMessageEventTopicUriReference;
		"messageTime"?: string;
		"messageSegmentCount"?: number;
		"messageStatus"?: string;
		"media"?: Array<Models.ConversationMessageEventTopicMessageMedia>;
		"stickers"?: Array<Models.ConversationMessageEventTopicMessageSticker>;
		"errorInfo"?: Models.ConversationMessageEventTopicErrorDetails;
		"messageMetadata"?: Models.ConversationMessageEventTopicMessageMetadata;
	}
	
	export interface ConversationMessageEventTopicMessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface ConversationMessageEventTopicMessageMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationMessageEventTopicUriReference;
		"queue"?: Models.ConversationMessageEventTopicUriReference;
		"team"?: Models.ConversationMessageEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationMessageEventTopicErrorBody;
		"script"?: Models.ConversationMessageEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationMessageEventTopicUriReference;
		"externalOrganization"?: Models.ConversationMessageEventTopicUriReference;
		"wrapup"?: Models.ConversationMessageEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationMessageEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationMessageEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationMessageEventTopicQueueMediaSettings;
		"messages"?: Array<Models.ConversationMessageEventTopicMessageDetails>;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"byoSmsIntegrationId"?: string;
		"monitoredParticipantId"?: string;
	}
	
	export interface ConversationMessageEventTopicMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.ConversationMessageEventTopicMessageMetadataEvent>;
		"content"?: Array<Models.ConversationMessageEventTopicMessageMetadataContent>;
	}
	
	export interface ConversationMessageEventTopicMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface ConversationMessageEventTopicMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface ConversationMessageEventTopicMessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface ConversationMessageEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationMessageEventTopicScoredAgent { 
		"agent"?: Models.ConversationMessageEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationMessageEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationMessageEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.ConversationMessageMetadataEvent>;
		"content"?: Array<Models.ConversationMessageMetadataContent>;
	}
	
	export interface ConversationMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface ConversationMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface ConversationMessagingChannel { 
		"id"?: string;
		"platform"?: string;
		"messageId"?: string;
		"to"?: Models.ConversationMessagingToRecipient;
		"from"?: Models.ConversationMessagingFromRecipient;
		"time"?: string;
		"dateModified"?: string;
		"dateDeleted"?: string;
	}
	
	export interface ConversationMessagingFromRecipient { 
		"nickname"?: string;
		"id": string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.ConversationRecipientAdditionalIdentifier>;
	}
	
	export interface ConversationMessagingToRecipient { 
		"nickname"?: string;
		"id": string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.ConversationRecipientAdditionalIdentifier>;
	}
	
	export interface ConversationMetrics { 
		"conversation"?: Models.AddressableEntityRef;
		"sentimentScore"?: number;
		"sentimentTrend"?: number;
		"sentimentTrendClass"?: string;
		"empathyScores"?: Array<Models.EmpathyScore>;
		"participantMetrics"?: Models.ParticipantMetrics;
	}
	
	export interface ConversationMetricsTopicConversationMetricRecord { 
		"metric"?: string;
		"metricDate"?: string;
		"value"?: number;
		"recordId"?: string;
		"activeRouting"?: string;
		"activeSkillIds"?: Array<string>;
		"addressFrom"?: string;
		"addressTo"?: string;
		"agentAssistantId"?: string;
		"agentBullseyeRing"?: number;
		"agentOwned"?: boolean;
		"ani"?: string;
		"assignerId"?: string;
		"authenticated"?: boolean;
		"conversationId"?: string;
		"conversationInitiator"?: string;
		"convertedFrom"?: string;
		"convertedTo"?: string;
		"customerParticipation"?: boolean;
		"deliveryStatus"?: string;
		"destinationAddresses"?: Array<string>;
		"direction"?: string;
		"disconnectType"?: string;
		"divisionIds"?: Array<string>;
		"dnis"?: string;
		"edgeId"?: string;
		"eligibleAgentCounts"?: Array<number>;
		"errorCode"?: string;
		"extendedDeliveryStatus"?: string;
		"externalContactId"?: string;
		"externalMediaCount"?: number;
		"externalOrganizationId"?: string;
		"externalTag"?: string;
		"firstQueue"?: boolean;
		"flaggedReason"?: string;
		"flowInType"?: string;
		"flowOutType"?: string;
		"groupId"?: string;
		"interactionType"?: string;
		"journeyActionId"?: string;
		"journeyActionMapId"?: string;
		"journeyActionMapVersion"?: number;
		"journeyCustomerId"?: string;
		"journeyCustomerIdType"?: string;
		"journeyCustomerSessionId"?: string;
		"journeyCustomerSessionIdType"?: string;
		"knowledgeBaseIds"?: Array<string>;
		"mediaCount"?: number;
		"mediaType"?: string;
		"messageType"?: string;
		"originatingDirection"?: string;
		"outboundCampaignId"?: string;
		"outboundContactId"?: string;
		"outboundContactListId"?: string;
		"participantName"?: string;
		"peerId"?: string;
		"provider"?: string;
		"purpose"?: string;
		"queueId"?: string;
		"remote"?: string;
		"removedSkillIds"?: Array<string>;
		"requestedLanguageId"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedRoutings"?: Array<string>;
		"roomId"?: string;
		"routingPriority"?: number;
		"routingRing"?: number;
		"routingRule"?: string;
		"routingRuleType"?: string;
		"selectedAgentId"?: string;
		"selectedAgentRank"?: number;
		"selfServed"?: boolean;
		"sessionDnis"?: string;
		"sessionId"?: string;
		"stationId"?: string;
		"teamId"?: string;
		"usedRouting"?: string;
		"userId"?: string;
		"waitingInteractionCounts"?: Array<number>;
		"wrapUpCode"?: string;
		"proposedAgents"?: Array<Models.ConversationMetricsTopicConversationProposedAgent>;
		"scoredAgents"?: Array<Models.ConversationMetricsTopicConversationScoredAgent>;
	}
	
	export interface ConversationMetricsTopicConversationProposedAgent { 
		"agentRank"?: number;
		"proposedAgentId"?: string;
	}
	
	export interface ConversationMetricsTopicConversationScoredAgent { 
		"agentScore"?: number;
		"scoredAgentId"?: string;
	}
	
	export interface ConversationNormalizedMessage { 
		"id"?: string;
		"channel"?: Models.ConversationMessagingChannel;
		"type": string;
		"text"?: string;
		"content"?: Array<Models.ConversationMessageContent>;
		"events"?: Array<Models.ConversationMessageEvent>;
		"status"?: string;
		"reasons"?: Array<Models.ConversationReason>;
		"originatingEntity"?: string;
		"isFinalReceipt"?: boolean;
		"direction"?: string;
		"metadata"?: { [key: string]: string; };
		"byoSmsIntegrationId"?: string;
	}
	
	export interface ConversationNotificationTemplateBody { 
		"text"?: string;
		"parameters": Array<Models.ConversationNotificationTemplateParameter>;
	}
	
	export interface ConversationNotificationTemplateFooter { 
		"text"?: string;
	}
	
	export interface ConversationNotificationTemplateHeader { 
		"type": string;
		"text"?: string;
		"media"?: Models.ConversationContentAttachment;
		"parameters"?: Array<Models.ConversationNotificationTemplateParameter>;
	}
	
	export interface ConversationNotificationTemplateParameter { 
		"name"?: string;
		"text": string;
	}
	
	export interface ConversationParticipantSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.ConversationParticipantSearchCriteria>;
		"dateFormat"?: string;
		"type": string;
		"fields"?: Array<string>;
	}
	
	export interface ConversationParticipantSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"sort"?: Array<Models.SearchSort>;
		"returnFields"?: Array<string>;
		"query"?: Array<Models.ConversationParticipantSearchCriteria>;
		"cursor"?: string;
	}
	
	export interface ConversationProperties { 
		"isWaiting"?: boolean;
		"isActive"?: boolean;
		"isAcd"?: boolean;
		"isPreferred"?: boolean;
		"isScreenshare"?: boolean;
		"isCobrowse"?: boolean;
		"isVoicemail"?: boolean;
		"isFlagged"?: boolean;
		"isMonitored"?: boolean;
		"filterWrapUpNotes"?: boolean;
		"matchAll"?: boolean;
	}
	
	export interface ConversationQuery { 
		"conversationFilters"?: Array<Models.ConversationDetailQueryFilter>;
		"segmentFilters"?: Array<Models.SegmentDetailQueryFilter>;
		"evaluationFilters"?: Array<Models.EvaluationDetailQueryFilter>;
		"surveyFilters"?: Array<Models.SurveyDetailQueryFilter>;
		"resolutionFilters"?: Array<Models.ResolutionDetailQueryFilter>;
		"order"?: string;
		"orderBy"?: string;
		"interval": string;
		"aggregations"?: Array<Models.AnalyticsQueryAggregation>;
		"paging"?: Models.PagingSpec;
	}
	
	export interface ConversationQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationReason { 
		"code"?: string;
		"message": string;
	}
	
	export interface ConversationRecipientAdditionalIdentifier { 
		"type": string;
		"value": string;
	}
	
	export interface ConversationReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ConversationRoutingData { 
		"queue"?: Models.AddressableEntityRef;
		"language"?: Models.AddressableEntityRef;
		"priority"?: number;
		"skills"?: Array<Models.AddressableEntityRef>;
		"scoredAgents"?: Array<Models.ScoredAgent>;
		"label"?: string;
	}
	
	export interface ConversationScreenShareEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationScreenShareEventTopicUriReference;
		"language"?: Models.ConversationScreenShareEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationScreenShareEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationScreenShareEventTopicScoredAgent>;
	}
	
	export interface ConversationScreenShareEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationScreenShareEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationScreenShareEventTopicDetail>;
		"errors"?: Array<Models.ConversationScreenShareEventTopicErrorBody>;
	}
	
	export interface ConversationScreenShareEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationScreenShareEventTopicJourneyActionMap;
	}
	
	export interface ConversationScreenShareEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationScreenShareEventTopicJourneyContext { 
		"customer"?: Models.ConversationScreenShareEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationScreenShareEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationScreenShareEventTopicJourneyAction;
	}
	
	export interface ConversationScreenShareEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationScreenShareEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationScreenShareEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationScreenShareEventTopicScoredAgent { 
		"agent"?: Models.ConversationScreenShareEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationScreenShareEventTopicScreenShareConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationScreenShareEventTopicScreenShareMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationScreenShareEventTopicScreenShareMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationScreenShareEventTopicUriReference;
		"queue"?: Models.ConversationScreenShareEventTopicUriReference;
		"team"?: Models.ConversationScreenShareEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationScreenShareEventTopicErrorBody;
		"script"?: Models.ConversationScreenShareEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationScreenShareEventTopicUriReference;
		"externalOrganization"?: Models.ConversationScreenShareEventTopicUriReference;
		"wrapup"?: Models.ConversationScreenShareEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationScreenShareEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationScreenShareEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationScreenShareEventTopicQueueMediaSettings;
		"context"?: string;
		"peerCount"?: number;
		"sharing"?: boolean;
	}
	
	export interface ConversationScreenShareEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationScreenShareEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationSecureAttributes { 
		"attributes"?: { [key: string]: string; };
		"version"?: number;
	}
	
	export interface ConversationSocialExpressionEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"language"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationSocialExpressionEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationSocialExpressionEventTopicScoredAgent>;
	}
	
	export interface ConversationSocialExpressionEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationSocialExpressionEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationSocialExpressionEventTopicDetail>;
		"errors"?: Array<Models.ConversationSocialExpressionEventTopicErrorBody>;
	}
	
	export interface ConversationSocialExpressionEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationSocialExpressionEventTopicJourneyActionMap;
	}
	
	export interface ConversationSocialExpressionEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationSocialExpressionEventTopicJourneyContext { 
		"customer"?: Models.ConversationSocialExpressionEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationSocialExpressionEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationSocialExpressionEventTopicJourneyAction;
	}
	
	export interface ConversationSocialExpressionEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationSocialExpressionEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationSocialExpressionEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationSocialExpressionEventTopicScoredAgent { 
		"agent"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationSocialExpressionEventTopicSocialConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationSocialExpressionEventTopicSocialMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationSocialExpressionEventTopicSocialMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"queue"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"team"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationSocialExpressionEventTopicErrorBody;
		"script"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"externalOrganization"?: Models.ConversationSocialExpressionEventTopicUriReference;
		"wrapup"?: Models.ConversationSocialExpressionEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationSocialExpressionEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationSocialExpressionEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationSocialExpressionEventTopicQueueMediaSettings;
		"socialMediaId"?: string;
		"socialMediaHub"?: string;
		"socialUserName"?: string;
		"previewText"?: string;
	}
	
	export interface ConversationSocialExpressionEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationSocialExpressionEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface ConversationTagsUpdate { 
		"externalTag": string;
	}
	
	export interface ConversationThreadingWindow { 
		"id"?: string;
		"settings": Array<Models.ConversationThreadingWindowSetting>;
		"defaultTimeoutMinutes"?: number;
	}
	
	export interface ConversationThreadingWindowSetting { 
		"messengerType": string;
		"timeoutInMinutes": number;
	}
	
	export interface ConversationUser { 
		"id": string;
	}
	
	export interface ConversationUserDisposition { 
		"code": string;
		"notes"?: string;
		"user": Models.AddressableEntityRef;
	}
	
	export interface ConversationUtilizationLabelUpdate { 
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationVideoEventTopicConversationRoutingData { 
		"queue"?: Models.ConversationVideoEventTopicUriReference;
		"language"?: Models.ConversationVideoEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.ConversationVideoEventTopicUriReference>;
		"scoredAgents"?: Array<Models.ConversationVideoEventTopicScoredAgent>;
	}
	
	export interface ConversationVideoEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface ConversationVideoEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.ConversationVideoEventTopicDetail>;
		"errors"?: Array<Models.ConversationVideoEventTopicErrorBody>;
	}
	
	export interface ConversationVideoEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.ConversationVideoEventTopicJourneyActionMap;
	}
	
	export interface ConversationVideoEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ConversationVideoEventTopicJourneyContext { 
		"customer"?: Models.ConversationVideoEventTopicJourneyCustomer;
		"customerSession"?: Models.ConversationVideoEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.ConversationVideoEventTopicJourneyAction;
	}
	
	export interface ConversationVideoEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface ConversationVideoEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface ConversationVideoEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface ConversationVideoEventTopicScoredAgent { 
		"agent"?: Models.ConversationVideoEventTopicUriReference;
		"score"?: number;
	}
	
	export interface ConversationVideoEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface ConversationVideoEventTopicVideoConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.ConversationVideoEventTopicVideoMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface ConversationVideoEventTopicVideoMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.ConversationVideoEventTopicUriReference;
		"queue"?: Models.ConversationVideoEventTopicUriReference;
		"team"?: Models.ConversationVideoEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ConversationVideoEventTopicErrorBody;
		"script"?: Models.ConversationVideoEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.ConversationVideoEventTopicUriReference;
		"externalOrganization"?: Models.ConversationVideoEventTopicUriReference;
		"wrapup"?: Models.ConversationVideoEventTopicWrapup;
		"conversationRoutingData"?: Models.ConversationVideoEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.ConversationVideoEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.ConversationVideoEventTopicQueueMediaSettings;
		"audioMuted"?: boolean;
		"videoMuted"?: boolean;
		"sharingScreen"?: boolean;
		"peerCount"?: number;
		"context"?: string;
		"msids"?: Array<string>;
	}
	
	export interface ConversationVideoEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface CopilotScoring { 
		"enabled"?: boolean;
		"prompt"?: string;
	}
	
	export interface CopyAttachmentsRequest { 
		"sourceMessage": Models.DomainEntityRef;
		"attachments": Array<Models.Attachment>;
	}
	
	export interface CopyBuForecastRequest { 
		"description": string;
		"weekDate": string;
	}
	
	export interface CopyVoicemailMessage { 
		"voicemailMessageId": string;
		"userId"?: string;
		"groupId"?: string;
	}
	
	export interface CopyWorkPlan { 
		"name": string;
	}
	
	export interface CopyWorkPlanRotationRequest { 
		"name": string;
	}
	
	export interface Coretype { 
		"id"?: string;
		"name"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"schema"?: Models.Schema;
		"current"?: boolean;
		"validationFields"?: Array<string>;
		"validationLimits"?: Models.ValidationLimits;
		"itemValidationFields"?: Array<string>;
		"itemValidationLimits"?: Models.ItemValidationLimits;
		"selfUri"?: string;
	}
	
	export interface CoretypeListing { 
		"total"?: number;
		"entities"?: Array<Models.Coretype>;
		"selfUri"?: string;
	}
	
	export interface CoverSheet { 
		"notes"?: string;
		"locale"?: string;
	}
	
	export interface CreateActivityCodeRequest { 
		"name": string;
		"category": string;
		"lengthInMinutes"?: number;
		"countsAsPaidTime"?: boolean;
		"countsAsWorkTime"?: boolean;
		"agentTimeOffSelectable"?: boolean;
		"countsTowardShrinkage"?: boolean;
		"plannedShrinkage"?: boolean;
		"interruptible"?: boolean;
		"secondaryPresences"?: Array<Models.SecondaryPresence>;
	}
	
	export interface CreateAdminTimeOffRequest { 
		"status": string;
		"users": Array<Models.UserReference>;
		"activityCodeId": string;
		"notes"?: string;
		"fullDayManagementUnitDates"?: Array<string>;
		"partialDayStartDateTimes"?: Array<string>;
		"dailyDurationMinutes": number;
		"durationMinutes"?: Array<number>;
		"payableMinutes"?: Array<number>;
		"paid"?: boolean;
	}
	
	export interface CreateAgentTimeOffRequest { 
		"activityCodeId": string;
		"notes"?: string;
		"fullDayManagementUnitDates"?: Array<string>;
		"partialDayStartDateTimes"?: Array<string>;
		"dailyDurationMinutes": number;
		"durationMinutes"?: Array<number>;
		"payableMinutes"?: Array<number>;
	}
	
	export interface CreateBenefitAssessmentJobRequest { 
		"divisionIds"?: Array<string>;
	}
	
	export interface CreateBenefitAssessmentRequest { 
		"queueIds": Array<string>;
	}
	
	export interface CreateBusinessUnitRequest { 
		"name": string;
		"divisionId": string;
		"settings": Models.CreateBusinessUnitSettingsRequest;
	}
	
	export interface CreateBusinessUnitSettingsRequest { 
		"startDayOfWeek": string;
		"timeZone": string;
		"shortTermForecasting"?: Models.BuShortTermForecastingSettings;
		"scheduling"?: Models.BuSchedulingSettingsRequest;
	}
	
	export interface CreateCallRequest { 
		"phoneNumber"?: string;
		"callerId"?: string;
		"callerIdName"?: string;
		"callFromQueueId"?: string;
		"callQueueId"?: string;
		"callUserId"?: string;
		"priority"?: number;
		"languageId"?: string;
		"routingSkillsIds"?: Array<string>;
		"conversationIds"?: Array<string>;
		"participants"?: Array<Models.Destination>;
		"uuiData"?: string;
		"externalContactId"?: string;
		"label"?: string;
	}
	
	export interface CreateCallResponse { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface CreateCallbackCommand { 
		"scriptId"?: string;
		"queueId"?: string;
		"routingData"?: Models.RoutingData;
		"callbackUserName"?: string;
		"callbackNumbers": Array<string>;
		"callbackScheduledTime"?: string;
		"countryCode"?: string;
		"validateCallbackNumbers"?: boolean;
		"data"?: { [key: string]: string; };
		"callerId"?: string;
		"callerIdName"?: string;
	}
	
	export interface CreateCallbackOnConversationCommand { 
		"scriptId"?: string;
		"queueId"?: string;
		"routingData"?: Models.RoutingData;
		"callbackUserName"?: string;
		"callbackNumbers": Array<string>;
		"callbackScheduledTime"?: string;
		"countryCode"?: string;
		"validateCallbackNumbers"?: boolean;
		"data"?: { [key: string]: string; };
		"callerId"?: string;
		"callerIdName"?: string;
	}
	
	export interface CreateCallbackResponse { 
		"conversation": Models.DomainEntityRef;
		"callbackIdentifiers": Array<Models.CallbackIdentifier>;
	}
	
	export interface CreateCoachingAppointmentRequest { 
		"name": string;
		"description": string;
		"dateStart": string;
		"lengthInMinutes": number;
		"facilitatorId"?: string;
		"attendeeIds": Array<string>;
		"conversationIds"?: Array<string>;
		"documentIds"?: Array<string>;
		"wfmSchedule"?: Models.WfmScheduleReference;
		"externalLinks"?: Array<string>;
	}
	
	export interface CreateEmailRequest { 
		"queueId"?: string;
		"flowId"?: string;
		"provider": string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"priority"?: number;
		"attributes"?: { [key: string]: string; };
		"toAddress"?: string;
		"toName"?: string;
		"fromAddress"?: string;
		"fromName"?: string;
		"subject"?: string;
		"direction"?: string;
		"htmlBody"?: string;
		"textBody"?: string;
		"externalContactId"?: string;
	}
	
	export interface CreateGeneralProgramTopicsDefinitionsJob { 
		"id"?: string;
		"state"?: string;
	}
	
	export interface CreateIntegrationRequest { 
		"id"?: string;
		"name": string;
		"integrationType": Models.IntegrationType;
		"selfUri"?: string;
	}
	
	export interface CreateManagementUnitApiRequest { 
		"name": string;
		"timeZone"?: string;
		"startDayOfWeek"?: string;
		"settings"?: Models.CreateManagementUnitSettingsRequest;
		"divisionId"?: string;
		"businessUnitId": string;
	}
	
	export interface CreateManagementUnitSettingsRequest { 
		"adherence"?: Models.AdherenceSettings;
		"shortTermForecasting"?: Models.ShortTermForecastingSettings;
		"timeOff"?: Models.TimeOffRequestSettings;
		"scheduling"?: Models.SchedulingSettingsRequest;
		"shiftTrading"?: Models.ShiftTradeSettings;
	}
	
	export interface CreateMetric { 
		"metricDefinitionId"?: string;
		"externalMetricDefinitionId"?: string;
		"objective"?: Models.CreateObjective;
		"performanceProfileId"?: string;
		"name": string;
		"precision"?: number;
		"timeDisplayUnit"?: string;
	}
	
	export interface CreateObjective { 
		"id"?: string;
		"templateId"?: string;
		"zones"?: Array<Models.ObjectiveZone>;
		"enabled"?: boolean;
		"topicIds"?: Array<string>;
		"mediaTypes"?: Array<string>;
		"queueIds"?: Array<string>;
		"topicIdsFilterType"?: string;
		"evaluationFormContextIds"?: Array<string>;
		"initialDirection"?: string;
		"dateStart"?: string;
	}
	
	export interface CreateOutboundMessagingConversationRequest { 
		"queueId": string;
		"toAddress": string;
		"toAddressMessengerType": string;
		"useExistingConversation"?: boolean;
		"externalContactId"?: string;
	}
	
	export interface CreatePerformanceProfile { 
		"id"?: string;
		"name": string;
		"division": Models.WritableDivision;
		"description": string;
		"metricOrders"?: Array<string>;
		"dateCreated"?: string;
		"reportingIntervals": Array<Models.ReportingInterval>;
		"active": boolean;
		"memberCount"?: number;
		"maxLeaderboardRankSize": number;
		"selfUri"?: string;
	}
	
	export interface CreatePlanningGroupRequest { 
		"name": string;
		"routePaths": Array<Models.RoutePathRequest>;
		"serviceGoalTemplateId": string;
	}
	
	export interface CreatePredictorRequest { 
		"queueIds": Array<string>;
		"kpi": string;
		"routingTimeoutSeconds"?: number;
		"schedule"?: Models.PredictorSchedule;
		"workloadBalancingConfig"?: Models.PredictorWorkloadBalancing;
	}
	
	export interface CreateQueueRequest { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"memberCount"?: number;
		"userMemberCount"?: number;
		"joinedMemberCount"?: number;
		"mediaSettings"?: Models.QueueMediaSettings;
		"routingRules"?: Array<Models.RoutingRule>;
		"conditionalGroupRouting"?: Models.ConditionalGroupRouting;
		"bullseye"?: Models.Bullseye;
		"scoringMethod"?: string;
		"acwSettings"?: Models.AcwSettings;
		"skillEvaluationMethod"?: string;
		"memberGroups"?: Array<Models.MemberGroup>;
		"queueFlow"?: Models.DomainEntityRef;
		"emailInQueueFlow"?: Models.DomainEntityRef;
		"messageInQueueFlow"?: Models.DomainEntityRef;
		"whisperPrompt"?: Models.DomainEntityRef;
		"onHoldPrompt"?: Models.DomainEntityRef;
		"autoAnswerOnly"?: boolean;
		"enableTranscription"?: boolean;
		"enableAudioMonitoring"?: boolean;
		"enableManualAssignment"?: boolean;
		"agentOwnedRouting"?: Models.AgentOwnedRouting;
		"directRouting"?: Models.DirectRouting;
		"callingPartyName"?: string;
		"callingPartyNumber"?: string;
		"defaultScripts"?: { [key: string]: Models.Script; };
		"outboundMessagingAddresses"?: Models.QueueMessagingAddresses;
		"outboundEmailAddress"?: Models.QueueEmailAddress;
		"peerId"?: string;
		"suppressInQueueCallRecording"?: boolean;
		"sourceQueueId"?: string;
		"selfUri"?: string;
	}
	
	export interface CreateResponseAssetRequest { 
		"name": string;
		"divisionId"?: string;
		"contentMd5"?: string;
	}
	
	export interface CreateResponseAssetResponse { 
		"id"?: string;
		"url"?: string;
		"headers"?: { [key: string]: string; };
	}
	
	export interface CreateRoomRequest { 
		"description"?: string;
		"subject": string;
		"userIds"?: Array<string>;
	}
	
	export interface CreateRoomResponse { 
		"jid": string;
	}
	
	export interface CreateSecureSession { 
		"sourceParticipantId"?: string;
		"flowId": string;
		"userData": string;
		"disconnect"?: boolean;
	}
	
	export interface CreateServiceGoalTemplate { 
		"name": string;
		"serviceLevel"?: Models.BuServiceLevel;
		"averageSpeedOfAnswer"?: Models.BuAverageSpeedOfAnswer;
		"abandonRate"?: Models.BuAbandonRate;
		"impactOverride"?: Models.ServiceGoalTemplateImpactOverride;
	}
	
	export interface CreateShareRequest { 
		"sharedEntityType": string;
		"sharedEntity": Models.SharedEntity;
		"memberType"?: string;
		"member"?: Models.SharedEntity;
		"members"?: Array<Models.CreateShareRequestMember>;
	}
	
	export interface CreateShareRequestMember { 
		"memberType"?: string;
		"member"?: Models.MemberEntity;
	}
	
	export interface CreateShareResponse { 
		"id"?: string;
		"name"?: string;
		"sharedEntityType"?: string;
		"sharedEntity"?: Models.DomainEntityRef;
		"memberType"?: string;
		"member"?: Models.DomainEntityRef;
		"sharedBy"?: Models.DomainEntityRef;
		"workspace"?: Models.DomainEntityRef;
		"succeeded"?: Array<Models.Share>;
		"failed"?: Array<Models.Share>;
		"selfUri"?: string;
	}
	
	export interface CreateStaffingGroupRequest { 
		"name": string;
		"userIds"?: Array<string>;
		"managementUnitId"?: string;
	}
	
	export interface CreateTimeOffLimitRequest { 
		"granularity"?: string;
		"defaultLimitMinutes"?: number;
	}
	
	export interface CreateTimeOffPlanBusinessUnitAssociation { 
		"managementUnitIds"?: Array<string>;
		"staffingGroupIds"?: Array<string>;
	}
	
	export interface CreateTimeOffPlanManagementUnitAssociation { 
		"managementUnitId": string;
		"staffingGroupIds"?: Array<string>;
	}
	
	export interface CreateTimeOffPlanRequest { 
		"name": string;
		"activityCodeIds"?: Array<string>;
		"timeOffLimitIds"?: Array<string>;
		"autoApprovalRule": string;
		"daysBeforeStartToExpireFromWaitlist"?: number;
		"hrisTimeOffType"?: Models.HrisTimeOffType;
		"active": boolean;
	}
	
	export interface CreateTriggerRequest { 
		"target": Models.TriggerTarget;
		"enabled": boolean;
		"matchCriteria"?: Array<Models.MatchCriteria>;
		"name": string;
		"topicName": string;
		"eventTTLSeconds"?: number;
		"delayBySeconds"?: number;
		"description"?: string;
	}
	
	export interface CreateUploadSourceUrlJobRequest { 
		"uploadUrl": string;
	}
	
	export interface CreateUploadSourceUrlJobResponse { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface CreateUser { 
		"name": string;
		"department"?: string;
		"email": string;
		"addresses"?: Array<Models.Contact>;
		"title"?: string;
		"password"?: string;
		"divisionId": string;
		"state"?: string;
	}
	
	export interface CreateUtilizationLabelRequest { 
		"name": string;
		"utilization"?: Models.LabelUtilizationRequest;
	}
	
	export interface CreateUtilizationTagRequest { 
		"name": string;
	}
	
	export interface CreateWebChatConversationRequest { 
		"organizationId": string;
		"deploymentId": string;
		"routingTarget": Models.WebChatRoutingTarget;
		"memberInfo": Models.GuestMemberInfo;
		"memberAuthToken"?: string;
		"journeyContext"?: Models.JourneyContext;
	}
	
	export interface CreateWebChatConversationResponse { 
		"id"?: string;
		"jwt"?: string;
		"eventStreamUri"?: string;
		"member"?: Models.WebChatMemberInfo;
	}
	
	export interface CreateWebChatMessageRequest { 
		"body": string;
		"bodyType"?: string;
	}
	
	export interface CreateWebChatRequest { 
		"queueId": string;
		"provider": string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"priority"?: number;
		"attributes"?: { [key: string]: string; };
		"customerName"?: string;
	}
	
	export interface CreateWorkPlan { 
		"name": string;
		"enabled"?: boolean;
		"constrainWeeklyPaidTime"?: boolean;
		"flexibleWeeklyPaidTime"?: boolean;
		"weeklyExactPaidMinutes"?: number;
		"weeklyMinimumPaidMinutes"?: number;
		"weeklyMaximumPaidMinutes"?: number;
		"constrainPaidTimeGranularity"?: boolean;
		"paidTimeGranularityMinutes"?: number;
		"constrainMinimumTimeBetweenShifts"?: boolean;
		"minimumTimeBetweenShiftsMinutes"?: number;
		"maximumDays"?: number;
		"minimumConsecutiveNonWorkingMinutesPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingWeekends"?: boolean;
		"maximumConsecutiveWorkingWeekends"?: number;
		"minimumWorkingDaysPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingDays"?: boolean;
		"maximumConsecutiveWorkingDays"?: number;
		"minimumShiftStartDistanceMinutes"?: number;
		"minimumDaysOffPerPlanningPeriod"?: number;
		"maximumDaysOffPerPlanningPeriod"?: number;
		"minimumPaidMinutesPerPlanningPeriod"?: number;
		"maximumPaidMinutesPerPlanningPeriod"?: number;
		"optionalDays"?: Models.SetWrapperDayOfWeek;
		"shiftStartVarianceType"?: string;
		"shiftStartVariances"?: Models.ListWrapperShiftStartVariance;
		"shifts"?: Array<Models.CreateWorkPlanShift>;
		"agents"?: Array<Models.UserReference>;
	}
	
	export interface CreateWorkPlanActivity { 
		"activityCodeId"?: string;
		"description"?: string;
		"lengthMinutes"?: number;
		"startTimeIsRelativeToShiftStart"?: boolean;
		"flexibleStartTime"?: boolean;
		"earliestStartTimeMinutes"?: number;
		"latestStartTimeMinutes"?: number;
		"exactStartTimeMinutes"?: number;
		"startTimeIncrementMinutes"?: number;
		"countsAsPaidTime"?: boolean;
		"countsAsContiguousWorkTime"?: boolean;
		"minimumLengthFromShiftStartMinutes"?: number;
		"minimumLengthFromShiftEndMinutes"?: number;
	}
	
	export interface CreateWorkPlanShift { 
		"name": string;
		"days"?: Models.SetWrapperDayOfWeek;
		"flexibleStartTime"?: boolean;
		"exactStartTimeMinutesFromMidnight"?: number;
		"earliestStartTimeMinutesFromMidnight"?: number;
		"latestStartTimeMinutesFromMidnight"?: number;
		"constrainStopTime"?: boolean;
		"constrainLatestStopTime"?: boolean;
		"latestStopTimeMinutesFromMidnight"?: number;
		"constrainEarliestStopTime"?: boolean;
		"earliestStopTimeMinutesFromMidnight"?: number;
		"startIncrementMinutes"?: number;
		"flexiblePaidTime"?: boolean;
		"exactPaidTimeMinutes"?: number;
		"minimumPaidTimeMinutes"?: number;
		"maximumPaidTimeMinutes"?: number;
		"constrainContiguousWorkTime"?: boolean;
		"minimumContiguousWorkTimeMinutes"?: number;
		"maximumContiguousWorkTimeMinutes"?: number;
		"constrainDayOff"?: boolean;
		"dayOffRule"?: string;
		"activities"?: Array<Models.CreateWorkPlanActivity>;
	}
	
	export interface Credential { 
		"id"?: string;
		"name"?: string;
		"type": Models.CredentialType;
		"credentialFields"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface CredentialInfo { 
		"id"?: string;
		"name"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"type"?: Models.CredentialType;
		"selfUri"?: string;
	}
	
	export interface CredentialInfoListing { 
		"entities"?: Array<Models.CredentialInfo>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface CredentialSpecification { 
		"required"?: boolean;
		"title"?: string;
		"credentialTypes"?: Array<string>;
	}
	
	export interface CredentialType { 
		"id"?: string;
		"name"?: string;
		"properties"?: object;
		"displayOrder"?: Array<string>;
		"required"?: Array<string>;
	}
	
	export interface CredentialTypeListing { 
		"entities"?: Array<Models.CredentialType>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Criteria { 
		"key": string;
		"values": Array<string>;
		"shouldIgnoreCase": boolean;
		"operator": string;
	}
	
	export interface CriteriaCategoryInfo { 
		"categoryId"?: string;
		"displayOrder"?: number;
	}
	
	export interface CriteriaGroup { 
		"and"?: Array<Models.CriteriaItem>;
		"or"?: Array<Models.CriteriaItem>;
		"not"?: Array<Models.CriteriaItem>;
		"criteria"?: Models.CriteriaItem;
	}
	
	export interface CriteriaItem { 
		"key"?: string;
		"operator"?: string;
		"value"?: string;
	}
	
	export interface CriteriaQuery { 
		"query": Array<Models.CriteriaGroup>;
	}
	
	export interface CrossPlatformCallMediaPolicy { 
		"actions"?: Models.CrossPlatformPolicyActions;
		"conditions"?: Models.CallMediaPolicyConditions;
	}
	
	export interface CrossPlatformChatMediaPolicy { 
		"actions"?: Models.CrossPlatformPolicyActions;
		"conditions"?: Models.ChatMediaPolicyConditions;
	}
	
	export interface CrossPlatformEmailMediaPolicy { 
		"actions"?: Models.CrossPlatformPolicyActions;
		"conditions"?: Models.EmailMediaPolicyConditions;
	}
	
	export interface CrossPlatformMediaPolicies { 
		"callPolicy"?: Models.CrossPlatformCallMediaPolicy;
		"chatPolicy"?: Models.CrossPlatformChatMediaPolicy;
		"emailPolicy"?: Models.CrossPlatformEmailMediaPolicy;
		"messagePolicy"?: Models.CrossPlatformMessageMediaPolicy;
	}
	
	export interface CrossPlatformMessageMediaPolicy { 
		"actions"?: Models.CrossPlatformPolicyActions;
		"conditions"?: Models.MessageMediaPolicyConditions;
	}
	
	export interface CrossPlatformPolicy { 
		"id"?: string;
		"name"?: string;
		"modifiedDate"?: string;
		"createdDate"?: string;
		"order"?: number;
		"description"?: string;
		"enabled"?: boolean;
		"mediaPolicies"?: Models.CrossPlatformMediaPolicies;
		"conditions"?: Models.PolicyConditions;
		"actions"?: Models.CrossPlatformPolicyActions;
		"policyErrors"?: Models.PolicyErrors;
		"selfUri"?: string;
	}
	
	export interface CrossPlatformPolicyActions { 
		"retainRecording"?: boolean;
		"deleteRecording"?: boolean;
		"alwaysDelete"?: boolean;
		"assignEvaluations"?: Array<Models.EvaluationAssignment>;
		"assignMeteredEvaluations"?: Array<Models.MeteredEvaluationAssignment>;
		"assignMeteredAssignmentByAgent"?: Array<Models.MeteredAssignmentByAgent>;
		"assignCalibrations"?: Array<Models.CalibrationAssignment>;
		"retentionDuration"?: Models.RetentionDuration;
		"mediaTranscriptions"?: Array<Models.MediaTranscription>;
		"integrationExport"?: Models.IntegrationExport;
	}
	
	export interface CrossPlatformPolicyCreate { 
		"id"?: string;
		"name": string;
		"modifiedDate"?: string;
		"createdDate"?: string;
		"order"?: number;
		"description"?: string;
		"enabled"?: boolean;
		"mediaPolicies"?: Models.CrossPlatformMediaPolicies;
		"conditions"?: Models.PolicyConditions;
		"actions"?: Models.CrossPlatformPolicyActions;
		"policyErrors"?: Models.PolicyErrors;
		"selfUri"?: string;
	}
	
	export interface CrossPlatformPolicyUpdate { 
		"enabled"?: boolean;
	}
	
	export interface CtaButtonStyleProperties { 
		"color"?: string;
		"font"?: string;
		"fontSize"?: string;
		"textAlign"?: string;
		"backgroundColor"?: string;
	}
	
	export interface CurrentUserScheduleRequestBody { 
		"startDate": string;
		"endDate": string;
		"loadFullWeeks"?: boolean;
	}
	
	export interface CurrentUserTimeOffIntegrationStatusRequest { 
		"timeOffRequestIds": Array<string>;
	}
	
	export interface CursorContactListing { 
		"entities"?: Array<Models.ExternalContact>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"cursors"?: Models.Cursors;
	}
	
	export interface CursorNoteListing { 
		"entities"?: Array<Models.Note>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"cursors"?: Models.Cursors;
	}
	
	export interface CursorOrganizationListing { 
		"entities"?: Array<Models.ExternalOrganization>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"cursors"?: Models.Cursors;
	}
	
	export interface CursorRelationshipListing { 
		"entities"?: Array<Models.Relationship>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"cursors"?: Models.Cursors;
	}
	
	export interface Cursors { 
		"before"?: string;
		"after"?: string;
	}
	
	export interface CustomEventAttribute { 
		"dataType": string;
		"value": string;
	}
	
	export interface CustomEventAttributeList { 
		"dataType": string;
		"values": Array<string>;
	}
	
	export interface CustomI18nLabels { 
		"language"?: string;
		"localizedLabels"?: Array<Models.LocalizedLabels>;
	}
	
	export interface CustomProvider { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"logoImageData"?: string;
		"endpointCompression"?: boolean;
		"nameIdentifierFormat"?: string;
		"ssoBinding"?: string;
		"signAuthnRequests"?: boolean;
		"selfUri"?: string;
	}
	
	export interface CustomerEndDetailEventTopicCustomerEndEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"disconnectType"?: string;
		"mediaType"?: string;
		"externalOrganizationId"?: string;
		"externalContactId"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"interactingDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface CustomerInteractionCenter { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface CustomerStartDetailEventTopicCustomerStartEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"externalOrganizationId"?: string;
		"externalContactId"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
		"journeyContext"?: Models.CustomerStartDetailEventTopicJourneyContext;
	}
	
	export interface CustomerStartDetailEventTopicJourneyContext { 
		"sessionId"?: string;
		"sessionIdType"?: string;
		"actionId"?: string;
		"actionMapId"?: string;
	}
	
	export interface DID { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"phoneNumber"?: string;
		"didPool"?: Models.DomainEntityRef;
		"owner"?: Models.DomainEntityRef;
		"ownerType"?: string;
		"selfUri"?: string;
	}
	
	export interface DIDEntityListing { 
		"entities"?: Array<Models.DID>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DIDNumber { 
		"id"?: string;
		"name"?: string;
		"number"?: string;
		"assigned"?: boolean;
		"didPool"?: Models.AddressableEntityRef;
		"owner"?: Models.DomainEntityRef;
		"ownerType"?: string;
		"selfUri"?: string;
	}
	
	export interface DIDNumberEntityListing { 
		"entities"?: Array<Models.DIDNumber>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DIDPool { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"startPhoneNumber": string;
		"endPhoneNumber": string;
		"comments"?: string;
		"provider"?: string;
		"selfUri"?: string;
	}
	
	export interface DIDPoolEntityListing { 
		"entities"?: Array<Models.DIDPool>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DailyPossibleShift { 
		"dayOfWeek"?: string;
		"earliestShiftStartMinutesFromMidnight"?: number;
		"required"?: boolean;
		"minimumPaidTimeMinutes"?: number;
		"maximumPaidTimeMinutes"?: number;
		"intervalScheduleProbabilities"?: Array<number>;
	}
	
	export interface DashboardConfiguration { 
		"id"?: string;
		"name": string;
		"rows"?: number;
		"columns"?: number;
		"widgets": Array<Models.Widget>;
		"favorite"?: boolean;
		"publicDashboard"?: boolean;
		"restricted"?: boolean;
		"layoutType"?: string;
		"dateCreated": string;
		"dateModified": string;
		"createdBy"?: Models.AddressableEntityRef;
		"selfUri"?: string;
	}
	
	export interface DashboardConfigurationBulkRequest { 
		"dashboardConfigurationIds": Array<string>;
	}
	
	export interface DashboardConfigurationListing { 
		"entities"?: Array<Models.DashboardConfiguration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DashboardConfigurationQueryRequest { 
		"dashboardConfigurationIds": Array<string>;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
	}
	
	export interface DashboardUser { 
		"id"?: string;
		"name"?: string;
		"dashboardCount"?: number;
		"publicDashboardCount"?: number;
		"state"?: string;
		"selfUri"?: string;
	}
	
	export interface DashboardUserListing { 
		"entities"?: Array<Models.DashboardUser>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DataActionConditionPredicate { 
		"outputField": string;
		"outputOperator": string;
		"comparisonValue": string;
		"inverted": boolean;
		"outputFieldMissingResolution": boolean;
	}
	
	export interface DataActionConditionSettings { 
		"dataActionId": string;
		"contactIdField"?: string;
		"dataNotFoundResolution": boolean;
		"predicates"?: Array<Models.DigitalDataActionConditionPredicate>;
		"contactColumnToDataActionFieldMappings"?: Array<Models.DataActionContactColumnFieldMapping>;
	}
	
	export interface DataActionContactColumnFieldMapping { 
		"contactColumnName": string;
		"dataActionField": string;
	}
	
	export interface DataAvailabilityResponse { 
		"dataAvailabilityDate"?: string;
	}
	
	export interface DataSchema { 
		"id"?: string;
		"name"?: string;
		"version": number;
		"appliesTo"?: Array<string>;
		"enabled"?: boolean;
		"createdBy"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"jsonSchema": Models.JsonSchemaDocument;
		"selfUri"?: string;
	}
	
	export interface DataSchemaListing { 
		"total"?: number;
		"entities"?: Array<Models.DataSchema>;
		"selfUri"?: string;
	}
	
	export interface DataTable { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"schema"?: Models.JsonSchemaDocument;
		"selfUri"?: string;
	}
	
	export interface DataTableExportJob { 
		"id"?: string;
		"name"?: string;
		"owner"?: Models.AddressableEntityRef;
		"status": string;
		"dateCreated"?: string;
		"dateCompleted"?: string;
		"downloadURI"?: string;
		"errorInformation"?: Models.ErrorBody;
		"countRecordsProcessed"?: number;
		"selfUri"?: string;
	}
	
	export interface DataTableImportEntityListing { 
		"entities"?: Array<Models.DataTableImportJob>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface DataTableImportJob { 
		"id"?: string;
		"name"?: string;
		"owner"?: Models.AddressableEntityRef;
		"status": string;
		"dateCreated"?: string;
		"dateCompleted"?: string;
		"uploadURI"?: string;
		"importMode"?: string;
		"errorInformation"?: Models.ErrorBody;
		"countRecordsUpdated"?: number;
		"countRecordsDeleted"?: number;
		"countRecordsFailed"?: number;
		"selfUri"?: string;
	}
	
	export interface DataTableRowEntityListing { 
		"entities"?: Array<{ [key: string]: object; }>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DataTablesDomainEntityListing { 
		"entities"?: Array<Models.DataTable>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DateRange { 
		"startDate"?: string;
		"endDate"?: string;
	}
	
	export interface DateRangeWithOptionalEnd { 
		"startBusinessUnitDate": string;
		"endBusinessUnitDate"?: string;
	}
	
	export interface DefaultGreetingList { 
		"id"?: string;
		"name"?: string;
		"owner"?: Models.GreetingOwner;
		"ownerType"?: string;
		"greetings"?: { [key: string]: Models.Greeting; };
		"createdDate"?: string;
		"createdBy"?: string;
		"modifiedDate"?: string;
		"modifiedBy"?: string;
		"selfUri"?: string;
	}
	
	export interface DefaultObjective { 
		"id"?: string;
		"templateId"?: string;
		"zones"?: Array<Models.ObjectiveZone>;
		"enabled"?: boolean;
		"mediaTypes"?: Array<string>;
		"queues"?: Array<Models.AddressableEntityRef>;
		"topics"?: Array<Models.AddressableEntityRef>;
		"topicIdsFilterType"?: string;
		"evaluationFormContextIds"?: Array<string>;
		"initialDirection"?: string;
	}
	
	export interface DeletableUserReference { 
		"id"?: string;
		"delete"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DeleteRetention { 
		"days"?: number;
	}
	
	export interface Dependency { 
		"id"?: string;
		"name"?: string;
		"version"?: string;
		"type"?: string;
		"deleted"?: boolean;
		"updated"?: boolean;
		"stateUnknown"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DependencyObject { 
		"id"?: string;
		"name"?: string;
		"version"?: string;
		"type"?: string;
		"deleted"?: boolean;
		"updated"?: boolean;
		"stateUnknown"?: boolean;
		"consumedResources"?: Array<Models.Dependency>;
		"consumingResources"?: Array<Models.Dependency>;
		"selfUri"?: string;
	}
	
	export interface DependencyObjectEntityListing { 
		"entities"?: Array<Models.DependencyObject>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DependencyStatus { 
		"id"?: string;
		"name"?: string;
		"user"?: Models.User;
		"client"?: Models.DomainEntityRef;
		"buildId"?: string;
		"dateStarted"?: string;
		"dateCompleted"?: string;
		"status"?: string;
		"failedObjects"?: Array<Models.FailedObject>;
		"selfUri"?: string;
	}
	
	export interface DependencyType { 
		"id"?: string;
		"name"?: string;
		"versioned"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DependencyTypeEntityListing { 
		"entities"?: Array<Models.DependencyType>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DeploymentPing { 
		"actions"?: Array<Models.DeploymentWebAction>;
		"pollIntervalMilliseconds"?: number;
	}
	
	export interface DeploymentWebAction { 
		"id": string;
		"mediaType": string;
		"customerId"?: string;
		"customerIdType"?: string;
		"actionMapId": string;
		"actionMapVersion": number;
		"sessionId": string;
		"webMessagingOfferProperties"?: Models.WebMessagingOfferProperties;
		"contentOfferProperties"?: Models.ContentOffer;
		"openActionProperties"?: Models.OpenActionProperties;
	}
	
	export interface Destination { 
		"address": string;
		"name"?: string;
		"userId"?: string;
		"queueId"?: string;
	}
	
	export interface Detail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface DetectedDialogAct { 
		"name"?: string;
		"probability"?: number;
	}
	
	export interface DetectedIntent { 
		"name"?: string;
		"probability"?: number;
		"entities"?: Array<Models.DetectedNamedEntity>;
	}
	
	export interface DetectedNamedEntity { 
		"name"?: string;
		"entityType"?: string;
		"probability"?: number;
		"value"?: Models.DetectedNamedEntityValue;
	}
	
	export interface DetectedNamedEntityValue { 
		"raw"?: string;
		"resolved"?: string;
		"unit"?: string;
	}
	
	export interface DevelopmentActivity { 
		"id"?: string;
		"dateCompleted"?: string;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"percentageScore"?: number;
		"isPassed"?: boolean;
		"isLatest"?: boolean;
		"isModuleArchived"?: boolean;
		"archivalMode"?: string;
		"selfUri"?: string;
		"name"?: string;
		"type"?: string;
		"status"?: string;
		"dateDue"?: string;
		"facilitator"?: Models.UserReference;
		"attendees"?: Array<Models.UserReference>;
		"isOverdue"?: boolean;
	}
	
	export interface DevelopmentActivityAggregateParam { 
		"interval": string;
		"metrics"?: Array<string>;
		"groupBy"?: Array<string>;
		"filter": Models.DevelopmentActivityAggregateQueryRequestFilter;
	}
	
	export interface DevelopmentActivityAggregateQueryRequestClause { 
		"type": string;
		"predicates": Array<Models.DevelopmentActivityAggregateQueryRequestPredicate>;
	}
	
	export interface DevelopmentActivityAggregateQueryRequestFilter { 
		"type": string;
		"clauses": Array<Models.DevelopmentActivityAggregateQueryRequestClause>;
	}
	
	export interface DevelopmentActivityAggregateQueryRequestPredicate { 
		"dimension": string;
		"value": string;
	}
	
	export interface DevelopmentActivityAggregateQueryResponseData { 
		"interval"?: string;
		"metrics"?: Array<Models.DevelopmentActivityAggregateQueryResponseMetric>;
	}
	
	export interface DevelopmentActivityAggregateQueryResponseGroupedData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.DevelopmentActivityAggregateQueryResponseData>;
	}
	
	export interface DevelopmentActivityAggregateQueryResponseMetric { 
		"metric"?: string;
		"stats"?: Models.DevelopmentActivityAggregateQueryResponseStatistics;
	}
	
	export interface DevelopmentActivityAggregateQueryResponseStatistics { 
		"count"?: number;
		"min"?: number;
		"max"?: number;
		"sum"?: number;
	}
	
	export interface DevelopmentActivityAggregateResponse { 
		"results"?: Array<Models.DevelopmentActivityAggregateQueryResponseGroupedData>;
	}
	
	export interface DevelopmentActivityListing { 
		"entities"?: Array<Models.DevelopmentActivity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Device { 
		"category": string;
		"type": string;
		"isMobile": boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily": string;
		"osVersion": string;
		"manufacturer"?: string;
	}
	
	export interface DialerAction { 
		"type": string;
		"actionTypeName": string;
		"updateOption"?: string;
		"properties"?: { [key: string]: string; };
		"dataAction"?: Models.DomainEntityRef;
		"contactColumnToDataActionFieldMappings"?: Array<Models.ContactColumnToDataActionFieldMapping>;
		"contactIdField"?: string;
		"callAnalysisResultField"?: string;
		"agentWrapupField"?: string;
	}
	
	export interface DialerAttemptLimitsConfigChangeAttemptLimits { 
		"maxAttemptsPerContact"?: number;
		"maxAttemptsPerNumber"?: number;
		"timeZoneId"?: string;
		"resetPeriod"?: string;
		"recallEntries"?: { [key: string]: Models.DialerAttemptLimitsConfigChangeRecallEntry; };
		"breadthFirstRecalls"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerAttemptLimitsConfigChangeObject { 
	}
	
	export interface DialerAttemptLimitsConfigChangeRecallEntry { 
		"nbrAttempts"?: number;
		"minutesBetweenAttempts"?: number;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerAuditRequest { 
		"queryPhrase"?: string;
		"queryFields"?: Array<string>;
		"facets"?: Array<Models.AuditFacet>;
		"filters"?: Array<Models.AuditFilter>;
	}
	
	export interface DialerCallabletimesetConfigChangeCallableTime { 
		"timeSlots"?: Array<Models.DialerCallabletimesetConfigChangeTimeSlot>;
		"timeZoneId"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCallabletimesetConfigChangeCallableTimeSet { 
		"callableTimes"?: Array<Models.DialerCallabletimesetConfigChangeCallableTime>;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerCallabletimesetConfigChangeObject { 
	}
	
	export interface DialerCallabletimesetConfigChangeTimeSlot { 
		"startTime"?: string;
		"stopTime"?: string;
		"day"?: number;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignConfigChangeCampaign { 
		"contactList"?: Models.DialerCampaignConfigChangeUriReference;
		"queue"?: Models.DialerCampaignConfigChangeUriReference;
		"dialingMode"?: string;
		"script"?: Models.DialerCampaignConfigChangeUriReference;
		"edgeGroup"?: Models.DialerCampaignConfigChangeUriReference;
		"site"?: Models.DialerCampaignConfigChangeUriReference;
		"campaignStatus"?: string;
		"phoneColumns"?: Array<Models.DialerCampaignConfigChangePhoneColumn>;
		"abandonRate"?: number;
		"dncLists"?: Array<Models.DialerCampaignConfigChangeUriReference>;
		"callableTimeSet"?: Models.DialerCampaignConfigChangeUriReference;
		"callAnalysisResponseSet"?: Models.DialerCampaignConfigChangeUriReference;
		"callerName"?: string;
		"callerAddress"?: string;
		"outboundLineCount"?: number;
		"errors"?: Array<Models.DialerCampaignConfigChangeRestErrorDetail>;
		"ruleSets"?: Array<Models.DialerCampaignConfigChangeUriReference>;
		"skipPreviewDisabled"?: boolean;
		"previewTimeOutSeconds"?: number;
		"singleNumberPreview"?: boolean;
		"contactSort"?: Models.DialerCampaignConfigChangeContactSort;
		"contactSorts"?: Array<Models.DialerCampaignConfigChangeContactSort>;
		"noAnswerTimeout"?: number;
		"callAnalysisLanguage"?: string;
		"priority"?: number;
		"contactListFilters"?: Array<Models.DialerCampaignConfigChangeUriReference>;
		"division"?: Models.DialerCampaignConfigChangeUriReference;
		"agentOwnedColumn"?: string;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerCampaignConfigChangeContactSort { 
		"fieldName"?: string;
		"direction"?: string;
		"numeric"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignConfigChangeObject { 
	}
	
	export interface DialerCampaignConfigChangePhoneColumn { 
		"columnName"?: string;
		"type"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignConfigChangeRestErrorDetail { 
		"error"?: string;
		"details"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerCampaignProgressEventCampaignProgress { 
		"campaign"?: Models.DialerCampaignProgressEventUriReference;
		"numberOfContactsCalled"?: number;
		"numberOfContactsMessaged"?: number;
		"totalNumberOfContacts"?: number;
		"percentage"?: number;
		"numberOfContactsSkipped"?: { [key: string]: number; };
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignProgressEventObject { 
	}
	
	export interface DialerCampaignProgressEventUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerCampaignRuleConfigChangeCampaignRule { 
		"campaignRuleEntities"?: Models.DialerCampaignRuleConfigChangeCampaignRuleEntities;
		"campaignRuleConditions"?: Array<Models.DialerCampaignRuleConfigChangeCampaignRuleCondition>;
		"campaignRuleActions"?: Array<Models.DialerCampaignRuleConfigChangeCampaignRuleAction>;
		"matchAnyConditions"?: boolean;
		"enabled"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerCampaignRuleConfigChangeCampaignRuleAction { 
		"id"?: string;
		"parameters"?: { [key: string]: string; };
		"actionType"?: string;
		"campaignRuleActionEntities"?: Models.DialerCampaignRuleConfigChangeCampaignRuleActionEntities;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignRuleConfigChangeCampaignRuleActionEntities { 
		"useTriggeringEntity"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
		"campaigns"?: Array<Models.DialerCampaignRuleConfigChangeUriReference>;
		"sequences"?: Array<Models.DialerCampaignRuleConfigChangeUriReference>;
	}
	
	export interface DialerCampaignRuleConfigChangeCampaignRuleCondition { 
		"id"?: string;
		"parameters"?: { [key: string]: string; };
		"conditionType"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignRuleConfigChangeCampaignRuleEntities { 
		"campaigns"?: Array<Models.DialerCampaignRuleConfigChangeUriReference>;
		"sequences"?: Array<Models.DialerCampaignRuleConfigChangeUriReference>;
	}
	
	export interface DialerCampaignRuleConfigChangeObject { 
	}
	
	export interface DialerCampaignRuleConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerCampaignScheduleConfigChangeAlteration { 
		"type"?: string;
		"start"?: string;
		"end"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignScheduleConfigChangeCampaignSchedule { 
		"intervals"?: Array<Models.DialerCampaignScheduleConfigChangeScheduleInterval>;
		"recurrences"?: Array<Models.DialerCampaignScheduleConfigChangeScheduleRecurrence>;
		"timeZone"?: string;
		"campaign"?: Models.DialerCampaignScheduleConfigChangeUriReference;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerCampaignScheduleConfigChangeObject { 
	}
	
	export interface DialerCampaignScheduleConfigChangeRecurrencePattern { 
		"type"?: string;
		"interval"?: number;
		"daysOfWeek"?: Array<string>;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignScheduleConfigChangeRecurrenceRange { 
		"type"?: string;
		"end"?: string;
		"numberOfOccurrences"?: number;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignScheduleConfigChangeScheduleInterval { 
		"start"?: string;
		"end"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignScheduleConfigChangeScheduleRecurrence { 
		"id"?: string;
		"start"?: string;
		"end"?: string;
		"timeZone"?: string;
		"range"?: Models.DialerCampaignScheduleConfigChangeRecurrenceRange;
		"pattern"?: Models.DialerCampaignScheduleConfigChangeRecurrencePattern;
		"alterations"?: Array<Models.DialerCampaignScheduleConfigChangeAlteration>;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerCampaignScheduleConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerContact { 
		"id"?: string;
		"name"?: string;
		"contactListId": string;
		"data": { [key: string]: string; };
		"callRecords"?: { [key: string]: Models.CallRecord; };
		"latestSmsEvaluations"?: { [key: string]: Models.MessageEvaluation; };
		"latestEmailEvaluations"?: { [key: string]: Models.MessageEvaluation; };
		"callable"?: boolean;
		"phoneNumberStatus"?: { [key: string]: Models.PhoneNumberStatus; };
		"contactableStatus"?: { [key: string]: Models.ContactableStatus; };
		"contactColumnTimeZones"?: { [key: string]: Models.ContactColumnTimeZone; };
		"configurationOverrides"?: Models.ConfigurationOverrides;
		"dateCreated"?: string;
		"selfUri"?: string;
	}
	
	export interface DialerContactId { 
		"id"?: string;
		"contactListId"?: string;
	}
	
	export interface DialerContactlistConfigChangeContactList { 
		"columnNames"?: Array<string>;
		"phoneColumns"?: Array<Models.DialerContactlistConfigChangeContactPhoneNumberColumn>;
		"emailColumns"?: Array<Models.DialerContactlistConfigChangeEmailColumn>;
		"importStatus"?: Models.DialerContactlistConfigChangeImportStatus;
		"previewModeColumnName"?: string;
		"previewModeAcceptedValues"?: Array<string>;
		"size"?: number;
		"attemptLimits"?: Models.DialerContactlistConfigChangeUriReference;
		"automaticTimeZoneMapping"?: boolean;
		"zipCodeColumnName"?: string;
		"division"?: Models.DialerContactlistConfigChangeUriReference;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerContactlistConfigChangeContactPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
		"callableTimeColumn"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerContactlistConfigChangeEmailColumn { 
		"columnName"?: string;
		"type"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerContactlistConfigChangeImportStatus { 
		"importState"?: string;
		"totalRecords"?: number;
		"completedRecords"?: number;
		"percentageComplete"?: number;
		"failureReason"?: string;
		"targetContactListIds"?: Array<string>;
		"listNamePrefix"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerContactlistConfigChangeObject { 
	}
	
	export interface DialerContactlistConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerContactlistfilterConfigChangeContactListFilter { 
		"contactList"?: Models.DialerContactlistfilterConfigChangeUriReference;
		"contactListColumns"?: Array<string>;
		"clauses"?: Array<Models.DialerContactlistfilterConfigChangeFilterClause>;
		"filterType"?: string;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerContactlistfilterConfigChangeFilterClause { 
		"filterType"?: string;
		"predicates"?: Array<Models.DialerContactlistfilterConfigChangeFilterPredicate>;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerContactlistfilterConfigChangeFilterPredicate { 
		"column"?: string;
		"columnType"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.DialerContactlistfilterConfigChangeRange;
		"inverted"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerContactlistfilterConfigChangeObject { 
	}
	
	export interface DialerContactlistfilterConfigChangeRange { 
		"min"?: string;
		"max"?: string;
		"minInclusive"?: boolean;
		"maxInclusive"?: boolean;
		"inSet"?: Array<string>;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerContactlistfilterConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerDnclistConfigChangeDncList { 
		"importStatus"?: Models.DialerDnclistConfigChangeImportStatus;
		"size"?: number;
		"dncSourceType"?: string;
		"loginId"?: string;
		"dncCodes"?: Array<string>;
		"licenseId"?: string;
		"contactMethod"?: string;
		"division"?: Models.DialerDnclistConfigChangeUriReference;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerDnclistConfigChangeImportStatus { 
		"importState"?: string;
		"totalRecords"?: number;
		"completedRecords"?: number;
		"percentageComplete"?: number;
		"failureReason"?: string;
		"targetContactListIds"?: Array<string>;
		"listNamePrefix"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerDnclistConfigChangeObject { 
	}
	
	export interface DialerDnclistConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerEventEntityListing { 
		"entities"?: Array<Models.EventLog>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DialerOutboundSettingsConfigChangeAtzmTimeSlot { 
		"earliestCallableTime"?: string;
		"latestCallableTime"?: string;
	}
	
	export interface DialerOutboundSettingsConfigChangeAtzmTimeSlotWithTimeZone { 
		"timeZoneId"?: string;
		"earliestCallableTime"?: string;
		"latestCallableTime"?: string;
	}
	
	export interface DialerOutboundSettingsConfigChangeAutomaticTimeZoneMappingSettings { 
		"callableWindows"?: Array<Models.DialerOutboundSettingsConfigChangeCallableWindow>;
	}
	
	export interface DialerOutboundSettingsConfigChangeCallableWindow { 
		"mapped"?: Models.DialerOutboundSettingsConfigChangeAtzmTimeSlot;
		"unmapped"?: Models.DialerOutboundSettingsConfigChangeAtzmTimeSlotWithTimeZone;
	}
	
	export interface DialerOutboundSettingsConfigChangeOutboundSettings { 
		"maxCallsPerAgent"?: number;
		"maxLineUtilization"?: number;
		"abandonSeconds"?: number;
		"complianceAbandonRateDenominator"?: string;
		"automaticTimeZoneMapping"?: Models.DialerOutboundSettingsConfigChangeAutomaticTimeZoneMappingSettings;
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.PhoneNumberColumn>;
		"callbackAutoAnswer"?: boolean;
	}
	
	export interface DialerResponsesetConfigChangeObject { 
	}
	
	export interface DialerResponsesetConfigChangeReaction { 
		"data"?: string;
		"name"?: string;
		"reactionType"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerResponsesetConfigChangeResponseSet { 
		"responses"?: { [key: string]: Models.DialerResponsesetConfigChangeReaction; };
		"beepDetectionEnabled"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerRule { 
		"id"?: string;
		"name": string;
		"order"?: number;
		"category": string;
		"conditions": Array<Models.Condition>;
		"actions"?: Array<Models.DialerAction>;
	}
	
	export interface DialerRulesetConfigChangeAction { 
		"type"?: string;
		"actionTypeName"?: string;
		"updateOption"?: string;
		"properties"?: { [key: string]: string; };
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerRulesetConfigChangeCondition { 
		"dataAction"?: Models.DialerRulesetConfigChangeUriReference;
		"additionalProperties"?: { [key: string]: object; };
		"type"?: string;
		"inverted"?: boolean;
		"attributeName"?: string;
		"value"?: string;
		"valueType"?: string;
		"operator"?: string;
		"codes"?: Array<string>;
		"propertyType"?: string;
		"property"?: string;
		"dataNotFoundResolution"?: boolean;
		"contactIdField"?: string;
		"callAnalysisResultField"?: string;
		"agentWrapupField"?: string;
		"contactColumnToDataActionFieldMappings"?: Array<Models.DialerRulesetConfigChangeContactColumnToDataActionFieldMapping>;
		"predicates"?: Array<Models.DialerRulesetConfigChangeDataActionConditionPredicate>;
	}
	
	export interface DialerRulesetConfigChangeContactColumnToDataActionFieldMapping { 
		"contactColumnName"?: string;
		"dataActionField"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerRulesetConfigChangeDataActionConditionPredicate { 
		"outputField"?: string;
		"outputOperator"?: string;
		"comparisonValue"?: string;
		"outputFieldMissingResolution"?: boolean;
		"inverted"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerRulesetConfigChangeObject { 
	}
	
	export interface DialerRulesetConfigChangeRule { 
		"conditions"?: Array<Models.DialerRulesetConfigChangeCondition>;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"order"?: number;
		"category"?: string;
		"actions"?: Array<Models.DialerRulesetConfigChangeAction>;
	}
	
	export interface DialerRulesetConfigChangeRuleSet { 
		"contactList"?: Models.DialerRulesetConfigChangeUriReference;
		"queue"?: Models.DialerRulesetConfigChangeUriReference;
		"rules"?: Array<Models.DialerRulesetConfigChangeRule>;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerRulesetConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerSequenceConfigChangeCampaignSequence { 
		"campaigns"?: Array<Models.DialerSequenceConfigChangeUriReference>;
		"currentCampaign"?: number;
		"status"?: string;
		"stopMessage"?: string;
		"repeat"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerSequenceConfigChangeObject { 
	}
	
	export interface DialerSequenceConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerSequenceScheduleConfigChangeObject { 
	}
	
	export interface DialerSequenceScheduleConfigChangeScheduleInterval { 
		"start"?: string;
		"end"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DialerSequenceScheduleConfigChangeSequenceSchedule { 
		"intervals"?: Array<Models.DialerSequenceScheduleConfigChangeScheduleInterval>;
		"timeZone"?: string;
		"sequence"?: Models.DialerSequenceScheduleConfigChangeUriReference;
		"additionalProperties"?: { [key: string]: object; };
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
	}
	
	export interface DialerSequenceScheduleConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialerWrapupcodemappingConfigChangeWrapUpCodeMapping { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"defaultSet"?: Array<string>;
		"mapping"?: { [key: string]: Array<string>; };
	}
	
	export interface DialogflowAgent { 
		"id"?: string;
		"name"?: string;
		"project"?: Models.DialogflowProject;
		"languages"?: Array<string>;
		"intents"?: Array<Models.DialogflowIntent>;
		"environments"?: Array<string>;
		"integration"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface DialogflowAgentSummary { 
		"id"?: string;
		"name"?: string;
		"project"?: Models.DialogflowProject;
		"description"?: string;
		"integration"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface DialogflowAgentSummaryEntityListing { 
		"entities"?: Array<Models.DialogflowAgentSummary>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DialogflowCXAgent { 
		"id"?: string;
		"name"?: string;
		"project"?: Models.DialogflowCXProject;
		"languages"?: Array<string>;
		"environments"?: Array<Models.DialogflowCXEnvironment>;
		"integration"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface DialogflowCXAgentSummary { 
		"id"?: string;
		"name"?: string;
		"project"?: Models.DialogflowCXProject;
		"description"?: string;
		"integration"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface DialogflowCXAgentSummaryEntityListing { 
		"entities"?: Array<Models.DialogflowCXAgentSummary>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DialogflowCXEnvironment { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface DialogflowCXProject { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DialogflowIntent { 
		"name": string;
		"parameters": { [key: string]: Models.DialogflowParameter; };
	}
	
	export interface DialogflowParameter { 
		"name": string;
		"type": string;
	}
	
	export interface DialogflowProject { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DictionaryFeedback { 
		"id"?: string;
		"term": string;
		"dialect": string;
		"boostValue"?: number;
		"source"?: string;
		"dateCreated"?: string;
		"createdBy"?: Models.UserReference;
		"dateModified"?: string;
		"modifiedBy"?: Models.UserReference;
		"examplePhrases": Array<Models.DictionaryFeedbackExamplePhrase>;
		"soundsLike"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface DictionaryFeedbackEntityListing { 
		"entities"?: Array<Models.ListedDictionaryFeedback>;
		"pageSize"?: number;
		"pageCount"?: number;
		"total"?: number;
		"selfUri"?: string;
		"nextUri"?: string;
	}
	
	export interface DictionaryFeedbackExamplePhrase { 
		"phrase": string;
		"source"?: string;
	}
	
	export interface DigitLength { 
		"start"?: string;
		"end"?: string;
	}
	
	export interface DigitalAction { 
		"updateContactColumnActionSettings"?: Models.UpdateContactColumnActionSettings;
		"doNotSendActionSettings"?: object;
		"appendToDncActionSettings"?: Models.AppendToDncActionSettings;
		"markContactUncontactableActionSettings"?: Models.MarkContactUncontactableActionSettings;
		"markContactAddressUncontactableActionSettings"?: object;
		"setContentTemplateActionSettings"?: Models.SetContentTemplateActionSettings;
		"setSmsPhoneNumberActionSettings"?: Models.SetSmsPhoneNumberActionSettings;
	}
	
	export interface DigitalCondition { 
		"inverted"?: boolean;
		"contactColumnConditionSettings"?: Models.ContactColumnConditionSettings;
		"contactAddressConditionSettings"?: Models.ContactAddressConditionSettings;
		"contactAddressTypeConditionSettings"?: Models.ContactAddressTypeConditionSettings;
		"lastAttemptByColumnConditionSettings"?: Models.LastAttemptByColumnConditionSettings;
		"lastAttemptOverallConditionSettings"?: Models.LastAttemptOverallConditionSettings;
		"lastResultByColumnConditionSettings"?: Models.LastResultByColumnConditionSettings;
		"lastResultOverallConditionSettings"?: Models.LastResultOverallConditionSettings;
		"dataActionConditionSettings"?: Models.DataActionConditionSettings;
	}
	
	export interface DigitalDataActionConditionPredicate { 
		"outputField": string;
		"outputOperator": string;
		"comparisonValue": string;
		"inverted": boolean;
		"outputFieldMissingResolution": boolean;
	}
	
	export interface DigitalRule { 
		"id"?: string;
		"name": string;
		"order": number;
		"category": string;
		"conditions": Array<Models.DigitalCondition>;
		"actions": Array<Models.DigitalAction>;
	}
	
	export interface DigitalRuleSet { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"contactList"?: Models.DomainEntityRef;
		"rules": Array<Models.DigitalRule>;
		"selfUri"?: string;
	}
	
	export interface DigitalRuleSetEntityListing { 
		"entities"?: Array<Models.DigitalRuleSet>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Digits { 
		"digits"?: string;
	}
	
	export interface DirectRouting { 
		"callMediaSettings"?: Models.DirectRoutingMediaSettings;
		"emailMediaSettings"?: Models.DirectRoutingMediaSettings;
		"messageMediaSettings"?: Models.DirectRoutingMediaSettings;
		"backupQueueId"?: string;
		"waitForAgent"?: boolean;
		"agentWaitSeconds"?: number;
	}
	
	export interface DirectRoutingMediaSettings { 
		"useAgentAddressOutbound"?: boolean;
	}
	
	export interface DirectoryUserDevicesListing { 
		"entities"?: Array<Models.UserDevice>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DisableSiteConnectionsRequest { 
		"enabled"?: boolean;
	}
	
	export interface DisallowedEntityLearningAssignmentItem { 
		"errorCode"?: string;
		"entity"?: Models.LearningAssignmentItem;
	}
	
	export interface DisallowedEntityLearningAssignmentReference { 
		"errorCode"?: string;
		"entity"?: Models.LearningAssignmentReference;
	}
	
	export interface DisconnectReason { 
		"type"?: string;
		"code"?: number;
		"phrase"?: string;
	}
	
	export interface Disposition { 
		"name": string;
		"analyzer"?: string;
		"dispositionParameters"?: Models.DispositionParameters;
	}
	
	export interface DispositionParameters { 
		"adjustableLiveSpeakerDetection"?: Models.AdjustableLiveSpeakerDetection;
	}
	
	export interface Division { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface DivisionReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface DivsPermittedEntityListing { 
		"entities"?: Array<Models.AuthzDivision>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"allDivsPermitted"?: boolean;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DncList { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"importStatus"?: Models.ImportStatus;
		"size"?: number;
		"dncSourceType": string;
		"contactMethod"?: string;
		"loginId"?: string;
		"campaignId"?: string;
		"dncCodes"?: Array<string>;
		"licenseId"?: string;
		"division"?: Models.DomainEntityRef;
		"customExclusionColumn"?: string;
		"selfUri"?: string;
	}
	
	export interface DncListCreate { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"importStatus"?: Models.ImportStatus;
		"size"?: number;
		"dncSourceType": string;
		"contactMethod"?: string;
		"loginId"?: string;
		"campaignId"?: string;
		"dncCodes"?: Array<string>;
		"licenseId"?: string;
		"division"?: Models.DomainEntityRef;
		"customExclusionColumn"?: string;
		"selfUri"?: string;
	}
	
	export interface DncListDivisionView { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"importStatus"?: Models.ImportStatus;
		"size"?: number;
		"dncSourceType"?: string;
		"contactMethod"?: string;
		"selfUri"?: string;
	}
	
	export interface DncListDivisionViewListing { 
		"entities"?: Array<Models.DncListDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DncListEntityListing { 
		"entities"?: Array<Models.DncList>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DncPatchCustomExclusionColumnsRequest { 
		"action"?: string;
		"customExclusionColumnEntries"?: Array<string>;
		"expirationDateTime"?: string;
	}
	
	export interface DncPatchEmailsRequest { 
		"action"?: string;
		"emailAddresses"?: Array<string>;
		"expirationDateTime"?: string;
	}
	
	export interface DncPatchPhoneNumbersRequest { 
		"action"?: string;
		"phoneNumbers"?: Array<string>;
		"expirationDateTime"?: string;
	}
	
	export interface DnclistDownloadReadyExportUri { 
		"uri"?: string;
		"exportTimestamp"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DnclistDownloadReadyObject { 
	}
	
	export interface DnclistImportStatusImportStatus { 
		"importState"?: string;
		"totalRecords"?: number;
		"completedRecords"?: number;
		"percentageComplete"?: number;
		"failureReason"?: string;
		"targetContactListIds"?: Array<string>;
		"listNamePrefix"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface DnclistImportStatusObject { 
	}
	
	export interface DnsRecordEntry { 
		"host"?: string;
		"recordContents"?: string;
		"verificationStatus"?: string;
	}
	
	export interface DoNotSendActionSettings { 
	}
	
	export interface Document { 
		"id"?: string;
		"name"?: string;
		"changeNumber"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateUploaded"?: string;
		"contentUri"?: string;
		"workspace"?: Models.DomainEntityRef;
		"createdBy"?: Models.DomainEntityRef;
		"uploadedBy"?: Models.DomainEntityRef;
		"sharingUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
		"systemType"?: string;
		"filename"?: string;
		"pageCount"?: number;
		"read"?: boolean;
		"callerAddress"?: string;
		"receiverAddress"?: string;
		"tags"?: Array<string>;
		"tagValues"?: Array<Models.TagValue>;
		"attributes"?: Array<Models.DocumentAttribute>;
		"thumbnails"?: Array<Models.DocumentThumbnail>;
		"uploadStatus"?: Models.DomainEntityRef;
		"uploadDestinationUri"?: string;
		"uploadMethod"?: string;
		"lockInfo"?: Models.LockInfo;
		"acl"?: Array<string>;
		"sharingStatus"?: string;
		"downloadSharingUri"?: string;
		"selfUri"?: string;
	}
	
	export interface DocumentArticle { 
		"title": string;
		"content"?: Models.ArticleContent;
		"alternatives"?: Array<string>;
	}
	
	export interface DocumentAttribute { 
		"attribute"?: Models.Attribute;
		"values"?: Array<string>;
	}
	
	export interface DocumentBody { 
		"blocks": Array<Models.DocumentBodyBlock>;
	}
	
	export interface DocumentBodyBlock { 
		"type": string;
		"image"?: Models.DocumentBodyImage;
		"video"?: Models.DocumentBodyVideo;
		"list"?: Models.DocumentBodyList;
		"table"?: Models.DocumentBodyTable;
		"paragraph"?: Models.DocumentBodyParagraph;
	}
	
	export interface DocumentBodyBlockWithHighlight { 
		"type": string;
		"image"?: Models.DocumentBodyImage;
		"video"?: Models.DocumentBodyVideo;
		"list"?: Models.DocumentBodyList;
		"table"?: Models.DocumentBodyTable;
		"paragraph"?: Models.DocumentBodyParagraphWithHighlight;
	}
	
	export interface DocumentBodyImage { 
		"url": string;
		"hyperlink"?: string;
		"properties"?: Models.DocumentBodyImageProperties;
	}
	
	export interface DocumentBodyImageProperties { 
		"backgroundColor"?: string;
		"align"?: string;
		"indentation"?: number;
	}
	
	export interface DocumentBodyList { 
		"blocks": Array<Models.DocumentBodyListBlock>;
		"properties"?: Models.DocumentBodyListBlockProperties;
	}
	
	export interface DocumentBodyListBlock { 
		"type": string;
		"blocks": Array<Models.DocumentListContentBlock>;
		"properties"?: Models.DocumentBodyListItemProperties;
	}
	
	export interface DocumentBodyListBlockProperties { 
		"unorderedType"?: string;
		"orderedType"?: string;
	}
	
	export interface DocumentBodyListItemProperties { 
		"backgroundColor"?: string;
		"align"?: string;
		"indentation"?: number;
		"fontSize"?: string;
		"fontType"?: string;
		"textColor"?: string;
		"unorderedType"?: string;
		"orderedType"?: string;
	}
	
	export interface DocumentBodyParagraph { 
		"blocks": Array<Models.DocumentContentBlock>;
		"properties"?: Models.DocumentBodyParagraphProperties;
	}
	
	export interface DocumentBodyParagraphProperties { 
		"fontSize"?: string;
		"fontType"?: string;
		"textColor"?: string;
		"backgroundColor"?: string;
		"align"?: string;
		"indentation"?: number;
	}
	
	export interface DocumentBodyParagraphWithHighlight { 
		"blocks": Array<Models.DocumentContentBlockWithHighlight>;
		"properties"?: Models.DocumentBodyParagraphProperties;
	}
	
	export interface DocumentBodyTable { 
		"rows": Array<Models.DocumentBodyTableRowBlock>;
		"properties"?: Models.DocumentBodyTableProperties;
	}
	
	export interface DocumentBodyTableCaptionBlock { 
		"blocks": Array<Models.DocumentBodyTableCaptionItem>;
	}
	
	export interface DocumentBodyTableCaptionItem { 
		"type": string;
		"text"?: Models.DocumentText;
		"paragraph"?: Models.DocumentBodyParagraph;
		"image"?: Models.DocumentBodyImage;
		"video"?: Models.DocumentBodyVideo;
		"list"?: Models.DocumentBodyList;
	}
	
	export interface DocumentBodyTableCellBlock { 
		"blocks": Array<Models.DocumentTableContentBlock>;
		"properties"?: Models.DocumentBodyTableCellBlockProperties;
	}
	
	export interface DocumentBodyTableCellBlockProperties { 
		"cellType"?: string;
		"width"?: number;
		"height"?: number;
		"horizontalAlign"?: string;
		"verticalAlign"?: string;
		"borderWidth"?: number;
		"borderStyle"?: string;
		"borderColor"?: string;
		"backgroundColor"?: string;
		"scope"?: string;
		"colSpan"?: number;
		"rowSpan"?: number;
	}
	
	export interface DocumentBodyTableProperties { 
		"width"?: number;
		"height"?: number;
		"cellSpacing"?: number;
		"cellPadding"?: number;
		"borderWidth"?: number;
		"alignment"?: string;
		"borderStyle"?: string;
		"borderColor"?: string;
		"backgroundColor"?: string;
		"caption"?: Models.DocumentBodyTableCaptionBlock;
	}
	
	export interface DocumentBodyTableRowBlock { 
		"cells": Array<Models.DocumentBodyTableCellBlock>;
		"properties"?: Models.DocumentBodyTableRowBlockProperties;
	}
	
	export interface DocumentBodyTableRowBlockProperties { 
		"rowType"?: string;
		"alignment"?: string;
		"height"?: number;
		"borderStyle"?: string;
		"borderColor"?: string;
		"backgroundColor"?: string;
	}
	
	export interface DocumentBodyVideo { 
		"url": string;
		"properties"?: Models.DocumentBodyVideoProperties;
	}
	
	export interface DocumentBodyVideoProperties { 
		"backgroundColor"?: string;
		"align"?: string;
		"indentation"?: number;
	}
	
	export interface DocumentBodyWithHighlight { 
		"blocks": Array<Models.DocumentBodyBlockWithHighlight>;
	}
	
	export interface DocumentCategoryInput { 
		"id": string;
	}
	
	export interface DocumentContentBlock { 
		"type": string;
		"text"?: Models.DocumentText;
		"image"?: Models.DocumentBodyImage;
		"video"?: Models.DocumentBodyVideo;
	}
	
	export interface DocumentContentBlockWithHighlight { 
		"type": string;
		"text"?: Models.DocumentText;
		"image"?: Models.DocumentBodyImage;
		"video"?: Models.DocumentBodyVideo;
		"answerHighlight"?: Models.DocumentContentHighlightIndex;
	}
	
	export interface DocumentContentHighlightIndex { 
		"startIndex"?: number;
		"endIndex"?: number;
	}
	
	export interface DocumentEntityListing { 
		"entities"?: Array<Models.Document>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DocumentFaq { 
		"question": string;
		"answer": string;
		"alternatives"?: Array<string>;
	}
	
	export interface DocumentListContentBlock { 
		"type": string;
		"text"?: Models.DocumentText;
		"image"?: Models.DocumentBodyImage;
		"list"?: Models.DocumentBodyList;
		"video"?: Models.DocumentBodyVideo;
	}
	
	export interface DocumentListing { 
		"entities"?: Array<Models.KnowledgeDocument>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface DocumentQuery { 
		"clauses": Array<Models.DocumentQueryClause>;
		"operator": string;
	}
	
	export interface DocumentQueryClause { 
		"operator": string;
		"predicates": Array<Models.DocumentQueryPredicate>;
	}
	
	export interface DocumentQueryInterval { 
		"field"?: string;
		"value"?: string;
	}
	
	export interface DocumentQueryPredicate { 
		"fields": Array<string>;
		"values": Array<string>;
		"type": string;
	}
	
	export interface DocumentReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface DocumentTableContentBlock { 
		"type": string;
		"paragraph"?: Models.DocumentBodyParagraph;
		"text"?: Models.DocumentText;
		"image"?: Models.DocumentBodyImage;
		"video"?: Models.DocumentBodyVideo;
		"list"?: Models.DocumentBodyList;
		"table"?: Models.DocumentBodyTable;
	}
	
	export interface DocumentText { 
		"text": string;
		"marks"?: Array<string>;
		"hyperlink"?: string;
		"properties"?: Models.DocumentTextProperties;
	}
	
	export interface DocumentTextProperties { 
		"fontSize"?: string;
		"textColor"?: string;
		"backgroundColor"?: string;
	}
	
	export interface DocumentThumbnail { 
		"resolution"?: string;
		"imageUri"?: string;
		"height"?: number;
		"width"?: number;
	}
	
	export interface DocumentUpdate { 
		"changeNumber"?: number;
		"name": string;
		"read"?: boolean;
		"addTags"?: Array<string>;
		"removeTags"?: Array<string>;
		"addTagIds"?: Array<string>;
		"removeTagIds"?: Array<string>;
		"updateAttributes"?: Array<Models.DocumentAttribute>;
		"removeAttributes"?: Array<string>;
	}
	
	export interface DocumentUpload { 
		"name": string;
		"workspace": Models.DomainEntityRef;
		"tags"?: Array<string>;
		"tagIds"?: Array<string>;
	}
	
	export interface DocumentVariation { 
		"id"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"documentVersion"?: Models.AddressableEntityRef;
		"contexts": Array<Models.DocumentVariationContext>;
		"document"?: Models.KnowledgeDocumentReference;
		"priority"?: number;
		"name"?: string;
		"body"?: Models.DocumentBody;
		"selfUri"?: string;
	}
	
	export interface DocumentVariationAnswer { 
		"id"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"documentVersion"?: Models.AddressableEntityRef;
		"contexts": Array<Models.DocumentVariationContext>;
		"document"?: Models.KnowledgeDocumentReference;
		"priority"?: number;
		"name"?: string;
		"body"?: Models.DocumentBodyWithHighlight;
		"selfUri"?: string;
	}
	
	export interface DocumentVariationContext { 
		"context": Models.KnowledgeContextReference;
		"values": Array<Models.KnowledgeContextValueReference>;
	}
	
	export interface DocumentVariationListing { 
		"entities"?: Array<Models.DocumentVariation>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface DocumentationResult { 
		"id": number;
		"categories"?: Array<number>;
		"description"?: string;
		"content"?: string;
		"excerpt"?: string;
		"link"?: string;
		"modified"?: string;
		"name"?: string;
		"service"?: Array<number>;
		"slug"?: string;
		"title"?: string;
		"get_type"?: string;
		"facet_feature"?: Array<number>;
		"facet_role"?: Array<number>;
		"facet_service"?: Array<number>;
		"faq_categories"?: Array<number>;
		"releasenote_category"?: Array<number>;
		"releasenote_tag"?: Array<number>;
		"service-area"?: Array<number>;
		"video_categories"?: Array<number>;
	}
	
	export interface DocumentationSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.DocumentationSearchCriteria>;
		"dateFormat"?: string;
		"type": string;
		"fields"?: Array<string>;
	}
	
	export interface DocumentationSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"query"?: Array<Models.DocumentationSearchCriteria>;
	}
	
	export interface DocumentationSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.DocumentationResult>;
	}
	
	export interface DocumentationV2SearchAggregation { 
		"field"?: string;
		"name"?: string;
		"type"?: string;
		"value"?: string;
		"size"?: number;
		"order"?: Array<string>;
	}
	
	export interface DocumentationV2SearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.DocumentationV2SearchCriteria>;
		"dateFormat"?: string;
		"type"?: string;
		"fields"?: Array<string>;
	}
	
	export interface DocumentationV2SearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"types": Array<string>;
		"query"?: Array<Models.DocumentationV2SearchCriteria>;
		"aggregations"?: Array<Models.DocumentationV2SearchAggregation>;
	}
	
	export interface DomainCapabilities { 
		"enabled"?: boolean;
		"dhcp"?: boolean;
		"metric"?: number;
		"autoMetric"?: boolean;
		"supportsMetric"?: boolean;
		"pingEnabled"?: boolean;
	}
	
	export interface DomainCertificateAuthority { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"certificate": string;
		"type": string;
		"services": Array<string>;
		"certificateDetails"?: Array<Models.CertificateDetails>;
		"selfUri"?: string;
	}
	
	export interface DomainEdgeSoftwareUpdateDto { 
		"version": Models.DomainEdgeSoftwareVersionDto;
		"maxDownloadRate"?: number;
		"downloadStartTime"?: string;
		"executeStartTime"?: string;
		"executeStopTime"?: string;
		"executeOnIdle"?: boolean;
		"status"?: string;
		"edgeUri"?: string;
		"callDrainingWaitTimeSeconds"?: number;
		"current"?: boolean;
	}
	
	export interface DomainEdgeSoftwareVersionDto { 
		"id"?: string;
		"name"?: string;
		"edgeVersion"?: string;
		"publishDate"?: string;
		"edgeUri"?: string;
		"latestRelease"?: boolean;
		"current"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DomainEdgeSoftwareVersionDtoEntityListing { 
		"entities"?: Array<Models.DomainEdgeSoftwareVersionDto>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DomainEntity { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface DomainEntityListing { 
		"entities"?: Array<Models.DomainEntity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DomainEntityListingEvaluationForm { 
		"entities"?: Array<Models.EvaluationForm>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DomainEntityListingQueryResult { 
		"entities"?: Array<Models.QueryResult>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DomainEntityListingSurveyForm { 
		"entities"?: Array<Models.SurveyForm>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface DomainEntityRef { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface DomainLogicalInterface { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"edgeUri"?: string;
		"edgeAssignedId"?: string;
		"friendlyName": string;
		"vlanTagId"?: number;
		"hardwareAddress": string;
		"physicalAdapterId": string;
		"ifStatus"?: string;
		"interfaceType"?: string;
		"publicNatAddressIpV4"?: string;
		"publicNatAddressIpV6"?: string;
		"routes"?: Array<Models.DomainNetworkRoute>;
		"addresses"?: Array<Models.DomainNetworkAddress>;
		"ipv4Capabilities"?: Models.DomainCapabilities;
		"ipv6Capabilities"?: Models.DomainCapabilities;
		"currentState"?: string;
		"lastModifiedUserId"?: string;
		"lastModifiedCorrelationId"?: string;
		"commandResponses"?: Array<Models.DomainNetworkCommandResponse>;
		"inheritPhoneTrunkBasesIPv4"?: boolean;
		"inheritPhoneTrunkBasesIPv6"?: boolean;
		"useForInternalEdgeCommunication"?: boolean;
		"useForIndirectEdgeCommunication"?: boolean;
		"useForCloudProxyEdgeCommunication"?: boolean;
		"useForWanInterface"?: boolean;
		"externalTrunkBaseAssignments"?: Array<Models.TrunkBaseAssignment>;
		"phoneTrunkBaseAssignments"?: Array<Models.TrunkBaseAssignment>;
		"traceEnabled"?: boolean;
		"startDate"?: string;
		"endDate"?: string;
		"selfUri"?: string;
	}
	
	export interface DomainNetworkAddress { 
		"type"?: string;
		"address"?: string;
		"persistent"?: boolean;
		"family"?: number;
	}
	
	export interface DomainNetworkCommandResponse { 
		"correlationId"?: string;
		"commandName"?: string;
		"acknowledged"?: boolean;
		"errorInfo"?: Models.ErrorDetails;
	}
	
	export interface DomainNetworkRoute { 
		"prefix"?: string;
		"nexthop"?: string;
		"persistent"?: boolean;
		"metric"?: number;
		"family"?: number;
	}
	
	export interface DomainOrgRoleDifference { 
		"removedPermissionPolicies"?: Array<Models.DomainPermissionPolicy>;
		"addedPermissionPolicies"?: Array<Models.DomainPermissionPolicy>;
		"samePermissionPolicies"?: Array<Models.DomainPermissionPolicy>;
		"userOrgRole"?: Models.DomainOrganizationRole;
		"roleFromDefault"?: Models.DomainOrganizationRole;
	}
	
	export interface DomainOrganizationProduct { 
		"id"?: string;
	}
	
	export interface DomainOrganizationRole { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"defaultRoleId"?: string;
		"permissions"?: Array<string>;
		"unusedPermissions"?: Array<string>;
		"permissionPolicies"?: Array<Models.DomainPermissionPolicy>;
		"userCount"?: number;
		"roleNeedsUpdate"?: boolean;
		"base"?: boolean;
		"default"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DomainOrganizationRoleCreate { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"defaultRoleId"?: string;
		"permissions"?: Array<string>;
		"unusedPermissions"?: Array<string>;
		"permissionPolicies"?: Array<Models.DomainPermissionPolicy>;
		"userCount"?: number;
		"roleNeedsUpdate"?: boolean;
		"base"?: boolean;
		"default"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DomainOrganizationRoleUpdate { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"defaultRoleId"?: string;
		"permissions"?: Array<string>;
		"unusedPermissions"?: Array<string>;
		"permissionPolicies"?: Array<Models.DomainPermissionPolicy>;
		"userCount"?: number;
		"roleNeedsUpdate"?: boolean;
		"base"?: boolean;
		"default"?: boolean;
		"selfUri"?: string;
	}
	
	export interface DomainPermission { 
		"domain"?: string;
		"entityType"?: string;
		"action"?: string;
		"label"?: string;
		"allowsConditions"?: boolean;
		"divisionAware"?: boolean;
	}
	
	export interface DomainPermissionCollection { 
		"id"?: string;
		"name"?: string;
		"domain"?: string;
		"permissionMap"?: { [key: string]: Array<Models.DomainPermission>; };
		"selfUri"?: string;
	}
	
	export interface DomainPermissionPolicy { 
		"domain"?: string;
		"entityName"?: string;
		"policyName"?: string;
		"policyDescription"?: string;
		"actionSet"?: Array<string>;
		"namedResources"?: Array<string>;
		"allowConditions"?: boolean;
		"resourceConditionNode"?: Models.DomainResourceConditionNode;
	}
	
	export interface DomainPhysicalCapabilities { 
		"vlan"?: boolean;
		"team"?: boolean;
	}
	
	export interface DomainPhysicalInterface { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"edgeUri"?: string;
		"friendlyName"?: string;
		"hardwareAddress"?: string;
		"portLabel"?: string;
		"physicalCapabilities"?: Models.DomainPhysicalCapabilities;
		"selfUri"?: string;
	}
	
	export interface DomainResourceConditionNode { 
		"variableName"?: string;
		"operator"?: string;
		"operands"?: Array<Models.DomainResourceConditionValue>;
		"conjunction"?: string;
		"terms"?: Array<Models.DomainResourceConditionNode>;
	}
	
	export interface DomainResourceConditionValue { 
		"user"?: Models.User;
		"queue"?: Models.Queue;
		"value"?: string;
		"type"?: string;
	}
	
	export interface DomainRole { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface DownloadResponse { 
		"contentLocationUri"?: string;
		"imageUri"?: string;
		"thumbnails"?: Array<Models.DocumentThumbnail>;
	}
	
	export interface Draft { 
		"id"?: string;
		"name": string;
		"miner"?: Models.Miner;
		"intents"?: Array<Models.DraftIntents>;
		"topics"?: Array<Models.DraftTopics>;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface DraftIntents { 
		"id": string;
		"name": string;
		"utterances": Array<string>;
		"selfUri"?: string;
	}
	
	export interface DraftListing { 
		"entities"?: Array<Models.Draft>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface DraftManipulationRequest { 
		"translate"?: Models.HistoryHeadersTranslation;
		"draftType"?: string;
	}
	
	export interface DraftRequest { 
		"intents"?: Array<Models.DraftIntents>;
		"topics"?: Array<Models.DraftTopicRequest>;
	}
	
	export interface DraftTopicRequest { 
		"id": string;
		"name": string;
		"phrases": Array<string>;
		"selfUri"?: string;
	}
	
	export interface DraftTopics { 
		"id": string;
		"name"?: string;
		"miner"?: Models.Miner;
		"conversationCount"?: number;
		"conversationPercent"?: number;
		"utteranceCount"?: number;
		"phraseCount"?: number;
		"phrases": Array<string>;
		"selfUri"?: string;
	}
	
	export interface DraftValidationResult { 
		"valid"?: boolean;
		"errors"?: Array<Models.ErrorBody>;
	}
	
	export interface DurationCondition { 
		"durationTarget"?: string;
		"durationOperator"?: string;
		"durationRange"?: string;
		"durationMode"?: string;
	}
	
	export interface DynamicContactQueueingSettings { 
		"sort"?: boolean;
	}
	
	export interface DynamicGroupDefinition { 
		"group": Models.AddressableEntityRef;
		"dateModified": string;
		"query": Models.DynamicGroupQuery;
		"selfUri"?: string;
	}
	
	export interface DynamicGroupLanguageSkillCondition { 
		"languageSkill": string;
		"comparator": string;
		"proficiency": number;
		"childConditions"?: Array<Models.DynamicGroupSkillCondition>;
	}
	
	export interface DynamicGroupQuery { 
		"skillConditions": Array<Models.DynamicGroupSkillCondition>;
	}
	
	export interface DynamicGroupQueryPreview { 
		"userCount"?: number;
	}
	
	export interface DynamicGroupRoutingSkillCondition { 
		"routingSkill": string;
		"comparator": string;
		"proficiency": number;
		"childConditions"?: Array<Models.DynamicGroupSkillCondition>;
	}
	
	export interface DynamicGroupSkillCondition { 
		"routingSkillConditions": Array<Models.DynamicGroupRoutingSkillCondition>;
		"languageSkillConditions": Array<Models.DynamicGroupLanguageSkillCondition>;
		"operation": string;
	}
	
	export interface DynamicLineBalancingSettings { 
		"enabled"?: boolean;
		"relativeWeight"?: number;
	}
	
	export interface Edge { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"interfaces"?: Array<Models.EdgeInterface>;
		"make"?: string;
		"model"?: string;
		"apiVersion"?: string;
		"softwareVersion"?: string;
		"softwareVersionTimestamp"?: string;
		"softwareVersionPlatform"?: string;
		"softwareVersionConfiguration"?: string;
		"fullSoftwareVersion"?: string;
		"pairingId"?: string;
		"fingerprint"?: string;
		"fingerprintHint"?: string;
		"currentVersion"?: string;
		"stagedVersion"?: string;
		"patch"?: string;
		"statusCode"?: string;
		"edgeGroup"?: Models.EdgeGroup;
		"site"?: Models.Site;
		"softwareStatus"?: Models.DomainEdgeSoftwareUpdateDto;
		"onlineStatus"?: string;
		"serialNumber"?: string;
		"physicalEdge"?: boolean;
		"managed"?: boolean;
		"edgeDeploymentType"?: string;
		"certType"?: string;
		"callDrainingState"?: string;
		"conversationCount"?: number;
		"proxy"?: string;
		"offlineConfigCalled"?: boolean;
		"osName"?: string;
		"selfUri"?: string;
	}
	
	export interface EdgeAutoUpdateConfig { 
		"timeZone": string;
		"rrule": string;
		"start": string;
		"end": string;
	}
	
	export interface EdgeChangeTopicEdge { 
		"id"?: string;
		"onlineStatus"?: string;
	}
	
	export interface EdgeConnectionInfo { 
		"id"?: string;
		"name"?: string;
		"interfaceName"?: string;
		"interfaceIpAddress"?: string;
		"connectionErrors"?: Array<string>;
		"site"?: Models.AddressableEntityRef;
		"selfUri"?: string;
	}
	
	export interface EdgeEntityListing { 
		"entities"?: Array<Models.Edge>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EdgeGroup { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"managed"?: boolean;
		"hybrid"?: boolean;
		"edgeTrunkBaseAssignment": Models.TrunkBaseAssignment;
		"phoneTrunkBases": Array<Models.TrunkBase>;
		"selfUri"?: string;
	}
	
	export interface EdgeGroupEntityListing { 
		"entities"?: Array<Models.EdgeGroup>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EdgeInterface { 
		"type"?: string;
		"ipAddress"?: string;
		"name"?: string;
		"macAddress"?: string;
		"ifName"?: string;
		"endpoints"?: Array<Models.DomainEntityRef>;
		"lineTypes"?: Array<string>;
		"addressFamilyId"?: string;
	}
	
	export interface EdgeLogicalInterfacesChangeTopicDomainLogicalInterfaceChange { 
		"id"?: string;
		"errorInfo"?: Models.EdgeLogicalInterfacesChangeTopicErrorInfo;
	}
	
	export interface EdgeLogicalInterfacesChangeTopicErrorInfo { 
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"code"?: string;
	}
	
	export interface EdgeLogsJob { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"files"?: Array<Models.EdgeLogsJobFile>;
		"selfUri"?: string;
	}
	
	export interface EdgeLogsJobFile { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"timeCreated"?: string;
		"timeModified"?: string;
		"sizeBytes"?: number;
		"uploadStatus"?: string;
		"edgePath"?: string;
		"downloadId"?: string;
		"selfUri"?: string;
	}
	
	export interface EdgeLogsJobRequest { 
		"path"?: string;
		"query"?: string;
		"recurse"?: boolean;
	}
	
	export interface EdgeLogsJobResponse { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"selfUri"?: string;
	}
	
	export interface EdgeLogsJobUploadRequest { 
		"fileIds": Array<string>;
	}
	
	export interface EdgeMetrics { 
		"edge"?: Models.DomainEntityRef;
		"eventTime"?: string;
		"upTimeMsec"?: number;
		"processors"?: Array<Models.EdgeMetricsProcessor>;
		"memory"?: Array<Models.EdgeMetricsMemory>;
		"disks"?: Array<Models.EdgeMetricsDisk>;
		"subsystems"?: Array<Models.EdgeMetricsSubsystem>;
		"networks"?: Array<Models.EdgeMetricsNetwork>;
	}
	
	export interface EdgeMetricsDisk { 
		"availableBytes"?: number;
		"partitionName"?: string;
		"totalBytes"?: number;
	}
	
	export interface EdgeMetricsMemory { 
		"availableBytes"?: number;
		"type"?: string;
		"totalBytes"?: number;
	}
	
	export interface EdgeMetricsNetwork { 
		"ifname"?: string;
		"sentBytesPerSec"?: number;
		"receivedBytesPerSec"?: number;
		"bandwidthBitsPerSec"?: number;
		"utilizationPct"?: number;
	}
	
	export interface EdgeMetricsProcessor { 
		"activeTimePct"?: number;
		"cpuId"?: string;
		"idleTimePct"?: number;
		"privilegedTimePct"?: number;
		"userTimePct"?: number;
	}
	
	export interface EdgeMetricsSubsystem { 
		"delayMs"?: number;
		"processName"?: string;
		"mediaSubsystem"?: Models.EdgeMetricsSubsystem;
	}
	
	export interface EdgeMetricsTopicEdgeMetricDisk { 
		"partitionName"?: string;
		"availableBytes"?: number;
		"totalBytes"?: number;
	}
	
	export interface EdgeMetricsTopicEdgeMetricMemory { 
		"type"?: string;
		"availableBytes"?: number;
		"totalBytes"?: number;
	}
	
	export interface EdgeMetricsTopicEdgeMetricNetworks { 
		"ifname"?: string;
		"sentBytesPerSec"?: number;
		"receivedBytesPerSec"?: number;
		"bandwidthBitsPerSec"?: number;
		"utilizationPct"?: number;
	}
	
	export interface EdgeMetricsTopicEdgeMetricProcessor { 
		"cpuId"?: string;
		"idleTimePct"?: number;
		"activeTimePct"?: number;
		"privilegedTimePct"?: number;
		"userTimePct"?: number;
	}
	
	export interface EdgeMetricsTopicEdgeMetricSubsystem { 
		"processName"?: string;
		"delayMs"?: number;
		"mediaSubsystem"?: Models.EdgeMetricsTopicEdgeMetricSubsystemMedia;
	}
	
	export interface EdgeMetricsTopicEdgeMetricSubsystemMedia { 
		"processName"?: string;
		"delayMs"?: number;
	}
	
	export interface EdgeMetricsTopicEdgeMetrics { 
		"edge"?: Models.EdgeMetricsTopicUriReference;
		"eventTime"?: string;
		"upTimeMsec"?: number;
		"processors"?: Array<Models.EdgeMetricsTopicEdgeMetricProcessor>;
		"memory"?: Array<Models.EdgeMetricsTopicEdgeMetricMemory>;
		"disks"?: Array<Models.EdgeMetricsTopicEdgeMetricDisk>;
		"subsystems"?: Array<Models.EdgeMetricsTopicEdgeMetricSubsystem>;
		"networks"?: Array<Models.EdgeMetricsTopicEdgeMetricNetworks>;
	}
	
	export interface EdgeMetricsTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface EdgeNetworkDiagnostic { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EdgeNetworkDiagnosticRequest { 
		"host": string;
	}
	
	export interface EdgeNetworkDiagnosticResponse { 
		"commandCorrelationId"?: string;
		"diagnostics"?: string;
	}
	
	export interface EdgeRebootParameters { 
		"callDrainingWaitTimeSeconds"?: number;
	}
	
	export interface EdgeServiceStateRequest { 
		"inService": boolean;
		"callDrainingWaitTimeSeconds"?: number;
	}
	
	export interface EdgeSoftwareUpdateTopicDomainEdgeSoftwareUpdate { 
		"id"?: string;
		"status"?: string;
		"downloadStartTime"?: string;
		"executeStartTime"?: string;
		"executeStopTime"?: string;
	}
	
	export interface EdgeTrunkBase { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"trunkMetabase": Models.DomainEntityRef;
		"properties"?: { [key: string]: object; };
		"trunkType": string;
		"site"?: Models.DomainEntityRef;
		"inboundSite"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface EdgeVersionInformation { 
		"softwareVersion"?: string;
	}
	
	export interface EdgeVersionReport { 
		"oldestVersion"?: Models.EdgeVersionInformation;
		"newestVersion"?: Models.EdgeVersionInformation;
	}
	
	export interface Education { 
		"school"?: string;
		"fieldOfStudy"?: string;
		"notes"?: string;
		"dateStart"?: string;
		"dateEnd"?: string;
	}
	
	export interface EffectiveConfiguration { 
		"properties": { [key: string]: object; };
		"advanced": { [key: string]: object; };
		"name": string;
		"notes": string;
		"credentials": { [key: string]: Models.CredentialInfo; };
	}
	
	export interface Email { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"held"?: boolean;
		"subject"?: string;
		"messagesSent"?: number;
		"segments"?: Array<Models.Segment>;
		"direction"?: string;
		"recordingId"?: string;
		"errorInfo"?: Models.ErrorBody;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"autoGenerated"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"messageId"?: string;
		"draftAttachments"?: Array<Models.Attachment>;
		"spam"?: boolean;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
	}
	
	export interface EmailAddress { 
		"email"?: string;
		"name"?: string;
	}
	
	export interface EmailAttachment { 
		"name"?: string;
		"contentPath"?: string;
		"contentType"?: string;
		"attachmentId"?: string;
		"contentLength"?: number;
	}
	
	export interface EmailBeginTransmittingEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
	}
	
	export interface EmailCampaignSchedule { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"intervals": Array<Models.ScheduleInterval>;
		"timeZone"?: string;
		"emailCampaign": Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface EmailCampaignScheduleEntityListing { 
		"entities"?: Array<Models.EmailCampaignSchedule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EmailColumn { 
		"columnName": string;
		"type": string;
		"contactableTimeColumn"?: string;
	}
	
	export interface EmailCommunicationAnsweredEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
	}
	
	export interface EmailCommunicationDispositionAppliedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
	}
	
	export interface EmailCommunicationEndedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"disconnectType": string;
	}
	
	export interface EmailCommunicationRepliedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
	}
	
	export interface EmailConfig { 
		"emailColumns": Array<string>;
		"contentTemplate"?: Models.DomainEntityRef;
		"fromAddress": Models.FromEmailAddress;
		"replyToAddress"?: Models.ReplyToEmailAddress;
	}
	
	export interface EmailConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.EmailMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
	}
	
	export interface EmailConversationEntityListing { 
		"entities"?: Array<Models.EmailConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EmailEndTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"commandId": string;
		"finalState": string;
		"objectCommunicationId": string;
	}
	
	export interface EmailErrorInfo { 
		"message"?: string;
		"code"?: string;
	}
	
	export interface EmailExternalEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"displayName"?: string;
		"includeMessage"?: boolean;
		"initialConfiguration": Models.EmailInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface EmailFlowEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"initialConfiguration": Models.EmailInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface EmailHoldUpdatedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"held": boolean;
	}
	
	export interface EmailInitialConfiguration { 
		"to": string;
		"from": string;
		"cc"?: Array<string>;
		"bcc"?: Array<string>;
		"subject"?: string;
		"previousEmailId"?: string;
		"held"?: boolean;
		"alerting"?: boolean;
		"inbound"?: boolean;
		"invitedBy"?: string;
		"additionalInfo"?: { [key: string]: string; };
	}
	
	export interface EmailMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"mediaRoles"?: Array<string>;
		"user"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"team"?: Models.DomainEntityRef;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ErrorInfo;
		"script"?: Models.DomainEntityRef;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.DomainEntityRef;
		"externalOrganization"?: Models.DomainEntityRef;
		"wrapup"?: Models.Wrapup;
		"peer"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.JourneyContext;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"subject"?: string;
		"messagesSent"?: number;
		"autoGenerated"?: boolean;
		"draftAttachments"?: Array<Models.Attachment>;
		"spam"?: boolean;
		"messageId"?: string;
	}
	
	export interface EmailMediaPolicy { 
		"actions"?: Models.PolicyActions;
		"conditions"?: Models.EmailMediaPolicyConditions;
	}
	
	export interface EmailMediaPolicyConditions { 
		"forUsers"?: Array<Models.User>;
		"dateRanges"?: Array<string>;
		"forQueues"?: Array<Models.Queue>;
		"wrapupCodes"?: Array<Models.WrapupCode>;
		"languages"?: Array<Models.Language>;
		"timeAllowed"?: Models.TimeAllowed;
		"teams"?: Array<Models.Team>;
		"customerParticipation"?: string;
	}
	
	export interface EmailMessage { 
		"id"?: string;
		"name"?: string;
		"to": Array<Models.EmailAddress>;
		"cc"?: Array<Models.EmailAddress>;
		"bcc"?: Array<Models.EmailAddress>;
		"from": Models.EmailAddress;
		"replyTo"?: Models.EmailAddress;
		"subject"?: string;
		"attachments"?: Array<Models.Attachment>;
		"textBody": string;
		"htmlBody"?: string;
		"time"?: string;
		"historyIncluded"?: boolean;
		"state"?: string;
		"draftType"?: string;
		"emailSizeBytes"?: number;
		"maxEmailSizeBytes"?: number;
		"selfUri"?: string;
	}
	
	export interface EmailMessagePreview { 
		"id"?: string;
		"name"?: string;
		"to": Array<Models.EmailAddress>;
		"cc"?: Array<Models.EmailAddress>;
		"bcc"?: Array<Models.EmailAddress>;
		"from": Models.EmailAddress;
		"replyTo"?: Models.EmailAddress;
		"subject"?: string;
		"attachments"?: Array<Models.Attachment>;
		"textBodyPreview"?: string;
		"time"?: string;
		"historyIncluded"?: boolean;
		"state"?: string;
		"draftType"?: string;
		"emailSizeBytes"?: number;
		"maxEmailSizeBytes"?: number;
		"selfUri"?: string;
	}
	
	export interface EmailMessagePreviewListing { 
		"entities"?: Array<Models.EmailMessagePreview>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EmailMessageReply { 
		"to": Array<Models.EmailAddress>;
		"cc"?: Array<Models.EmailAddress>;
		"bcc"?: Array<Models.EmailAddress>;
		"from": Models.EmailAddress;
		"replyTo"?: Models.EmailAddress;
		"subject"?: string;
		"attachments"?: Array<Models.Attachment>;
		"textBody": string;
		"htmlBody"?: string;
		"time"?: string;
		"historyIncluded"?: boolean;
		"emailSizeBytes"?: number;
		"maxEmailSizeBytes"?: number;
	}
	
	export interface EmailOutboundDomainResult { 
		"dnsCnameBounceRecord"?: Models.DnsRecordEntry;
		"dnsTxtSendingRecord"?: Models.DnsRecordEntry;
		"domainName"?: string;
		"senderStatus"?: string;
		"senderType"?: string;
	}
	
	export interface EmailProgressTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"commandId": string;
		"objectCommunicationId": string;
		"destinationCommunicationId": string;
	}
	
	export interface EmailRoutingEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"queueId": string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"label"?: string;
		"initialConfiguration": Models.EmailInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface EmailRoutingTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationQueueId": string;
		"languageId"?: string;
		"skillIds"?: Array<string>;
	}
	
	export interface EmailSettings { 
		"multipleRouteDestinationsOnInboundEmailEnabled"?: boolean;
	}
	
	export interface EmailSetup { 
		"rootDomain"?: string;
	}
	
	export interface EmailUserEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"userId": string;
		"queueId"?: string;
		"afterCallWorkRequired"?: boolean;
		"initialConfiguration": Models.EmailInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface EmailUserTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationUserId": string;
	}
	
	export interface EmailsSettings { 
		"sendingSizeLimit"?: number;
	}
	
	export interface EmbeddedIntegration { 
		"enableWhitelist"?: boolean;
		"domainWhitelist"?: Array<string>;
	}
	
	export interface EmergencyCallFlow { 
		"emergencyFlow"?: Models.DomainEntityRef;
		"ivrs"?: Array<Models.DomainEntityRef>;
	}
	
	export interface EmergencyGroup { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"enabled"?: boolean;
		"emergencyCallFlows"?: Array<Models.EmergencyCallFlow>;
		"selfUri"?: string;
	}
	
	export interface EmergencyGroupDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"selfUri"?: string;
	}
	
	export interface EmergencyGroupDivisionViewEntityListing { 
		"entities"?: Array<Models.EmergencyGroupDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EmergencyGroupListing { 
		"entities"?: Array<Models.EmergencyGroup>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EmergencyLocation { 
		"id"?: string;
		"name"?: string;
		"address": Models.LocationAddress;
		"did": string;
		"source": string;
		"selfUri"?: string;
	}
	
	export interface EmpathyScore { 
		"score"?: number;
		"userId"?: string;
	}
	
	export interface EmployerInfo { 
		"officialName"?: string;
		"employeeId"?: string;
		"employeeType"?: string;
		"dateHire"?: string;
	}
	
	export interface Empty { 
	}
	
	export interface EncryptionKey { 
		"id"?: string;
		"name"?: string;
		"createDate"?: string;
		"keydataSummary"?: string;
		"user"?: Models.User;
		"localEncryptionConfiguration"?: Models.LocalEncryptionConfiguration;
		"keyConfigurationType"?: string;
		"kmsKeyArn"?: string;
		"selfUri"?: string;
	}
	
	export interface EncryptionKeyEntityListing { 
		"entities"?: Array<Models.EncryptionKey>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EndConsultTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
	}
	
	export interface EndTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"commandId": string;
		"finalState": string;
		"objectCommunicationId": string;
	}
	
	export interface Endpoint { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"count"?: number;
		"properties"?: { [key: string]: object; };
		"schema": Models.DomainEntityRef;
		"enabled"?: boolean;
		"site"?: Models.DomainEntityRef;
		"dids"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface EngineIntegration { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface Entity { 
		"id"?: string;
	}
	
	export interface EntityChange { 
		"entityId"?: string;
		"entityName"?: string;
		"entityType"?: string;
		"oldValues"?: Array<string>;
		"newValues"?: Array<string>;
	}
	
	export interface EntityListing { 
		"entities"?: Array<object>;
	}
	
	export interface EntityReference { 
		"id": string;
	}
	
	export interface EntityTypeCriteria { 
		"key": string;
		"values": Array<string>;
		"shouldIgnoreCase": boolean;
		"operator": string;
		"entityType": string;
	}
	
	export interface Entry { 
		"value"?: string;
		"count"?: number;
	}
	
	export interface ErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.Detail>;
		"errors"?: Array<Models.ErrorBody>;
		"limit"?: Models.Limit;
	}
	
	export interface ErrorDetails { 
		"status"?: number;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"code"?: string;
		"contextId"?: string;
		"nested"?: Models.ErrorDetails;
		"details"?: string;
	}
	
	export interface ErrorInfo { 
		"message"?: string;
		"code"?: string;
	}
	
	export interface EstimateAvailableFullDayTimeOffRequest { 
		"date": string;
		"requestedDurationMinutes"?: number;
	}
	
	export interface EstimateAvailableFullDayTimeOffResponse { 
		"date": string;
		"durationMinutes": number;
		"payableMinutes": number;
		"flexible": boolean;
	}
	
	export interface EstimateAvailablePartialDayTimeOffRequest { 
		"date": string;
		"requestedDurationMinutes"?: number;
	}
	
	export interface EstimateAvailablePartialDayTimeOffResponse { 
		"date": string;
		"durationMinutes": number;
		"payableMinutes": number;
		"flexible": boolean;
	}
	
	export interface EstimateAvailableTimeOffRequest { 
		"fullDayDates"?: Array<Models.EstimateAvailableFullDayTimeOffRequest>;
		"partialDayDates"?: Array<Models.EstimateAvailablePartialDayTimeOffRequest>;
		"activityCodeId": string;
		"paid": boolean;
	}
	
	export interface EstimateAvailableTimeOffResponse { 
		"fullDayDates"?: Array<Models.EstimateAvailableFullDayTimeOffResponse>;
		"partialDayDates"?: Array<Models.EstimateAvailablePartialDayTimeOffResponse>;
		"user": Models.UserReference;
		"activityCodeId": string;
		"paid": boolean;
	}
	
	export interface EstimateJobAsyncResponse { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EstimatedWaitTimePredictions { 
		"results": Array<Models.PredictionResults>;
	}
	
	export interface Evaluation { 
		"id"?: string;
		"name"?: string;
		"conversation"?: Models.ConversationReference;
		"evaluationForm"?: Models.EvaluationForm;
		"evaluator"?: Models.User;
		"agent"?: Models.User;
		"calibration"?: Models.Calibration;
		"status"?: string;
		"answers"?: Models.EvaluationScoringSet;
		"agentHasRead"?: boolean;
		"assignee"?: Models.User;
		"assigneeApplicable"?: boolean;
		"releaseDate"?: string;
		"assignedDate"?: string;
		"changedDate"?: string;
		"revisionCreatedDate"?: string;
		"queue"?: Models.Queue;
		"mediaType"?: Array<string>;
		"rescore"?: boolean;
		"conversationDate"?: string;
		"conversationEndDate"?: string;
		"neverRelease"?: boolean;
		"assigned"?: boolean;
		"dateAssigneeChanged"?: string;
		"resourceId"?: string;
		"resourceType"?: string;
		"redacted"?: boolean;
		"agentTeam"?: Models.Team;
		"isScoringIndex"?: boolean;
		"authorizedActions"?: Array<string>;
		"hasAssistanceFailed"?: boolean;
		"evaluationSource"?: Models.EvaluationSource;
		"selfUri"?: string;
	}
	
	export interface EvaluationAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface EvaluationAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.EvaluationAggregateQueryPredicate>;
	}
	
	export interface EvaluationAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.EvaluationAggregateQueryClause>;
		"predicates"?: Array<Models.EvaluationAggregateQueryPredicate>;
	}
	
	export interface EvaluationAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface EvaluationAggregateQueryResponse { 
		"results"?: Array<Models.EvaluationAggregateDataContainer>;
	}
	
	export interface EvaluationAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.EvaluationAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.EvaluationAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface EvaluationAggregationQueryMe { 
		"interval": string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"metrics": Array<string>;
		"alternateTimeDimension"?: string;
		"contextId"?: string;
	}
	
	export interface EvaluationAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface EvaluationAssignment { 
		"evaluationForm"?: Models.EvaluationForm;
		"user"?: Models.User;
	}
	
	export interface EvaluationAsyncAggregateQueryResponse { 
		"results"?: Array<Models.EvaluationAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface EvaluationAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.EvaluationAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.EvaluationAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface EvaluationCreateBody { 
		"id"?: string;
		"evaluationForm"?: Models.EvaluationCreateEvalForm;
		"evaluator"?: Models.EvaluationCreateUser;
		"agent"?: Models.EvaluationCreateUser;
		"agentHasRead"?: boolean;
		"answers"?: Models.EvaluationScoringSet;
		"calibration"?: Models.EvaluationCreateCalibration;
		"evaluationContextId"?: string;
		"conversation"?: Models.EvaluationCreateConversation;
		"resourceType"?: string;
		"evaluationSource"?: Models.EvaluationSource;
		"rescore"?: boolean;
		"queue"?: Models.EvaluationCreateQueue;
		"releaseDate"?: string;
		"status"?: string;
		"neverRelease"?: boolean;
		"dateAssigneeChanged"?: string;
		"assignee"?: Models.EvaluationCreateUser;
		"selfUri"?: string;
	}
	
	export interface EvaluationCreateCalibration { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluationCreateConversation { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluationCreateEvalForm { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluationCreateQueue { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluationCreateUser { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface EvaluationDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.EvaluationDetailQueryPredicate>;
	}
	
	export interface EvaluationDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.EvaluationDetailQueryClause>;
		"predicates"?: Array<Models.EvaluationDetailQueryPredicate>;
	}
	
	export interface EvaluationDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"metric"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface EvaluationEntityListing { 
		"entities"?: Array<Models.Evaluation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EvaluationForm { 
		"id"?: string;
		"name": string;
		"modifiedDate"?: string;
		"published"?: boolean;
		"contextId"?: string;
		"questionGroups": Array<Models.EvaluationQuestionGroup>;
		"publishedVersions"?: Models.DomainEntityListingEvaluationForm;
		"selfUri"?: string;
	}
	
	export interface EvaluationFormAndScoringSet { 
		"evaluationForm"?: Models.EvaluationForm;
		"answers"?: Models.EvaluationScoringSet;
	}
	
	export interface EvaluationFormResponse { 
		"id"?: string;
		"name": string;
		"modifiedDate"?: string;
		"published"?: boolean;
		"contextId"?: string;
		"questionGroups"?: Array<Models.EvaluationQuestionGroup>;
		"weightMode"?: string;
		"publishedVersions"?: Models.DomainEntityListingEvaluationForm;
		"selfUri"?: string;
	}
	
	export interface EvaluationFormResponseEntityListing { 
		"entities"?: Array<Models.EvaluationFormResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface EvaluationQualityV2TopicCalibration { 
		"id"?: string;
	}
	
	export interface EvaluationQualityV2TopicEvaluationReference { 
		"id"?: string;
	}
	
	export interface EvaluationQualityV2TopicEvaluationScoringSet { 
		"totalScore"?: number;
		"totalCriticalScore"?: number;
	}
	
	export interface EvaluationQualityV2TopicEvaluationSource { 
		"evaluationSourceType"?: string;
		"evaluationSourceId"?: string;
		"evaluationSourceName"?: string;
	}
	
	export interface EvaluationQualityV2TopicEvaluationV2 { 
		"id"?: string;
		"conversationId"?: string;
		"agent"?: Models.EvaluationQualityV2TopicUser;
		"evaluator"?: Models.EvaluationQualityV2TopicUser;
		"eventTime"?: string;
		"evaluationFormId"?: string;
		"formName"?: string;
		"scoringSet"?: Models.EvaluationQualityV2TopicEvaluationScoringSet;
		"contextId"?: string;
		"status"?: string;
		"agentHasRead"?: boolean;
		"releaseDate"?: string;
		"assignedDate"?: string;
		"changedDate"?: string;
		"eventType"?: string;
		"resourceId"?: string;
		"resourceType"?: string;
		"divisionIds"?: Array<string>;
		"rescore"?: boolean;
		"conversationDate"?: string;
		"mediaType"?: Array<string>;
		"calibration"?: Models.EvaluationQualityV2TopicCalibration;
		"evaluationSource"?: Models.EvaluationQualityV2TopicEvaluationSource;
		"assigneeUserId"?: string;
		"previousAssigneeUserId"?: string;
		"assigneeApplicable"?: boolean;
		"evaluationContextId"?: string;
		"disputeCount"?: number;
		"version"?: number;
		"previousStatus"?: string;
		"declinedReview"?: boolean;
		"retractedEvaluation"?: Models.EvaluationQualityV2TopicEvaluationReference;
		"rescoreCount"?: number;
		"evaluatorCommentHasUpdated"?: boolean;
		"agentCommentHasUpdated"?: boolean;
		"previousRescoreCount"?: number;
		"previousEvaluatorUserId"?: string;
	}
	
	export interface EvaluationQualityV2TopicUser { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface EvaluationQuestion { 
		"id"?: string;
		"text"?: string;
		"helpText"?: string;
		"type"?: string;
		"naEnabled"?: boolean;
		"commentsRequired"?: boolean;
		"visibilityCondition"?: Models.VisibilityCondition;
		"answerOptions"?: Array<Models.AnswerOption>;
		"isKill"?: boolean;
		"isCritical"?: boolean;
	}
	
	export interface EvaluationQuestionGroup { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"defaultAnswersToHighest"?: boolean;
		"defaultAnswersToNA"?: boolean;
		"naEnabled"?: boolean;
		"weight"?: number;
		"manualWeight"?: boolean;
		"questions"?: Array<Models.EvaluationQuestion>;
		"visibilityCondition"?: Models.VisibilityCondition;
	}
	
	export interface EvaluationQuestionGroupScore { 
		"questionGroupId"?: string;
		"totalScore"?: number;
		"maxTotalScore"?: number;
		"markedNA"?: boolean;
		"systemMarkedNA"?: boolean;
		"totalCriticalScore"?: number;
		"maxTotalCriticalScore"?: number;
		"totalNonCriticalScore"?: number;
		"maxTotalNonCriticalScore"?: number;
		"totalScoreUnweighted"?: number;
		"maxTotalScoreUnweighted"?: number;
		"totalCriticalScoreUnweighted"?: number;
		"maxTotalCriticalScoreUnweighted"?: number;
		"totalNonCriticalScoreUnweighted"?: number;
		"maxTotalNonCriticalScoreUnweighted"?: number;
		"questionScores"?: Array<Models.EvaluationQuestionScore>;
	}
	
	export interface EvaluationQuestionScore { 
		"questionId"?: string;
		"answerId"?: string;
		"score"?: number;
		"markedNA"?: boolean;
		"systemMarkedNA"?: boolean;
		"assistedAnswerId"?: string;
		"failedKillQuestion"?: boolean;
		"comments"?: string;
	}
	
	export interface EvaluationReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluationResponse { 
		"id"?: string;
		"name"?: string;
		"conversation"?: Models.ConversationReference;
		"evaluationForm"?: Models.EvaluationFormResponse;
		"evaluator"?: Models.User;
		"agent"?: Models.User;
		"calibration"?: Models.Calibration;
		"status"?: string;
		"answers"?: Models.EvaluationScoringSet;
		"agentHasRead"?: boolean;
		"assignee"?: Models.User;
		"assigneeApplicable"?: boolean;
		"releaseDate"?: string;
		"assignedDate"?: string;
		"changedDate"?: string;
		"queue"?: Models.Queue;
		"mediaType"?: Array<string>;
		"rescore"?: boolean;
		"conversationDate"?: string;
		"conversationEndDate"?: string;
		"neverRelease"?: boolean;
		"assigned"?: boolean;
		"dateAssigneeChanged"?: string;
		"resourceId"?: string;
		"resourceType"?: string;
		"redacted"?: boolean;
		"isScoringIndex"?: boolean;
		"authorizedActions"?: Array<string>;
		"hasAssistanceFailed"?: boolean;
		"evaluationSource"?: Models.EvaluationSource;
		"selfUri"?: string;
	}
	
	export interface EvaluationScoringSet { 
		"totalScore"?: number;
		"totalCriticalScore"?: number;
		"totalNonCriticalScore"?: number;
		"questionGroupScores"?: Array<Models.EvaluationQuestionGroupScore>;
		"anyFailedKillQuestions"?: boolean;
		"comments"?: string;
		"privateComments"?: string;
		"agentComments"?: string;
		"transcriptTopics"?: Array<Models.TranscriptTopic>;
	}
	
	export interface EvaluationSettings { 
	}
	
	export interface EvaluationSettingsAssignee { 
	}
	
	export interface EvaluationSource { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluationVersion { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface EvaluatorActivity { 
		"id"?: string;
		"name"?: string;
		"evaluator"?: Models.User;
		"numEvaluationsAssigned"?: number;
		"numEvaluationsStarted"?: number;
		"numEvaluationsCompleted"?: number;
		"numCalibrationsAssigned"?: number;
		"numCalibrationsStarted"?: number;
		"numCalibrationsCompleted"?: number;
		"numEvaluationsWithoutViewPermission"?: number;
		"selfUri"?: string;
	}
	
	export interface EvaluatorActivityEntityListing { 
		"entities"?: Array<Models.EvaluatorActivity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Event { 
		"id": string;
		"correlationId": string;
		"customerId"?: string;
		"customerIdType"?: string;
		"session": Models.EventSession;
		"eventType": string;
		"genericActionEvent"?: Models.GenericActionEvent;
		"outcomeAchievedEvent"?: Models.OutcomeAchievedEvent;
		"segmentAssignmentEvent"?: Models.SegmentAssignmentEvent;
		"webActionEvent"?: Models.WebActionEvent;
		"webEvent"?: Models.WebEvent;
		"appEvent"?: Models.AppEvent;
		"createdDate": string;
	}
	
	export interface EventAction { 
		"id": string;
		"state": string;
		"mediaType": string;
		"prompt": string;
		"createdDate": string;
	}
	
	export interface EventCondition { 
		"key": string;
		"values": Array<string>;
		"operator"?: string;
		"streamType": string;
		"sessionType": string;
		"eventName"?: string;
	}
	
	export interface EventDefinition { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
	}
	
	export interface EventDefinitionListing { 
		"entities"?: Array<Models.EventDefinition>;
	}
	
	export interface EventError { 
		"eventId"?: string;
		"message"?: string;
		"retryable"?: boolean;
	}
	
	export interface EventListing { 
		"entities"?: Array<Models.Event>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface EventLog { 
		"id"?: string;
		"name"?: string;
		"errorEntity"?: Models.DomainEntityRef;
		"relatedEntity"?: Models.DomainEntityRef;
		"timestamp"?: string;
		"level"?: string;
		"category"?: string;
		"correlationId"?: string;
		"eventMessage"?: Models.EventMessage;
		"selfUri"?: string;
	}
	
	export interface EventMessage { 
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: object; };
		"documentationUri"?: string;
		"resourceURIs"?: Array<string>;
	}
	
	export interface EventSession { 
		"id": string;
		"selfUri"?: string;
		"type": string;
	}
	
	export interface EventSetting { 
		"typing"?: Models.TypingSetting;
	}
	
	export interface ExecuteRecordingJobsQuery { 
		"state": string;
	}
	
	export interface ExecutionDataEntity { 
		"id"?: string;
		"downloadUri"?: string;
		"failed"?: boolean;
		"statusCode"?: string;
	}
	
	export interface ExecutionDataFlowSettingsResponse { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"modifiedBy"?: Models.UserReference;
		"modifiedByClient"?: Models.DomainEntityRef;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface ExecutionDataGlobalSettingsResponse { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"modifiedBy"?: Models.UserReference;
		"modifiedByClient"?: Models.DomainEntityRef;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface ExecutionDataRequest { 
		"ids": Array<string>;
	}
	
	export interface ExecutionDataSettingsRequest { 
		"enabled": boolean;
	}
	
	export interface ExpandableWebDeployment { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"allowAllDomains"?: boolean;
		"allowedDomains"?: Array<string>;
		"supportedContent"?: Models.SupportedContentReference;
		"snippet"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"lastModifiedUser"?: Models.AddressableEntityRef;
		"flow"?: Models.DomainEntityRef;
		"status"?: string;
		"configuration": Models.WebDeploymentConfigurationVersionResponse;
		"selfUri"?: string;
	}
	
	export interface ExpandableWebDeploymentEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.ExpandableWebDeployment>;
		"selfUri"?: string;
	}
	
	export interface ExpansionCriterium { 
		"type"?: string;
		"threshold"?: number;
	}
	
	export interface ExpiredEdgeListing { 
		"entities"?: Array<Models.DomainEntityRef>;
	}
	
	export interface ExportScriptRequest { 
		"fileName"?: string;
		"versionId"?: string;
	}
	
	export interface ExportScriptResponse { 
		"url"?: string;
	}
	
	export interface ExportUri { 
		"uri"?: string;
		"exportTimestamp"?: string;
	}
	
	export interface Extension { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"number"?: string;
		"owner"?: Models.DomainEntityRef;
		"extensionPool"?: Models.DomainEntityRef;
		"ownerType"?: string;
		"selfUri"?: string;
	}
	
	export interface ExtensionEntityListing { 
		"entities"?: Array<Models.Extension>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ExtensionPool { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"startNumber"?: string;
		"endNumber"?: string;
		"selfUri"?: string;
	}
	
	export interface ExtensionPoolDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"selfUri"?: string;
	}
	
	export interface ExtensionPoolDivisionViewEntityListing { 
		"entities"?: Array<Models.ExtensionPoolDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ExtensionPoolEntityListing { 
		"entities"?: Array<Models.ExtensionPool>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ExternalContact { 
		"id"?: string;
		"firstName"?: string;
		"middleName"?: string;
		"lastName"?: string;
		"salutation"?: string;
		"title"?: string;
		"workPhone"?: Models.PhoneNumber;
		"cellPhone"?: Models.PhoneNumber;
		"homePhone"?: Models.PhoneNumber;
		"otherPhone"?: Models.PhoneNumber;
		"workEmail"?: string;
		"personalEmail"?: string;
		"otherEmail"?: string;
		"address"?: Models.ContactAddress;
		"twitterId"?: Models.TwitterId;
		"lineId"?: Models.LineId;
		"whatsAppId"?: Models.WhatsAppId;
		"facebookId"?: Models.FacebookId;
		"modifyDate"?: string;
		"createDate"?: string;
		"externalOrganization"?: Models.ExternalOrganization;
		"surveyOptOut"?: boolean;
		"externalSystemUrl"?: string;
		"schema"?: Models.DataSchema;
		"customFields"?: { [key: string]: object; };
		"externalDataSources"?: Array<Models.ExternalDataSource>;
		"type"?: string;
		"canonicalContact"?: Models.ContactAddressableEntityRef;
		"mergeSet"?: Array<Models.ContactAddressableEntityRef>;
		"mergeOperation"?: Models.MergeOperation;
		"selfUri"?: string;
	}
	
	export interface ExternalContactReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicContact { 
		"id"?: string;
		"division"?: Models.ExternalContactsContactChangedTopicDivision;
		"externalOrganization"?: Models.ExternalContactsContactChangedTopicExternalOrganization;
		"type"?: string;
		"firstName"?: string;
		"middleName"?: string;
		"lastName"?: string;
		"salutation"?: string;
		"title"?: string;
		"workPhone"?: Models.ExternalContactsContactChangedTopicPhoneNumber;
		"cellPhone"?: Models.ExternalContactsContactChangedTopicPhoneNumber;
		"homePhone"?: Models.ExternalContactsContactChangedTopicPhoneNumber;
		"otherPhone"?: Models.ExternalContactsContactChangedTopicPhoneNumber;
		"workEmail"?: string;
		"personalEmail"?: string;
		"otherEmail"?: string;
		"address"?: Models.ExternalContactsContactChangedTopicContactAddress;
		"surveyOptOut"?: boolean;
		"externalSystemUrl"?: string;
		"twitterId"?: Models.ExternalContactsContactChangedTopicTwitterId;
		"lineId"?: Models.ExternalContactsContactChangedTopicLineId;
		"whatsAppId"?: Models.ExternalContactsContactChangedTopicWhatsAppId;
		"facebookId"?: Models.ExternalContactsContactChangedTopicFacebookId;
		"instagramId"?: Models.ExternalContactsContactChangedTopicInstagramId;
		"schema"?: Models.ExternalContactsContactChangedTopicDataSchema;
		"customFields"?: { [key: string]: object; };
		"createDate"?: string;
		"modifyDate"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicContactAddress { 
		"address1"?: string;
		"address2"?: string;
		"city"?: string;
		"state"?: string;
		"postalCode"?: string;
		"countryCode"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicDataSchema { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ExternalContactsContactChangedTopicDivision { 
		"id"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicExternalOrganization { 
		"id"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicFacebookId { 
		"ids"?: Array<Models.ExternalContactsContactChangedTopicFacebookScopedId>;
		"displayName"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicFacebookScopedId { 
		"scopedId"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicInstagramId { 
		"ids"?: Array<Models.ExternalContactsContactChangedTopicInstagramScopedId>;
		"displayName"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicInstagramScopedId { 
		"scopedId"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicLineId { 
		"ids"?: Array<Models.ExternalContactsContactChangedTopicLineUserId>;
		"displayName"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicLineUserId { 
		"userId"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicObject { 
	}
	
	export interface ExternalContactsContactChangedTopicPhoneNumber { 
		"display"?: string;
		"extension"?: number;
		"acceptsSMS"?: boolean;
		"userInput"?: string;
		"e164"?: string;
		"countryCode"?: string;
		"normalizationCountryCode"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicTwitterId { 
		"id"?: string;
		"name"?: string;
		"screenName"?: string;
		"verified"?: boolean;
		"profileUrl"?: string;
	}
	
	export interface ExternalContactsContactChangedTopicWhatsAppId { 
		"phoneNumber"?: Models.ExternalContactsContactChangedTopicPhoneNumber;
		"displayName"?: string;
	}
	
	export interface ExternalContactsEntity { 
		"id"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicContact { 
		"id"?: string;
		"division"?: Models.ExternalContactsUnresolvedContactChangedTopicDivision;
		"externalOrganization"?: Models.ExternalContactsUnresolvedContactChangedTopicExternalOrganization;
		"type"?: string;
		"firstName"?: string;
		"middleName"?: string;
		"lastName"?: string;
		"salutation"?: string;
		"title"?: string;
		"workPhone"?: Models.ExternalContactsUnresolvedContactChangedTopicPhoneNumber;
		"cellPhone"?: Models.ExternalContactsUnresolvedContactChangedTopicPhoneNumber;
		"homePhone"?: Models.ExternalContactsUnresolvedContactChangedTopicPhoneNumber;
		"otherPhone"?: Models.ExternalContactsUnresolvedContactChangedTopicPhoneNumber;
		"workEmail"?: string;
		"personalEmail"?: string;
		"otherEmail"?: string;
		"address"?: Models.ExternalContactsUnresolvedContactChangedTopicContactAddress;
		"surveyOptOut"?: boolean;
		"externalSystemUrl"?: string;
		"twitterId"?: Models.ExternalContactsUnresolvedContactChangedTopicTwitterId;
		"lineId"?: Models.ExternalContactsUnresolvedContactChangedTopicLineId;
		"whatsAppId"?: Models.ExternalContactsUnresolvedContactChangedTopicWhatsAppId;
		"facebookId"?: Models.ExternalContactsUnresolvedContactChangedTopicFacebookId;
		"instagramId"?: Models.ExternalContactsUnresolvedContactChangedTopicInstagramId;
		"schema"?: Models.ExternalContactsUnresolvedContactChangedTopicDataSchema;
		"customFields"?: { [key: string]: object; };
		"createDate"?: string;
		"modifyDate"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicContactAddress { 
		"address1"?: string;
		"address2"?: string;
		"city"?: string;
		"state"?: string;
		"postalCode"?: string;
		"countryCode"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicDataSchema { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicDivision { 
		"id"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicExternalOrganization { 
		"id"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicFacebookId { 
		"ids"?: Array<Models.ExternalContactsUnresolvedContactChangedTopicFacebookScopedId>;
		"displayName"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicFacebookScopedId { 
		"scopedId"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicInstagramId { 
		"ids"?: Array<Models.ExternalContactsUnresolvedContactChangedTopicInstagramScopedId>;
		"displayName"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicInstagramScopedId { 
		"scopedId"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicLineId { 
		"ids"?: Array<Models.ExternalContactsUnresolvedContactChangedTopicLineUserId>;
		"displayName"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicLineUserId { 
		"userId"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicObject { 
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicPhoneNumber { 
		"display"?: string;
		"extension"?: number;
		"acceptsSMS"?: boolean;
		"userInput"?: string;
		"e164"?: string;
		"countryCode"?: string;
		"normalizationCountryCode"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicTwitterId { 
		"id"?: string;
		"name"?: string;
		"screenName"?: string;
		"verified"?: boolean;
		"profileUrl"?: string;
	}
	
	export interface ExternalContactsUnresolvedContactChangedTopicWhatsAppId { 
		"phoneNumber"?: Models.ExternalContactsUnresolvedContactChangedTopicPhoneNumber;
		"displayName"?: string;
	}
	
	export interface ExternalDataSource { 
		"platform"?: string;
		"url"?: string;
	}
	
	export interface ExternalEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"ani"?: string;
		"aniName"?: string;
		"dnis"?: string;
		"dnisName"?: string;
		"initialConfiguration": Models.InitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface ExternalId { 
		"externalSource"?: Models.ExternalSource;
		"value"?: string;
	}
	
	export interface ExternalMetricDataItem { 
		"userId"?: string;
		"userEmail"?: string;
		"metricId": string;
		"dateOccurred": string;
		"value": number;
		"count"?: number;
		"type"?: string;
	}
	
	export interface ExternalMetricDataProcessedItem { 
		"userId"?: string;
		"userEmail"?: string;
		"metricId": string;
		"dateOccurred": string;
		"value": number;
		"count"?: number;
		"type"?: string;
		"totalValue"?: number;
		"totalCount"?: number;
	}
	
	export interface ExternalMetricDataUnprocessedItem { 
		"userId"?: string;
		"userEmail"?: string;
		"metricId": string;
		"dateOccurred": string;
		"value": number;
		"count"?: number;
		"type"?: string;
		"message"?: string;
		"code"?: string;
	}
	
	export interface ExternalMetricDataWriteRequest { 
		"items": Array<Models.ExternalMetricDataItem>;
	}
	
	export interface ExternalMetricDataWriteResponse { 
		"processedEntities"?: Array<Models.ExternalMetricDataProcessedItem>;
		"unprocessedEntities"?: Array<Models.ExternalMetricDataUnprocessedItem>;
	}
	
	export interface ExternalMetricDefinition { 
		"id"?: string;
		"name"?: string;
		"unit"?: string;
		"unitDefinition"?: string;
		"precision"?: number;
		"defaultObjectiveType"?: string;
		"retentionMonths"?: number;
		"enabled"?: boolean;
		"inUse"?: boolean;
		"dateLastRefreshed"?: string;
		"selfUri"?: string;
	}
	
	export interface ExternalMetricDefinitionCreateRequest { 
		"name": string;
		"unit": string;
		"unitDefinition"?: string;
		"precision": number;
		"defaultObjectiveType": string;
		"enabled": boolean;
	}
	
	export interface ExternalMetricDefinitionListing { 
		"entities"?: Array<Models.ExternalMetricDefinition>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ExternalMetricDefinitionUpdateRequest { 
		"name"?: string;
		"precision"?: number;
		"defaultObjectiveType"?: string;
		"enabled"?: boolean;
	}
	
	export interface ExternalOrganization { 
		"id"?: string;
		"name": string;
		"companyType"?: string;
		"industry"?: string;
		"primaryContactId"?: string;
		"address"?: Models.ContactAddress;
		"phoneNumber"?: Models.PhoneNumber;
		"faxNumber"?: Models.PhoneNumber;
		"employeeCount"?: number;
		"revenue"?: number;
		"tags"?: Array<string>;
		"websites"?: Array<string>;
		"tickers"?: Array<Models.Ticker>;
		"twitterId"?: Models.TwitterId;
		"externalSystemUrl"?: string;
		"modifyDate"?: string;
		"createDate"?: string;
		"trustor"?: Models.Trustor;
		"schema"?: Models.DataSchema;
		"customFields"?: { [key: string]: object; };
		"externalDataSources"?: Array<Models.ExternalDataSource>;
		"selfUri"?: string;
	}
	
	export interface ExternalOrganizationListing { 
		"entities"?: Array<Models.ExternalOrganization>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"partialResults"?: boolean;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ExternalOrganizationTrustorLink { 
		"id"?: string;
		"externalOrganizationId"?: string;
		"trustorOrgId"?: string;
		"dateCreated"?: string;
		"externalOrganizationUri"?: string;
		"selfUri"?: string;
	}
	
	export interface ExternalSegment { 
		"id": string;
		"name": string;
		"source": string;
	}
	
	export interface ExternalSource { 
		"id"?: string;
		"name": string;
		"active"?: boolean;
		"linkConfiguration"?: Models.LinkConfiguration;
		"selfUri"?: string;
	}
	
	export interface FacebookAppCredentials { 
		"id": string;
	}
	
	export interface FacebookId { 
		"ids"?: Array<Models.FacebookScopedId>;
		"displayName"?: string;
	}
	
	export interface FacebookIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"appId": string;
		"pageId"?: string;
		"pageName"?: string;
		"pageProfileImageUrl"?: string;
		"status"?: string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version": number;
		"createStatus"?: string;
		"createError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface FacebookIntegrationEntityListing { 
		"entities"?: Array<Models.FacebookIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FacebookIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"pageAccessToken"?: string;
		"userAccessToken"?: string;
		"pageId"?: string;
		"appId"?: string;
		"appSecret"?: string;
		"selfUri"?: string;
	}
	
	export interface FacebookIntegrationUpdateRequest { 
		"id"?: string;
		"name"?: string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"pageAccessToken"?: string;
		"userAccessToken"?: string;
		"selfUri"?: string;
	}
	
	export interface FacebookPermission { 
		"name"?: string;
		"type"?: string;
	}
	
	export interface FacebookPermissionEntityListing { 
		"entities"?: Array<Models.FacebookPermission>;
	}
	
	export interface FacebookScopedId { 
		"scopedId"?: string;
	}
	
	export interface Facet { 
		"name": string;
		"type": string;
	}
	
	export interface FacetEntry { 
		"attribute"?: Models.TermAttribute;
		"statistics"?: Models.FacetStatistics;
		"other"?: number;
		"total"?: number;
		"missing"?: number;
		"termCount"?: number;
		"termType"?: string;
		"terms"?: Array<Models.FacetTerm>;
	}
	
	export interface FacetInfo { 
		"name"?: string;
		"entries"?: Array<Models.Entry>;
	}
	
	export interface FacetKeyAttribute { 
		"id"?: string;
		"name"?: string;
		"count"?: number;
	}
	
	export interface FacetStatistics { 
		"count"?: number;
		"min"?: number;
		"max"?: number;
		"mean"?: number;
		"stdDeviation"?: number;
		"dateMin"?: string;
		"dateMax"?: string;
	}
	
	export interface FacetTerm { 
		"term"?: string;
		"key"?: number;
		"id"?: string;
		"name"?: string;
		"count"?: number;
		"time"?: string;
	}
	
	export interface FailedObject { 
		"id"?: string;
		"version"?: string;
		"name"?: string;
		"errorCode"?: string;
	}
	
	export interface FailedRecordingEntityListing { 
		"entities"?: Array<Models.RecordingJobFailedRecording>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FaxConfig { 
		"sendEmailNotifications": boolean;
		"disableEmailPii": boolean;
	}
	
	export interface FaxDocument { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"contentUri"?: string;
		"workspace"?: Models.DomainEntityRef;
		"createdBy"?: Models.DomainEntityRef;
		"sharingUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
		"filename"?: string;
		"read"?: boolean;
		"pageCount"?: number;
		"callerAddress"?: string;
		"receiverAddress"?: string;
		"thumbnails"?: Array<Models.DocumentThumbnail>;
		"downloadSharingUri"?: string;
		"selfUri"?: string;
	}
	
	export interface FaxDocumentEntityListing { 
		"entities"?: Array<Models.FaxDocument>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FaxSendRequest { 
		"id"?: string;
		"name"?: string;
		"addresses": Array<string>;
		"documentId"?: string;
		"contentType"?: string;
		"workspace"?: Models.Workspace;
		"coverSheet"?: Models.CoverSheet;
		"timeZoneOffsetMinutes"?: number;
		"selfUri"?: string;
	}
	
	export interface FaxSendResponse { 
		"id"?: string;
		"name"?: string;
		"uploadDestinationUri"?: string;
		"uploadMethodType"?: string;
		"headers"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface FaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"baudRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface FaxSummary { 
		"readCount"?: number;
		"unreadCount"?: number;
		"totalCount"?: number;
	}
	
	export interface FaxTopicFaxDataV2 { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"workspace"?: Models.FaxTopicWorkspaceData;
		"createdBy"?: Models.FaxTopicUserData;
		"contentType"?: string;
		"contentLength"?: number;
		"filename"?: string;
		"changeNumber"?: number;
		"dateUploaded"?: string;
		"uploadedBy"?: Models.FaxTopicUserData;
		"lockInfo"?: Models.FaxTopicLockData;
		"selfUri"?: string;
		"callerAddress"?: string;
		"receiverAddress"?: string;
		"read"?: boolean;
	}
	
	export interface FaxTopicLockData { 
		"lockedBy"?: Models.FaxTopicUserData;
		"dateCreated"?: string;
		"dateExpires"?: string;
	}
	
	export interface FaxTopicUserData { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface FaxTopicWorkspaceData { 
		"id"?: string;
	}
	
	export interface FeatureState { 
		"enabled"?: boolean;
	}
	
	export interface FeedbackAddRequest { 
		"summary": string;
		"rating"?: string;
	}
	
	export interface FieldConfig { 
		"id"?: string;
		"name"?: string;
		"entityType"?: string;
		"state"?: string;
		"sections"?: Array<Models.Section>;
		"version"?: string;
		"schemaVersion"?: string;
		"selfUri"?: string;
	}
	
	export interface FieldConfigs { 
		"org"?: Models.FieldConfig;
		"person"?: Models.FieldConfig;
		"group"?: Models.FieldConfig;
		"externalContact"?: Models.FieldConfig;
	}
	
	export interface FieldList { 
		"customLabels"?: boolean;
		"instructionText"?: string;
		"key"?: string;
		"labelKeys"?: Array<string>;
		"params"?: { [key: string]: object; };
		"repeatable"?: boolean;
		"state"?: string;
		"type"?: string;
		"required"?: boolean;
		"gdpr"?: boolean;
	}
	
	export interface FileSpecificationTemplate { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"description"?: string;
		"format": string;
		"numberOfHeadingLinesSkipped"?: number;
		"numberOfTrailingLinesSkipped"?: number;
		"header"?: boolean;
		"delimiter"?: string;
		"delimiterValue"?: string;
		"columnInformation"?: Array<Models.Column>;
		"preprocessingRules"?: Array<Models.PreprocessingRule>;
		"selfUri"?: string;
	}
	
	export interface FileSpecificationTemplateEntityListing { 
		"entities"?: Array<Models.FileSpecificationTemplate>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FileUploadMode { 
		"fileTypes"?: Array<string>;
		"maxFileSizeKB"?: number;
	}
	
	export interface FileUploadSettings { 
		"enableAttachments"?: boolean;
		"modes"?: Array<Models.FileUploadMode>;
	}
	
	export interface Filter { 
		"name": string;
		"type": string;
		"operator": string;
		"values": Array<string>;
	}
	
	export interface FilterPreviewResponse { 
		"filteredContacts"?: number;
		"totalContacts"?: number;
		"preview"?: Array<Models.DialerContact>;
	}
	
	export interface Flow { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"type"?: string;
		"lockedUser"?: Models.User;
		"lockedClient"?: Models.DomainEntityRef;
		"active"?: boolean;
		"system"?: boolean;
		"deleted"?: boolean;
		"publishedVersion"?: Models.FlowVersion;
		"savedVersion"?: Models.FlowVersion;
		"inputSchema"?: object;
		"outputSchema"?: object;
		"checkedInVersion"?: Models.FlowVersion;
		"debugVersion"?: Models.FlowVersion;
		"publishedBy"?: Models.User;
		"currentOperation"?: Models.Operation;
		"nluInfo"?: Models.NluInfo;
		"supportedLanguages"?: Array<Models.SupportedLanguage>;
		"compatibleFlowTypes"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface FlowActivityData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.FlowActivityMetricValue>;
		"truncated"?: boolean;
		"entities"?: Array<Models.FlowActivityEntityData>;
	}
	
	export interface FlowActivityEntityData { 
		"activityDate": string;
		"metric"?: string;
		"activeRouting"?: string;
		"addressFrom"?: string;
		"addressTo"?: string;
		"ani"?: string;
		"conversationId"?: string;
		"convertedFrom"?: string;
		"convertedTo"?: string;
		"direction"?: string;
		"dnis"?: string;
		"flowId"?: string;
		"flowType"?: string;
		"mediaType"?: string;
		"participantName"?: string;
		"queueId"?: string;
		"requestedLanguageId"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedRoutings"?: Array<string>;
		"routingPriority"?: number;
		"sessionId"?: string;
		"teamId"?: string;
		"usedRouting"?: string;
		"userId"?: string;
		"scoredAgents"?: Array<Models.FlowActivityScoredAgent>;
	}
	
	export interface FlowActivityMetricValue { 
		"metric"?: string;
		"count"?: number;
	}
	
	export interface FlowActivityQuery { 
		"metrics": Array<Models.FlowActivityQueryMetric>;
		"groupBy": Array<string>;
		"filter"?: Models.FlowActivityQueryFilter;
		"order"?: string;
	}
	
	export interface FlowActivityQueryClause { 
		"type": string;
		"predicates": Array<Models.FlowActivityQueryPredicate>;
	}
	
	export interface FlowActivityQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.FlowActivityQueryClause>;
		"predicates"?: Array<Models.FlowActivityQueryPredicate>;
	}
	
	export interface FlowActivityQueryMetric { 
		"metric": string;
		"details"?: boolean;
	}
	
	export interface FlowActivityQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
	}
	
	export interface FlowActivityResponse { 
		"results"?: Array<Models.FlowActivityData>;
		"entityIdDimension"?: string;
	}
	
	export interface FlowActivityScoredAgent { 
		"agentScore"?: number;
		"scoredAgentId"?: string;
	}
	
	export interface FlowAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface FlowAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.FlowAggregateQueryPredicate>;
	}
	
	export interface FlowAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.FlowAggregateQueryClause>;
		"predicates"?: Array<Models.FlowAggregateQueryPredicate>;
	}
	
	export interface FlowAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface FlowAggregateQueryResponse { 
		"results"?: Array<Models.FlowAggregateDataContainer>;
	}
	
	export interface FlowAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.FlowAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.FlowAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface FlowAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface FlowAsyncAggregateQueryResponse { 
		"results"?: Array<Models.FlowAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface FlowAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.FlowAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.FlowAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface FlowCharacteristics { 
		"executionItems"?: boolean;
		"executionInputOutputs"?: boolean;
		"communications"?: boolean;
		"eventError"?: boolean;
		"eventWarning"?: boolean;
		"eventOther"?: boolean;
		"variables"?: boolean;
		"names"?: boolean;
	}
	
	export interface FlowDiagnosticInfo { 
		"lastActionId"?: number;
	}
	
	export interface FlowDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"type"?: string;
		"description"?: string;
		"inputSchema"?: Models.JsonSchemaDocument;
		"outputSchema"?: Models.JsonSchemaDocument;
		"supportedLanguages"?: Array<Models.SupportedLanguage>;
		"publishedVersion"?: Models.FlowVersion;
		"debugVersion"?: Models.FlowVersion;
		"selfUri"?: string;
	}
	
	export interface FlowDivisionViewEntityListing { 
		"entities"?: Array<Models.FlowDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowEndDetailEventTopicFlowEndEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"disconnectType"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"subject"?: string;
		"messageType"?: string;
		"flowType"?: string;
		"flowId"?: string;
		"divisionId"?: string;
		"flowVersion"?: string;
		"connectedDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
		"exitReason"?: string;
		"transferType"?: string;
	}
	
	export interface FlowEntityListing { 
		"entities"?: Array<Models.Flow>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowExecutionAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface FlowExecutionAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.FlowExecutionAggregateQueryPredicate>;
	}
	
	export interface FlowExecutionAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.FlowExecutionAggregateQueryClause>;
		"predicates"?: Array<Models.FlowExecutionAggregateQueryPredicate>;
	}
	
	export interface FlowExecutionAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface FlowExecutionAggregateQueryResponse { 
		"results"?: Array<Models.FlowExecutionAggregateDataContainer>;
	}
	
	export interface FlowExecutionAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.FlowExecutionAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.FlowExecutionAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface FlowExecutionAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface FlowExecutionAsyncAggregateQueryResponse { 
		"results"?: Array<Models.FlowExecutionAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface FlowExecutionAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.FlowExecutionAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.FlowExecutionAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface FlowExecutionDataQueryResult { 
		"id"?: string;
		"name"?: string;
		"startDateTime"?: string;
		"endDateTime"?: string;
		"flowId"?: string;
		"flowVersion"?: string;
		"conversationId"?: string;
		"flowType"?: string;
		"flowErrorReason"?: string;
		"flowName"?: string;
		"selfUri"?: string;
	}
	
	export interface FlowExecutionLaunchRequest { 
		"flowId": string;
		"flowVersion"?: string;
		"inputData"?: { [key: string]: object; };
		"name"?: string;
	}
	
	export interface FlowExecutionLaunchResponse { 
		"id"?: string;
		"name"?: string;
		"flowVersion"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface FlowHealth { 
		"flowVersionInfo"?: Models.FlowHealthVersionInfo;
		"languageInfo"?: { [key: string]: Models.LocaleInfo; };
		"intents"?: Array<Models.FlowHealthIntentInfo>;
		"selfUri"?: string;
	}
	
	export interface FlowHealthErrorInfo { 
		"message"?: string;
		"code"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: object; };
	}
	
	export interface FlowHealthIntent { 
		"id"?: string;
		"name"?: string;
		"flowVersionInfo"?: Models.FlowHealthIntentVersionInfo;
		"language"?: string;
		"health"?: Models.HealthInfo;
		"selfUri"?: string;
	}
	
	export interface FlowHealthIntentInfo { 
		"id"?: string;
		"name"?: string;
		"languageHealth"?: { [key: string]: Models.LocaleHealth; };
		"selfUri"?: string;
	}
	
	export interface FlowHealthIntentUtterance { 
		"id"?: string;
		"text"?: string;
		"issueCount"?: number;
		"staticValidationResults"?: Array<string>;
		"outlierInfo"?: Models.OutlierInfo;
		"confusionInfo"?: Models.ConfusionInfo;
	}
	
	export interface FlowHealthIntentVersionInfo { 
		"nluVersion"?: Models.AddressableEntityRef;
		"flowVersion"?: Models.AddressableEntityRef;
		"nluDomain"?: Models.AddressableEntityRef;
	}
	
	export interface FlowHealthUtterance { 
		"id"?: string;
		"text"?: string;
		"issueCount"?: number;
		"language"?: string;
		"staticValidationResults"?: Array<string>;
		"outlierInfo"?: Models.OutlierInfo;
		"confusionInfo"?: Models.ConfusionDetails;
		"selfUri"?: string;
	}
	
	export interface FlowHealthVersionInfo { 
		"flowVersion"?: Models.AddressableEntityRef;
		"nluDomain"?: Models.AddressableEntityRef;
	}
	
	export interface FlowLogLevel { 
		"level"?: string;
		"characteristics"?: Models.FlowCharacteristics;
	}
	
	export interface FlowLogLevelCharacteristicsDefinition { 
		"id"?: string;
		"minimumLevel"?: string;
		"dependsOn"?: Models.FlowCharacteristics;
	}
	
	export interface FlowLogLevelCharacteristicsDefinitions { 
		"logLevels"?: Array<Models.FlowLogLevel>;
		"characteristics"?: Array<Models.FlowLogLevelCharacteristicsDefinition>;
	}
	
	export interface FlowLogLevelRequest { 
		"logLevelCharacteristics": Models.FlowLogLevel;
	}
	
	export interface FlowMetricsTopicFlowMetricRecord { 
		"metric"?: string;
		"metricDate"?: string;
		"value"?: number;
		"recordId"?: string;
		"activeRouting"?: string;
		"activeSkillIds"?: Array<string>;
		"addressFrom"?: string;
		"addressTo"?: string;
		"agentAssistantId"?: string;
		"agentBullseyeRing"?: number;
		"agentOwned"?: boolean;
		"ani"?: string;
		"assignerId"?: string;
		"authenticated"?: boolean;
		"conversationId"?: string;
		"conversationInitiator"?: string;
		"convertedFrom"?: string;
		"convertedTo"?: string;
		"customerParticipation"?: boolean;
		"deliveryStatus"?: string;
		"destinationAddresses"?: Array<string>;
		"direction"?: string;
		"disconnectType"?: string;
		"divisionIds"?: Array<string>;
		"dnis"?: string;
		"edgeId"?: string;
		"eligibleAgentCounts"?: Array<number>;
		"endingLanguage"?: string;
		"entryReason"?: string;
		"entryType"?: string;
		"errorCode"?: string;
		"exitReason"?: string;
		"extendedDeliveryStatus"?: string;
		"externalContactId"?: string;
		"externalMediaCount"?: number;
		"externalOrganizationId"?: string;
		"externalTag"?: string;
		"firstQueue"?: boolean;
		"flaggedReason"?: string;
		"flowId"?: string;
		"flowInType"?: string;
		"flowMilestoneIds"?: Array<string>;
		"flowName"?: string;
		"flowOutType"?: string;
		"flowType"?: string;
		"flowVersion"?: string;
		"groupId"?: string;
		"interactionType"?: string;
		"journeyActionId"?: string;
		"journeyActionMapId"?: string;
		"journeyActionMapVersion"?: number;
		"journeyCustomerId"?: string;
		"journeyCustomerIdType"?: string;
		"journeyCustomerSessionId"?: string;
		"journeyCustomerSessionIdType"?: string;
		"knowledgeBaseId"?: string;
		"mediaCount"?: number;
		"mediaType"?: string;
		"messageType"?: string;
		"originatingDirection"?: string;
		"outboundCampaignId"?: string;
		"outboundContactId"?: string;
		"outboundContactListId"?: string;
		"participantName"?: string;
		"peerId"?: string;
		"provider"?: string;
		"purpose"?: string;
		"queueId"?: string;
		"recognitionFailureReason"?: string;
		"remote"?: string;
		"removedSkillIds"?: Array<string>;
		"requestedLanguageId"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedRoutings"?: Array<string>;
		"roomId"?: string;
		"routingPriority"?: number;
		"routingRing"?: number;
		"routingRule"?: string;
		"routingRuleType"?: string;
		"selectedAgentId"?: string;
		"selectedAgentRank"?: number;
		"selfServed"?: boolean;
		"sessionDnis"?: string;
		"sessionId"?: string;
		"startingLanguage"?: string;
		"stationId"?: string;
		"teamId"?: string;
		"transferTargetAddress"?: string;
		"transferTargetName"?: string;
		"transferType"?: string;
		"usedRouting"?: string;
		"userId"?: string;
		"waitingInteractionCounts"?: Array<number>;
		"wrapUpCode"?: string;
		"proposedAgents"?: Array<Models.FlowMetricsTopicFlowProposedAgent>;
		"outcomes"?: Array<Models.FlowMetricsTopicFlowOutcome>;
		"scoredAgents"?: Array<Models.FlowMetricsTopicFlowScoredAgent>;
	}
	
	export interface FlowMetricsTopicFlowOutcome { 
		"flowOutcome"?: string;
		"flowOutcomeId"?: string;
		"flowOutcomeValue"?: string;
	}
	
	export interface FlowMetricsTopicFlowProposedAgent { 
		"agentRank"?: number;
		"proposedAgentId"?: string;
	}
	
	export interface FlowMetricsTopicFlowScoredAgent { 
		"agentScore"?: number;
		"scoredAgentId"?: string;
	}
	
	export interface FlowMilestone { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface FlowMilestoneDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"selfUri"?: string;
	}
	
	export interface FlowMilestoneDivisionViewEntityListing { 
		"entities"?: Array<Models.FlowMilestoneDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowMilestoneListing { 
		"entities"?: Array<Models.FlowMilestone>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowObservationDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.ObservationMetricData>;
	}
	
	export interface FlowObservationQuery { 
		"filter": Models.FlowObservationQueryFilter;
		"metrics": Array<string>;
		"detailMetrics"?: Array<string>;
	}
	
	export interface FlowObservationQueryClause { 
		"type": string;
		"predicates": Array<Models.FlowObservationQueryPredicate>;
	}
	
	export interface FlowObservationQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.FlowObservationQueryClause>;
		"predicates"?: Array<Models.FlowObservationQueryPredicate>;
	}
	
	export interface FlowObservationQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface FlowObservationQueryResponse { 
		"results"?: Array<Models.FlowObservationDataContainer>;
	}
	
	export interface FlowOutcome { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"currentOperation"?: Models.Operation;
		"selfUri"?: string;
	}
	
	export interface FlowOutcomeDetailEventTopicFlowMilestone { 
		"milestoneId"?: string;
		"milestoneTime"?: number;
	}
	
	export interface FlowOutcomeDetailEventTopicFlowOutcomeEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"subject"?: string;
		"messageType"?: string;
		"flowType"?: string;
		"flowId"?: string;
		"divisionId"?: string;
		"flowVersion"?: string;
		"flowOutcomeId"?: string;
		"flowOutcomeStartTime"?: number;
		"flowOutcomeEndTime"?: number;
		"flowOutcomeValue"?: string;
		"flowMilestones"?: Array<Models.FlowOutcomeDetailEventTopicFlowMilestone>;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface FlowOutcomeDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"selfUri"?: string;
	}
	
	export interface FlowOutcomeDivisionViewEntityListing { 
		"entities"?: Array<Models.FlowOutcomeDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowOutcomeListing { 
		"entities"?: Array<Models.FlowOutcome>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowPaths { 
		"category": string;
		"elements": { [key: string]: Models.FlowPathsElement; };
	}
	
	export interface FlowPathsElement { 
		"parentId"?: string;
		"type": string;
		"count": number;
		"flows": Array<Models.FlowPathsFlowDetails>;
		"flowOutcomeValue"?: string;
		"flowMilestone"?: Models.AddressableEntityRef;
		"flowOutcome"?: Models.AddressableEntityRef;
	}
	
	export interface FlowPathsFlowDetails { 
		"version": string;
		"type": string;
		"count": number;
		"flow": Models.AddressableEntityRef;
	}
	
	export interface FlowPathsFlowFilter { 
		"id": string;
	}
	
	export interface FlowPathsQuery { 
		"category": string;
		"flows": Array<Models.FlowPathsFlowFilter>;
	}
	
	export interface FlowResultEntityListing { 
		"entities"?: Array<Models.FlowExecutionDataQueryResult>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowRuntimeExecution { 
		"id"?: string;
		"name"?: string;
		"flowVersion": Models.FlowVersion;
		"dateLaunched": string;
		"status": string;
		"dateCompleted"?: string;
		"completionReason"?: string;
		"flowErrorInfo"?: Models.ErrorBody;
		"outputData"?: { [key: string]: object; };
		"conversation"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface FlowSettingsResponse { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"modifiedBy"?: Models.UserReference;
		"modifiedByClient"?: Models.DomainEntityRef;
		"dateModified"?: string;
		"logLevelCharacteristics"?: Models.FlowLogLevel;
		"selfUri"?: string;
	}
	
	export interface FlowSettingsResponseEntityListing { 
		"entities"?: Array<Models.FlowSettingsResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowStartDetailEventTopicFlowStartEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"subject"?: string;
		"messageType"?: string;
		"flowType"?: string;
		"flowId"?: string;
		"divisionId"?: string;
		"flowVersion"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface FlowVersion { 
		"id"?: string;
		"name"?: string;
		"commitVersion"?: string;
		"configurationVersion"?: string;
		"type"?: string;
		"secure"?: boolean;
		"debug"?: boolean;
		"createdBy"?: Models.User;
		"createdByClient"?: Models.DomainEntityRef;
		"configurationUri"?: string;
		"dateCreated"?: number;
		"dateCheckedIn"?: number;
		"dateSaved"?: number;
		"generationId"?: string;
		"publishResultUri"?: string;
		"inputSchema"?: Models.JsonSchemaDocument;
		"outputSchema"?: Models.JsonSchemaDocument;
		"datePublished"?: string;
		"datePublishedEnd"?: string;
		"nluInfo"?: Models.NluInfo;
		"supportedLanguages"?: Array<Models.SupportedLanguage>;
		"compatibleFlowTypes"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface FlowVersionEntityListing { 
		"entities"?: Array<Models.FlowVersion>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface FlowsQueryCriteriaResponse { 
		"criteria"?: Array<Models.QueryCriteria>;
		"flowTypes"?: Array<string>;
		"actionTypes"?: Array<string>;
		"errorCodes"?: Array<string>;
		"warningCodes"?: Array<string>;
	}
	
	export interface FooterTemplate { 
		"type"?: string;
		"applicableResources"?: Array<string>;
	}
	
	export interface ForecastAbandonRateResponse { 
		"percent"?: number;
	}
	
	export interface ForecastAverageSpeedOfAnswerResponse { 
		"seconds"?: number;
	}
	
	export interface ForecastPlanningGroupData { 
		"planningGroupId": string;
		"offeredPerInterval": Array<number>;
		"averageHandleTimeSecondsPerInterval": Array<number>;
	}
	
	export interface ForecastPlanningGroupResponse { 
		"id"?: string;
		"name"?: string;
		"routePaths"?: Array<Models.RoutePathResponse>;
		"serviceGoalTemplate"?: Models.ForecastServiceGoalTemplateResponse;
	}
	
	export interface ForecastPlanningGroupsResponse { 
		"entities"?: Array<Models.ForecastPlanningGroupResponse>;
		"businessUnitServiceGoalImpact"?: Models.WfmServiceGoalImpactSettings;
	}
	
	export interface ForecastServiceGoalTemplateImpactOverrideResponse { 
		"serviceLevel"?: Models.WfmServiceGoalImpact;
		"averageSpeedOfAnswer"?: Models.WfmServiceGoalImpact;
		"abandonRate"?: Models.WfmServiceGoalImpact;
	}
	
	export interface ForecastServiceGoalTemplateResponse { 
		"serviceLevel"?: Models.ForecastServiceLevelResponse;
		"averageSpeedOfAnswer"?: Models.ForecastAverageSpeedOfAnswerResponse;
		"abandonRate"?: Models.ForecastAbandonRateResponse;
		"impactOverride"?: Models.ForecastServiceGoalTemplateImpactOverrideResponse;
	}
	
	export interface ForecastServiceLevelResponse { 
		"percent"?: number;
		"seconds"?: number;
	}
	
	export interface ForecastSourceDayPointer { 
		"dayOfWeek"?: string;
		"weight"?: number;
		"date"?: string;
		"fileName"?: string;
		"dataKey"?: string;
	}
	
	export interface Format { 
		"flags"?: Array<string>;
	}
	
	export interface FormsTrackTrigger { 
		"selector": string;
		"formName": string;
		"captureDataOnFormAbandon": boolean;
		"captureDataOnFormSubmit": boolean;
	}
	
	export interface FromEmailAddress { 
		"domain": Models.DomainEntityRef;
		"friendlyName"?: string;
		"localPart"?: string;
	}
	
	export interface FullDayTimeOffMarker { 
		"businessUnitDate"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"timeOffRequestId"?: string;
	}
	
	export interface Function { 
		"id"?: string;
		"name"?: string;
		"description": string;
		"dateCreated"?: string;
		"zipId"?: string;
		"handler": string;
		"runtime": string;
		"timeoutSeconds"?: number;
	}
	
	export interface FunctionConfig { 
		"id"?: string;
		"function"?: Models.Function;
		"zip"?: Models.FunctionZipConfig;
		"selfUri"?: string;
	}
	
	export interface FunctionRuntime { 
		"name"?: string;
		"description"?: string;
		"status"?: string;
		"dateEndOfLife"?: string;
	}
	
	export interface FunctionUploadRequest { 
		"fileName": string;
		"signedUrlTimeoutSeconds"?: number;
	}
	
	export interface FunctionUploadResponse { 
		"url"?: string;
		"headers"?: { [key: string]: string; };
		"signedUrlTimeoutSeconds"?: number;
	}
	
	export interface FunctionZipConfig { 
		"status"?: string;
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
	}
	
	export interface GDPRJourneyCustomer { 
		"type"?: string;
		"id"?: string;
	}
	
	export interface GDPRRequest { 
		"id"?: string;
		"name"?: string;
		"createdBy": Models.DomainEntityRef;
		"replacementTerms"?: Array<Models.ReplacementTerm>;
		"requestType": string;
		"createdDate": string;
		"status": string;
		"subject": Models.GDPRSubject;
		"resultsUrl"?: string;
		"selfUri"?: string;
	}
	
	export interface GDPRRequestEntityListing { 
		"entities"?: Array<Models.GDPRRequest>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface GDPRSubject { 
		"name"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"dialerContactId"?: Models.DialerContactId;
		"journeyCustomer"?: Models.GDPRJourneyCustomer;
		"socialHandle"?: Models.SocialHandle;
		"externalId"?: string;
		"addresses"?: Array<string>;
		"phoneNumbers"?: Array<string>;
		"emailAddresses"?: Array<string>;
	}
	
	export interface GDPRSubjectEntityListing { 
		"entities"?: Array<Models.GDPRSubject>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface GKNDocumentationResult { 
		"content"?: string;
		"link"?: string;
		"title"?: string;
		"_type": string;
	}
	
	export interface GKNDocumentationSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.GKNDocumentationSearchCriteria>;
		"dateFormat"?: string;
		"type": string;
		"fields"?: Array<string>;
	}
	
	export interface GKNDocumentationSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"query"?: Array<Models.GKNDocumentationSearchCriteria>;
	}
	
	export interface GKNDocumentationSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.GKNDocumentationResult>;
	}
	
	export interface GSuite { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface GamificationScorecardChangeTopicEvaluationDetail { 
		"evaluationId"?: string;
		"conversationId"?: string;
		"conversationDate"?: string;
		"formName"?: string;
		"points"?: number;
		"maxPoints"?: number;
		"evaluationScore"?: number;
		"evaluationScoreDouble"?: number;
		"mediaTypes"?: Array<string>;
	}
	
	export interface GamificationScorecardChangeTopicMetric { 
		"id"?: string;
	}
	
	export interface GamificationScorecardChangeTopicPerformanceMetric { 
		"metric"?: Models.GamificationScorecardChangeTopicMetric;
		"points"?: number;
		"value"?: number;
		"punctualityEvents"?: Array<Models.GamificationScorecardChangeTopicPunctualityEvent>;
		"evaluationDetails"?: Array<Models.GamificationScorecardChangeTopicEvaluationDetail>;
	}
	
	export interface GamificationScorecardChangeTopicPunctualityEvent { 
		"dateStart"?: string;
		"dateScheduleStart"?: string;
		"activityCode"?: string;
		"points"?: number;
	}
	
	export interface GamificationScorecardChangeTopicScorecardChange { 
		"workday"?: string;
		"divisionId"?: string;
		"teamId"?: string;
		"performanceProfileId"?: string;
		"userId"?: string;
		"performanceMetrics"?: Array<Models.GamificationScorecardChangeTopicPerformanceMetric>;
	}
	
	export interface GamificationStatus { 
		"isActive"?: boolean;
		"dateStart"?: string;
		"automaticUserAssignment"?: boolean;
		"dateStartPersonalBest"?: string;
	}
	
	export interface GeneralProgramJob { 
		"id"?: string;
		"state"?: string;
		"createdBy"?: Models.AddressableEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface GeneralProgramJobRequest { 
		"dialect": string;
		"mode"?: string;
	}
	
	export interface GeneralTopic { 
		"name"?: string;
	}
	
	export interface GeneralTopicsEntityListing { 
		"entities"?: Array<Models.GeneralTopic>;
	}
	
	export interface GenerateBuForecastRequest { 
		"description": string;
		"weekCount"?: number;
		"canUseForScheduling"?: boolean;
	}
	
	export interface GenerateMeetingIdRequest { 
		"conferenceId"?: string;
		"ephemeral": boolean;
		"expireTimeDays"?: number;
	}
	
	export interface GenericActionEvent { 
		"action": Models.GenericEventAction;
		"actionMap"?: Models.ActionEventActionMap;
		"errorCode"?: string;
		"errorMessage"?: string;
	}
	
	export interface GenericEventAction { 
		"id": string;
		"state": string;
		"mediaType": string;
		"prompt": string;
		"mediaAddress"?: string;
		"createdDate": string;
	}
	
	export interface GenericSAML { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"logoImageData"?: string;
		"endpointCompression"?: boolean;
		"nameIdentifierFormat"?: string;
		"selfUri"?: string;
	}
	
	export interface GenericTemplate { 
		"title"?: string;
		"description"?: string;
		"url"?: string;
		"components"?: Array<Models.RecordingButtonComponent>;
		"actions"?: Models.RecordingContentActions;
	}
	
	export interface GenesysBotConnector { 
		"queryParameters"?: { [key: string]: string; };
	}
	
	export interface Geolocation { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"primary"?: boolean;
		"latitude"?: number;
		"longitude"?: number;
		"country"?: string;
		"region"?: string;
		"city"?: string;
		"locations"?: Array<Models.LocationDefinition>;
		"selfUri"?: string;
	}
	
	export interface GeolocationEventGeolocation { 
		"userId"?: string;
		"type"?: string;
		"country"?: string;
		"region"?: string;
		"city"?: string;
	}
	
	export interface GeolocationSettings { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"mapboxKey"?: string;
		"selfUri"?: string;
	}
	
	export interface GetAlertQuery { 
		"ruleType": string;
		"queryType": string;
		"alertStatus"?: string;
		"viewedStatus"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
	}
	
	export interface GetFlowExecutionDataJobResult { 
		"id"?: string;
		"name"?: string;
		"entities"?: Array<Models.ExecutionDataEntity>;
		"jobState"?: string;
		"selfUri"?: string;
	}
	
	export interface GetMetricDefinitionsResponse { 
		"total"?: number;
		"entities"?: Array<Models.MetricDefinition>;
		"selfUri"?: string;
	}
	
	export interface GetMetricResponse { 
		"total"?: number;
		"entities"?: Array<Models.Metric>;
		"selfUri"?: string;
	}
	
	export interface GetMetricsResponse { 
		"total"?: number;
		"entities"?: Array<Models.Metrics>;
		"selfUri"?: string;
	}
	
	export interface GetProfilesResponse { 
		"total"?: number;
		"entities"?: Array<Models.PerformanceProfile>;
		"selfUri"?: string;
	}
	
	export interface GetRulesQuery { 
		"ruleType": string;
		"queryType": string;
		"enabledType"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"sortBy"?: string;
		"sortOrder"?: string;
		"ruleName"?: string;
		"nameSearchType"?: string;
	}
	
	export interface GetTemplatesResponse { 
		"total"?: number;
		"entities"?: Array<Models.ObjectiveTemplate>;
		"selfUri"?: string;
	}
	
	export interface GetUploadSourceUrlJobStatusResponse { 
		"id"?: string;
		"status"?: string;
		"uploadKey"?: string;
		"errorInformation"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface GoogleDialogflowCustomSettings { 
		"environment"?: string;
		"eventName"?: string;
		"webhookQueryParameters"?: { [key: string]: string; };
		"eventInputParameters"?: { [key: string]: string; };
	}
	
	export interface Grammar { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"languages"?: Array<Models.GrammarLanguage>;
		"selfUri"?: string;
	}
	
	export interface GrammarFileUploadRequest { 
		"fileType"?: string;
	}
	
	export interface GrammarLanguage { 
		"id"?: string;
		"grammarId"?: string;
		"language"?: string;
		"voiceFileUrl"?: string;
		"dtmfFileUrl"?: string;
		"voiceFileMetadata"?: Models.GrammarLanguageFileMetadata;
		"dtmfFileMetadata"?: Models.GrammarLanguageFileMetadata;
		"selfUri"?: string;
	}
	
	export interface GrammarLanguageFileMetadata { 
		"fileName"?: string;
		"fileSizeBytes"?: number;
		"dateUploaded"?: string;
		"fileType"?: string;
	}
	
	export interface GrammarLanguageUpdate { 
		"voiceFileMetadata"?: Models.GrammarLanguageFileMetadata;
		"dtmfFileMetadata"?: Models.GrammarLanguageFileMetadata;
	}
	
	export interface GrammarListing { 
		"entities"?: Array<Models.Grammar>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Greeting { 
		"id"?: string;
		"name"?: string;
		"type": string;
		"ownerType": string;
		"owner": Models.DomainEntity;
		"audioFile"?: Models.GreetingAudioFile;
		"audioTTS"?: string;
		"createdDate"?: string;
		"createdBy"?: string;
		"modifiedDate"?: string;
		"modifiedBy"?: string;
		"selfUri"?: string;
	}
	
	export interface GreetingAudioFile { 
		"durationMilliseconds"?: number;
		"sizeBytes"?: number;
		"selfUri"?: string;
	}
	
	export interface GreetingListing { 
		"entities"?: Array<Models.Greeting>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface GreetingMediaInfo { 
		"id"?: string;
		"mediaFileUri"?: string;
		"mediaImageUri"?: string;
	}
	
	export interface GreetingOwner { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface Group { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"dateModified"?: string;
		"memberCount"?: number;
		"state"?: string;
		"version"?: number;
		"type": string;
		"images"?: Array<Models.UserImage>;
		"addresses"?: Array<Models.GroupContact>;
		"rulesVisible": boolean;
		"visibility": string;
		"rolesEnabled"?: boolean;
		"owners"?: Array<Models.User>;
		"selfUri"?: string;
	}
	
	export interface GroupByAttribute { 
		"attribute"?: string;
		"value"?: string;
	}
	
	export interface GroupContact { 
		"address": string;
		"extension"?: string;
		"display"?: string;
		"type": string;
		"mediaType": string;
	}
	
	export interface GroupCreate { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"dateModified"?: string;
		"memberCount"?: number;
		"state"?: string;
		"version"?: number;
		"type": string;
		"images"?: Array<Models.UserImage>;
		"addresses"?: Array<Models.GroupContact>;
		"rulesVisible": boolean;
		"visibility": string;
		"rolesEnabled"?: boolean;
		"ownerIds"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface GroupEntityListing { 
		"entities"?: Array<Models.Group>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface GroupGreetingEventGreeting { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"ownerType"?: string;
		"owner"?: Models.GroupGreetingEventGreetingOwner;
		"greetingAudioFile"?: Models.GroupGreetingEventGreetingAudioFile;
		"audioTTS"?: string;
	}
	
	export interface GroupGreetingEventGreetingAudioFile { 
		"durationMilliseconds"?: number;
		"sizeBytes"?: number;
	}
	
	export interface GroupGreetingEventGreetingOwner { 
		"id"?: string;
	}
	
	export interface GroupMembersUpdate { 
		"memberIds": Array<string>;
		"version": number;
	}
	
	export interface GroupProfile { 
		"id"?: string;
		"name"?: string;
		"state"?: string;
		"dateModified"?: string;
		"version": number;
		"selfUri"?: string;
	}
	
	export interface GroupProfileEntityListing { 
		"entities"?: Array<Models.GroupProfile>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface GroupSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.GroupSearchCriteria>;
		"dateFormat"?: string;
		"type": string;
		"fields"?: Array<string>;
	}
	
	export interface GroupSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"query"?: Array<Models.GroupSearchCriteria>;
	}
	
	export interface GroupUpdate { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"state"?: string;
		"version": number;
		"images"?: Array<Models.UserImage>;
		"addresses"?: Array<Models.GroupContact>;
		"rulesVisible"?: boolean;
		"visibility"?: string;
		"rolesEnabled"?: boolean;
		"ownerIds"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface GroupsSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.Group>;
	}
	
	export interface GuestCategoryReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface GuestCategoryResponseListing { 
		"entities"?: Array<Models.GuestResponseCategory>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"sessionId"?: string;
	}
	
	export interface GuestMemberInfo { 
		"displayName": string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"phoneNumber"?: string;
		"avatarImageUrl"?: string;
		"customFields"?: { [key: string]: string; };
	}
	
	export interface GuestResponseCategory { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"externalId"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"parentCategory"?: Models.GuestCategoryReference;
		"selfUri"?: string;
	}
	
	export interface HeadcountForecast { 
		"required": Array<Models.HeadcountInterval>;
		"requiredWithoutShrinkage": Array<Models.HeadcountInterval>;
	}
	
	export interface HeadcountInterval { 
		"interval": string;
		"value": number;
	}
	
	export interface HealthInfo { 
		"status"?: string;
		"errorInfo"?: Models.FlowHealthErrorInfo;
		"overallScore"?: number;
		"issueCount"?: number;
		"staticValidationResults"?: Array<string>;
		"utterances"?: Array<Models.FlowHealthIntentUtterance>;
	}
	
	export interface HelpLink { 
		"uri"?: string;
		"title"?: string;
		"description"?: string;
	}
	
	export interface HelpSettings { 
		"keyword": Array<string>;
		"response": Models.ComplianceResponse;
	}
	
	export interface HistoricalAdherenceActuals { 
		"actualActivityCategory"?: string;
		"actualSecondaryPresenceLookupId"?: string;
		"startOffsetSeconds"?: number;
		"endOffsetSeconds"?: number;
	}
	
	export interface HistoricalAdherenceDayMetrics { 
		"dayStartOffsetSecs"?: number;
		"adherenceScheduleSecs"?: number;
		"conformanceScheduleSecs"?: number;
		"conformanceActualSecs"?: number;
		"exceptionCount"?: number;
		"exceptionDurationSecs"?: number;
		"impactSeconds"?: number;
		"scheduleLengthSecs"?: number;
		"actualLengthSecs"?: number;
		"adherencePercentage"?: number;
		"conformancePercentage"?: number;
	}
	
	export interface HistoricalAdherenceExceptionInfo { 
		"startOffsetSeconds"?: number;
		"endOffsetSeconds"?: number;
		"scheduledActivityCodeId"?: string;
		"scheduledActivityCategory"?: string;
		"scheduledSecondaryPresenceLookupIds"?: Array<string>;
		"actualActivityCodeId"?: string;
		"actualActivityCategory"?: string;
		"systemPresence"?: string;
		"routingStatus"?: string;
		"impact"?: string;
		"secondaryPresenceLookupId"?: string;
	}
	
	export interface HistoricalAdherenceQueryResult { 
		"userId"?: string;
		"managementUnitId"?: string;
		"startDate"?: string;
		"endDate"?: string;
		"adherencePercentage"?: number;
		"conformancePercentage"?: number;
		"impact"?: string;
		"exceptionInfo"?: Array<Models.HistoricalAdherenceExceptionInfo>;
		"dayMetrics"?: Array<Models.HistoricalAdherenceDayMetrics>;
		"actualsEndDate"?: string;
		"actuals"?: Array<Models.HistoricalAdherenceActuals>;
	}
	
	export interface HistoricalImportDeleteJobResponse { 
		"id"?: string;
		"name"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface HistoricalImportStatus { 
		"requestId"?: string;
		"dateImportEnded"?: string;
		"dateImportStarted"?: string;
		"status"?: string;
		"error"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"active"?: boolean;
		"type"?: string;
	}
	
	export interface HistoricalImportStatusListing { 
		"entities"?: Array<Models.HistoricalImportStatus>;
	}
	
	export interface HistoricalShrinkageActivityCategoryResponse { 
		"activityCategory"?: string;
		"shrinkageForActivityCategory"?: Models.HistoricalShrinkageAggregateResponse;
		"shrinkageForActivityCodes"?: Array<Models.HistoricalShrinkageActivityCodeResponse>;
	}
	
	export interface HistoricalShrinkageActivityCodeResponse { 
		"activityCodeId"?: string;
		"shrinkageForActivityCode"?: Models.HistoricalShrinkageAggregateResponse;
	}
	
	export interface HistoricalShrinkageAggregateResponse { 
		"scheduledShrinkageSeconds"?: number;
		"scheduledShrinkagePercent"?: number;
		"actualShrinkageSeconds"?: number;
		"actualShrinkagePercent"?: number;
		"paidShrinkageSeconds"?: number;
		"unpaidShrinkageSeconds"?: number;
		"plannedShrinkageSeconds"?: number;
		"unplannedShrinkageSeconds"?: number;
	}
	
	export interface HistoricalShrinkageResult { 
		"startDate"?: string;
		"endDate"?: string;
		"totalScheduledDurationSeconds"?: number;
		"totalLoggedInDurationSeconds"?: number;
		"aggregatedShrinkage"?: Models.HistoricalShrinkageAggregateResponse;
		"shrinkageForActivityCategories"?: Array<Models.HistoricalShrinkageActivityCategoryResponse>;
		"businessUnitIds"?: Array<string>;
	}
	
	export interface HistoricalShrinkageResultListing { 
		"entities"?: Array<Models.HistoricalShrinkageResult>;
	}
	
	export interface HistoryEntry { 
		"action"?: string;
		"resource"?: string;
		"timestamp"?: string;
		"user"?: Models.User;
		"client"?: Models.DomainEntityRef;
		"version"?: string;
		"secure"?: boolean;
	}
	
	export interface HistoryHeadersTranslation { 
		"from": string;
		"to": string;
		"cc": string;
		"subject": string;
		"replyPrefix": string;
		"forwardPrefix": string;
		"sent": string;
		"language": string;
		"timeZone"?: string;
	}
	
	export interface HistoryListing { 
		"id"?: string;
		"complete"?: boolean;
		"user"?: Models.User;
		"client"?: Models.DomainEntityRef;
		"errorMessage"?: string;
		"errorCode"?: string;
		"errorDetails"?: Array<Models.Detail>;
		"errorMessageParams"?: { [key: string]: string; };
		"actionName"?: string;
		"actionStatus"?: string;
		"name"?: string;
		"description"?: string;
		"system"?: boolean;
		"started"?: string;
		"completed"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"entities"?: Array<Models.HistoryEntry>;
		"pageCount"?: number;
	}
	
	export interface HoldUpdatedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"held": boolean;
	}
	
	export interface HomerRecord { 
		"id"?: string;
		"name"?: string;
		"date"?: string;
		"milliTs"?: string;
		"microTs"?: string;
		"method"?: string;
		"replyReason"?: string;
		"ruri"?: string;
		"ruriUser"?: string;
		"ruriDomain"?: string;
		"fromUser"?: string;
		"fromDomain"?: string;
		"fromTag"?: string;
		"toUser"?: string;
		"toDomain"?: string;
		"toTag"?: string;
		"pidUser"?: string;
		"contactUser"?: string;
		"authUser"?: string;
		"callid"?: string;
		"callidAleg"?: string;
		"via1"?: string;
		"via1Branch"?: string;
		"cseq"?: string;
		"diversion"?: string;
		"reason"?: string;
		"contentType"?: string;
		"auth"?: string;
		"userAgent"?: string;
		"sourceIp"?: string;
		"sourcePort"?: string;
		"destinationIp"?: string;
		"destinationPort"?: string;
		"contactIp"?: string;
		"contactPort"?: string;
		"originatorIp"?: string;
		"originatorPort"?: string;
		"correlationId"?: string;
		"proto"?: string;
		"family"?: string;
		"rtpStat"?: string;
		"type"?: string;
		"node"?: string;
		"trans"?: string;
		"dbnode"?: string;
		"msg"?: string;
		"sourceAlias"?: string;
		"destinationAlias"?: string;
		"conversationId"?: string;
		"participantId"?: string;
		"selfUri"?: string;
	}
	
	export interface HrisTimeOffType { 
		"id": string;
		"name": string;
		"hrisIntegrationId": string;
		"secondaryId"?: string;
	}
	
	export interface HrisTimeOffTypeResponse { 
		"id": string;
		"name": string;
		"secondaryId"?: string;
	}
	
	export interface HrisTimeOffTypesJobReference { 
		"id"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface HrisTimeOffTypesJobResponse { 
		"entities"?: Array<Models.HrisTimeOffTypeResponse>;
		"status"?: string;
	}
	
	export interface HrisTimeOffTypesResponse { 
		"job"?: Models.HrisTimeOffTypesJobReference;
		"entities"?: Array<Models.HrisTimeOffTypeResponse>;
	}
	
	export interface Humanize { 
		"enabled"?: boolean;
		"bot"?: Models.BotMessengerProfile;
	}
	
	export interface IVR { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"dnis"?: Array<string>;
		"openHoursFlow"?: Models.DomainEntityRef;
		"closedHoursFlow"?: Models.DomainEntityRef;
		"holidayHoursFlow"?: Models.DomainEntityRef;
		"scheduleGroup"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface IVRDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"selfUri"?: string;
	}
	
	export interface IVRDivisionViewEntityListing { 
		"entities"?: Array<Models.IVRDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface IVREntityListing { 
		"entities"?: Array<Models.IVR>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface IdentifierClaimRequest { 
		"operation": string;
		"identifier": Models.ContactIdentifier;
	}
	
	export interface IdentityNow { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface IdentityProvider { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"selfUri"?: string;
	}
	
	export interface IdentityProviderEntityListing { 
		"entities"?: Array<Models.IdentityProvider>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface IdleEventTrigger { 
		"eventName": string;
		"idleAfterSeconds"?: number;
	}
	
	export interface IdleTokenTimeout { 
		"idleTokenTimeoutSeconds"?: number;
		"enableIdleTokenTimeout"?: boolean;
	}
	
	export interface IgnoredActivityCategories { 
		"values"?: Array<string>;
	}
	
	export interface ImapSettings { 
		"integration"?: Models.DomainEntityRef;
		"status"?: string;
		"errorInfo"?: Models.EmailErrorInfo;
	}
	
	export interface ImportError { 
		"message"?: string;
		"line"?: number;
	}
	
	export interface ImportForecastResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuShortTermForecast;
	}
	
	export interface ImportForecastUploadResponse { 
		"uploadKey"?: string;
		"url"?: string;
		"headers"?: { [key: string]: string; };
		"uploadBodySchema"?: Models.BuImportShortTermForecastSchema;
	}
	
	export interface ImportReport { 
		"errors"?: Array<Models.ImportError>;
		"validated"?: Models.ResultCounters;
		"imported"?: Models.ResultCounters;
		"totalDocuments"?: number;
	}
	
	export interface ImportScheduleUploadResponse { 
		"uploadKey"?: string;
		"url"?: string;
		"headers"?: { [key: string]: string; };
		"uploadBodySchema"?: Models.ImportScheduleUploadSchema;
	}
	
	export interface ImportScheduleUploadSchema { 
		"description": string;
		"weekCount": number;
		"published"?: boolean;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"headcountForecast"?: Models.BuHeadcountForecast;
		"agentSchedules"?: Array<Models.BuImportAgentScheduleUploadSchema>;
	}
	
	export interface ImportScriptStatusResponse { 
		"url"?: string;
		"succeeded"?: boolean;
		"message"?: string;
	}
	
	export interface ImportStatus { 
		"state": string;
		"totalRecords": number;
		"completedRecords": number;
		"percentComplete": number;
		"failureReason"?: string;
		"targetContactListIds"?: Array<string>;
		"listNamePrefix"?: string;
	}
	
	export interface ImportStatusRequest { 
		"status": string;
	}
	
	export interface ImportTemplate { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"contactListTemplate": Models.DomainEntityRef;
		"contactListFilter"?: Models.DomainEntityRef;
		"useSplittingCriteria"?: boolean;
		"splittingInformation"?: Models.SplittingInformation;
		"listNameFormat"?: string;
		"customListNameFormatValue"?: string;
		"importStatus"?: Models.ImportStatus;
		"selfUri"?: string;
	}
	
	export interface ImportTemplateEntityListing { 
		"entities"?: Array<Models.ImportTemplate>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ImportTemplateImportStatusImportStatus { 
		"importState"?: string;
		"totalRecords"?: number;
		"completedRecords"?: number;
		"percentageComplete"?: number;
		"failureReason"?: string;
		"targetContactListIds"?: Array<string>;
		"listNamePrefix"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface ImportTemplateImportStatusObject { 
	}
	
	export interface InboundDomain { 
		"id"?: string;
		"name"?: string;
		"mxRecordStatus"?: string;
		"subDomain"?: boolean;
		"mailFromSettings"?: Models.MailFromResult;
		"customSMTPServer"?: Models.DomainEntityRef;
		"imapSettings"?: Models.ImapSettings;
		"selfUri"?: string;
	}
	
	export interface InboundDomainEntityListing { 
		"entities"?: Array<Models.InboundDomain>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface InboundDomainPatchRequest { 
		"mailFromSettings"?: Models.MailFromResult;
		"customSMTPServer"?: Models.DomainEntityRef;
		"imapSettings"?: Models.ImapSettings;
	}
	
	export interface InboundMessageRequest { 
		"queueId"?: string;
		"flowId"?: string;
		"provider": string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"priority"?: number;
		"attributes"?: { [key: string]: string; };
		"toAddress"?: string;
		"toName"?: string;
		"fromAddress"?: string;
		"fromName"?: string;
		"subject"?: string;
	}
	
	export interface InboundOnlySetting { 
		"inbound"?: string;
	}
	
	export interface InboundRoute { 
		"id"?: string;
		"name"?: string;
		"pattern": string;
		"queue"?: Models.DomainEntityRef;
		"priority"?: number;
		"skills"?: Array<Models.DomainEntityRef>;
		"language"?: Models.DomainEntityRef;
		"fromName": string;
		"fromEmail"?: string;
		"flow"?: Models.DomainEntityRef;
		"replyEmailAddress"?: Models.QueueEmailAddress;
		"autoBcc"?: Array<Models.EmailAddress>;
		"spamFlow"?: Models.DomainEntityRef;
		"signature"?: Models.Signature;
		"historyInclusion"?: string;
		"allowMultipleActions"?: boolean;
		"imapFolder"?: string;
		"selfUri"?: string;
	}
	
	export interface InboundRouteEntityListing { 
		"entities"?: Array<Models.InboundRoute>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface InfrastructureascodeJob { 
		"id"?: string;
		"dryRun": boolean;
		"acceleratorId"?: string;
		"dateSubmitted"?: string;
		"submittedBy"?: Models.UserReference;
		"status"?: string;
		"errorInfo"?: Models.ErrorInfo;
		"results"?: string;
		"selfUri"?: string;
	}
	
	export interface InitialConfiguration { 
		"audioState"?: Models.AudioState;
		"alerting"?: boolean;
		"inbound"?: boolean;
		"invitedBy"?: string;
		"recordingActive"?: boolean;
		"additionalInfo"?: { [key: string]: string; };
	}
	
	export interface InitiateScreenRecording { 
		"recordACW"?: boolean;
		"archiveRetention"?: Models.ArchiveRetention;
		"deleteRetention"?: Models.DeleteRetention;
	}
	
	export interface InitiatingAction { 
		"transactionId"?: string;
		"actionContext"?: string;
	}
	
	export interface InsightsAgentItem { 
		"id"?: string;
		"name"?: string;
		"manager"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface InsightsAgents { 
		"performanceProfile"?: Models.AddressableEntityRef;
		"division"?: Models.DivisionReference;
		"granularity"?: string;
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"entities"?: Array<Models.InsightsAgentItem>;
	}
	
	export interface InsightsDetails { 
		"performanceProfile"?: Models.AddressableEntityRef;
		"division"?: Models.DivisionReference;
		"granularity"?: string;
		"comparativePeriod"?: Models.WorkdayPeriod;
		"primaryPeriod"?: Models.WorkdayPeriod;
		"user"?: Models.UserReference;
		"metricData"?: Array<Models.InsightsDetailsMetricItem>;
		"overallData"?: Models.InsightsDetailsOverallItem;
	}
	
	export interface InsightsDetailsMetricItem { 
		"metric"?: Models.AddressableEntityRef;
		"comparativePeriod"?: Models.InsightsDetailsMetricPeriodPoints;
		"primaryPeriod"?: Models.InsightsDetailsMetricPeriodPoints;
		"percentOfGoalChange"?: number;
		"valueChange"?: number;
	}
	
	export interface InsightsDetailsMetricPeriodPoints { 
		"points"?: number;
		"maxPoints"?: number;
		"dataPointCount"?: number;
		"percentOfGoal"?: number;
		"rankTotalPoints"?: number;
		"rankPercentagePoints"?: number;
		"value"?: number;
	}
	
	export interface InsightsDetailsOverallItem { 
		"comparativePeriod"?: Models.InsightsDetailsOverallPeriodPoints;
		"primaryPeriod"?: Models.InsightsDetailsOverallPeriodPoints;
		"percentOfGoalChange"?: number;
	}
	
	export interface InsightsDetailsOverallPeriodPoints { 
		"points"?: number;
		"maxPoints"?: number;
		"dataPointCount"?: number;
		"percentOfGoal"?: number;
		"rankTotalPoints"?: number;
		"rankPercentagePoints"?: number;
	}
	
	export interface InsightsSummary { 
		"entities"?: Array<Models.InsightsSummaryUserItem>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"performanceProfile"?: Models.AddressableEntityRef;
		"division"?: Models.DivisionReference;
		"granularity"?: string;
		"comparativePeriod"?: Models.WorkdayPeriod;
		"primaryPeriod"?: Models.WorkdayPeriod;
		"pageCount"?: number;
	}
	
	export interface InsightsSummaryMetricItem { 
		"metric"?: Models.AddressableEntityRef;
		"comparativePeriod"?: Models.InsightsSummaryMetricPeriodPoints;
		"primaryPeriod"?: Models.InsightsSummaryMetricPeriodPoints;
		"percentOfGoalChange"?: number;
		"valueChange"?: number;
	}
	
	export interface InsightsSummaryMetricPeriodPoints { 
		"points"?: number;
		"maxPoints"?: number;
		"dataPointCount"?: number;
		"percentOfGoal"?: number;
		"value"?: number;
	}
	
	export interface InsightsSummaryOverallItem { 
		"comparativePeriod"?: Models.InsightsSummaryOverallPeriodPoints;
		"primaryPeriod"?: Models.InsightsSummaryOverallPeriodPoints;
		"percentOfGoalChange"?: number;
	}
	
	export interface InsightsSummaryOverallPeriodPoints { 
		"points"?: number;
		"maxPoints"?: number;
		"dataPointCount"?: number;
		"percentOfGoal"?: number;
	}
	
	export interface InsightsSummaryUserItem { 
		"user"?: Models.UserReference;
		"metricData"?: Array<Models.InsightsSummaryMetricItem>;
		"overallData"?: Models.InsightsSummaryOverallItem;
		"ranking"?: number;
	}
	
	export interface InsightsTrend { 
		"performanceProfile"?: Models.AddressableEntityRef;
		"division"?: Models.DivisionReference;
		"granularity"?: string;
		"comparativePeriod"?: Models.WorkdayPeriod;
		"primaryPeriod"?: Models.WorkdayPeriod;
		"entities"?: Array<Models.InsightsTrendMetricItem>;
		"total"?: Models.InsightsTrendTotalItem;
	}
	
	export interface InsightsTrendMetricItem { 
		"metric"?: Models.AddressableEntityRef;
		"trends"?: Models.InsightsTrends;
	}
	
	export interface InsightsTrendTotalItem { 
		"trends"?: Models.InsightsTrends;
	}
	
	export interface InsightsTrends { 
		"comparativePeriod"?: Array<Models.TrendData>;
		"primaryPeriod"?: Array<Models.TrendData>;
	}
	
	export interface InstagramId { 
		"ids"?: Array<Models.InstagramScopedId>;
		"displayName"?: string;
	}
	
	export interface InstagramIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"appId": string;
		"pageId"?: string;
		"instagramId"?: string;
		"instagramUsername"?: string;
		"instagramName"?: string;
		"instagramProfileImageUrl"?: string;
		"status"?: string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version": number;
		"createStatus"?: string;
		"createError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface InstagramIntegrationEntityListing { 
		"entities"?: Array<Models.InstagramIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface InstagramIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"pageAccessToken"?: string;
		"userAccessToken"?: string;
		"pageId"?: string;
		"appId"?: string;
		"appSecret"?: string;
		"selfUri"?: string;
	}
	
	export interface InstagramIntegrationUpdateRequest { 
		"id"?: string;
		"name"?: string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"pageAccessToken"?: string;
		"userAccessToken"?: string;
		"selfUri"?: string;
	}
	
	export interface InstagramScopedId { 
		"scopedId"?: string;
	}
	
	export interface Integration { 
		"id"?: string;
		"name"?: string;
		"integrationType"?: Models.IntegrationType;
		"notes"?: string;
		"intendedState": string;
		"config"?: Models.IntegrationConfigurationInfo;
		"reportedState"?: Models.IntegrationStatusInfo;
		"attributes"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface IntegrationAction { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface IntegrationActionFields { 
		"integrationAction"?: Models.IntegrationAction;
		"requestMappings"?: Array<Models.RequestMapping>;
	}
	
	export interface IntegrationConfiguration { 
		"id"?: string;
		"name": string;
		"version": number;
		"properties": object;
		"advanced": object;
		"notes": string;
		"credentials": { [key: string]: Models.CredentialInfo; };
		"selfUri"?: string;
	}
	
	export interface IntegrationConfigurationInfo { 
		"current"?: Models.IntegrationConfiguration;
	}
	
	export interface IntegrationEntityListing { 
		"entities"?: Array<Models.Integration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface IntegrationExport { 
		"integration": Models.DomainEntityRef;
		"shouldExportScreenRecordings"?: boolean;
	}
	
	export interface IntegrationStatusInfo { 
		"code"?: string;
		"effective"?: string;
		"detail"?: Models.MessageInfo;
		"lastUpdated"?: string;
	}
	
	export interface IntegrationType { 
		"id": string;
		"name"?: string;
		"description"?: string;
		"provider"?: string;
		"category"?: string;
		"images"?: Array<Models.UserImage>;
		"configPropertiesSchemaUri"?: string;
		"configAdvancedSchemaUri"?: string;
		"helpUri"?: string;
		"termsOfServiceUri"?: string;
		"vendorName"?: string;
		"vendorWebsiteUri"?: string;
		"marketplaceUri"?: string;
		"faqUri"?: string;
		"privacyPolicyUri"?: string;
		"supportContactUri"?: string;
		"salesContactUri"?: string;
		"helpLinks"?: Array<Models.HelpLink>;
		"credentials"?: { [key: string]: Models.CredentialSpecification; };
		"nonInstallable"?: boolean;
		"maxInstances"?: number;
		"userPermissions"?: Array<string>;
		"vendorOAuthClientIds"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface IntegrationTypeEntityListing { 
		"entities"?: Array<Models.IntegrationType>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Intent { 
		"name"?: string;
	}
	
	export interface IntentDefinition { 
		"id"?: string;
		"name": string;
		"entityTypeBindings"?: Array<Models.NamedEntityTypeBinding>;
		"entityNameReferences"?: Array<string>;
		"utterances": Array<Models.NluUtterance>;
		"additionalLanguages"?: { [key: string]: Models.AdditionalLanguagesIntent; };
	}
	
	export interface IntentFeedback { 
		"name"?: string;
		"probability"?: number;
		"entities"?: Array<Models.DetectedNamedEntity>;
		"assessment"?: string;
	}
	
	export interface InteractionStatsAlert { 
		"id"?: string;
		"name": string;
		"dimension": string;
		"dimensionValue": string;
		"metric": string;
		"mediaType": string;
		"numericRange": string;
		"statistic": string;
		"value": number;
		"ruleId": string;
		"unread": boolean;
		"startDate": string;
		"endDate"?: string;
		"notificationUsers": Array<Models.User>;
		"alertTypes": Array<string>;
		"ruleUri"?: string;
		"selfUri"?: string;
	}
	
	export interface InteractionStatsAlertContainer { 
		"entities"?: Array<Models.InteractionStatsAlert>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface InteractionStatsRule { 
		"id"?: string;
		"name": string;
		"dimension": string;
		"dimensionValue": string;
		"metric": string;
		"mediaType": string;
		"numericRange": string;
		"statistic": string;
		"value": number;
		"enabled": boolean;
		"inAlarm"?: boolean;
		"notificationUsers": Array<Models.User>;
		"alertTypes": Array<string>;
		"selfUri"?: string;
	}
	
	export interface InteractionStatsRuleContainer { 
		"entities"?: Array<Models.InteractionStatsRule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface IntradayPerformancePredictionData { 
		"serviceLevelPercent"?: number;
		"averageSpeedOfAnswerSeconds"?: number;
		"occupancyPercent"?: number;
	}
	
	export interface IntradayPlanningGroupRequest { 
		"businessUnitDate": string;
		"categories": Array<string>;
		"planningGroupIds"?: Array<string>;
		"intervalLengthMinutes"?: number;
	}
	
	export interface InvalidAssignment { 
		"user"?: Models.UserReference;
		"message"?: string;
	}
	
	export interface IpAddressAuthentication { 
		"networkWhitelist"?: Array<string>;
	}
	
	export interface IpAddressRange { 
		"cidr"?: string;
		"service"?: string;
		"region"?: string;
	}
	
	export interface IpAddressRangeListing { 
		"entities"?: Array<Models.IpAddressRange>;
	}
	
	export interface ItemValidationLimits { 
		"minLength": Models.MinLength;
		"maxLength": Models.MaxLength;
	}
	
	export interface Items { 
		"type"?: string;
		"pattern"?: string;
	}
	
	export interface IvrEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"ivrPhoneNumber"?: string;
		"ivrName"?: string;
		"ani"?: string;
		"dnis"?: string;
		"initialConfiguration": Models.InitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface Journey { 
		"patterns": Array<Models.JourneyPattern>;
	}
	
	export interface JourneyAction { 
		"id": string;
		"actionMap": Models.JourneyActionMap;
	}
	
	export interface JourneyActionMap { 
		"id": string;
		"version": number;
	}
	
	export interface JourneyAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface JourneyAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.JourneyAggregateQueryPredicate>;
	}
	
	export interface JourneyAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.JourneyAggregateQueryClause>;
		"predicates"?: Array<Models.JourneyAggregateQueryPredicate>;
	}
	
	export interface JourneyAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface JourneyAggregateQueryResponse { 
		"results"?: Array<Models.JourneyAggregateDataContainer>;
	}
	
	export interface JourneyAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.JourneyAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.JourneyAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface JourneyAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface JourneyApp { 
		"name": string;
		"namespace": string;
		"version": string;
		"buildNumber": string;
	}
	
	export interface JourneyAppEventsNotificationApp { 
		"name"?: string;
		"namespace"?: string;
		"version"?: string;
		"buildNumber"?: string;
	}
	
	export interface JourneyAppEventsNotificationAppEventsNotification { 
		"id"?: string;
		"correlationId"?: string;
		"externalContact"?: Models.JourneyAppEventsNotificationExternalContact;
		"createdDate"?: string;
		"customerId"?: string;
		"customerIdType"?: string;
		"session"?: Models.JourneyAppEventsNotificationSession;
		"eventType"?: string;
		"appEvent"?: Models.JourneyAppEventsNotificationAppMessage;
		"outcomeAchievedEvent"?: Models.JourneyAppEventsNotificationOutcomeAchievedMessage;
		"segmentAssignmentEvent"?: Models.JourneyAppEventsNotificationSegmentAssignmentMessage;
	}
	
	export interface JourneyAppEventsNotificationAppMessage { 
		"eventName"?: string;
		"screenName"?: string;
		"app"?: Models.JourneyAppEventsNotificationApp;
		"device"?: Models.JourneyAppEventsNotificationDevice;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"geolocation"?: Models.JourneyAppEventsNotificationGeoLocation;
		"sdkLibrary"?: Models.JourneyAppEventsNotificationSdkLibrary;
		"networkConnectivity"?: Models.JourneyAppEventsNotificationNetworkConnectivity;
		"mktCampaign"?: Models.JourneyAppEventsNotificationMktCampaign;
		"searchQuery"?: string;
		"attributes"?: { [key: string]: Models.JourneyAppEventsNotificationCustomEventAttribute; };
		"traits"?: { [key: string]: Models.JourneyAppEventsNotificationCustomEventAttribute; };
	}
	
	export interface JourneyAppEventsNotificationAssociatedValue { 
		"dataType"?: string;
		"value"?: number;
	}
	
	export interface JourneyAppEventsNotificationBrowser { 
		"family"?: string;
		"version"?: string;
		"lang"?: string;
		"fingerprint"?: string;
		"viewHeight"?: number;
		"viewWidth"?: number;
		"featuresFlash"?: boolean;
		"featuresJava"?: boolean;
		"featuresPdf"?: boolean;
		"featuresWebrtc"?: boolean;
	}
	
	export interface JourneyAppEventsNotificationCustomEventAttribute { 
		"value"?: string;
		"dataType"?: string;
	}
	
	export interface JourneyAppEventsNotificationDevice { 
		"type"?: string;
		"isMobile"?: boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily"?: string;
		"osVersion"?: string;
		"category"?: string;
		"manufacturer"?: string;
	}
	
	export interface JourneyAppEventsNotificationExternalContact { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyAppEventsNotificationGeoLocation { 
		"country"?: string;
		"countryName"?: string;
		"latitude"?: number;
		"longitude"?: number;
		"locality"?: string;
		"postalCode"?: string;
		"region"?: string;
		"regionName"?: string;
		"timezone"?: string;
		"source"?: string;
	}
	
	export interface JourneyAppEventsNotificationMktCampaign { 
		"content"?: string;
		"medium"?: string;
		"name"?: string;
		"source"?: string;
		"term"?: string;
		"clickId"?: string;
		"network"?: string;
	}
	
	export interface JourneyAppEventsNotificationNetworkConnectivity { 
		"carrier"?: string;
		"bluetoothEnabled"?: boolean;
		"cellularEnabled"?: boolean;
		"wifiEnabled"?: boolean;
	}
	
	export interface JourneyAppEventsNotificationOutcome { 
		"id"?: string;
		"selfUri"?: string;
		"displayName"?: string;
		"version"?: string;
	}
	
	export interface JourneyAppEventsNotificationOutcomeAchievedMessage { 
		"outcome"?: Models.JourneyAppEventsNotificationOutcome;
		"browser"?: Models.JourneyAppEventsNotificationBrowser;
		"visitCreatedDate"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"userAgentString"?: string;
		"device"?: Models.JourneyAppEventsNotificationDevice;
		"geolocation"?: Models.JourneyAppEventsNotificationGeoLocation;
		"mktCampaign"?: Models.JourneyAppEventsNotificationMktCampaign;
		"visitReferrer"?: Models.JourneyAppEventsNotificationReferrer;
		"associatedValue"?: Models.JourneyAppEventsNotificationAssociatedValue;
	}
	
	export interface JourneyAppEventsNotificationReferrer { 
		"url"?: string;
		"domain"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"fragment"?: string;
		"name"?: string;
		"medium"?: string;
	}
	
	export interface JourneyAppEventsNotificationSdkLibrary { 
		"name"?: string;
		"version"?: string;
	}
	
	export interface JourneyAppEventsNotificationSegment { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyAppEventsNotificationSegmentAssignmentMessage { 
		"segment"?: Models.JourneyAppEventsNotificationSegment;
	}
	
	export interface JourneyAppEventsNotificationSession { 
		"id"?: string;
		"selfUri"?: string;
		"type"?: string;
	}
	
	export interface JourneyAsyncAggregateQueryResponse { 
		"results"?: Array<Models.JourneyAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface JourneyAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.JourneyAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.JourneyAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface JourneyCampaign { 
		"content"?: string;
		"medium"?: string;
		"name"?: string;
		"source"?: string;
		"term"?: string;
		"clickId"?: string;
		"network"?: string;
	}
	
	export interface JourneyContext { 
		"customer": Models.JourneyCustomer;
		"customerSession"?: Models.JourneyCustomerSession;
		"triggeringAction"?: Models.JourneyAction;
	}
	
	export interface JourneyCustomer { 
		"id": string;
		"idType": string;
	}
	
	export interface JourneyCustomerSession { 
		"id": string;
		"type": string;
	}
	
	export interface JourneyEventDefinition { 
		"id"?: string;
		"name": string;
		"source": string;
		"description": string;
		"jsonSchema": Models.JsonSchemaDocument;
		"selfUri"?: string;
	}
	
	export interface JourneyEventDefinitionListing { 
		"total"?: number;
		"entities"?: Array<Models.JourneyEventDefinition>;
		"selfUri"?: string;
	}
	
	export interface JourneyEventsSettings { 
		"enabled"?: boolean;
		"excludedQueryParameters"?: Array<string>;
		"shouldKeepUrlFragment"?: boolean;
		"searchQueryParameters"?: Array<string>;
		"pageviewConfig"?: string;
		"clickEvents"?: Array<Models.SelectorEventTrigger>;
		"formsTrackEvents"?: Array<Models.FormsTrackTrigger>;
		"idleEvents"?: Array<Models.IdleEventTrigger>;
		"inViewportEvents"?: Array<Models.SelectorEventTrigger>;
		"scrollDepthEvents"?: Array<Models.ScrollPercentageEventTrigger>;
	}
	
	export interface JourneyGeolocation { 
		"country"?: string;
		"countryName"?: string;
		"latitude"?: number;
		"longitude"?: number;
		"locality"?: string;
		"postalCode"?: string;
		"region"?: string;
		"regionName"?: string;
		"source"?: string;
		"timezone"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationActionMap { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationAssociatedValue { 
		"dataType"?: string;
		"value"?: number;
	}
	
	export interface JourneyOutcomeEventsNotificationBrowser { 
		"family"?: string;
		"version"?: string;
		"lang"?: string;
		"fingerprint"?: string;
		"viewHeight"?: number;
		"viewWidth"?: number;
		"featuresFlash"?: boolean;
		"featuresJava"?: boolean;
		"featuresPdf"?: boolean;
		"featuresWebrtc"?: boolean;
	}
	
	export interface JourneyOutcomeEventsNotificationDevice { 
		"type"?: string;
		"isMobile"?: boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily"?: string;
		"osVersion"?: string;
		"category"?: string;
		"manufacturer"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationExternalContact { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationGeoLocation { 
		"country"?: string;
		"countryName"?: string;
		"latitude"?: number;
		"longitude"?: number;
		"locality"?: string;
		"postalCode"?: string;
		"region"?: string;
		"regionName"?: string;
		"timezone"?: string;
		"source"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationMktCampaign { 
		"content"?: string;
		"medium"?: string;
		"name"?: string;
		"source"?: string;
		"term"?: string;
		"clickId"?: string;
		"network"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationOutcome { 
		"id"?: string;
		"selfUri"?: string;
		"displayName"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationOutcomeAchievedMessage { 
		"outcome"?: Models.JourneyOutcomeEventsNotificationOutcome;
		"browser"?: Models.JourneyOutcomeEventsNotificationBrowser;
		"visitCreatedDate"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"userAgentString"?: string;
		"device"?: Models.JourneyOutcomeEventsNotificationDevice;
		"geolocation"?: Models.JourneyOutcomeEventsNotificationGeoLocation;
		"mktCampaign"?: Models.JourneyOutcomeEventsNotificationMktCampaign;
		"visitReferrer"?: Models.JourneyOutcomeEventsNotificationReferrer;
		"associatedValue"?: Models.JourneyOutcomeEventsNotificationAssociatedValue;
	}
	
	export interface JourneyOutcomeEventsNotificationOutcomeAttributionMessage { 
		"outcome"?: Models.JourneyOutcomeEventsNotificationOutcome;
		"outcomeTouchpoints"?: Array<Models.JourneyOutcomeEventsNotificationOutcomeTouchpoint>;
		"segmentAssignments"?: Array<Models.JourneyOutcomeEventsNotificationSegment>;
		"associatedValue"?: Models.JourneyOutcomeEventsNotificationAssociatedValue;
	}
	
	export interface JourneyOutcomeEventsNotificationOutcomeEventsNotification { 
		"id"?: string;
		"correlationId"?: string;
		"externalContact"?: Models.JourneyOutcomeEventsNotificationExternalContact;
		"createdDate"?: string;
		"customerId"?: string;
		"customerIdType"?: string;
		"session"?: Models.JourneyOutcomeEventsNotificationSession;
		"eventType"?: string;
		"outcomeAchievedEvent"?: Models.JourneyOutcomeEventsNotificationOutcomeAchievedMessage;
		"outcomeAttributionEventMessage"?: Models.JourneyOutcomeEventsNotificationOutcomeAttributionMessage;
	}
	
	export interface JourneyOutcomeEventsNotificationOutcomeTouchpoint { 
		"id"?: string;
		"channels"?: Array<Models.JourneyOutcomeEventsNotificationOutcomeTouchpointChannel>;
		"createdDate"?: string;
		"actionMap"?: Models.JourneyOutcomeEventsNotificationActionMap;
	}
	
	export interface JourneyOutcomeEventsNotificationOutcomeTouchpointChannel { 
		"type"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationReferrer { 
		"url"?: string;
		"domain"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"fragment"?: string;
		"name"?: string;
		"medium"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationSegment { 
		"id"?: string;
		"selfUri"?: string;
		"assignedDate"?: string;
	}
	
	export interface JourneyOutcomeEventsNotificationSession { 
		"id"?: string;
		"selfUri"?: string;
		"type"?: string;
	}
	
	export interface JourneyPage { 
		"url": string;
		"title"?: string;
		"domain": string;
		"fragment"?: string;
		"hostname": string;
		"keywords"?: string;
		"lang"?: string;
		"pathname": string;
		"queryString"?: string;
		"breadcrumb": Array<string>;
	}
	
	export interface JourneyPattern { 
		"criteria": Array<Models.Criteria>;
		"count": number;
		"streamType": string;
		"sessionType": string;
		"eventName"?: string;
	}
	
	export interface JourneySegment { 
		"id": string;
		"isActive": boolean;
		"displayName": string;
		"version": number;
		"description"?: string;
		"color": string;
		"scope": string;
		"shouldDisplayToAgent": boolean;
		"context": Models.Context;
		"journey": Models.Journey;
		"externalSegment"?: Models.ExternalSegment;
		"assignmentExpirationDays"?: number;
		"selfUri"?: string;
		"createdDate": string;
		"modifiedDate": string;
	}
	
	export interface JourneySegmentRequest { 
		"isActive"?: boolean;
		"displayName": string;
		"version"?: number;
		"description"?: string;
		"color": string;
		"scope"?: string;
		"shouldDisplayToAgent"?: boolean;
		"context": Models.RequestContext;
		"journey": Models.RequestJourney;
		"externalSegment"?: Models.RequestExternalSegment;
		"assignmentExpirationDays"?: number;
	}
	
	export interface JourneySessionEventsNotificationApp { 
		"name"?: string;
		"namespace"?: string;
		"version"?: string;
		"buildNumber"?: string;
	}
	
	export interface JourneySessionEventsNotificationBrowser { 
		"family"?: string;
		"version"?: string;
		"lang"?: string;
		"fingerprint"?: string;
		"viewHeight"?: number;
		"viewWidth"?: number;
		"featuresFlash"?: boolean;
		"featuresJava"?: boolean;
		"featuresPdf"?: boolean;
		"featuresWebrtc"?: boolean;
	}
	
	export interface JourneySessionEventsNotificationConnectedQueue { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneySessionEventsNotificationConversation { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneySessionEventsNotificationConversationChannel { 
		"type"?: string;
		"messageType"?: string;
		"platform"?: string;
	}
	
	export interface JourneySessionEventsNotificationConversationUserDisposition { 
		"code"?: string;
		"notes"?: string;
		"user"?: Models.JourneySessionEventsNotificationUser;
	}
	
	export interface JourneySessionEventsNotificationDevice { 
		"type"?: string;
		"isMobile"?: boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily"?: string;
		"osVersion"?: string;
		"category"?: string;
		"manufacturer"?: string;
	}
	
	export interface JourneySessionEventsNotificationExternalContact { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneySessionEventsNotificationGeoLocation { 
		"country"?: string;
		"countryName"?: string;
		"latitude"?: number;
		"longitude"?: number;
		"locality"?: string;
		"postalCode"?: string;
		"region"?: string;
		"regionName"?: string;
		"timezone"?: string;
		"source"?: string;
	}
	
	export interface JourneySessionEventsNotificationMktCampaign { 
		"content"?: string;
		"medium"?: string;
		"name"?: string;
		"source"?: string;
		"term"?: string;
		"clickId"?: string;
		"network"?: string;
	}
	
	export interface JourneySessionEventsNotificationNetworkConnectivity { 
		"carrier"?: string;
		"bluetoothEnabled"?: boolean;
		"cellularEnabled"?: boolean;
		"wifiEnabled"?: boolean;
	}
	
	export interface JourneySessionEventsNotificationOutcome { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneySessionEventsNotificationOutcomeAchievement { 
		"outcome"?: Models.JourneySessionEventsNotificationOutcome;
		"achievedDate"?: string;
	}
	
	export interface JourneySessionEventsNotificationPage { 
		"url"?: string;
		"title"?: string;
		"domain"?: string;
		"fragment"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"lang"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"breadcrumb"?: Array<string>;
	}
	
	export interface JourneySessionEventsNotificationReferrer { 
		"url"?: string;
		"domain"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"fragment"?: string;
		"name"?: string;
		"medium"?: string;
	}
	
	export interface JourneySessionEventsNotificationSdkLibrary { 
		"name"?: string;
		"version"?: string;
	}
	
	export interface JourneySessionEventsNotificationSegment { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneySessionEventsNotificationSegmentAssignment { 
		"segment"?: Models.JourneySessionEventsNotificationSegment;
		"assignedDate"?: string;
	}
	
	export interface JourneySessionEventsNotificationSessionEvent { 
		"id"?: string;
		"selfUri"?: string;
		"createdDate"?: string;
		"endedDate"?: string;
		"externalContact"?: Models.JourneySessionEventsNotificationExternalContact;
		"customerId"?: string;
		"customerIdType"?: string;
		"type"?: string;
		"outcomeAchievements"?: Array<Models.JourneySessionEventsNotificationOutcomeAchievement>;
		"segmentAssignments"?: Array<Models.JourneySessionEventsNotificationSegmentAssignment>;
		"awayDate"?: string;
		"browser"?: Models.JourneySessionEventsNotificationBrowser;
		"device"?: Models.JourneySessionEventsNotificationDevice;
		"geolocation"?: Models.JourneySessionEventsNotificationGeoLocation;
		"idleDate"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"lastPage"?: Models.JourneySessionEventsNotificationPage;
		"mktCampaign"?: Models.JourneySessionEventsNotificationMktCampaign;
		"referrer"?: Models.JourneySessionEventsNotificationReferrer;
		"searchTerms"?: Array<string>;
		"userAgentString"?: string;
		"durationInSeconds"?: number;
		"eventCount"?: number;
		"pageviewCount"?: number;
		"screenviewCount"?: number;
		"lastEvent"?: Models.JourneySessionEventsNotificationSessionLastEvent;
		"conversation"?: Models.JourneySessionEventsNotificationConversation;
		"originatingDirection"?: string;
		"conversationSubject"?: string;
		"lastUserDisposition"?: Models.JourneySessionEventsNotificationConversationUserDisposition;
		"lastConnectedUser"?: Models.JourneySessionEventsNotificationUser;
		"lastConnectedQueue"?: Models.JourneySessionEventsNotificationConnectedQueue;
		"conversationChannels"?: Array<Models.JourneySessionEventsNotificationConversationChannel>;
		"lastUserDisconnectType"?: string;
		"lastAcdOutcome"?: string;
		"authenticated"?: boolean;
		"app"?: Models.JourneySessionEventsNotificationApp;
		"sdkLibrary"?: Models.JourneySessionEventsNotificationSdkLibrary;
		"networkConnectivity"?: Models.JourneySessionEventsNotificationNetworkConnectivity;
		"divisionIds"?: Array<string>;
	}
	
	export interface JourneySessionEventsNotificationSessionLastEvent { 
		"id"?: string;
		"eventName"?: string;
		"createdDate"?: string;
	}
	
	export interface JourneySessionEventsNotificationUser { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneySurveyQuestion { 
		"type"?: string;
		"label": string;
		"customerProperty"?: string;
		"choices"?: Array<string>;
		"isMandatory"?: boolean;
	}
	
	export interface JourneyView { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"version"?: number;
		"createdBy"?: Models.JourneyViewUser;
		"modifiedBy"?: Models.JourneyViewUser;
		"interval"?: string;
		"duration"?: string;
		"elements": Array<Models.JourneyViewElement>;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyViewChart { 
		"id"?: string;
		"name"?: string;
		"version"?: number;
		"groupByTime"?: string;
		"groupByAttributes"?: Array<Models.JourneyViewChartGroupByAttribute>;
		"metrics": Array<Models.JourneyViewChartMetric>;
		"selfUri"?: string;
	}
	
	export interface JourneyViewChartGroupByAttribute { 
		"elementId": string;
		"attribute": string;
	}
	
	export interface JourneyViewChartMetric { 
		"id": string;
		"elementId": string;
		"aggregate"?: string;
	}
	
	export interface JourneyViewChartMetricResult { 
		"id"?: string;
		"values"?: Array<Models.JourneyViewChartMetricResultValue>;
	}
	
	export interface JourneyViewChartMetricResultValue { 
		"value"?: number;
		"groupByAttributes"?: Array<Models.GroupByAttribute>;
	}
	
	export interface JourneyViewChartResult { 
		"id"?: string;
		"version"?: number;
		"metrics"?: Array<Models.JourneyViewChartMetricResult>;
		"selfUri"?: string;
	}
	
	export interface JourneyViewElement { 
		"id": string;
		"name": string;
		"attributes": Models.JourneyViewElementAttributes;
		"filter"?: Models.JourneyViewElementFilter;
		"followedBy"?: Array<Models.JourneyViewLink>;
	}
	
	export interface JourneyViewElementAttributes { 
		"type": string;
		"id"?: string;
		"source"?: string;
	}
	
	export interface JourneyViewElementFilter { 
		"type": string;
		"predicates": Array<Models.JourneyViewElementFilterPredicate>;
	}
	
	export interface JourneyViewElementFilterPredicate { 
		"dimension": string;
		"values": Array<string>;
		"operator"?: string;
		"noValue"?: boolean;
	}
	
	export interface JourneyViewJob { 
		"id"?: string;
		"dateCreated": string;
		"dateCompleted": string;
		"status": string;
		"journeyView": Models.JourneyView;
		"selfUri"?: string;
	}
	
	export interface JourneyViewLink { 
		"id": string;
		"constraintWithin"?: Models.JourneyViewLinkTimeConstraint;
		"constraintAfter"?: Models.JourneyViewLinkTimeConstraint;
		"eventCountType"?: string;
		"joinAttributes"?: Array<string>;
	}
	
	export interface JourneyViewLinkTimeConstraint { 
		"unit"?: string;
		"value"?: number;
	}
	
	export interface JourneyViewResult { 
		"elements"?: Array<Models.JourneyViewResultElement>;
	}
	
	export interface JourneyViewResultElement { 
		"id"?: string;
		"metrics"?: Models.JourneyViewResultMetrics;
		"followedBy"?: Array<Models.JourneyViewResultLink>;
		"selfUri"?: string;
	}
	
	export interface JourneyViewResultLink { 
		"id"?: string;
		"connectionCount"?: number;
		"selfUri"?: string;
	}
	
	export interface JourneyViewResultMetrics { 
		"participantCount"?: number;
		"activeCount"?: number;
		"completedCount"?: number;
		"dropoutCount"?: number;
		"flowCount"?: number;
	}
	
	export interface JourneyViewUser { 
		"id"?: string;
		"emailAddress"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationActionMap { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationActionMapPageUrlCondition { 
		"values"?: Array<string>;
		"operator"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationActionTarget { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationBlockedWebActionOfferMessage { 
		"action"?: Models.JourneyWebActionEventsNotificationEventAction;
		"actionMap"?: Models.JourneyWebActionEventsNotificationActionMap;
		"actionTarget"?: Models.JourneyWebActionEventsNotificationActionTarget;
		"blockingReason"?: string;
		"blockingActionMap"?: Models.JourneyWebActionEventsNotificationActionMap;
		"blockingAction"?: Models.JourneyWebActionEventsNotificationEventAction;
		"blockingFrequencyCapBehaviour"?: string;
		"blockingPageUrlConditions"?: Array<Models.JourneyWebActionEventsNotificationActionMapPageUrlCondition>;
		"blockingScheduleGroup"?: Models.JourneyWebActionEventsNotificationScheduleGroup;
		"blockingEmergencyScheduleGroup"?: Models.JourneyWebActionEventsNotificationEmergencyGroup;
	}
	
	export interface JourneyWebActionEventsNotificationBrowser { 
		"family"?: string;
		"version"?: string;
		"lang"?: string;
		"fingerprint"?: string;
		"viewHeight"?: number;
		"viewWidth"?: number;
		"featuresFlash"?: boolean;
		"featuresJava"?: boolean;
		"featuresPdf"?: boolean;
		"featuresWebrtc"?: boolean;
	}
	
	export interface JourneyWebActionEventsNotificationDevice { 
		"type"?: string;
		"isMobile"?: boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily"?: string;
		"osVersion"?: string;
		"category"?: string;
		"manufacturer"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationEmergencyGroup { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationEventAction { 
		"id"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationExternalContact { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationGeoLocation { 
		"country"?: string;
		"countryName"?: string;
		"latitude"?: number;
		"longitude"?: number;
		"locality"?: string;
		"postalCode"?: string;
		"region"?: string;
		"regionName"?: string;
		"timezone"?: string;
		"source"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationMktCampaign { 
		"content"?: string;
		"medium"?: string;
		"name"?: string;
		"source"?: string;
		"term"?: string;
		"clickId"?: string;
		"network"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationReferrer { 
		"url"?: string;
		"domain"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"fragment"?: string;
		"name"?: string;
		"medium"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationScheduleGroup { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationSession { 
		"id"?: string;
		"selfUri"?: string;
		"type"?: string;
	}
	
	export interface JourneyWebActionEventsNotificationWebActionEventsNotification { 
		"id"?: string;
		"correlationId"?: string;
		"externalContact"?: Models.JourneyWebActionEventsNotificationExternalContact;
		"createdDate"?: string;
		"customerId"?: string;
		"customerIdType"?: string;
		"session"?: Models.JourneyWebActionEventsNotificationSession;
		"eventType"?: string;
		"webActionEvent"?: Models.JourneyWebActionEventsNotificationWebActionMessage;
		"blockedWebActionOfferEvent"?: Models.JourneyWebActionEventsNotificationBlockedWebActionOfferMessage;
	}
	
	export interface JourneyWebActionEventsNotificationWebActionMessage { 
		"action"?: Models.JourneyWebActionEventsNotificationEventAction;
		"actionTarget"?: Models.JourneyWebActionEventsNotificationActionTarget;
		"actionMap"?: Models.JourneyWebActionEventsNotificationActionMap;
		"errorCode"?: string;
		"errorMessage"?: string;
		"userAgentString"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"browser"?: Models.JourneyWebActionEventsNotificationBrowser;
		"device"?: Models.JourneyWebActionEventsNotificationDevice;
		"geolocation"?: Models.JourneyWebActionEventsNotificationGeoLocation;
		"mktCampaign"?: Models.JourneyWebActionEventsNotificationMktCampaign;
		"visitReferrer"?: Models.JourneyWebActionEventsNotificationReferrer;
		"timeToDisposition"?: number;
	}
	
	export interface JourneyWebEventsNotificationActionMap { 
		"id"?: string;
		"selfUri"?: string;
		"displayName"?: string;
		"version"?: number;
	}
	
	export interface JourneyWebEventsNotificationActionTarget { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebEventsNotificationAssociatedValue { 
		"dataType"?: string;
		"value"?: number;
	}
	
	export interface JourneyWebEventsNotificationBrowser { 
		"family"?: string;
		"version"?: string;
		"lang"?: string;
		"fingerprint"?: string;
		"viewHeight"?: number;
		"viewWidth"?: number;
		"featuresFlash"?: boolean;
		"featuresJava"?: boolean;
		"featuresPdf"?: boolean;
		"featuresWebrtc"?: boolean;
	}
	
	export interface JourneyWebEventsNotificationCustomEventAttribute { 
		"value"?: string;
		"dataType"?: string;
	}
	
	export interface JourneyWebEventsNotificationDevice { 
		"type"?: string;
		"isMobile"?: boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily"?: string;
		"osVersion"?: string;
		"category"?: string;
		"manufacturer"?: string;
	}
	
	export interface JourneyWebEventsNotificationEventAction { 
		"id"?: string;
		"createdDate"?: string;
		"state"?: string;
		"mediaType"?: string;
		"prompt"?: string;
	}
	
	export interface JourneyWebEventsNotificationExternalContact { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebEventsNotificationGeoLocation { 
		"country"?: string;
		"countryName"?: string;
		"latitude"?: number;
		"longitude"?: number;
		"locality"?: string;
		"postalCode"?: string;
		"region"?: string;
		"regionName"?: string;
		"timezone"?: string;
		"source"?: string;
	}
	
	export interface JourneyWebEventsNotificationMktCampaign { 
		"content"?: string;
		"medium"?: string;
		"name"?: string;
		"source"?: string;
		"term"?: string;
		"clickId"?: string;
		"network"?: string;
	}
	
	export interface JourneyWebEventsNotificationOutcome { 
		"id"?: string;
		"selfUri"?: string;
		"displayName"?: string;
		"version"?: string;
	}
	
	export interface JourneyWebEventsNotificationOutcomeAchievedMessage { 
		"outcome"?: Models.JourneyWebEventsNotificationOutcome;
		"browser"?: Models.JourneyWebEventsNotificationBrowser;
		"visitCreatedDate"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"userAgentString"?: string;
		"device"?: Models.JourneyWebEventsNotificationDevice;
		"geolocation"?: Models.JourneyWebEventsNotificationGeoLocation;
		"mktCampaign"?: Models.JourneyWebEventsNotificationMktCampaign;
		"visitReferrer"?: Models.JourneyWebEventsNotificationReferrer;
		"associatedValue"?: Models.JourneyWebEventsNotificationAssociatedValue;
	}
	
	export interface JourneyWebEventsNotificationPage { 
		"url"?: string;
		"title"?: string;
		"domain"?: string;
		"fragment"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"lang"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"breadcrumb"?: Array<string>;
	}
	
	export interface JourneyWebEventsNotificationReferrer { 
		"url"?: string;
		"domain"?: string;
		"hostname"?: string;
		"keywords"?: string;
		"pathname"?: string;
		"queryString"?: string;
		"fragment"?: string;
		"name"?: string;
		"medium"?: string;
	}
	
	export interface JourneyWebEventsNotificationSegment { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface JourneyWebEventsNotificationSegmentAssignmentMessage { 
		"segment"?: Models.JourneyWebEventsNotificationSegment;
	}
	
	export interface JourneyWebEventsNotificationSession { 
		"id"?: string;
		"selfUri"?: string;
		"type"?: string;
	}
	
	export interface JourneyWebEventsNotificationWebActionMessage { 
		"action"?: Models.JourneyWebEventsNotificationEventAction;
		"actionTarget"?: Models.JourneyWebEventsNotificationActionTarget;
		"actionMap"?: Models.JourneyWebEventsNotificationActionMap;
		"errorCode"?: string;
		"errorMessage"?: string;
		"userAgentString"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"browser"?: Models.JourneyWebEventsNotificationBrowser;
		"device"?: Models.JourneyWebEventsNotificationDevice;
		"geolocation"?: Models.JourneyWebEventsNotificationGeoLocation;
		"mktCampaign"?: Models.JourneyWebEventsNotificationMktCampaign;
		"visitReferrer"?: Models.JourneyWebEventsNotificationReferrer;
		"timeToDisposition"?: number;
	}
	
	export interface JourneyWebEventsNotificationWebEventsNotification { 
		"id"?: string;
		"correlationId"?: string;
		"externalContact"?: Models.JourneyWebEventsNotificationExternalContact;
		"createdDate"?: string;
		"customerId"?: string;
		"customerIdType"?: string;
		"session"?: Models.JourneyWebEventsNotificationSession;
		"eventType"?: string;
		"webEvent"?: Models.JourneyWebEventsNotificationWebMessage;
		"webActionEvent"?: Models.JourneyWebEventsNotificationWebActionMessage;
		"outcomeAchievedEvent"?: Models.JourneyWebEventsNotificationOutcomeAchievedMessage;
		"segmentAssignmentEvent"?: Models.JourneyWebEventsNotificationSegmentAssignmentMessage;
	}
	
	export interface JourneyWebEventsNotificationWebMessage { 
		"eventName"?: string;
		"totalEventCount"?: number;
		"totalPageviewCount"?: number;
		"userAgentString"?: string;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"searchQuery"?: string;
		"authenticated"?: boolean;
		"browser"?: Models.JourneyWebEventsNotificationBrowser;
		"device"?: Models.JourneyWebEventsNotificationDevice;
		"geolocation"?: Models.JourneyWebEventsNotificationGeoLocation;
		"mktCampaign"?: Models.JourneyWebEventsNotificationMktCampaign;
		"page"?: Models.JourneyWebEventsNotificationPage;
		"referrer"?: Models.JourneyWebEventsNotificationReferrer;
		"attributes"?: { [key: string]: Models.JourneyWebEventsNotificationCustomEventAttribute; };
		"traits"?: { [key: string]: Models.JourneyWebEventsNotificationCustomEventAttribute; };
	}
	
	export interface JsonCursorSearchResponse { 
		"types": Array<string>;
		"results": object;
		"aggregations"?: object;
		"cursor"?: string;
	}
	
	export interface JsonNode { 
	}
	
	export interface JsonNodeSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": object;
		"aggregations"?: object;
	}
	
	export interface JsonSchemaDocument { 
		"id"?: string;
		"$schema"?: string;
		"title"?: string;
		"description"?: string;
		"type"?: string;
		"required"?: Array<string>;
		"properties"?: { [key: string]: object; };
		"additionalProperties"?: object;
	}
	
	export interface JsonSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"types": Array<string>;
		"results": object;
		"aggregations"?: object;
	}
	
	export interface KeyPerformanceIndicator { 
		"id"?: string;
		"name"?: string;
		"optimizationType"?: string;
		"problemType"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"description"?: string;
		"kpiType"?: string;
		"source"?: string;
		"wrapUpCodeConfig"?: Models.WrapUpCodeConfig;
		"outcomeConfig"?: Models.OutcomeConfig;
		"status"?: string;
		"kpiGroup"?: string;
		"queues"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface KeyPerformanceIndicatorAssessment { 
		"kpi"?: string;
		"assessmentResult"?: string;
		"checks"?: Array<Models.Check>;
	}
	
	export interface KeyRotationSchedule { 
		"id"?: string;
		"name"?: string;
		"period": string;
		"selfUri"?: string;
	}
	
	export interface KeyValue { 
		"key": string;
		"value": string;
	}
	
	export interface KlaxonHeartBeatAlertsTopicHeartBeatAlert { 
		"id"?: string;
		"name"?: string;
		"senderId"?: string;
		"heartBeatTimeoutInMinutes"?: number;
		"ruleId"?: string;
		"startDate"?: string;
		"endDate"?: string;
		"notificationUsers"?: Array<Models.KlaxonHeartBeatAlertsTopicNotificationUser>;
		"alertTypes"?: Array<string>;
		"ruleType"?: string;
	}
	
	export interface KlaxonHeartBeatAlertsTopicNotificationUser { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface KlaxonHeartBeatRulesTopicHeartBeatRule { 
		"id"?: string;
		"name"?: string;
		"senderId"?: string;
		"heartBeatTimeoutInMinutes"?: number;
		"enabled"?: boolean;
		"inAlarm"?: boolean;
		"notificationUsers"?: Array<Models.KlaxonHeartBeatRulesTopicNotificationUser>;
		"alertTypes"?: Array<string>;
		"ruleType"?: string;
	}
	
	export interface KlaxonHeartBeatRulesTopicNotificationUser { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface KlaxonInteractionStatsAlertsTopicInteractionStatAlert { 
		"id"?: string;
		"name"?: string;
		"ruleId"?: string;
		"dimension"?: string;
		"dimensionValue"?: string;
		"dimensionValueName"?: string;
		"metric"?: string;
		"mediaType"?: string;
		"numericRange"?: string;
		"statistic"?: string;
		"value"?: number;
		"unread"?: boolean;
		"startDate"?: string;
		"endDate"?: string;
		"notificationUsers"?: Array<Models.KlaxonInteractionStatsAlertsTopicNotificationUser>;
		"alertTypes"?: Array<string>;
	}
	
	export interface KlaxonInteractionStatsAlertsTopicNotificationUser { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface KlaxonInteractionStatsRulesTopicInteractionStatRule { 
		"id"?: string;
		"name"?: string;
		"dimension"?: string;
		"dimensionValue"?: string;
		"dimensionValueName"?: string;
		"metric"?: string;
		"mediaType"?: string;
		"numericRange"?: string;
		"statistic"?: string;
		"value"?: number;
		"inAlarm"?: boolean;
		"enabled"?: boolean;
		"notificationUsers"?: Array<Models.KlaxonInteractionStatsRulesTopicNotificationUser>;
		"alertTypes"?: Array<string>;
	}
	
	export interface KlaxonInteractionStatsRulesTopicNotificationUser { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface Knowledge { 
		"enabled"?: boolean;
		"knowledgeBase"?: Models.AddressableEntityRef;
	}
	
	export interface KnowledgeAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface KnowledgeAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.KnowledgeAggregateQueryPredicate>;
	}
	
	export interface KnowledgeAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.KnowledgeAggregateQueryClause>;
		"predicates"?: Array<Models.KnowledgeAggregateQueryPredicate>;
	}
	
	export interface KnowledgeAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface KnowledgeAggregateQueryResponse { 
		"results"?: Array<Models.KnowledgeAggregateDataContainer>;
	}
	
	export interface KnowledgeAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.KnowledgeAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.KnowledgeAggregationView>;
		"alternateTimeDimension"?: string;
		"queryType"?: string;
		"limit"?: number;
	}
	
	export interface KnowledgeAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface KnowledgeAsyncAggregateQueryResponse { 
		"results"?: Array<Models.KnowledgeAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface KnowledgeAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.KnowledgeAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.KnowledgeAggregationView>;
		"alternateTimeDimension"?: string;
		"queryType"?: string;
		"limit"?: number;
		"pageSize"?: number;
	}
	
	export interface KnowledgeBase { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"coreLanguage": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"faqCount"?: number;
		"dateDocumentLastModified"?: string;
		"articleCount"?: number;
		"published"?: boolean;
		"selfUri"?: string;
	}
	
	export interface KnowledgeBaseCreateRequest { 
		"name": string;
		"description"?: string;
		"coreLanguage": string;
	}
	
	export interface KnowledgeBaseListing { 
		"entities"?: Array<Models.KnowledgeBase>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface KnowledgeBaseReference { 
		"id": string;
		"languageCode"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeBaseUpdateRequest { 
		"name"?: string;
		"description"?: string;
	}
	
	export interface KnowledgeCategory { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"knowledgeBase"?: Models.KnowledgeBase;
		"languageCode"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeCategoryRequest { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"parent"?: Models.DocumentCategoryInput;
		"selfUri"?: string;
	}
	
	export interface KnowledgeContextReference { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeContextValueReference { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeConversationContext { 
		"conversationId": string;
		"mediaType"?: string;
		"queueId"?: string;
		"externalContactId"?: string;
	}
	
	export interface KnowledgeConversationContextResponse { 
		"conversation": Models.AddressableEntityRef;
		"queue"?: Models.AddressableEntityRef;
		"externalContact"?: Models.AddressableEntityRef;
		"mediaType"?: string;
	}
	
	export interface KnowledgeDocument { 
		"id"?: string;
		"name"?: string;
		"languageCode": string;
		"type": string;
		"faq"?: Models.DocumentFaq;
		"dateCreated"?: string;
		"dateModified"?: string;
		"categories"?: Array<Models.KnowledgeCategory>;
		"knowledgeBase"?: Models.KnowledgeBase;
		"externalUrl"?: string;
		"article"?: Models.DocumentArticle;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentAlternative { 
		"phrase": string;
		"autocomplete": boolean;
	}
	
	export interface KnowledgeDocumentBulkRemoveRequest { 
		"entities": Array<Models.WritableEntity>;
	}
	
	export interface KnowledgeDocumentBulkRequest { 
		"type": string;
		"externalUrl"?: string;
		"faq"?: Models.DocumentFaq;
		"categories"?: Array<Models.DocumentCategoryInput>;
		"article"?: Models.DocumentArticle;
		"id"?: string;
	}
	
	export interface KnowledgeDocumentBulkUpdateEntity { 
		"id"?: string;
		"categoryId"?: string;
		"labelIds"?: Array<string>;
	}
	
	export interface KnowledgeDocumentBulkUpdateRequest { 
		"entities": Array<Models.KnowledgeDocumentBulkUpdateEntity>;
	}
	
	export interface KnowledgeDocumentBulkVersionAddEntity { 
		"id"?: string;
		"restoreFromVersionId"?: string;
		"restorePrevious"?: boolean;
	}
	
	export interface KnowledgeDocumentBulkVersionAddRequest { 
		"entities": Array<Models.KnowledgeDocumentBulkVersionAddEntity>;
	}
	
	export interface KnowledgeDocumentContentUpload { 
		"id"?: string;
		"contentType": string;
		"fileName": string;
		"status"?: string;
		"uploadKey"?: string;
		"url"?: string;
		"headers"?: { [key: string]: string; };
		"document"?: Models.AddressableEntityRef;
		"errorMessage"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentCopy { 
		"documentVariationId": string;
		"documentVersionId": string;
		"searchId"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"sessionId"?: string;
		"conversationContext"?: Models.KnowledgeConversationContext;
		"application": Models.KnowledgeSearchClientApplication;
	}
	
	export interface KnowledgeDocumentFeedback { 
		"id"?: string;
		"documentVariation": Models.EntityReference;
		"rating": string;
		"reason"?: string;
		"comment"?: string;
		"search"?: Models.EntityReference;
		"sessionId"?: string;
		"dateCreated"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"state"?: string;
		"document": Models.KnowledgeDocumentVersionReference;
		"application": Models.KnowledgeSearchClientApplication;
		"conversationContext"?: Models.KnowledgeConversationContext;
		"userId"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentFeedbackResponse { 
		"id"?: string;
		"documentVariation": Models.EntityReference;
		"rating": string;
		"reason"?: string;
		"comment"?: string;
		"search"?: Models.EntityReference;
		"sessionId"?: string;
		"dateCreated"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"state"?: string;
		"document"?: Models.KnowledgeDocumentVersionReference;
		"application"?: Models.KnowledgeSearchClientApplication;
		"conversationContext"?: Models.KnowledgeConversationContextResponse;
		"user"?: Models.AddressableEntityRef;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentFeedbackResponseListing { 
		"entities"?: Array<Models.KnowledgeDocumentFeedbackResponse>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface KnowledgeDocumentGuestSearch { 
		"query": string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"searchId"?: string;
		"total"?: number;
		"pageCount"?: number;
		"queryType"?: string;
		"sessionId"?: string;
		"results"?: Array<Models.KnowledgeDocumentGuestSearchResult>;
	}
	
	export interface KnowledgeDocumentGuestSearchRequest { 
		"query": string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"searchId"?: string;
		"total"?: number;
		"pageCount"?: number;
		"queryType"?: string;
		"sessionId"?: string;
		"answerHighlightTopResults"?: number;
		"includeDraftDocuments"?: boolean;
	}
	
	export interface KnowledgeDocumentGuestSearchResult { 
		"confidence"?: number;
		"document"?: Models.KnowledgeGuestSearchDocumentResponse;
	}
	
	export interface KnowledgeDocumentPresentation { 
		"documents": Array<Models.KnowledgeDocumentVersionVariationReference>;
		"searchId"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"sessionId"?: string;
		"conversationContext"?: Models.KnowledgeConversationContext;
		"application": Models.KnowledgeSearchClientApplication;
	}
	
	export interface KnowledgeDocumentReference { 
		"id": string;
		"knowledgeBase": Models.KnowledgeBaseReference;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentReq { 
		"id"?: string;
		"title": string;
		"visible"?: boolean;
		"alternatives"?: Array<Models.KnowledgeDocumentAlternative>;
		"categoryId"?: string;
		"labelIds"?: Array<string>;
		"externalId"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentRequest { 
		"type": string;
		"externalUrl"?: string;
		"faq"?: Models.DocumentFaq;
		"categories"?: Array<Models.DocumentCategoryInput>;
		"article"?: Models.DocumentArticle;
	}
	
	export interface KnowledgeDocumentResponse { 
		"id"?: string;
		"title"?: string;
		"visible"?: boolean;
		"alternatives"?: Array<Models.KnowledgeDocumentAlternative>;
		"state"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateImported"?: string;
		"lastPublishedVersionNumber"?: number;
		"datePublished"?: string;
		"createdBy"?: Models.UserReference;
		"modifiedBy"?: Models.UserReference;
		"documentVersion"?: Models.AddressableEntityRef;
		"category"?: Models.CategoryResponse;
		"labels"?: Array<Models.LabelResponse>;
		"knowledgeBase"?: Models.KnowledgeBaseReference;
		"externalId"?: string;
		"variations"?: Array<Models.DocumentVariation>;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentResponseListing { 
		"entities"?: Array<Models.KnowledgeDocumentResponse>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface KnowledgeDocumentSearch { 
		"query": string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"searchId"?: string;
		"total"?: number;
		"pageCount"?: number;
		"queryType"?: string;
		"results"?: Array<Models.KnowledgeDocumentSearchResult>;
		"application"?: Models.KnowledgeSearchClientApplication;
		"conversationContext"?: Models.KnowledgeConversationContextResponse;
		"confidenceThreshold"?: number;
	}
	
	export interface KnowledgeDocumentSearchRequest { 
		"query": string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"searchId"?: string;
		"total"?: number;
		"pageCount"?: number;
		"queryType"?: string;
		"includeDraftDocuments"?: boolean;
		"interval"?: Models.DocumentQueryInterval;
		"filter"?: Models.DocumentQuery;
		"sortOrder"?: string;
		"sortBy"?: string;
		"application"?: Models.KnowledgeSearchClientApplication;
		"conversationContext"?: Models.KnowledgeConversationContext;
		"confidenceThreshold"?: number;
		"answerHighlightTopResults"?: number;
	}
	
	export interface KnowledgeDocumentSearchResult { 
		"confidence"?: number;
		"document"?: Models.KnowledgeSearchDocumentResponse;
	}
	
	export interface KnowledgeDocumentSuggestion { 
		"query": string;
		"pageSize"?: number;
		"results"?: Array<Models.KnowledgeDocumentSuggestionResult>;
	}
	
	export interface KnowledgeDocumentSuggestionRequest { 
		"query": string;
		"pageSize"?: number;
		"includeDraftDocuments"?: boolean;
		"interval"?: Models.DocumentQueryInterval;
		"filter"?: Models.DocumentQuery;
	}
	
	export interface KnowledgeDocumentSuggestionResult { 
		"matchedPhrase"?: string;
		"document"?: Models.KnowledgeDocumentSuggestionResultDocument;
	}
	
	export interface KnowledgeDocumentSuggestionResultDocument { 
		"id": string;
		"knowledgeBase": Models.KnowledgeBaseReference;
		"title": string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentVersion { 
		"id"?: string;
		"datePublished"?: string;
		"document"?: Models.KnowledgeDocumentResponse;
		"restoreFromVersionId": string;
		"versionNumber"?: number;
		"dateExpires"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentVersionListing { 
		"entities"?: Array<Models.KnowledgeDocumentVersion>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface KnowledgeDocumentVersionReference { 
		"id"?: string;
		"knowledgeBase": Models.KnowledgeBaseReference;
		"versionId": string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeDocumentVersionVariation { 
		"id"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"contexts": Array<Models.DocumentVariationContext>;
		"priority"?: number;
		"name"?: string;
		"body"?: Models.DocumentBody;
		"selfUri"?: string;
		"documentVersion"?: Models.AddressableEntityRef;
	}
	
	export interface KnowledgeDocumentVersionVariationListing { 
		"entities"?: Array<Models.KnowledgeDocumentVersionVariation>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface KnowledgeDocumentVersionVariationReference { 
		"documentId": string;
		"documentVariationId": string;
		"documentVersionId": string;
	}
	
	export interface KnowledgeDocumentView { 
		"documentVariationId": string;
		"documentVersionId": string;
		"searchId"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"application": Models.KnowledgeSearchClientApplication;
		"sessionId"?: string;
		"conversationContext"?: Models.KnowledgeConversationContext;
	}
	
	export interface KnowledgeExportJobDocumentsFilter { 
		"interval"?: string;
		"entities"?: Array<Models.Entity>;
	}
	
	export interface KnowledgeExportJobFilter { 
		"documentsFilter"?: Models.KnowledgeExportJobDocumentsFilter;
		"versionFilter": string;
	}
	
	export interface KnowledgeExportJobRequest { 
		"exportFilter": Models.KnowledgeExportJobFilter;
		"fileType": string;
		"jsonFileVersion"?: number;
	}
	
	export interface KnowledgeExportJobResponse { 
		"id"?: string;
		"downloadURL"?: string;
		"fileType": string;
		"jsonFileVersion"?: number;
		"countDocumentProcessed"?: number;
		"exportFilter"?: Models.KnowledgeExportJobFilter;
		"status"?: string;
		"knowledgeBase"?: Models.KnowledgeBase;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"dateModified"?: string;
		"errorInformation"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface KnowledgeExtendedCategory { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"knowledgeBase"?: Models.KnowledgeBase;
		"languageCode"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"parent"?: Models.KnowledgeCategory;
		"children"?: Array<Models.KnowledgeCategory>;
		"selfUri"?: string;
	}
	
	export interface KnowledgeGroupStatistics { 
		"unlinkedPhraseCount"?: number;
		"unlinkedPhraseHitCount"?: number;
		"totalPhraseHitCount"?: number;
	}
	
	export interface KnowledgeGuestDocumentCopy { 
		"documentVariationId": string;
		"documentVersionId": string;
		"searchId"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"sessionId"?: string;
		"application"?: Models.KnowledgeGuestSearchClientApplication;
	}
	
	export interface KnowledgeGuestDocumentFeedback { 
		"id"?: string;
		"documentVariation": Models.EntityReference;
		"rating": string;
		"reason"?: string;
		"comment"?: string;
		"search"?: Models.EntityReference;
		"sessionId"?: string;
		"dateCreated"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"state"?: string;
		"document": Models.KnowledgeGuestDocumentVersionReference;
		"application"?: Models.KnowledgeGuestSearchClientApplication;
	}
	
	export interface KnowledgeGuestDocumentPresentation { 
		"documents": Array<Models.KnowledgeDocumentVersionVariationReference>;
		"searchId"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
		"sessionId"?: string;
		"application"?: Models.KnowledgeGuestSearchClientApplication;
	}
	
	export interface KnowledgeGuestDocumentResponse { 
		"id"?: string;
		"title"?: string;
		"visible"?: boolean;
		"alternatives"?: Array<Models.KnowledgeDocumentAlternative>;
		"state"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateImported"?: string;
		"lastPublishedVersionNumber"?: number;
		"datePublished"?: string;
		"createdBy"?: Models.UserReference;
		"modifiedBy"?: Models.UserReference;
		"documentVersion"?: Models.AddressableEntityRef;
		"sessionId"?: string;
		"category"?: Models.GuestCategoryReference;
		"variations"?: Array<Models.KnowledgeGuestDocumentVariation>;
		"selfUri"?: string;
	}
	
	export interface KnowledgeGuestDocumentResponseListing { 
		"entities"?: Array<Models.KnowledgeGuestDocumentResponse>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface KnowledgeGuestDocumentSuggestion { 
		"query": string;
		"pageSize"?: number;
		"sessionId"?: string;
		"results"?: Array<Models.KnowledgeGuestDocumentSuggestionResult>;
	}
	
	export interface KnowledgeGuestDocumentSuggestionRequest { 
		"query": string;
		"pageSize"?: number;
		"includeDraftDocuments"?: boolean;
	}
	
	export interface KnowledgeGuestDocumentSuggestionResult { 
		"matchedPhrase"?: string;
	}
	
	export interface KnowledgeGuestDocumentVariation { 
		"id"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"documentVersion"?: Models.AddressableEntityRef;
		"contexts": Array<Models.KnowledgeGuestDocumentVariationContext>;
		"document"?: Models.AddressableEntityRef;
		"body"?: Models.DocumentBody;
		"selfUri"?: string;
	}
	
	export interface KnowledgeGuestDocumentVariationAnswer { 
		"id"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"documentVersion"?: Models.AddressableEntityRef;
		"contexts": Array<Models.KnowledgeGuestDocumentVariationContext>;
		"document"?: Models.AddressableEntityRef;
		"body"?: Models.DocumentBodyWithHighlight;
		"selfUri"?: string;
	}
	
	export interface KnowledgeGuestDocumentVariationContext { 
		"context": Models.AddressableEntityRef;
		"values": Array<Models.AddressableEntityRef>;
	}
	
	export interface KnowledgeGuestDocumentVersionReference { 
		"id"?: string;
		"versionId": string;
	}
	
	export interface KnowledgeGuestDocumentView { 
		"documentVariationId": string;
		"documentVersionId": string;
		"searchId"?: string;
		"queryType"?: string;
		"surfacingMethod"?: string;
	}
	
	export interface KnowledgeGuestSearchClientApplication { 
		"type": string;
		"deployment"?: Models.EntityReference;
		"botFlow"?: Models.EntityReference;
		"assistant"?: Models.EntityReference;
	}
	
	export interface KnowledgeGuestSearchDocumentResponse { 
		"id"?: string;
		"title"?: string;
		"visible"?: boolean;
		"alternatives"?: Array<Models.KnowledgeDocumentAlternative>;
		"state"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateImported"?: string;
		"lastPublishedVersionNumber"?: number;
		"datePublished"?: string;
		"createdBy"?: Models.UserReference;
		"modifiedBy"?: Models.UserReference;
		"documentVersion"?: Models.AddressableEntityRef;
		"sessionId"?: string;
		"category"?: Models.GuestCategoryReference;
		"variations"?: Array<Models.KnowledgeGuestDocumentVariationAnswer>;
		"answer"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeGuestSession { 
		"id"?: string;
		"app": Models.KnowledgeGuestSessionApp;
		"customerId": string;
		"pageUrl"?: string;
		"contexts"?: Array<Models.KnowledgeGuestSessionContext>;
	}
	
	export interface KnowledgeGuestSessionApp { 
		"deploymentId": string;
		"type": string;
	}
	
	export interface KnowledgeGuestSessionContext { 
		"id": string;
		"values": Array<Models.Entity>;
	}
	
	export interface KnowledgeImport { 
		"id"?: string;
		"name"?: string;
		"uploadKey": string;
		"fileType": string;
		"ignoreHeaders"?: boolean;
		"status"?: string;
		"report"?: Models.ImportReport;
		"knowledgeBase"?: Models.KnowledgeBase;
		"languageCode"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeImportJobError { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.Detail>;
		"errors"?: Array<Models.ErrorBody>;
		"limit"?: Models.Limit;
		"documentIndex"?: number;
	}
	
	export interface KnowledgeImportJobReport { 
		"errors"?: Array<Models.KnowledgeImportJobError>;
		"statistics"?: Models.KnowledgeImportJobStatistics;
	}
	
	export interface KnowledgeImportJobRequest { 
		"uploadKey": string;
		"fileType": string;
		"settings"?: Models.KnowledgeImportJobSettings;
		"skipConfirmationStep"?: boolean;
	}
	
	export interface KnowledgeImportJobResponse { 
		"id"?: string;
		"downloadURL"?: string;
		"failedEntitiesURL"?: string;
		"uploadKey": string;
		"fileType": string;
		"settings"?: Models.KnowledgeImportJobSettings;
		"status"?: string;
		"report"?: Models.KnowledgeImportJobReport;
		"knowledgeBase"?: Models.KnowledgeBase;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"dateModified"?: string;
		"skipConfirmationStep"?: boolean;
		"selfUri"?: string;
	}
	
	export interface KnowledgeImportJobSettings { 
		"importAsNew"?: boolean;
		"visible"?: boolean;
		"categoryId"?: string;
		"labelIds"?: Array<string>;
	}
	
	export interface KnowledgeImportJobStatistics { 
		"countDocumentImportActivityCreate"?: number;
		"countDocumentImportActivityUpdate"?: number;
		"countDocumentStateDraft"?: number;
		"countDocumentStatePublished"?: number;
		"countDocumentValidationSuccess"?: number;
		"countDocumentValidationFailure"?: number;
		"countDocumentImportSuccess"?: number;
		"countDocumentImportFailure"?: number;
		"countCategoryValidationSuccess"?: number;
		"countCategoryValidationFailure"?: number;
		"countCategoryImportSuccess"?: number;
		"countCategoryImportFailure"?: number;
		"countLabelValidationSuccess"?: number;
		"countLabelValidationFailure"?: number;
		"countLabelImportSuccess"?: number;
		"countLabelImportFailure"?: number;
		"migrationDetected"?: boolean;
	}
	
	export interface KnowledgeParseImportResult { 
		"success": number;
		"failure": number;
		"errors"?: Array<Models.ErrorBody>;
	}
	
	export interface KnowledgeParseJobRequest { 
		"uploadKey": string;
		"hints"?: Array<string>;
	}
	
	export interface KnowledgeParseJobRequestImport { 
		"edits"?: Array<Models.KnowledgeParseRecord>;
		"excludes"?: Array<string>;
	}
	
	export interface KnowledgeParseJobRequestPatch { 
		"hints"?: Array<string>;
	}
	
	export interface KnowledgeParseJobResponse { 
		"id"?: string;
		"downloadURL"?: string;
		"hints"?: Array<string>;
		"status"?: string;
		"parseResults"?: Array<Models.KnowledgeParseRecord>;
		"importResult"?: Models.KnowledgeParseImportResult;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeParseRecord { 
		"id"?: string;
		"title"?: string;
		"body"?: Models.DocumentBody;
	}
	
	export interface KnowledgeSearchClientApplication { 
		"type": string;
		"deployment"?: Models.AddressableEntityRef;
		"botFlow"?: Models.AddressableEntityRef;
		"assistant"?: Models.AddressableEntityRef;
	}
	
	export interface KnowledgeSearchDocumentResponse { 
		"id"?: string;
		"title"?: string;
		"visible"?: boolean;
		"alternatives"?: Array<Models.KnowledgeDocumentAlternative>;
		"state"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateImported"?: string;
		"lastPublishedVersionNumber"?: number;
		"datePublished"?: string;
		"createdBy"?: Models.UserReference;
		"modifiedBy"?: Models.UserReference;
		"documentVersion"?: Models.AddressableEntityRef;
		"category"?: Models.CategoryResponse;
		"labels"?: Array<Models.LabelResponse>;
		"knowledgeBase"?: Models.KnowledgeBaseReference;
		"externalId"?: string;
		"variations"?: Array<Models.DocumentVariationAnswer>;
		"answer"?: string;
		"selfUri"?: string;
	}
	
	export interface KnowledgeSearchDocumentV1 { 
		"id"?: string;
		"name"?: string;
		"languageCode": string;
		"type": string;
		"faq"?: Models.DocumentFaq;
		"dateCreated"?: string;
		"dateModified"?: string;
		"categories"?: Array<Models.KnowledgeCategory>;
		"knowledgeBase"?: Models.KnowledgeBase;
		"externalUrl"?: string;
		"article"?: Models.DocumentArticle;
		"confidence"?: number;
		"selfUri"?: string;
	}
	
	export interface KnowledgeSearchRequest { 
		"query": string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"documentType"?: string;
		"languageCode": string;
		"searchOnDraftDocuments"?: boolean;
	}
	
	export interface KnowledgeSearchResponse { 
		"searchId"?: string;
		"total"?: number;
		"pageCount"?: number;
		"pageSize"?: number;
		"pageNumber"?: number;
		"results"?: Array<Models.KnowledgeSearchDocumentV1>;
	}
	
	export interface KnowledgeTraining { 
		"id"?: string;
		"dateTriggered"?: string;
		"dateCompleted"?: string;
		"status"?: string;
		"languageCode"?: string;
		"knowledgeBase"?: Models.KnowledgeBase;
		"errorMessage"?: string;
		"knowledgeDocumentsState"?: string;
		"datePromoted"?: string;
		"selfUri"?: string;
	}
	
	export interface KpiResult { 
		"kpiTotalOn"?: number;
		"kpiTotalOff"?: number;
		"interactionCountOn"?: number;
		"interactionCountOff"?: number;
		"mediaType"?: string;
		"percentageBenefit"?: number;
	}
	
	export interface Label { 
		"name": string;
		"value": string;
		"encoded": boolean;
	}
	
	export interface LabelCreateRequest { 
		"id"?: string;
		"name": string;
		"color": string;
		"externalId"?: string;
		"selfUri"?: string;
	}
	
	export interface LabelListing { 
		"entities"?: Array<Models.LabelResponse>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface LabelResponse { 
		"id"?: string;
		"name"?: string;
		"color"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"documentCount"?: number;
		"externalId"?: string;
		"selfUri"?: string;
	}
	
	export interface LabelUpdateRequest { 
		"id"?: string;
		"name"?: string;
		"color"?: string;
		"externalId"?: string;
		"selfUri"?: string;
	}
	
	export interface LabelUtilizationRequest { 
		"maximumCapacity"?: number;
		"interruptingLabelIds"?: Array<string>;
	}
	
	export interface LabelUtilizationResponse { 
		"maximumCapacity"?: number;
		"interruptingLabelIds"?: Array<string>;
		"labelName"?: string;
	}
	
	export interface Language { 
		"id"?: string;
		"name": string;
		"dateModified"?: string;
		"state"?: string;
		"version"?: string;
		"selfUri"?: string;
	}
	
	export interface LanguageEntityListing { 
		"entities"?: Array<Models.Language>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LanguageOverride { 
		"language": string;
		"engine": string;
		"voice": string;
	}
	
	export interface LanguageReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface LastAttemptByColumnConditionSettings { 
		"emailColumnName"?: string;
		"smsColumnName"?: string;
		"operator": string;
		"value": string;
	}
	
	export interface LastAttemptOverallConditionSettings { 
		"mediaTypes": Array<string>;
		"operator": string;
		"value": string;
	}
	
	export interface LastResultByColumnConditionSettings { 
		"emailColumnName"?: string;
		"emailWrapupCodes"?: Array<string>;
		"smsColumnName"?: string;
		"smsWrapupCodes"?: Array<string>;
	}
	
	export interface LastResultOverallConditionSettings { 
		"emailWrapupCodes"?: Array<string>;
		"smsWrapupCodes"?: Array<string>;
	}
	
	export interface LauncherButtonSettings { 
		"visibility"?: string;
	}
	
	export interface Leaderboard { 
		"division"?: Models.Division;
		"metric"?: Models.AddressableEntityRef;
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"leaders"?: Array<Models.LeaderboardItem>;
		"userRank"?: Models.LeaderboardItem;
		"performanceProfile"?: Models.AddressableEntityRef;
	}
	
	export interface LeaderboardItem { 
		"user"?: Models.UserReference;
		"rank"?: number;
		"points"?: number;
	}
	
	export interface LearningAssessment { 
		"assessmentId"?: string;
		"contextId"?: string;
		"assessmentFormId"?: string;
		"status"?: string;
		"answers"?: Models.AssessmentScoringSet;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateSubmitted"?: string;
	}
	
	export interface LearningAssessmentScoringRequest { 
		"assessmentForm": Models.AssessmentForm;
		"answers": Models.AssessmentScoringSet;
	}
	
	export interface LearningAssignment { 
		"id"?: string;
		"assessment"?: Models.LearningAssessment;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"modifiedBy"?: Models.UserReference;
		"dateModified"?: string;
		"isOverdue"?: boolean;
		"percentageScore"?: number;
		"isRule"?: boolean;
		"isManual"?: boolean;
		"isPassed"?: boolean;
		"isLatest"?: boolean;
		"selfUri"?: string;
		"state"?: string;
		"dateRecommendedForCompletion"?: string;
		"version"?: number;
		"module"?: Models.LearningModule;
		"user"?: Models.UserReference;
		"assessmentForm"?: Models.AssessmentForm;
		"lengthInMinutes"?: number;
	}
	
	export interface LearningAssignmentAggregateParam { 
		"interval": string;
		"metrics"?: Array<string>;
		"groupBy"?: Array<string>;
		"filter": Models.LearningAssignmentAggregateQueryRequestFilter;
	}
	
	export interface LearningAssignmentAggregateQueryRequestClause { 
		"type": string;
		"predicates": Array<Models.LearningAssignmentAggregateQueryRequestPredicate>;
	}
	
	export interface LearningAssignmentAggregateQueryRequestFilter { 
		"type": string;
		"clauses": Array<Models.LearningAssignmentAggregateQueryRequestClause>;
	}
	
	export interface LearningAssignmentAggregateQueryRequestPredicate { 
		"dimension": string;
		"value": string;
	}
	
	export interface LearningAssignmentAggregateQueryResponseData { 
		"interval"?: string;
		"metrics"?: Array<Models.LearningAssignmentAggregateQueryResponseMetric>;
	}
	
	export interface LearningAssignmentAggregateQueryResponseGroupedData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.LearningAssignmentAggregateQueryResponseData>;
	}
	
	export interface LearningAssignmentAggregateQueryResponseMetric { 
		"metric"?: string;
		"stats"?: Models.LearningAssignmentAggregateQueryResponseStats;
	}
	
	export interface LearningAssignmentAggregateQueryResponseStats { 
		"count"?: number;
		"min"?: number;
		"max"?: number;
		"sum"?: number;
	}
	
	export interface LearningAssignmentAggregateResponse { 
		"results"?: Array<Models.LearningAssignmentAggregateQueryResponseGroupedData>;
	}
	
	export interface LearningAssignmentBulkAddResponse { 
		"entities"?: Array<Models.LearningAssignment>;
		"disallowedEntities"?: Array<Models.DisallowedEntityLearningAssignmentItem>;
	}
	
	export interface LearningAssignmentBulkRemoveResponse { 
		"entities"?: Array<Models.LearningAssignmentEntity>;
		"disallowedEntities"?: Array<Models.DisallowedEntityLearningAssignmentReference>;
	}
	
	export interface LearningAssignmentCreate { 
		"moduleId": string;
		"userId": string;
		"recommendedCompletionDate"?: string;
		"lengthInMinutes"?: number;
	}
	
	export interface LearningAssignmentEntity { 
		"assignmentId"?: string;
	}
	
	export interface LearningAssignmentExternalUpdate { 
		"state"?: string;
		"percentageScore"?: number;
		"isPassed"?: boolean;
	}
	
	export interface LearningAssignmentItem { 
		"moduleId": string;
		"userId": string;
	}
	
	export interface LearningAssignmentReassign { 
		"recommendedCompletionDate"?: string;
		"lengthInMinutes"?: number;
	}
	
	export interface LearningAssignmentReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface LearningAssignmentReschedule { 
		"dateRecommendedForCompletion": string;
		"lengthInMinutes"?: number;
	}
	
	export interface LearningAssignmentRuleRunTopicLearningAssignmentRuleRunNotification { 
		"entities"?: Array<Models.LearningAssignmentRuleRunTopicLearningAssignmentsCreated>;
		"total"?: number;
	}
	
	export interface LearningAssignmentRuleRunTopicLearningAssignmentsCreated { 
		"module"?: Models.LearningAssignmentRuleRunTopicLearningModuleReference;
	}
	
	export interface LearningAssignmentRuleRunTopicLearningModuleReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface LearningAssignmentStep { 
		"id"?: string;
		"moduleStep"?: Models.LearningModuleInformStep;
		"structure"?: Array<Models.LearningAssignmentStepScoStructure>;
		"successStatus"?: string;
		"completionStatus"?: string;
		"completionPercentage"?: number;
		"percentageScore"?: number;
		"shareableContentObject"?: Models.LearningShareableContentObject;
		"signedCookie"?: Models.LearningAssignmentStepSignedCookie;
		"selfUri"?: string;
	}
	
	export interface LearningAssignmentStepScoStructure { 
		"id"?: string;
		"name"?: string;
		"successStatus"?: string;
		"completionStatus"?: string;
		"children"?: Array<Models.LearningAssignmentStepScoStructure>;
	}
	
	export interface LearningAssignmentStepSignedCookie { 
		"url"?: string;
		"cookieValues"?: { [key: string]: string; };
	}
	
	export interface LearningAssignmentTopicLearningAssignmentNotification { 
		"id"?: string;
		"user"?: Models.LearningAssignmentTopicUserReference;
		"module"?: Models.LearningAssignmentTopicLearningModuleReference;
		"version"?: number;
		"state"?: string;
		"dateRecommendedForCompletion"?: string;
		"createdBy"?: Models.LearningAssignmentTopicUserReference;
		"dateCreated"?: string;
		"modifiedBy"?: Models.LearningAssignmentTopicUserReference;
		"dateModified"?: string;
		"isOverdue"?: boolean;
		"lengthInMinutes"?: number;
	}
	
	export interface LearningAssignmentTopicLearningModuleReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface LearningAssignmentTopicUserReference { 
		"id"?: string;
	}
	
	export interface LearningAssignmentUpdate { 
		"state"?: string;
		"assessment"?: Models.LearningAssessment;
	}
	
	export interface LearningAssignmentUser { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface LearningAssignmentUserListing { 
		"entities"?: Array<Models.LearningAssignmentUser>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"unfilteredTotal"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LearningAssignmentUserQuery { 
		"rule": Models.LearningModuleRule;
		"searchTerm"?: string;
	}
	
	export interface LearningAssignmentsDomainEntity { 
		"entities"?: Array<Models.LearningAssignment>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LearningCoverArtThumbnail { 
		"resolution"?: string;
		"url"?: string;
	}
	
	export interface LearningCoverArtUploadUrlRequest { 
		"fileName"?: string;
		"contentMd5"?: string;
		"signedUrlTimeoutSeconds"?: number;
		"contentType": string;
		"serverSideEncryption"?: string;
	}
	
	export interface LearningModule { 
		"id"?: string;
		"name": string;
		"excludedFromCatalog"?: boolean;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"modifiedBy"?: Models.UserReference;
		"dateModified"?: string;
		"version"?: number;
		"externalId"?: string;
		"source"?: string;
		"rule"?: Models.LearningModuleRule;
		"selfUri"?: string;
		"isArchived"?: boolean;
		"isPublished"?: boolean;
		"description"?: string;
		"completionTimeInDays": number;
		"type"?: string;
		"informSteps"?: Array<Models.LearningModuleInformStep>;
		"assessmentForm"?: Models.AssessmentForm;
		"summaryData"?: Models.LearningModuleSummary;
		"reassignSummaryData"?: Models.LearningModuleReassignSummary;
		"coverArt"?: Models.LearningModuleCoverArtResponse;
		"lengthInMinutes"?: number;
		"archivalMode"?: string;
	}
	
	export interface LearningModuleCoverArtRequest { 
		"id": string;
	}
	
	export interface LearningModuleCoverArtResponse { 
		"id"?: string;
		"selfUri"?: string;
		"url"?: string;
		"thumbnails"?: Array<Models.LearningCoverArtThumbnail>;
	}
	
	export interface LearningModuleInformStep { 
		"type": string;
		"name"?: string;
		"value": string;
		"sharingUri"?: string;
		"contentType"?: string;
		"order": number;
		"displayName"?: string;
		"description"?: string;
	}
	
	export interface LearningModuleInformStepRequest { 
		"type": string;
		"name"?: string;
		"value": string;
		"sharingUri"?: string;
		"contentType"?: string;
		"order": number;
		"displayName"?: string;
		"description"?: string;
	}
	
	export interface LearningModuleJobRequest { 
		"action": string;
	}
	
	export interface LearningModuleJobResponse { 
		"id"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface LearningModulePublishRequest { 
		"termsAndConditionsAccepted"?: boolean;
	}
	
	export interface LearningModulePublishResponse { 
		"id"?: string;
		"version"?: number;
		"selfUri"?: string;
	}
	
	export interface LearningModuleReassignSummary { 
		"totalReassigned"?: number;
		"completedCount"?: number;
		"inProgressCount"?: number;
		"assignedCount"?: number;
		"notCompletedCount"?: number;
	}
	
	export interface LearningModuleRequest { 
		"name": string;
		"description"?: string;
		"completionTimeInDays": number;
		"informSteps"?: Array<Models.LearningModuleInformStepRequest>;
		"type"?: string;
		"assessmentForm"?: Models.AssessmentForm;
		"coverArt"?: Models.LearningModuleCoverArtRequest;
		"lengthInMinutes"?: number;
		"excludedFromCatalog"?: boolean;
		"externalId"?: string;
	}
	
	export interface LearningModuleRule { 
		"id"?: string;
		"isActive": boolean;
		"parts": Array<Models.LearningModuleRuleParts>;
		"selfUri"?: string;
	}
	
	export interface LearningModuleRuleParts { 
		"operation": string;
		"selector": string;
		"value": Array<string>;
		"order": number;
	}
	
	export interface LearningModuleSummary { 
		"assignedCount"?: number;
		"completedCount"?: number;
		"passedCount"?: number;
		"completedSum"?: number;
	}
	
	export interface LearningModulesDomainEntityListing { 
		"entities"?: Array<Models.LearningModule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LearningScheduleSlotsQueryRequest { 
		"interval": string;
		"lengthInMinutes": number;
		"userIds": Array<string>;
		"interruptibleAssignmentId"?: string;
	}
	
	export interface LearningScheduleSlotsQueryResponse { 
		"suggestedSlots"?: Array<Models.LearningSlot>;
		"wfmScheduleActivities"?: Array<Models.LearningSlotWfmScheduleActivity>;
	}
	
	export interface LearningShareableContentObject { 
		"id": string;
		"lessonStatus"?: string;
		"exit"?: string;
		"location"?: string;
		"scoreRaw"?: number;
		"scoreMax"?: number;
		"scoreMin"?: number;
		"suspendData"?: string;
		"credit"?: string;
		"entry"?: string;
		"mode"?: string;
		"totalTime"?: string;
		"sessionTime"?: string;
		"href"?: string;
		"parameters"?: string;
		"launchData"?: string;
	}
	
	export interface LearningSlot { 
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"staffingDifference"?: number;
		"differenceRating"?: string;
	}
	
	export interface LearningSlotFullDayTimeOffMarker { 
		"businessUnitDate"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"timeOffRequestId"?: string;
	}
	
	export interface LearningSlotScheduleActivity { 
		"dateStart"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"timeOffRequestId"?: string;
		"externalActivityId"?: string;
		"externalActivityType"?: string;
	}
	
	export interface LearningSlotWfmScheduleActivity { 
		"user"?: Models.UserReference;
		"activities"?: Array<Models.LearningSlotScheduleActivity>;
		"fullDayTimeOffMarkers"?: Array<Models.LearningSlotFullDayTimeOffMarker>;
	}
	
	export interface LexBot { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface LexBotAlias { 
		"id"?: string;
		"name"?: string;
		"bot"?: Models.LexBot;
		"botVersion"?: string;
		"status": string;
		"failureReason"?: string;
		"language"?: string;
		"intents"?: Array<Models.LexIntent>;
		"selfUri"?: string;
	}
	
	export interface LexBotAliasEntityListing { 
		"entities"?: Array<Models.LexBotAlias>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LexBotEntityListing { 
		"entities"?: Array<Models.LexBot>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LexIntent { 
		"name": string;
		"description"?: string;
		"slots": { [key: string]: Models.LexSlot; };
		"version": string;
	}
	
	export interface LexSlot { 
		"name": string;
		"description"?: string;
		"type": string;
		"priority"?: number;
	}
	
	export interface LexV2Bot { 
		"id"?: string;
		"name"?: string;
		"botId": string;
		"region": string;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface LexV2BotAlias { 
		"id"?: string;
		"name"?: string;
		"region": string;
		"aliasId": string;
		"bot"?: Models.LexV2Bot;
		"botVersion"?: string;
		"status"?: string;
		"language"?: string;
		"intents"?: Array<Models.LexV2Intent>;
		"selfUri"?: string;
	}
	
	export interface LexV2BotAliasEntityListing { 
		"entities"?: Array<Models.LexV2BotAlias>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LexV2BotEntityListing { 
		"entities"?: Array<Models.LexV2Bot>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LexV2Intent { 
		"intentName": string;
		"description"?: string;
		"slots": { [key: string]: Models.LexV2Slot; };
		"intentId": string;
	}
	
	export interface LexV2Slot { 
		"slotName": string;
		"description"?: string;
		"slotId": string;
		"type": string;
		"slotTypeId": string;
	}
	
	export interface Library { 
		"id"?: string;
		"name": string;
		"version"?: number;
		"createdBy"?: Models.User;
		"dateCreated"?: string;
		"responseType"?: string;
		"selfUri"?: string;
	}
	
	export interface LibraryBatchRequest { 
		"libraryIds": Array<string>;
	}
	
	export interface LibraryEntityListing { 
		"entities"?: Array<Models.Library>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LicenseAssignmentRequest { 
		"licenseId": string;
		"userIdsAdd": Array<string>;
		"userIdsRemove": Array<string>;
	}
	
	export interface LicenseBatchAssignmentRequest { 
		"assignments": Array<Models.LicenseAssignmentRequest>;
	}
	
	export interface LicenseDefinition { 
		"id"?: string;
		"description"?: string;
		"permissions"?: Models.Permissions;
		"prerequisites"?: Array<Models.AddressableLicenseDefinition>;
		"comprises"?: Array<Models.LicenseDefinition>;
		"selfUri"?: string;
	}
	
	export interface LicenseOrgToggle { 
		"featureName"?: string;
		"enabled"?: boolean;
	}
	
	export interface LicenseUpdateStatus { 
		"userId"?: string;
		"licenseId"?: string;
		"result"?: string;
	}
	
	export interface LicenseUser { 
		"id"?: string;
		"licenses"?: Array<Models.LicenseDefinition>;
		"selfUri"?: string;
	}
	
	export interface Limit { 
		"key"?: string;
		"namespace"?: string;
		"value"?: number;
	}
	
	export interface LimitChangeRequestDetails { 
		"id"?: string;
		"key": string;
		"namespace": string;
		"requestedValue": number;
		"description": string;
		"supportCaseUrl": string;
		"status"?: string;
		"currentValue"?: number;
		"dateCreated"?: string;
		"statusHistory"?: Array<Models.StatusChange>;
		"dateCompleted"?: string;
		"rejectReason"?: string;
		"approvalNamespaces"?: Array<Models.ApprovalNamespace>;
		"selfUri"?: string;
	}
	
	export interface LimitChangeRequestsEntityListing { 
		"entities"?: Array<Models.LimitChangeRequestDetails>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface LimitDocs { 
		"key"?: string;
		"defaultValue"?: number;
		"description"?: string;
		"resource"?: string;
		"configurable"?: boolean;
		"trackable"?: boolean;
	}
	
	export interface LimitDocumentation { 
		"url"?: string;
		"namespaces"?: Array<Models.NamespaceDocs>;
	}
	
	export interface LimitsEntityListing { 
		"entities"?: Array<Models.Limit>;
	}
	
	export interface Line { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"properties"?: { [key: string]: object; };
		"edgeGroup"?: Models.DomainEntityRef;
		"template"?: Models.DomainEntityRef;
		"site"?: Models.DomainEntityRef;
		"lineBaseSettings"?: Models.DomainEntityRef;
		"primaryEdge"?: Models.Edge;
		"secondaryEdge"?: Models.Edge;
		"loggedInUser"?: Models.DomainEntityRef;
		"defaultForUser"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface LineBase { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"lineMetaBase"?: Models.DomainEntityRef;
		"properties"?: { [key: string]: object; };
		"selfUri"?: string;
	}
	
	export interface LineBaseEntityListing { 
		"entities"?: Array<Models.LineBase>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LineEntityListing { 
		"entities"?: Array<Models.Line>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LineId { 
		"ids"?: Array<Models.LineUserId>;
		"displayName"?: string;
	}
	
	export interface LineIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"channelId": string;
		"webhookUri": string;
		"status"?: string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version": number;
		"createStatus"?: string;
		"createError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface LineIntegrationEntityListing { 
		"entities"?: Array<Models.LineIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LineIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"channelId"?: string;
		"channelSecret"?: string;
		"switcherSecret"?: string;
		"serviceCode"?: string;
		"selfUri"?: string;
	}
	
	export interface LineStatus { 
		"id"?: string;
		"reachable"?: boolean;
		"addressOfRecord"?: string;
		"contactAddresses"?: Array<string>;
		"reachableStateTime"?: string;
	}
	
	export interface LineUserId { 
		"userId"?: string;
	}
	
	export interface LinkConfiguration { 
		"uriTemplate"?: string;
	}
	
	export interface ListItemComponent { 
		"id"?: string;
		"rmid"?: string;
		"type"?: string;
		"image"?: string;
		"title"?: string;
		"description"?: string;
		"actions"?: Models.ContentActions;
	}
	
	export interface ListWrapperInterval { 
		"values"?: Array<string>;
	}
	
	export interface ListWrapperSecondaryPresence { 
		"values"?: Array<Models.SecondaryPresence>;
	}
	
	export interface ListWrapperShiftStartVariance { 
		"values"?: Array<Models.ShiftStartVariance>;
	}
	
	export interface ListWrapperString { 
		"values"?: Array<string>;
	}
	
	export interface ListedDictionaryFeedback { 
		"id"?: string;
		"term": string;
		"dialect": string;
		"boostValue"?: number;
		"source"?: string;
		"dateCreated"?: string;
		"createdBy"?: Models.UserReference;
		"dateModified"?: string;
		"modifiedBy"?: Models.UserReference;
		"selfUri"?: string;
	}
	
	export interface ListedProgram { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"published"?: boolean;
		"topicsCount"?: number;
		"tags"?: Array<string>;
		"modifiedBy"?: Models.AddressableEntityRef;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface ListedTopic { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"published"?: boolean;
		"strictness"?: string;
		"programsCount"?: number;
		"tags"?: Array<string>;
		"dialect"?: string;
		"participants"?: string;
		"phrasesCount"?: number;
		"modifiedBy"?: Models.AddressableEntityRef;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface LocalDateRange { 
		"startDate"?: string;
		"endDate"?: string;
	}
	
	export interface LocalEncryptionConfiguration { 
		"id"?: string;
		"name"?: string;
		"url": string;
		"apiId": string;
		"apiKey": string;
		"selfUri"?: string;
	}
	
	export interface LocalEncryptionKeyRequest { 
		"configId": string;
		"publicKey": string;
		"keypairId": string;
	}
	
	export interface LocaleFlowVersionInfo { 
		"nluVersion"?: Models.AddressableEntityRef;
	}
	
	export interface LocaleHealth { 
		"overallScore"?: number;
		"issueCount"?: number;
		"staticValidationResults"?: Array<string>;
	}
	
	export interface LocaleInfo { 
		"status"?: string;
		"errorInfo"?: Models.FlowHealthErrorInfo;
		"flowVersionInfo"?: Models.LocaleFlowVersionInfo;
	}
	
	export interface LocalizedLabels { 
		"key"?: string;
		"value"?: string;
	}
	
	export interface Location { 
		"id"?: string;
		"floorplanId"?: string;
		"coordinates"?: { [key: string]: number; };
		"notes"?: string;
		"locationDefinition"?: Models.LocationDefinition;
	}
	
	export interface LocationAddress { 
		"city"?: string;
		"country"?: string;
		"countryName"?: string;
		"state"?: string;
		"street1"?: string;
		"street2"?: string;
		"zipcode"?: string;
	}
	
	export interface LocationAddressVerificationDetails { 
		"status"?: string;
		"dateFinished"?: string;
		"dateStarted"?: string;
		"service"?: string;
	}
	
	export interface LocationCreateDefinition { 
		"name": string;
		"version"?: number;
		"state"?: string;
		"path"?: Array<string>;
		"notes"?: string;
		"contactUser"?: string;
		"emergencyNumber"?: Models.LocationEmergencyNumber;
		"address"?: Models.LocationAddress;
	}
	
	export interface LocationDefinition { 
		"id"?: string;
		"name"?: string;
		"contactUser"?: Models.AddressableEntityRef;
		"emergencyNumber"?: Models.LocationEmergencyNumber;
		"address"?: Models.LocationAddress;
		"state"?: string;
		"notes"?: string;
		"version"?: number;
		"path"?: Array<string>;
		"profileImage"?: Array<Models.LocationImage>;
		"floorplanImage"?: Array<Models.LocationImage>;
		"addressVerificationDetails"?: Models.LocationAddressVerificationDetails;
		"addressVerified"?: boolean;
		"addressStored"?: boolean;
		"images"?: string;
		"selfUri"?: string;
	}
	
	export interface LocationEmergencyNumber { 
		"e164"?: string;
		"number"?: string;
		"type"?: string;
	}
	
	export interface LocationEntityListing { 
		"entities"?: Array<Models.LocationDefinition>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LocationImage { 
		"resolution"?: string;
		"imageUri"?: string;
	}
	
	export interface LocationSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.LocationSearchCriteria>;
		"dateFormat"?: string;
		"type": string;
		"fields"?: Array<string>;
	}
	
	export interface LocationSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"expand"?: Array<string>;
		"query"?: Array<Models.LocationSearchCriteria>;
	}
	
	export interface LocationUpdateDefinition { 
		"name": string;
		"version": number;
		"state"?: string;
		"path"?: Array<string>;
		"notes"?: string;
		"contactUser"?: string;
		"emergencyNumber"?: Models.LocationEmergencyNumber;
		"address"?: Models.LocationAddress;
	}
	
	export interface LocationsSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.LocationDefinition>;
	}
	
	export interface LockInfo { 
		"lockedBy"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateExpires"?: string;
		"action"?: string;
	}
	
	export interface LogCaptureDownloadExecutionResponse { 
		"id": string;
		"state": string;
		"dateStart": string;
		"fileUrl": string;
		"selfUri"?: string;
		"user": Models.AddressableEntityRef;
	}
	
	export interface LogCaptureQueryRequest { 
		"interval": string;
		"userId": string;
		"sortOrder"?: string;
	}
	
	export interface LogCaptureQueryResponse { 
		"entities"?: Array<Models.LogEntry>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface LogCaptureUserConfiguration { 
		"id"?: string;
		"dateExpired": string;
		"selfUri"?: string;
	}
	
	export interface LogEntry { 
		"level"?: string;
		"message"?: string;
		"timestamp"?: number;
	}
	
	export interface LogicalInterfaceEntityListing { 
		"entities"?: Array<Models.DomainLogicalInterface>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface LongTermForecastPlanningGroupData { 
		"planningGroupId": string;
		"offeredPerDay": Array<number>;
		"averageHandleTimeSecondsPerDay": Array<number>;
	}
	
	export interface LongTermForecastResult { 
		"planningGroups"?: Array<Models.LongTermForecastPlanningGroupData>;
		"referenceStartDate"?: string;
		"weekCount"?: number;
	}
	
	export interface LongTermForecastResultResponse { 
		"result"?: Models.LongTermForecastResult;
		"downloadUrl"?: string;
	}
	
	export interface MailFromResult { 
		"status"?: string;
		"records"?: Array<Models.Record>;
		"mailFromDomain": string;
	}
	
	export interface ManagementUnit { 
		"id"?: string;
		"name"?: string;
		"businessUnit"?: Models.BusinessUnitReference;
		"startDayOfWeek"?: string;
		"timeZone"?: string;
		"settings"?: Models.ManagementUnitSettingsResponse;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"division"?: Models.DivisionReference;
		"modifiedBy"?: Models.UserReference;
		"version"?: number;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface ManagementUnitListing { 
		"entities"?: Array<Models.ManagementUnit>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"pageCount"?: number;
		"lastUri"?: string;
		"firstUri"?: string;
		"previousUri"?: string;
		"selfUri"?: string;
	}
	
	export interface ManagementUnitReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ManagementUnitSettingsRequest { 
		"adherence"?: Models.AdherenceSettings;
		"shortTermForecasting"?: Models.ShortTermForecastingSettings;
		"timeOff"?: Models.TimeOffRequestSettings;
		"scheduling"?: Models.SchedulingSettingsRequest;
		"shiftTrading"?: Models.ShiftTradeSettings;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface ManagementUnitSettingsResponse { 
		"adherence"?: Models.AdherenceSettings;
		"shortTermForecasting"?: Models.ShortTermForecastingSettings;
		"timeOff"?: Models.TimeOffRequestSettings;
		"scheduling"?: Models.SchedulingSettingsResponse;
		"shiftTrading"?: Models.ShiftTradeSettings;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface Manager { 
		"value"?: string;
		"$ref"?: string;
	}
	
	export interface MarkContactAddressUncontactableActionSettings { 
	}
	
	export interface MarkContactUncontactableActionSettings { 
		"mediaTypes": Array<string>;
	}
	
	export interface Markdown { 
		"enabled"?: boolean;
	}
	
	export interface MatchCriteria { 
		"jsonPath"?: string;
		"operator"?: string;
		"value"?: object;
		"values"?: Array<object>;
	}
	
	export interface MatchCriteriaTestResult { 
		"jsonPath"?: string;
		"operator"?: string;
		"value"?: object;
		"values"?: Array<object>;
		"generatedJsonPathCondition"?: string;
		"match"?: boolean;
		"jsonPathExtraction"?: Array<Models.MatchTestResult>;
	}
	
	export interface MatchShiftTradeRequest { 
		"receivingScheduleId": string;
		"receivingShiftId"?: string;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface MatchShiftTradeResponse { 
		"trade"?: Models.ShiftTradeResponse;
		"violations"?: Array<Models.ShiftTradeMatchViolation>;
		"adminReviewViolations"?: Array<Models.ShiftTradeMatchViolation>;
	}
	
	export interface MatchTestResult { 
		"value"?: object;
		"path"?: string;
	}
	
	export interface MaxLength { 
		"min": number;
		"max": number;
	}
	
	export interface MaxParticipants { 
		"maxParticipants"?: number;
	}
	
	export interface MediaEndpointStatistics { 
		"trunk"?: Models.MediaStatisticsTrunkInfo;
		"station"?: Models.NamedEntity;
		"user"?: Models.NamedEntity;
		"ice"?: Models.MediaIceStatistics;
		"rtp"?: Models.MediaRtpStatistics;
		"reconnectAttemptCount"?: number;
	}
	
	export interface MediaIceSelectedCandidate { 
		"address"?: string;
		"type"?: string;
	}
	
	export interface MediaIceSelectedPair { 
		"client"?: Models.MediaIceSelectedCandidate;
		"server"?: Models.MediaIceSelectedCandidate;
		"candidatePairSelectedMilliseconds"?: number;
	}
	
	export interface MediaIceStatistics { 
		"selectedPairs"?: Array<Models.MediaIceSelectedPair>;
	}
	
	export interface MediaParticipantRequest { 
		"wrapup"?: Models.WrapupInput;
		"state"?: string;
		"recording"?: boolean;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"wrapupSkipped"?: boolean;
	}
	
	export interface MediaPolicies { 
		"callPolicy"?: Models.CallMediaPolicy;
		"chatPolicy"?: Models.ChatMediaPolicy;
		"emailPolicy"?: Models.EmailMediaPolicy;
		"messagePolicy"?: Models.MessageMediaPolicy;
	}
	
	export interface MediaRegions { 
		"awsHomeRegion"?: string;
		"awsCoreRegions"?: Array<string>;
		"awsSatelliteRegions"?: Array<string>;
	}
	
	export interface MediaResult { 
		"mediaUri"?: string;
		"waveformData"?: Array<number>;
	}
	
	export interface MediaRtpStatistics { 
		"packetsReceived"?: number;
		"packetsSent"?: number;
		"rtpEventsReceived"?: number;
		"rtpEventsSent"?: number;
		"estimatedAverageMos"?: number;
	}
	
	export interface MediaSettings { 
		"enableAutoAnswer"?: boolean;
		"alertingTimeoutSeconds"?: number;
		"serviceLevel"?: Models.ServiceLevel;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"subTypeSettings"?: { [key: string]: Models.BaseMediaSettings; };
	}
	
	export interface MediaStatistics { 
		"communicationId"?: string;
		"dateStart"?: string;
		"creationMilliseconds"?: number;
		"preferredRegion"?: string;
		"effectiveRegion"?: string;
		"mediaStatistics"?: Array<Models.MediaEndpointStatistics>;
	}
	
	export interface MediaStatisticsListing { 
		"entities"?: Array<Models.MediaStatistics>;
	}
	
	export interface MediaStatisticsTrunkInfo { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
	}
	
	export interface MediaSummary { 
		"contactCenter"?: Models.MediaSummaryDetail;
		"enterprise"?: Models.MediaSummaryDetail;
	}
	
	export interface MediaSummaryDetail { 
		"active"?: number;
		"acw"?: number;
	}
	
	export interface MediaTranscription { 
		"displayName"?: string;
		"transcriptionProvider"?: string;
		"integrationId"?: string;
	}
	
	export interface MediaType { 
		"type"?: string;
	}
	
	export interface MediaTypeAccess { 
		"inbound"?: Array<Models.MediaType>;
		"outbound"?: Array<Models.MediaType>;
	}
	
	export interface MediaTypes { 
		"allow"?: Models.MediaTypeAccess;
	}
	
	export interface MediaUtilization { 
		"maximumCapacity"?: number;
		"interruptableMediaTypes"?: Array<string>;
		"includeNonAcd"?: boolean;
	}
	
	export interface MeetingIdRecord { 
		"id"?: string;
		"ephemeral": boolean;
		"conferenceId"?: string;
		"dateExpired"?: string;
		"selfUri"?: string;
	}
	
	export interface Member { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface MemberEntity { 
		"id"?: string;
	}
	
	export interface MemberGroup { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.WritableDivision;
		"type"?: string;
		"memberCount"?: number;
		"selfUri"?: string;
	}
	
	export interface MemberListing { 
		"entities"?: Array<Models.Member>;
	}
	
	export interface MergeOperation { 
		"sourceContact"?: Models.AddressableEntityRef;
		"targetContact"?: Models.AddressableEntityRef;
		"resultingContact"?: Models.AddressableEntityRef;
	}
	
	export interface MergeRequest { 
		"sourceContactId": string;
		"targetContactId": string;
	}
	
	export interface Message { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"held"?: boolean;
		"segments"?: Array<Models.Segment>;
		"direction"?: string;
		"recordingId"?: string;
		"errorInfo"?: Models.ErrorBody;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"provider"?: string;
		"authenticated"?: boolean;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"toAddress"?: Models.Address;
		"fromAddress"?: Models.Address;
		"messages"?: Array<Models.MessageDetails>;
		"journeyContext"?: Models.JourneyContext;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"byoSmsIntegrationId"?: string;
		"queueMediaSettings"?: Models.ConversationQueueMediaSettings;
	}
	
	export interface MessageContent { 
		"contentType": string;
		"location"?: Models.ContentLocation;
		"attachment"?: Models.ContentAttachment;
		"quickReply"?: Models.ContentQuickReply;
		"buttonResponse"?: Models.ContentButtonResponse;
		"generic"?: Models.ContentGeneric;
		"list"?: Models.ContentList;
		"template"?: Models.ContentNotificationTemplate;
		"reactions"?: Array<Models.ContentReaction>;
		"mention"?: Models.MessagingRecipient;
		"postback"?: Models.ContentPostback;
		"story"?: Models.ContentStory;
		"card"?: Models.ContentCard;
		"carousel"?: Models.ContentCarousel;
		"text"?: Models.ContentText;
		"quickReplyV2"?: Models.ContentQuickReplyV2;
	}
	
	export interface MessageConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.MessageMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"recentTransfers"?: Array<Models.TransferResponse>;
		"utilizationLabelId"?: string;
		"selfUri"?: string;
	}
	
	export interface MessageConversationEntityListing { 
		"entities"?: Array<Models.MessageConversation>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessageData { 
		"id"?: string;
		"name"?: string;
		"providerMessageId"?: string;
		"timestamp": string;
		"fromAddress"?: string;
		"toAddress"?: string;
		"direction"?: string;
		"messengerType"?: string;
		"textBody": string;
		"status": string;
		"media"?: Array<Models.MessageMedia>;
		"stickers"?: Array<Models.MessageSticker>;
		"normalizedMessage"?: Models.ConversationNormalizedMessage;
		"normalizedReceipts"?: Array<Models.ConversationNormalizedMessage>;
		"createdBy"?: Models.User;
		"conversationId"?: string;
		"selfUri"?: string;
	}
	
	export interface MessageDetails { 
		"messageId"?: string;
		"messageURI"?: string;
		"messageStatus"?: string;
		"messageSegmentCount"?: number;
		"messageTime"?: string;
		"media"?: Array<Models.MessageMedia>;
		"stickers"?: Array<Models.MessageSticker>;
		"messageMetadata"?: Models.ConversationMessageMetadata;
		"errorInfo"?: Models.ErrorBody;
	}
	
	export interface MessageEvaluation { 
		"contactColumn"?: string;
		"contactAddress"?: string;
		"messageType"?: string;
		"wrapupCodeId"?: string;
		"timestamp"?: string;
	}
	
	export interface MessageInfo { 
		"localizableMessageCode"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface MessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface MessageMediaAttachment { 
		"url"?: string;
		"mediaType"?: string;
		"contentLength"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface MessageMediaData { 
		"id"?: string;
		"name"?: string;
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"uploadUrl"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface MessageMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"mediaRoles"?: Array<string>;
		"user"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"team"?: Models.DomainEntityRef;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.ErrorInfo;
		"script"?: Models.DomainEntityRef;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.DomainEntityRef;
		"externalOrganization"?: Models.DomainEntityRef;
		"wrapup"?: Models.Wrapup;
		"peer"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.JourneyContext;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"toAddress"?: Models.Address;
		"fromAddress"?: Models.Address;
		"messages"?: Array<Models.MessageDetails>;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"authenticated"?: boolean;
		"monitoredParticipantId"?: string;
		"monitoredParticipant"?: Models.AddressableEntityRef;
	}
	
	export interface MessageMediaPolicy { 
		"actions"?: Models.PolicyActions;
		"conditions"?: Models.MessageMediaPolicyConditions;
	}
	
	export interface MessageMediaPolicyConditions { 
		"forUsers"?: Array<Models.User>;
		"dateRanges"?: Array<string>;
		"forQueues"?: Array<Models.Queue>;
		"wrapupCodes"?: Array<Models.WrapupCode>;
		"languages"?: Array<Models.Language>;
		"timeAllowed"?: Models.TimeAllowed;
		"teams"?: Array<Models.Team>;
		"customerParticipation"?: string;
	}
	
	export interface MessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface MessageStickerAttachment { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface MessageTypingEventRequest { 
		"typing": Models.ConversationEventTyping;
		"dateSent"?: string;
	}
	
	export interface MessagingCampaign { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"division"?: Models.DomainEntityRef;
		"campaignStatus"?: string;
		"callableTimeSet"?: Models.DomainEntityRef;
		"contactList": Models.DomainEntityRef;
		"dncLists"?: Array<Models.DomainEntityRef>;
		"alwaysRunning"?: boolean;
		"contactSorts"?: Array<Models.ContactSort>;
		"messagesPerMinute": number;
		"ruleSets"?: Array<Models.DomainEntityRef>;
		"contactListFilters"?: Array<Models.DomainEntityRef>;
		"errors"?: Array<Models.RestErrorDetail>;
		"dynamicContactQueueingSettings"?: Models.DynamicContactQueueingSettings;
		"emailConfig"?: Models.EmailConfig;
		"smsConfig"?: Models.SmsConfig;
		"selfUri"?: string;
	}
	
	export interface MessagingCampaignDiagnostics { 
		"timeZoneRescheduledContactsCount"?: number;
	}
	
	export interface MessagingCampaignDivisionView { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"selfUri"?: string;
	}
	
	export interface MessagingCampaignDivisionViewEntityListing { 
		"entities"?: Array<Models.MessagingCampaignDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessagingCampaignEntityListing { 
		"entities"?: Array<Models.MessagingCampaign>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessagingCampaignSchedule { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"intervals": Array<Models.ScheduleInterval>;
		"timeZone"?: string;
		"messagingCampaign": Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface MessagingCampaignScheduleEntityListing { 
		"entities"?: Array<Models.MessagingCampaignSchedule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessagingCommunicationAnsweredEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
	}
	
	export interface MessagingCommunicationDispositionAppliedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
	}
	
	export interface MessagingCommunicationEndedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"disconnectType": string;
	}
	
	export interface MessagingConfigListing { 
		"entities"?: Array<Models.MessagingSetting>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessagingEndTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"commandId": string;
		"finalState": string;
		"objectCommunicationId": string;
	}
	
	export interface MessagingExternalEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"displayName"?: string;
		"initialConfiguration": Models.MessagingInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface MessagingFlowEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"initialConfiguration": Models.MessagingInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface MessagingHoldUpdatedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"held": boolean;
	}
	
	export interface MessagingInitialConfiguration { 
		"toAddress": string;
		"fromAddress": string;
		"messageType"?: string;
		"held"?: boolean;
		"alerting"?: boolean;
		"inbound"?: boolean;
		"invitedBy"?: string;
		"additionalInfo"?: { [key: string]: string; };
	}
	
	export interface MessagingIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"status"?: string;
		"messengerType": string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version": number;
		"selfUri"?: string;
	}
	
	export interface MessagingIntegrationEntityListing { 
		"entities"?: Array<Models.MessagingIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessagingProgressTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"commandId": string;
		"objectCommunicationId": string;
		"destinationCommunicationId": string;
	}
	
	export interface MessagingRecipient { 
		"nickname"?: string;
		"id": string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.RecipientAdditionalIdentifier>;
	}
	
	export interface MessagingRoutingEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"queueId": string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"label"?: string;
		"initialConfiguration": Models.MessagingInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface MessagingRoutingTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationQueueId": string;
		"languageId"?: string;
		"skillIds"?: Array<string>;
	}
	
	export interface MessagingSetting { 
		"id": string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"updatedBy"?: Models.DomainEntityRef;
		"content"?: Models.ContentSetting;
		"event"?: Models.EventSetting;
		"selfUri"?: string;
	}
	
	export interface MessagingSettingDefaultRequest { 
		"settingId": string;
	}
	
	export interface MessagingSettingPatchRequest { 
		"id"?: string;
		"name"?: string;
		"content"?: Models.ContentSetting;
		"event"?: Models.EventSetting;
		"selfUri"?: string;
	}
	
	export interface MessagingSettingReference { 
		"id": string;
		"name"?: string;
		"selfUri"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"updatedBy"?: Models.DomainEntityRef;
		"content"?: Models.ContentSetting;
		"event"?: Models.EventSetting;
	}
	
	export interface MessagingSettingRequest { 
		"id"?: string;
		"name": string;
		"content"?: Models.ContentSetting;
		"event"?: Models.EventSetting;
		"selfUri"?: string;
	}
	
	export interface MessagingSettingRequestReference { 
		"id": string;
	}
	
	export interface MessagingSticker { 
		"id"?: string;
		"name"?: string;
		"providerStickerId": number;
		"providerPackageId"?: number;
		"packageName"?: string;
		"messengerType": string;
		"stickerType": string;
		"providerVersion"?: number;
		"uriLocation"?: string;
		"selfUri"?: string;
	}
	
	export interface MessagingStickerEntityListing { 
		"entities"?: Array<Models.MessagingSticker>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface MessagingTemplate { 
		"whatsApp"?: Models.WhatsAppDefinition;
	}
	
	export interface MessagingTemplateRequest { 
		"responseId"?: string;
		"parameters"?: Array<Models.TemplateParameter>;
	}
	
	export interface MessagingUserEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"userId": string;
		"queueId"?: string;
		"afterCallWorkRequired"?: boolean;
		"initialConfiguration": Models.MessagingInitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface MessagingUserTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationUserId": string;
	}
	
	export interface MessengerApps { 
		"conversations"?: Models.ConversationAppSettings;
		"knowledge"?: Models.Knowledge;
	}
	
	export interface MessengerHomeScreen { 
		"enabled"?: boolean;
		"logoUrl"?: string;
	}
	
	export interface MessengerSettings { 
		"enabled"?: boolean;
		"styles"?: Models.MessengerStyles;
		"launcherButton"?: Models.LauncherButtonSettings;
		"fileUpload"?: Models.FileUploadSettings;
		"apps"?: Models.MessengerApps;
		"homeScreen"?: Models.MessengerHomeScreen;
	}
	
	export interface MessengerStyles { 
		"primaryColor"?: string;
	}
	
	export interface MetaData { 
		"pairing-token"?: string;
		"pairing-trust"?: Array<string>;
		"pairing-url"?: string;
	}
	
	export interface Metabase { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"type"?: string;
		"selfUri"?: string;
	}
	
	export interface MetadataDocumentation { 
		"description"?: string;
		"location"?: string;
	}
	
	export interface MetadataItem { 
		"text"?: string;
		"attributes"?: { [key: string]: string; };
	}
	
	export interface MetadataPresentation { 
		"title"?: string;
		"schema"?: Models.MetadataSchema;
	}
	
	export interface MetadataProperty { 
		"type"?: string;
		"displayname"?: string;
		"description"?: string;
		"sensitive"?: string;
		"help"?: string;
		"default"?: string;
		"enum"?: Array<string>;
	}
	
	export interface MetadataResultEntity { 
		"type"?: string;
		"description"?: string;
		"visibility"?: string;
	}
	
	export interface MetadataResults { 
		"entities"?: Array<Models.MetadataResultEntity>;
	}
	
	export interface MetadataSchema { 
		"title"?: string;
		"description"?: string;
		"type"?: string;
		"properties"?: Array<{ [key: string]: Models.MetadataProperty; }>;
		"required"?: Array<string>;
	}
	
	export interface MeteredAssignmentByAgent { 
		"evaluationContextId"?: string;
		"evaluators"?: Array<Models.User>;
		"maxNumberEvaluations"?: number;
		"evaluationForm"?: Models.EvaluationForm;
		"timeInterval"?: Models.TimeInterval;
		"timeZone"?: string;
	}
	
	export interface MeteredEvaluationAssignment { 
		"evaluationContextId"?: string;
		"evaluators"?: Array<Models.User>;
		"maxNumberEvaluations"?: number;
		"evaluationForm"?: Models.EvaluationForm;
		"assignToActiveUser"?: boolean;
		"timeInterval"?: Models.TimeInterval;
	}
	
	export interface Metric { 
		"id"?: string;
		"name": string;
		"metricDefinitionId"?: string;
		"externalMetricDefinitionId"?: string;
		"objective"?: Models.Objective;
		"performanceProfileId"?: string;
		"linkedMetric"?: Models.AddressableEntityRef;
		"dateCreated"?: string;
		"dateUnlinked"?: string;
		"precision"?: number;
		"timeDisplayUnit"?: string;
		"sourcePerformanceProfile"?: Models.PerformanceProfile;
		"selfUri"?: string;
	}
	
	export interface MetricDefinition { 
		"id"?: string;
		"name"?: string;
		"unitType"?: string;
		"shortName"?: string;
		"dividendMetrics"?: Array<string>;
		"divisorMetrics"?: Array<string>;
		"defaultObjective"?: Models.DefaultObjective;
		"lockTemplateId"?: string;
		"mediaTypeFilteringAllowed"?: boolean;
		"initialDirectionFilteringAllowed"?: boolean;
		"queueFilteringAllowed"?: boolean;
		"selfUri"?: string;
	}
	
	export interface MetricValueTrendAverage { 
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"dateReferenceWorkday"?: string;
		"division"?: Models.Division;
		"user"?: Models.UserReference;
		"timezone"?: string;
		"result"?: Models.WorkdayValuesMetricItem;
		"performanceProfile"?: Models.AddressableEntityRef;
		"metric"?: Models.AddressableEntityRef;
	}
	
	export interface Metrics { 
		"id"?: string;
		"name"?: string;
		"order"?: number;
		"metricDefinitionName"?: string;
		"metricDefinitionId"?: string;
		"externalMetricDefinitionId"?: string;
		"unitType"?: string;
		"enabled"?: boolean;
		"templateName"?: string;
		"maxPoints"?: number;
		"performanceProfileId"?: string;
		"linkedMetric"?: Models.AddressableEntityRef;
		"dateCreated"?: string;
		"dateUnlinked"?: string;
		"sourcePerformanceProfile"?: Models.PerformanceProfile;
		"unitDefinition"?: string;
		"precision"?: number;
		"timeDisplayUnit"?: string;
		"selfUri"?: string;
	}
	
	export interface MinLength { 
		"min": number;
		"max": number;
	}
	
	export interface MinedIntentsListing { 
		"entities"?: Array<Models.MinerIntent>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface Miner { 
		"id"?: string;
		"name": string;
		"language"?: string;
		"minerType"?: string;
		"dateCreated"?: string;
		"status"?: string;
		"conversationsDateRangeStart"?: string;
		"conversationsDateRangeEnd"?: string;
		"dateCompleted"?: string;
		"message"?: string;
		"errorInfo"?: Models.MinerErrorInfo;
		"warningInfo"?: Models.MinerErrorInfo;
		"conversationDataUploaded"?: boolean;
		"mediaType"?: string;
		"participantType"?: string;
		"queueIds"?: Array<string>;
		"dateTriggered"?: string;
		"dateModified"?: string;
		"latestDraftVersion"?: Models.Draft;
		"conversationsFetchedCount"?: number;
		"conversationsValidCount"?: number;
		"getminedItemCount"?: number;
		"selfUri"?: string;
	}
	
	export interface MinerErrorInfo { 
		"message"?: string;
		"code"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: object; };
	}
	
	export interface MinerExecuteRequest { 
		"dateStart"?: string;
		"dateEnd"?: string;
		"uploadKey"?: string;
		"mediaType"?: string;
		"participantType"?: string;
		"queueIds"?: Array<string>;
	}
	
	export interface MinerIntent { 
		"id"?: string;
		"name"?: string;
		"miner"?: Models.Miner;
		"utterances"?: Array<Models.Utterance>;
		"analyticVolumePercent"?: number;
		"selfUri"?: string;
	}
	
	export interface MinerListing { 
		"entities"?: Array<Models.Miner>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface MinerTopic { 
		"id"?: string;
		"name"?: string;
		"miner"?: Models.Miner;
		"conversationCount"?: number;
		"conversationPercent"?: number;
		"utteranceCount"?: number;
		"phraseCount"?: number;
		"phrases"?: Array<Models.TopicPhrase>;
		"selfUri"?: string;
	}
	
	export interface MinerTopicPhrase { 
		"id"?: string;
		"name"?: string;
		"topic"?: Models.MinerTopic;
		"utterances"?: Array<Models.Utterance>;
		"utteranceCount"?: number;
		"selfUri"?: string;
	}
	
	export interface MinerTopicsListing { 
		"entities"?: Array<Models.MinerTopic>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface MobileNotificationSettings { 
		"when": string;
	}
	
	export interface MobileSettings { 
		"notifications": Models.MobileNotificationSettings;
	}
	
	export interface ModelingProcessingError { 
		"internalErrorCode"?: string;
		"description"?: string;
	}
	
	export interface ModelingStatusResponse { 
		"id"?: string;
		"status"?: string;
		"errorDetails"?: Array<Models.ModelingProcessingError>;
		"modelingResultUri"?: string;
	}
	
	export interface ModifiableRuleProperties { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"enabled"?: boolean;
		"notifications"?: Array<Models.AlertNotification>;
		"sendExitingAlarmNotifications"?: boolean;
		"waitBetweenNotificationMs"?: number;
		"conditions"?: Models.CommonRuleConditions;
		"selfUri"?: string;
	}
	
	export interface MoveAgentResponse { 
		"user"?: Models.UserReference;
		"result"?: string;
	}
	
	export interface MoveAgentsRequest { 
		"userIds": Array<string>;
		"destinationManagementUnitId"?: string;
	}
	
	export interface MoveAgentsResponse { 
		"requestingUser"?: Models.UserReference;
		"destinationManagementUnit"?: Models.ManagementUnitReference;
		"results"?: Array<Models.MoveAgentResponse>;
	}
	
	export interface MoveManagementUnitRequest { 
		"businessUnitId": string;
	}
	
	export interface MoveManagementUnitResponse { 
		"businessUnit"?: Models.BusinessUnitReference;
		"status"?: string;
	}
	
	export interface MuAgentQueueTimeRequest { 
		"managementUnitId": string;
		"agentOnQueueTimes": Array<Models.AgentQueueTimeRequest>;
	}
	
	export interface MuRescheduleResultWrapper { 
		"agentSchedules"?: Array<Models.BuAgentScheduleRescheduleResponse>;
	}
	
	export interface MutableUserPresence { 
		"id"?: string;
		"name"?: string;
		"source"?: string;
		"sourceId"?: string;
		"primary"?: boolean;
		"presenceDefinition"?: Models.PresenceDefinition;
		"message"?: string;
		"modifiedDate"?: string;
		"selfUri"?: string;
	}
	
	export interface MuteSnoozeFields { 
		"dateStart": string;
		"dateEnd": string;
	}
	
	export interface NTPSettings { 
		"servers"?: Array<string>;
	}
	
	export interface NamedEntity { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface NamedEntityAnnotation { 
		"name": string;
	}
	
	export interface NamedEntityDefinition { 
		"name": string;
		"type": string;
	}
	
	export interface NamedEntityTypeBinding { 
		"entityType": string;
		"entityName": string;
	}
	
	export interface NamedEntityTypeDefinition { 
		"name": string;
		"description"?: string;
		"mechanism": Models.NamedEntityTypeMechanism;
	}
	
	export interface NamedEntityTypeItem { 
		"value": string;
		"synonyms"?: Array<string>;
		"additionalLanguages"?: { [key: string]: Models.AdditionalLanguagesSynonyms; };
	}
	
	export interface NamedEntityTypeMechanism { 
		"items": Array<Models.NamedEntityTypeItem>;
		"restricted"?: boolean;
		"type": string;
	}
	
	export interface NamespaceDocs { 
		"friendlyName"?: string;
		"limits"?: Array<Models.LimitDocs>;
	}
	
	export interface NetworkConnectivity { 
		"carrier"?: string;
		"bluetoothEnabled": boolean;
		"cellularEnabled": boolean;
		"wifiEnabled": boolean;
	}
	
	export interface NluConfusionMatrixColumn { 
		"name": string;
		"value": number;
	}
	
	export interface NluConfusionMatrixRow { 
		"name": string;
		"columns": Array<Models.NluConfusionMatrixColumn>;
	}
	
	export interface NluDetectionContext { 
		"intent"?: Models.ContextIntent;
		"entity"?: Models.ContextEntity;
	}
	
	export interface NluDetectionInput { 
		"text": string;
		"language"?: string;
	}
	
	export interface NluDetectionOutput { 
		"intents"?: Array<Models.DetectedIntent>;
		"dialogActs"?: Array<Models.DetectedDialogAct>;
	}
	
	export interface NluDetectionRequest { 
		"input": Models.NluDetectionInput;
		"context"?: Models.NluDetectionContext;
	}
	
	export interface NluDetectionResponse { 
		"version"?: Models.NluDomainVersion;
		"output"?: Models.NluDetectionOutput;
		"input"?: Models.NluDetectionInput;
	}
	
	export interface NluDomain { 
		"id"?: string;
		"name": string;
		"language"?: string;
		"draftVersion"?: Models.NluDomainVersion;
		"lastPublishedVersion"?: Models.NluDomainVersion;
		"dateCreated"?: string;
		"dateModified"?: string;
		"engineVersion"?: string;
		"selfUri"?: string;
	}
	
	export interface NluDomainListing { 
		"entities"?: Array<Models.NluDomain>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface NluDomainVersion { 
		"id"?: string;
		"domain"?: Models.NluDomain;
		"description"?: string;
		"language": string;
		"published"?: boolean;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateTrained"?: string;
		"datePublished"?: string;
		"trainingStatus"?: string;
		"evaluationStatus"?: string;
		"intents"?: Array<Models.IntentDefinition>;
		"entityTypes"?: Array<Models.NamedEntityTypeDefinition>;
		"entities"?: Array<Models.NamedEntityDefinition>;
		"selfUri"?: string;
	}
	
	export interface NluDomainVersionListing { 
		"entities"?: Array<Models.NluDomainVersion>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface NluDomainVersionQualityReport { 
		"version": Models.NluDomainVersion;
		"confusionMatrix": Array<Models.NluConfusionMatrixRow>;
		"summary": Models.NluQualityReportSummary;
	}
	
	export interface NluDomainVersionTrainingResponse { 
		"message"?: string;
		"version"?: Models.NluDomainVersion;
	}
	
	export interface NluFeedbackListing { 
		"entities"?: Array<Models.NluFeedbackResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface NluFeedbackRequest { 
		"text": string;
		"intents": Array<Models.IntentFeedback>;
		"versionId": string;
		"language"?: string;
	}
	
	export interface NluFeedbackResponse { 
		"id"?: string;
		"text"?: string;
		"intents"?: Array<Models.IntentFeedback>;
		"version"?: Models.NluDomainVersion;
		"dateCreated"?: string;
		"language"?: string;
		"selfUri"?: string;
	}
	
	export interface NluInfo { 
		"domain"?: Models.AddressableEntityRef;
		"version"?: Models.NluDomainVersion;
		"intents"?: Array<Models.Intent>;
		"engineVersion"?: string;
		"nluData"?: Models.NluDomainVersion;
	}
	
	export interface NluOrganization { 
		"limits"?: { [key: string]: number; };
		"supportedLanguagesInfo"?: Array<Models.SupportedLanguagesInfoDefinition>;
	}
	
	export interface NluQualityReportSummary { 
		"metrics": Array<Models.NluQualityReportSummaryMetric>;
	}
	
	export interface NluQualityReportSummaryMetric { 
		"name": string;
		"value": number;
	}
	
	export interface NluUtterance { 
		"id"?: string;
		"segments": Array<Models.NluUtteranceSegment>;
	}
	
	export interface NluUtteranceSegment { 
		"text": string;
		"entity"?: Models.NamedEntityAnnotation;
	}
	
	export interface Note { 
		"id"?: string;
		"entityId"?: string;
		"entityType"?: string;
		"noteText"?: string;
		"modifyDate"?: string;
		"createDate"?: string;
		"createdBy": Models.User;
		"externalDataSources"?: Array<Models.ExternalDataSource>;
		"selfUri"?: string;
	}
	
	export interface NoteListing { 
		"entities"?: Array<Models.Note>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"partialResults"?: boolean;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface NotificationTemplateBody { 
		"text"?: string;
		"parameters": Array<Models.NotificationTemplateParameter>;
	}
	
	export interface NotificationTemplateFooter { 
		"text"?: string;
	}
	
	export interface NotificationTemplateHeader { 
		"type": string;
		"text"?: string;
		"media"?: Models.ContentAttachment;
		"parameters"?: Array<Models.NotificationTemplateParameter>;
	}
	
	export interface NotificationTemplateParameter { 
		"name"?: string;
		"text": string;
	}
	
	export interface NotificationsResponse { 
		"entities"?: Array<Models.WfmUserNotification>;
	}
	
	export interface NuanceApplication { 
		"id": string;
		"tag": string;
		"name": string;
	}
	
	export interface NuanceBot { 
		"id": string;
		"name": string;
		"integrationId": string;
		"nuanceOrganization": Models.NuanceOrganization;
		"application": Models.NuanceApplication;
		"nuanceEnvironment": Models.NuanceEnvironment;
		"geography": Models.NuanceGeography;
		"credentials"?: Array<Models.NuanceBotCredentials>;
		"variables"?: Array<Models.NuanceBotVariable>;
		"transferNodes"?: Array<Models.NuanceBotTransferNode>;
		"locales"?: Array<string>;
		"channels"?: Array<Models.NuanceChannel>;
		"selfUri"?: string;
	}
	
	export interface NuanceBotCredentials { 
		"appId": string;
		"clientId": string;
		"clientSecret"?: string;
		"clientSecretProvided"?: boolean;
	}
	
	export interface NuanceBotEntityListing { 
		"entities"?: Array<Models.NuanceBot>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface NuanceBotLaunchSettings { 
		"botExecutionConfigurations": Array<Models.BotExecutionConfiguration>;
	}
	
	export interface NuanceBotTransferNode { 
		"id": string;
		"name": string;
		"type": string;
		"description"?: string;
		"requestVariables"?: Array<Models.NuanceBotVariable>;
	}
	
	export interface NuanceBotVariable { 
		"id": string;
		"name": string;
		"description"?: string;
		"reserved"?: boolean;
		"simpleVariableInfo"?: string;
		"complexGenericVariableInfo"?: Models.ComplexVariableInfo;
	}
	
	export interface NuanceChannel { 
		"id": string;
		"name": string;
		"modes"?: Array<string>;
		"color"?: string;
	}
	
	export interface NuanceEnvironment { 
		"id": string;
		"name": string;
		"environmentDesignation": string;
		"executionHost"?: string;
	}
	
	export interface NuanceGeography { 
		"id": string;
		"name": string;
	}
	
	export interface NuanceMixDlgSettings { 
		"channelId"?: string;
		"inputParameters"?: { [key: string]: object; };
	}
	
	export interface NuanceOrganization { 
		"id": string;
		"name": string;
	}
	
	export interface Number { 
		"start"?: string;
		"end"?: string;
	}
	
	export interface NumberPlan { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"match"?: string;
		"normalizedFormat"?: string;
		"priority"?: number;
		"numbers"?: Array<Models.Number>;
		"digitLength"?: Models.DigitLength;
		"classification"?: string;
		"matchType"?: string;
		"selfUri"?: string;
	}
	
	export interface NumericRange { 
		"gt"?: number;
		"gte"?: number;
		"lt"?: number;
		"lte"?: number;
	}
	
	export interface OAuthAuthorization { 
		"client"?: Models.OAuthClient;
		"scope"?: Array<string>;
		"roles"?: Array<string>;
		"resourceOwner"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"pending"?: boolean;
		"state"?: string;
		"selfUri"?: string;
	}
	
	export interface OAuthAuthorizationListing { 
		"total"?: number;
		"entities"?: Array<Models.OAuthAuthorization>;
		"selfUri"?: string;
	}
	
	export interface OAuthClient { 
		"id"?: string;
		"name": string;
		"accessTokenValiditySeconds"?: number;
		"description"?: string;
		"registeredRedirectUri"?: Array<string>;
		"secret"?: string;
		"roleIds"?: Array<string>;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"authorizedGrantType": string;
		"scope"?: Array<string>;
		"roleDivisions"?: Array<Models.RoleDivision>;
		"state"?: string;
		"dateToDelete"?: string;
		"selfUri"?: string;
	}
	
	export interface OAuthClientEntityListing { 
		"entities"?: Array<Models.OAuthClientListing>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OAuthClientListing { 
		"id"?: string;
		"name": string;
		"accessTokenValiditySeconds"?: number;
		"description"?: string;
		"registeredRedirectUri"?: Array<string>;
		"secret"?: string;
		"roleIds"?: Array<string>;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"scope"?: Array<string>;
		"roleDivisions"?: Array<Models.RoleDivision>;
		"state"?: string;
		"dateToDelete"?: string;
		"selfUri"?: string;
	}
	
	export interface OAuthClientRequest { 
		"name": string;
		"accessTokenValiditySeconds"?: number;
		"description"?: string;
		"registeredRedirectUri"?: Array<string>;
		"roleIds"?: Array<string>;
		"authorizedGrantType": string;
		"scope"?: Array<string>;
		"roleDivisions"?: Array<Models.RoleDivision>;
		"state"?: string;
		"dateToDelete"?: string;
	}
	
	export interface OAuthLastTokenIssued { 
		"dateIssued"?: string;
	}
	
	export interface OAuthScope { 
		"id"?: string;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface OAuthScopeListing { 
		"total"?: number;
		"entities"?: Array<Models.OAuthScope>;
		"selfUri"?: string;
	}
	
	export interface Objective { 
		"id"?: string;
		"templateId"?: string;
		"zones"?: Array<Models.ObjectiveZone>;
		"enabled"?: boolean;
		"mediaTypes"?: Array<string>;
		"queues"?: Array<Models.AddressableEntityRef>;
		"topics"?: Array<Models.AddressableEntityRef>;
		"topicIdsFilterType"?: string;
		"evaluationFormContextIds"?: Array<string>;
		"initialDirection"?: string;
		"dateStart"?: string;
	}
	
	export interface ObjectiveTemplate { 
		"id"?: string;
		"name"?: string;
		"zones"?: Array<Models.ObjectiveZone>;
		"selfUri"?: string;
	}
	
	export interface ObjectiveZone { 
		"label": string;
		"directionType": string;
		"zoneType": string;
		"upperLimitPoints": number;
		"lowerLimitPoints": number;
		"upperLimitValue"?: number;
		"lowerLimitValue"?: number;
	}
	
	export interface ObservationMetricData { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: Models.StatisticalSummary;
		"truncated"?: boolean;
		"observations"?: Array<Models.ObservationValue>;
	}
	
	export interface ObservationValue { 
		"observationDate": string;
		"conversationId"?: string;
		"sessionId"?: string;
		"requestedRoutingSkillIds"?: Array<string>;
		"requestedLanguageId"?: string;
		"routingPriority"?: number;
		"participantName"?: string;
		"userId"?: string;
		"direction"?: string;
		"convertedFrom"?: string;
		"convertedTo"?: string;
		"addressFrom"?: string;
		"addressTo"?: string;
		"ani"?: string;
		"dnis"?: string;
		"teamId"?: string;
		"requestedRoutings"?: Array<string>;
		"usedRouting"?: string;
		"scoredAgents"?: Array<Models.AnalyticsScoredAgent>;
	}
	
	export interface Okta { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface OneLogin { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface OneOnOne { 
		"pinnedMessages"?: Array<Models.AddressableEntityRef>;
	}
	
	export interface OpenActionFields { 
		"openAction": Models.DomainEntityRef;
		"configurationFields"?: { [key: string]: object; };
	}
	
	export interface OpenActionProperties { 
		"openActionName"?: string;
		"configurationFields"?: { [key: string]: object; };
	}
	
	export interface OpenContentAttachment { 
		"id"?: string;
		"mediaType": string;
		"url": string;
		"mime": string;
		"text"?: string;
		"sha256"?: string;
		"filename"?: string;
	}
	
	export interface OpenEvent { 
		"eventType": string;
	}
	
	export interface OpenEventNormalizedMessage { 
		"id"?: string;
		"channel": Models.OpenMessagingChannel;
		"type": string;
		"events"?: Array<Models.OpenMessageEvent>;
	}
	
	export interface OpenInboundMessageContent { 
		"attachment"?: Models.OpenContentAttachment;
	}
	
	export interface OpenInboundMessageMessagingChannel { 
		"from": Models.OpenMessagingFromRecipient;
		"time": string;
		"messageId"?: string;
		"metadata"?: object;
	}
	
	export interface OpenInboundMessagingChannel { 
		"from": Models.OpenMessagingFromRecipient;
		"time": string;
	}
	
	export interface OpenInboundMessagingReceiptChannel { 
		"to": Models.OpenMessagingToRecipient;
		"time": string;
	}
	
	export interface OpenInboundNormalizedEvent { 
		"channel": Models.OpenInboundMessagingChannel;
		"events": Array<Models.OpenEvent>;
	}
	
	export interface OpenInboundNormalizedMessage { 
		"channel": Models.OpenInboundMessageMessagingChannel;
		"text"?: string;
		"content"?: Array<Models.OpenInboundMessageContent>;
		"metadata"?: { [key: string]: string; };
	}
	
	export interface OpenInboundNormalizedReceipt { 
		"id": string;
		"channel": Models.OpenInboundMessagingReceiptChannel;
		"status": string;
		"reasons"?: Array<Models.ConversationReason>;
		"isFinalReceipt"?: boolean;
	}
	
	export interface OpenIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"outboundNotificationWebhookUrl": string;
		"outboundNotificationWebhookSignatureSecretToken": string;
		"webhookHeaders"?: { [key: string]: string; };
		"status"?: string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"createStatus"?: string;
		"createError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface OpenIntegrationEntityListing { 
		"entities"?: Array<Models.OpenIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OpenIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"outboundNotificationWebhookUrl": string;
		"outboundNotificationWebhookSignatureSecretToken": string;
		"webhookHeaders"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface OpenIntegrationUpdateRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"outboundNotificationWebhookUrl"?: string;
		"outboundNotificationWebhookSignatureSecretToken"?: string;
		"webhookHeaders"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface OpenMessageContent { 
		"contentType": string;
		"attachment"?: Models.ConversationContentAttachment;
	}
	
	export interface OpenMessageEvent { 
		"eventType": string;
		"typing"?: Models.ConversationEventTyping;
	}
	
	export interface OpenMessageNormalizedMessage { 
		"id"?: string;
		"channel": Models.OpenMessagingChannel;
		"type": string;
		"text"?: string;
		"content"?: Array<Models.OpenMessageContent>;
		"metadata"?: { [key: string]: string; };
	}
	
	export interface OpenMessagingChannel { 
		"id"?: string;
		"platform"?: string;
		"type"?: string;
		"messageId"?: string;
		"to": Models.OpenMessagingToRecipient;
		"from": Models.OpenMessagingFromRecipient;
		"time": string;
		"metadata"?: object;
	}
	
	export interface OpenMessagingFromRecipient { 
		"nickname"?: string;
		"id": string;
		"idType": string;
		"firstName"?: string;
		"lastName"?: string;
		"image"?: string;
		"email"?: string;
	}
	
	export interface OpenMessagingToRecipient { 
		"nickname"?: string;
		"id": string;
		"idType"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"image"?: string;
		"email"?: string;
	}
	
	export interface OpenNormalizedMessage { 
		"id"?: string;
		"channel": Models.OpenMessagingChannel;
		"type": string;
		"text"?: string;
		"content"?: Array<Models.OpenMessageContent>;
		"status"?: string;
		"reasons"?: Array<Models.ConversationReason>;
		"isFinalReceipt"?: boolean;
		"direction"?: string;
		"metadata"?: { [key: string]: string; };
	}
	
	export interface OpenReceiptNormalizedMessage { 
		"id": string;
		"channel": Models.OpenMessagingChannel;
		"type": string;
		"status": string;
		"reasons"?: Array<Models.ConversationReason>;
		"isFinalReceipt"?: boolean;
		"direction": string;
	}
	
	export interface Operation { 
		"id"?: string;
		"complete"?: boolean;
		"user"?: Models.User;
		"client"?: Models.DomainEntityRef;
		"errorMessage"?: string;
		"errorCode"?: string;
		"errorDetails"?: Array<Models.Detail>;
		"errorMessageParams"?: { [key: string]: string; };
		"actionName"?: string;
		"actionStatus"?: string;
	}
	
	export interface OperationCreatorUserResponse { 
		"id"?: string;
		"type"?: string;
		"selfUri"?: string;
	}
	
	export interface OperationListing { 
		"entities"?: Array<Models.OperationResponse>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface OperationResponse { 
		"id"?: string;
		"status"?: string;
		"type"?: string;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface OperationalEventNotificationTopicEventEntity { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
	}
	
	export interface OperationalEventNotificationTopicOperationalEventNotification { 
		"eventEntity"?: Models.OperationalEventNotificationTopicEventEntity;
		"entityId"?: string;
		"entityName"?: string;
		"previousValue"?: string;
		"currentValue"?: string;
		"errorCode"?: string;
		"version"?: string;
		"parentEntity"?: string;
		"entityType"?: string;
		"conversationId"?: string;
		"timestamp"?: number;
	}
	
	export interface OptInSettings { 
		"keyword": Array<string>;
		"response": Models.ComplianceResponse;
	}
	
	export interface OrgAuthSettings { 
		"multifactorAuthenticationRequired"?: boolean;
		"domainAllowlistEnabled"?: boolean;
		"domainAllowlist"?: Array<string>;
		"ipAddressAllowlist"?: Array<string>;
		"passwordRequirements"?: Models.PasswordRequirements;
	}
	
	export interface OrgOAuthClient { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"authorizedGrantType": string;
		"scope"?: Array<string>;
		"roleDivisions"?: Array<Models.RoleDivision>;
		"state"?: string;
		"dateToDelete"?: string;
		"organization"?: Models.NamedEntity;
	}
	
	export interface OrgUser { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"chat"?: Models.Chat;
		"department"?: string;
		"email"?: string;
		"primaryContactInfo"?: Array<Models.Contact>;
		"addresses"?: Array<Models.Contact>;
		"state"?: string;
		"title"?: string;
		"username"?: string;
		"manager"?: Models.User;
		"images"?: Array<Models.UserImage>;
		"version": number;
		"certifications"?: Array<string>;
		"biography"?: Models.Biography;
		"employerInfo"?: Models.EmployerInfo;
		"preferredName"?: string;
		"routingStatus"?: Models.RoutingStatus;
		"presence"?: Models.UserPresence;
		"integrationPresence"?: Models.UserPresence;
		"conversationSummary"?: Models.UserConversationSummary;
		"outOfOffice"?: Models.OutOfOffice;
		"geolocation"?: Models.Geolocation;
		"station"?: Models.UserStations;
		"authorization"?: Models.UserAuthorization;
		"profileSkills"?: Array<string>;
		"locations"?: Array<Models.Location>;
		"groups"?: Array<Models.Group>;
		"team"?: Models.Team;
		"skills"?: Array<Models.UserRoutingSkill>;
		"languages"?: Array<Models.UserRoutingLanguage>;
		"acdAutoAnswer"?: boolean;
		"languagePreference"?: string;
		"lastTokenIssued"?: Models.OAuthLastTokenIssued;
		"dateLastLogin"?: string;
		"organization"?: Models.Organization;
	}
	
	export interface OrgWhitelistSettings { 
		"enableWhitelist"?: boolean;
		"domainWhitelist"?: Array<string>;
	}
	
	export interface Organization { 
		"id"?: string;
		"name"?: string;
		"defaultLanguage"?: string;
		"defaultCountryCode"?: string;
		"thirdPartyOrgName"?: string;
		"thirdPartyURI"?: string;
		"domain"?: string;
		"version": number;
		"state"?: string;
		"defaultSiteId"?: string;
		"supportURI"?: string;
		"voicemailEnabled"?: boolean;
		"productPlatform"?: string;
		"selfUri"?: string;
		"features"?: { [key: string]: boolean; };
	}
	
	export interface OrganizationFeatures { 
		"realtimeCIC"?: boolean;
		"purecloud"?: boolean;
		"hipaa"?: boolean;
		"ucEnabled"?: boolean;
		"pci"?: boolean;
		"purecloudVoice"?: boolean;
		"xmppFederation"?: boolean;
		"chat"?: boolean;
		"informalPhotos"?: boolean;
		"directory"?: boolean;
		"contactCenter"?: boolean;
		"unifiedCommunications"?: boolean;
		"custserv"?: boolean;
	}
	
	export interface OrganizationPresence { 
		"id"?: string;
		"name"?: string;
		"languageLabels": { [key: string]: string; };
		"systemPresence"?: string;
		"deactivated"?: boolean;
		"primary"?: boolean;
		"createdBy"?: Models.User;
		"createdDate"?: string;
		"modifiedBy"?: Models.User;
		"modifiedDate"?: string;
		"selfUri"?: string;
	}
	
	export interface OrganizationPresenceDefinition { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"languageLabels": { [key: string]: string; };
		"systemPresence"?: string;
		"divisionId"?: string;
		"deactivated"?: boolean;
		"selfUri"?: string;
	}
	
	export interface OrganizationPresenceDefinitionEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.OrganizationPresenceDefinition>;
		"selfUri"?: string;
	}
	
	export interface OrganizationPresenceEntityListing { 
		"entities"?: Array<Models.OrganizationPresence>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OrganizationProductEntityListing { 
		"entities"?: Array<Models.DomainOrganizationProduct>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface OrganizationRoleEntityListing { 
		"entities"?: Array<Models.DomainOrganizationRole>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OrphanRecording { 
		"id"?: string;
		"name"?: string;
		"createdTime"?: string;
		"recoveredTime"?: string;
		"providerType"?: string;
		"mediaSizeBytes"?: number;
		"mediaType"?: string;
		"mediaSubtype"?: string;
		"mediaSubject"?: string;
		"fileState"?: string;
		"providerEndpoint"?: Models.Endpoint;
		"recording"?: Models.Recording;
		"orphanStatus"?: string;
		"sourceOrphaningId"?: string;
		"region"?: string;
		"selfUri"?: string;
	}
	
	export interface OrphanRecordingListing { 
		"entities"?: Array<Models.OrphanRecording>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OrphanUpdateRequest { 
		"archiveDate"?: string;
		"deleteDate"?: string;
		"exportDate"?: string;
		"integrationId"?: string;
		"conversationId"?: string;
	}
	
	export interface OtherProfileAssignment { 
		"id"?: string;
		"currentProfile"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface OutOfOffice { 
		"id"?: string;
		"name"?: string;
		"user"?: Models.User;
		"startDate"?: string;
		"endDate"?: string;
		"active"?: boolean;
		"indefinite"?: boolean;
		"selfUri"?: string;
	}
	
	export interface OutOfOfficeEventOutOfOffice { 
		"user"?: Models.OutOfOfficeEventUser;
		"active"?: boolean;
		"indefinite"?: boolean;
		"startDate"?: string;
		"endDate"?: string;
	}
	
	export interface OutOfOfficeEventUser { 
		"id"?: string;
	}
	
	export interface OutboundDetailEventTopicOutboundInitEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"subject"?: string;
		"messageType"?: string;
		"outboundCampaignId"?: string;
		"divisionId"?: string;
		"outboundContactListId"?: string;
		"outboundContactId"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface OutboundDomain { 
		"id": string;
		"name"?: string;
		"cnameVerificationResult"?: Models.VerificationResult;
		"dkimVerificationResult"?: Models.VerificationResult;
		"senderType"?: string;
		"selfUri"?: string;
	}
	
	export interface OutboundDomainEntityListing { 
		"entities"?: Array<Models.OutboundDomain>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OutboundMessagingCampaignPostContactEmailEventTopicEmailAttributes { 
		"emailSubject"?: string;
		"configuredEmailAddress"?: string;
		"contactEmailAddress"?: string;
		"replyToAddress"?: string;
		"contactEmailColumnName"?: string;
	}
	
	export interface OutboundMessagingCampaignPostContactEmailEventTopicOutboundMessagingCampaignPostContactEmailEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"outboundCampaignType"?: string;
		"emailAttributes"?: Models.OutboundMessagingCampaignPostContactEmailEventTopicEmailAttributes;
		"wrapupCode"?: string;
		"outboundCampaignId"?: string;
		"divisionId"?: string;
		"contentTemplateId"?: string;
		"outboundContactListId"?: string;
		"outboundContactId"?: string;
		"isCampaignAlwaysRunning"?: boolean;
	}
	
	export interface OutboundMessagingCampaignPostContactSmsEventTopicOutboundMessagingCampaignPostContactSMSEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"outboundCampaignType"?: string;
		"smsAttributes"?: Models.OutboundMessagingCampaignPostContactSmsEventTopicSMSAttributes;
		"wrapupCode"?: string;
		"outboundCampaignId"?: string;
		"divisionId"?: string;
		"contentTemplateId"?: string;
		"outboundContactListId"?: string;
		"outboundContactId"?: string;
		"isCampaignAlwaysRunning"?: boolean;
	}
	
	export interface OutboundMessagingCampaignPostContactSmsEventTopicSMSAttributes { 
		"contactPhoneNumber"?: string;
		"contactPhoneNumberColumnName"?: string;
		"configuredSenderPhoneNumber"?: string;
		"senderPhoneNumber"?: string;
	}
	
	export interface OutboundMessagingCampaignPreContactEmailEventTopicEmailAttributes { 
		"emailSubject"?: string;
		"configuredEmailAddress"?: string;
		"contactEmailAddress"?: string;
		"replyToAddress"?: string;
		"contactEmailColumnName"?: string;
	}
	
	export interface OutboundMessagingCampaignPreContactEmailEventTopicOutboundMessagingCampaignPreContactEmailEvent { 
		"eventTime"?: number;
		"outboundCampaignType"?: string;
		"emailAttributes"?: Models.OutboundMessagingCampaignPreContactEmailEventTopicEmailAttributes;
		"wrapupCode"?: string;
		"outboundCampaignId"?: string;
		"divisionId"?: string;
		"contentTemplateId"?: string;
		"outboundContactListId"?: string;
		"outboundContactId"?: string;
		"isCampaignAlwaysRunning"?: boolean;
	}
	
	export interface OutboundMessagingCampaignPreContactSmsEventTopicOutboundMessagingCampaignPreContactSMSEvent { 
		"eventTime"?: number;
		"outboundCampaignType"?: string;
		"smsAttributes"?: Models.OutboundMessagingCampaignPreContactSmsEventTopicSMSAttributes;
		"wrapupCode"?: string;
		"outboundCampaignId"?: string;
		"divisionId"?: string;
		"contentTemplateId"?: string;
		"outboundContactListId"?: string;
		"outboundContactId"?: string;
		"isCampaignAlwaysRunning"?: boolean;
	}
	
	export interface OutboundMessagingCampaignPreContactSmsEventTopicSMSAttributes { 
		"contactPhoneNumber"?: string;
		"contactPhoneNumberColumnName"?: string;
		"configuredSenderPhoneNumber"?: string;
		"senderPhoneNumber"?: string;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeContactSort { 
		"fieldName"?: string;
		"direction"?: string;
		"numeric"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeEmailConfig { 
		"emailColumns"?: Array<string>;
		"contentTemplate"?: Models.OutboundMessagingMessagingCampaignConfigChangeResponseRef;
		"fromAddress"?: Models.OutboundMessagingMessagingCampaignConfigChangeFromEmailAddress;
		"replyToAddress"?: Models.OutboundMessagingMessagingCampaignConfigChangeReplyToEmailAddress;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeErrorDetail { 
		"error"?: string;
		"details"?: string;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeFromEmailAddress { 
		"friendlyName"?: string;
		"localPart"?: string;
		"domain"?: Models.OutboundMessagingMessagingCampaignConfigChangeUriReference;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign { 
		"campaignStatus"?: string;
		"callableTimeSet"?: Models.OutboundMessagingMessagingCampaignConfigChangeUriReference;
		"contactList"?: Models.OutboundMessagingMessagingCampaignConfigChangeUriReference;
		"dncLists"?: Array<Models.OutboundMessagingMessagingCampaignConfigChangeUriReference>;
		"contactListFilters"?: Array<Models.OutboundMessagingMessagingCampaignConfigChangeUriReference>;
		"alwaysRunning"?: boolean;
		"contactSorts"?: Array<Models.OutboundMessagingMessagingCampaignConfigChangeContactSort>;
		"messagesPerMinute"?: number;
		"ruleSets"?: Array<Models.OutboundMessagingMessagingCampaignConfigChangeUriReference>;
		"smsConfig"?: Models.OutboundMessagingMessagingCampaignConfigChangeSmsConfig;
		"emailConfig"?: Models.OutboundMessagingMessagingCampaignConfigChangeEmailConfig;
		"errors"?: Array<Models.OutboundMessagingMessagingCampaignConfigChangeErrorDetail>;
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"division"?: Models.OutboundMessagingMessagingCampaignConfigChangeUriReference;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeObject { 
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeReplyToEmailAddress { 
		"domain"?: Models.OutboundMessagingMessagingCampaignConfigChangeUriReference;
		"route"?: Models.OutboundMessagingMessagingCampaignConfigChangeUriReference;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeResponseRef { 
		"id"?: string;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeSmsConfig { 
		"messageColumn"?: string;
		"phoneColumn"?: string;
		"senderSmsPhoneNumber"?: Models.OutboundMessagingMessagingCampaignConfigChangeSmsPhoneNumberRef;
		"contentTemplate"?: Models.OutboundMessagingMessagingCampaignConfigChangeResponseRef;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeSmsPhoneNumberRef { 
		"phoneNumber"?: string;
	}
	
	export interface OutboundMessagingMessagingCampaignConfigChangeUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface OutboundMessagingMessagingCampaignProgressEventCampaignProgress { 
		"campaign"?: Models.OutboundMessagingMessagingCampaignProgressEventUriReference;
		"numberOfContactsCalled"?: number;
		"numberOfContactsMessaged"?: number;
		"totalNumberOfContacts"?: number;
		"percentage"?: number;
		"numberOfContactsSkipped"?: { [key: string]: number; };
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface OutboundMessagingMessagingCampaignProgressEventObject { 
	}
	
	export interface OutboundMessagingMessagingCampaignProgressEventUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface OutboundRoute { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"classificationTypes": Array<string>;
		"enabled"?: boolean;
		"distribution"?: string;
		"externalTrunkBases"?: Array<Models.DomainEntityRef>;
		"site"?: Models.Site;
		"managed"?: boolean;
		"selfUri"?: string;
	}
	
	export interface OutboundRouteBase { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"classificationTypes": Array<string>;
		"enabled"?: boolean;
		"distribution"?: string;
		"externalTrunkBases"?: Array<Models.DomainEntityRef>;
		"selfUri"?: string;
	}
	
	export interface OutboundRouteBaseEntityListing { 
		"entities"?: Array<Models.OutboundRouteBase>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OutboundRouteEntityListing { 
		"entities"?: Array<Models.OutboundRoute>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OutboundSettings { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"maxCallsPerAgent"?: number;
		"maxConfigurableCallsPerAgent"?: number;
		"maxLineUtilization"?: number;
		"abandonSeconds"?: number;
		"complianceAbandonRateDenominator"?: string;
		"automaticTimeZoneMapping"?: Models.AutomaticTimeZoneMappingSettings;
		"rescheduleTimeZoneSkippedContacts"?: boolean;
		"selfUri"?: string;
	}
	
	export interface Outcome { 
		"id": string;
		"isActive": boolean;
		"displayName": string;
		"version": number;
		"description"?: string;
		"isPositive": boolean;
		"context": Models.Context;
		"journey": Models.Journey;
		"associatedValueField"?: Models.AssociatedValueField;
		"selfUri"?: string;
		"createdDate": string;
		"modifiedDate": string;
	}
	
	export interface OutcomeAchievedEvent { 
		"outcome": Models.OutcomeAchievedEventOutcome;
		"userAgentString"?: string;
		"browser"?: Models.Browser;
		"device"?: Models.Device;
		"geolocation"?: Models.JourneyGeolocation;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"mktCampaign"?: Models.JourneyCampaign;
		"visitReferrer"?: Models.Referrer;
		"visitCreatedDate"?: string;
	}
	
	export interface OutcomeAchievedEventOutcome { 
		"id": string;
		"selfUri"?: string;
		"displayName": string;
		"version": number;
	}
	
	export interface OutcomeAchievement { 
		"outcome": Models.AchievedOutcome;
		"achievedDate": string;
	}
	
	export interface OutcomeAttributionAsyncResponse { 
		"id"?: string;
		"percentFailedThreshold"?: number;
		"selfUri"?: string;
	}
	
	export interface OutcomeAttributionJobStateResponse { 
		"id"?: string;
		"state"?: string;
		"resultsUri"?: string;
		"percentFailedThreshold"?: number;
		"selfUri"?: string;
		"createdDate"?: string;
	}
	
	export interface OutcomeAttributionListing { 
		"entities": Array<Models.OutcomeAttributionRequest>;
		"percentFailedThreshold"?: number;
	}
	
	export interface OutcomeAttributionRequest { 
		"outcomeId": string;
		"externalContactId"?: string;
		"associatedValue": number;
		"touchpoints": Array<Models.Touchpoint>;
		"createdDate": string;
	}
	
	export interface OutcomeAttributionResponseListing { 
		"entities"?: Array<Models.OutcomeAttributionResultsResponse>;
	}
	
	export interface OutcomeAttributionResultsResponse { 
		"outcomeId"?: string;
		"index"?: number;
		"externalContactId"?: string;
		"associatedValue"?: number;
		"state": string;
		"message": string;
		"touchpoints"?: Array<Models.TouchpointResponse>;
		"createdDate"?: string;
	}
	
	export interface OutcomeConfig { 
		"values"?: Array<string>;
	}
	
	export interface OutcomeListing { 
		"entities"?: Array<Models.Outcome>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface OutcomePercentileCondition { 
		"outcomeId": string;
		"maximumPercentile": number;
		"fallbackPercentile"?: number;
	}
	
	export interface OutcomePredictor { 
		"id"?: string;
		"outcome"?: Models.OutcomeRef;
		"selfUri"?: string;
	}
	
	export interface OutcomePredictorListing { 
		"entities"?: Array<Models.OutcomePredictor>;
	}
	
	export interface OutcomePredictorRequest { 
		"outcome": Models.OutcomeRefRequest;
	}
	
	export interface OutcomeProbabilityCondition { 
		"outcomeId": string;
		"maximumProbability": number;
		"probability"?: number;
	}
	
	export interface OutcomeQuantileCondition { 
		"outcomeId": string;
		"maxQuantileThreshold": number;
		"fallbackQuantileThreshold"?: number;
	}
	
	export interface OutcomeRef { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface OutcomeRefRequest { 
		"id": string;
	}
	
	export interface OutcomeRequest { 
		"isActive"?: boolean;
		"displayName": string;
		"version"?: number;
		"description"?: string;
		"isPositive"?: boolean;
		"context"?: Models.RequestContext;
		"journey"?: Models.RequestJourney;
		"associatedValueField"?: Models.AssociatedValueField;
	}
	
	export interface OutcomeScore { 
		"outcome"?: Models.AddressableEntityRef;
		"sessionMaxProbability"?: number;
		"probability"?: number;
		"percentile"?: number;
		"sessionMaxPercentile"?: number;
		"quantile"?: number;
		"sessionMaxQuantile"?: number;
	}
	
	export interface OutcomeScoresResult { 
		"outcomeScores"?: Array<Models.OutcomeScore>;
		"modifiedDate"?: string;
	}
	
	export interface OutlierInfo { 
		"outlier"?: boolean;
		"score"?: number;
	}
	
	export interface OverallBestPoints { 
		"division"?: Models.Division;
		"bestPoints"?: Array<Models.OverallBestPointsItem>;
		"performanceProfile"?: Models.AddressableEntityRef;
	}
	
	export interface OverallBestPointsItem { 
		"granularityType"?: string;
		"users"?: Array<Models.UserReference>;
		"count"?: number;
		"points"?: number;
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
	}
	
	export interface PINConfiguration { 
		"minimumLength"?: number;
		"maximumLength"?: number;
	}
	
	export interface Page { 
		"id"?: string;
		"name"?: string;
		"versionId"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"rootContainer"?: { [key: string]: object; };
		"properties"?: { [key: string]: object; };
		"selfUri"?: string;
	}
	
	export interface PagedNamespaceListing { 
	}
	
	export interface PagelessDomainEntityListingEvaluationVersion { 
		"total"?: number;
		"entities"?: Array<Models.EvaluationVersion>;
		"selfUri"?: string;
	}
	
	export interface PagelessEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.AddressableEntity>;
		"selfUri"?: string;
	}
	
	export interface PagingSpec { 
		"pageSize": number;
		"pageNumber": number;
	}
	
	export interface Parameter { 
		"name"?: string;
		"parameterType"?: string;
		"domain"?: string;
		"required"?: boolean;
	}
	
	export interface ParsedCertificate { 
		"certificateDetails"?: Array<Models.CertificateDetails>;
	}
	
	export interface Participant { 
		"id"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"connectedTime"?: string;
		"name"?: string;
		"userUri"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"queueId"?: string;
		"groupId"?: string;
		"teamId"?: string;
		"queueName"?: string;
		"purpose"?: string;
		"participantType"?: string;
		"consultParticipantId"?: string;
		"address"?: string;
		"ani"?: string;
		"aniName"?: string;
		"dnis"?: string;
		"locale"?: string;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"wrapup"?: Models.Wrapup;
		"mediaRoles"?: Array<string>;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"alertingTimeoutMs"?: number;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"attributes"?: { [key: string]: string; };
		"calls"?: Array<Models.Call>;
		"callbacks"?: Array<Models.Callback>;
		"chats"?: Array<Models.ConversationChat>;
		"cobrowsesessions"?: Array<Models.Cobrowsesession>;
		"emails"?: Array<Models.Email>;
		"messages"?: Array<Models.Message>;
		"screenshares"?: Array<Models.Screenshare>;
		"socialExpressions"?: Array<Models.SocialExpression>;
		"videos"?: Array<Models.Video>;
		"evaluations"?: Array<Models.Evaluation>;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"bargedParticipantId"?: string;
	}
	
	export interface ParticipantAttributes { 
		"attributes"?: { [key: string]: string; };
	}
	
	export interface ParticipantBasic { 
		"id"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"connectedTime"?: string;
		"name"?: string;
		"userUri"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"queueId"?: string;
		"groupId"?: string;
		"teamId"?: string;
		"queueName"?: string;
		"purpose"?: string;
		"participantType"?: string;
		"consultParticipantId"?: string;
		"address"?: string;
		"ani"?: string;
		"aniName"?: string;
		"dnis"?: string;
		"locale"?: string;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"wrapup"?: Models.Wrapup;
		"mediaRoles"?: Array<string>;
		"conversationRoutingData"?: Models.ConversationRoutingData;
		"alertingTimeoutMs"?: number;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"attributes"?: { [key: string]: string; };
		"calls"?: Array<Models.CallBasic>;
		"callbacks"?: Array<Models.CallbackBasic>;
		"chats"?: Array<Models.ConversationChat>;
		"cobrowsesessions"?: Array<Models.Cobrowsesession>;
		"emails"?: Array<Models.Email>;
		"messages"?: Array<Models.Message>;
		"screenshares"?: Array<Models.Screenshare>;
		"socialExpressions"?: Array<Models.SocialExpression>;
		"videos"?: Array<Models.Video>;
		"evaluations"?: Array<Models.Evaluation>;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"bargedParticipantId"?: string;
	}
	
	export interface ParticipantInfo { 
		"activeParticipantCount"?: number;
		"version"?: number;
	}
	
	export interface ParticipantMetrics { 
		"agentDurationPercentage"?: number;
		"customerDurationPercentage"?: number;
		"silenceDurationPercentage"?: number;
		"ivrDurationPercentage"?: number;
		"acdDurationPercentage"?: number;
		"overtalkDurationPercentage"?: number;
		"otherDurationPercentage"?: number;
		"overtalkCount"?: number;
	}
	
	export interface PasswordRequirements { 
		"minimumLength"?: number;
		"minimumDigits"?: number;
		"minimumLetters"?: number;
		"minimumUpper"?: number;
		"minimumLower"?: number;
		"minimumSpecials"?: number;
		"minimumAgeSeconds"?: number;
		"expirationDays"?: number;
	}
	
	export interface PatchAction { 
		"mediaType": string;
		"actionTemplate"?: Models.ActionMapActionTemplate;
		"actionTargetId"?: string;
		"isPacingEnabled"?: boolean;
		"props"?: Models.PatchActionProperties;
		"architectFlowFields"?: Models.ArchitectFlowFields;
		"webMessagingOfferFields"?: Models.PatchWebMessagingOfferFields;
		"openActionFields"?: Models.OpenActionFields;
	}
	
	export interface PatchActionMap { 
		"id"?: string;
		"version"?: number;
		"isActive"?: boolean;
		"displayName": string;
		"triggerWithSegments": Array<string>;
		"triggerWithEventConditions"?: Array<Models.EventCondition>;
		"triggerWithOutcomeProbabilityConditions"?: Array<Models.OutcomeProbabilityCondition>;
		"triggerWithOutcomePercentileConditions"?: Array<Models.OutcomePercentileCondition>;
		"triggerWithOutcomeQuantileConditions"?: Array<Models.OutcomeQuantileCondition>;
		"pageUrlConditions": Array<Models.UrlCondition>;
		"activation"?: Models.Activation;
		"weight"?: number;
		"action"?: Models.PatchAction;
		"actionMapScheduleGroups"?: Models.PatchActionMapScheduleGroups;
		"ignoreFrequencyCap"?: boolean;
		"selfUri"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"startDate"?: string;
		"endDate"?: string;
	}
	
	export interface PatchActionMapScheduleGroups { 
		"actionMapScheduleGroup": Models.ActionMapScheduleGroup;
		"emergencyActionMapScheduleGroup"?: Models.ActionMapScheduleGroup;
	}
	
	export interface PatchActionProperties { 
		"webchatPrompt"?: string;
		"webchatTitleText"?: string;
		"webchatAcceptText"?: string;
		"webchatDeclineText"?: string;
		"webchatSurvey"?: Models.PatchActionSurvey;
	}
	
	export interface PatchActionSurvey { 
		"questions": Array<Models.PatchSurveyQuestion>;
	}
	
	export interface PatchActionTarget { 
		"id"?: string;
		"name"?: string;
		"serviceLevel"?: Models.ServiceLevel;
		"shortAbandonThreshold"?: number;
		"selfUri"?: string;
	}
	
	export interface PatchActionTemplate { 
		"name": string;
		"description"?: string;
		"version"?: number;
		"mediaType"?: string;
		"state"?: string;
		"contentOffer"?: Models.PatchContentOffer;
	}
	
	export interface PatchAssociatedValueField { 
		"dataType"?: string;
		"name"?: string;
	}
	
	export interface PatchBuReschedulingOptionsManagementUnitRequest { 
		"managementUnitId": string;
		"applied"?: boolean;
	}
	
	export interface PatchBuReschedulingOptionsRequest { 
		"managementUnits"?: Array<Models.PatchBuReschedulingOptionsManagementUnitRequest>;
	}
	
	export interface PatchBuScheduleRunRequest { 
		"reschedulingOptions"?: Models.PatchBuReschedulingOptionsRequest;
	}
	
	export interface PatchCallToAction { 
		"text"?: string;
		"url"?: string;
		"target"?: string;
	}
	
	export interface PatchCallbackRequest { 
		"conversationId": string;
		"queueId"?: string;
		"agentId": string;
		"callbackScheduledTime"?: string;
	}
	
	export interface PatchCallbackResponse { 
		"conversation": Models.DomainEntityRef;
		"callbackIdentifiers": Array<Models.CallbackIdentifier>;
	}
	
	export interface PatchCloseButtonStyleProperties { 
		"color"?: string;
		"opacity"?: number;
	}
	
	export interface PatchContentOffer { 
		"imageUrl"?: string;
		"displayMode"?: string;
		"layoutMode"?: string;
		"title"?: string;
		"headline"?: string;
		"body"?: string;
		"callToAction"?: Models.PatchCallToAction;
		"style"?: Models.PatchContentOfferStylingConfiguration;
	}
	
	export interface PatchContentOfferStyleProperties { 
		"padding"?: string;
		"color"?: string;
		"backgroundColor"?: string;
	}
	
	export interface PatchContentOfferStylingConfiguration { 
		"position"?: Models.PatchContentPositionProperties;
		"offer"?: Models.PatchContentOfferStyleProperties;
		"closeButton"?: Models.PatchCloseButtonStyleProperties;
		"ctaButton"?: Models.PatchCtaButtonStyleProperties;
		"title"?: Models.PatchTextStyleProperties;
		"headline"?: Models.PatchTextStyleProperties;
		"body"?: Models.PatchTextStyleProperties;
	}
	
	export interface PatchContentPositionProperties { 
		"top"?: string;
		"bottom"?: string;
		"left"?: string;
		"right"?: string;
	}
	
	export interface PatchContext { 
		"patterns"?: Array<Models.PatchContextPattern>;
	}
	
	export interface PatchContextPattern { 
		"criteria"?: Array<Models.PatchEntityTypeCriteria>;
	}
	
	export interface PatchCriteria { 
		"key"?: string;
		"values"?: Array<string>;
		"shouldIgnoreCase"?: boolean;
		"operator"?: string;
	}
	
	export interface PatchCtaButtonStyleProperties { 
		"color"?: string;
		"font"?: string;
		"fontSize"?: string;
		"textAlign"?: string;
		"backgroundColor"?: string;
	}
	
	export interface PatchEntityTypeCriteria { 
		"key"?: string;
		"values"?: Array<string>;
		"shouldIgnoreCase"?: boolean;
		"operator"?: string;
		"entityType"?: string;
	}
	
	export interface PatchExternalSegment { 
		"name"?: string;
	}
	
	export interface PatchIntegrationAction { 
		"id"?: string;
	}
	
	export interface PatchIntegrationActionFields { 
		"integrationAction"?: Models.PatchIntegrationAction;
		"requestMappings"?: Array<Models.RequestMapping>;
	}
	
	export interface PatchJourney { 
		"patterns"?: Array<Models.PatchJourneyPattern>;
	}
	
	export interface PatchJourneyPattern { 
		"criteria"?: Array<Models.PatchCriteria>;
		"count"?: number;
		"streamType"?: string;
		"sessionType"?: string;
		"eventName"?: string;
	}
	
	export interface PatchOutcome { 
		"isActive"?: boolean;
		"displayName": string;
		"version"?: number;
		"description"?: string;
		"isPositive"?: boolean;
		"context"?: Models.PatchContext;
		"journey"?: Models.PatchJourney;
		"associatedValueField"?: Models.PatchAssociatedValueField;
	}
	
	export interface PatchPredictorRequest { 
		"routingTimeoutSeconds"?: number;
		"schedule"?: Models.PredictorSchedule;
		"workloadBalancingConfig"?: Models.PredictorWorkloadBalancing;
	}
	
	export interface PatchSegment { 
		"isActive"?: boolean;
		"displayName"?: string;
		"version"?: number;
		"description"?: string;
		"color"?: string;
		"shouldDisplayToAgent"?: boolean;
		"context"?: Models.PatchContext;
		"journey"?: Models.PatchJourney;
		"externalSegment"?: Models.PatchExternalSegment;
		"assignmentExpirationDays"?: number;
	}
	
	export interface PatchShiftTradeRequest { 
		"receivingUserId"?: Models.ValueWrapperString;
		"expiration"?: Models.ValueWrapperDate;
		"acceptableIntervals"?: Models.ListWrapperInterval;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface PatchSurveyQuestion { 
		"type"?: string;
		"label": string;
		"customerProperty"?: string;
		"choices"?: Array<string>;
		"isMandatory"?: boolean;
	}
	
	export interface PatchTextStyleProperties { 
		"color"?: string;
		"font"?: string;
		"fontSize"?: string;
		"textAlign"?: string;
	}
	
	export interface PatchUser { 
		"id"?: string;
		"preferredName"?: string;
		"acdAutoAnswer"?: boolean;
	}
	
	export interface PatchWebMessagingOfferFields { 
		"offerText"?: string;
		"architectFlow"?: Models.AddressableEntityRef;
	}
	
	export interface Pattern { 
		"type": string;
		"interval": number;
		"daysOfWeek"?: Array<string>;
	}
	
	export interface PerformancePredictionCompleteEventTopicErrorBody { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface PerformancePredictionCompleteEventTopicPerformancePredictionCalculationNotification { 
		"scheduleId"?: string;
		"weekDate"?: string;
		"downloadUrl"?: string;
		"state"?: string;
		"error"?: Models.PerformancePredictionCompleteEventTopicErrorBody;
	}
	
	export interface PerformancePredictionOutputs { 
		"calculationStartDate": string;
		"calculationIntervalLengthMinutes": number;
		"planningGroupResults": Array<Models.PlanningGroupOutputs>;
	}
	
	export interface PerformancePredictionRecalculationCompleteEventTopicErrorBody { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface PerformancePredictionRecalculationCompleteEventTopicPerformancePredictionUserRecalculationNotification { 
		"operationId"?: string;
		"downloadUrl"?: string;
		"state"?: string;
		"error"?: Models.PerformancePredictionRecalculationCompleteEventTopicErrorBody;
	}
	
	export interface PerformancePredictionRecalculationResponse { 
		"operationId": string;
		"downloadUrl"?: string;
		"downloadResult"?: Models.PerformancePredictionOutputs;
		"state": string;
	}
	
	export interface PerformancePredictionRecalculationUploadResponse { 
		"uploadKey"?: string;
		"url"?: string;
		"headers"?: { [key: string]: string; };
		"uploadBodySchema"?: Models.PerformancePredictionUploadSchema;
	}
	
	export interface PerformancePredictionResponse { 
		"id"?: string;
		"weekDate": string;
		"scheduleId": string;
		"downloadUrl"?: string;
		"downloadResult"?: Models.PerformancePredictionOutputs;
		"state": string;
		"selfUri"?: string;
	}
	
	export interface PerformancePredictionUploadSchema { 
		"calculationStartDate": string;
		"onQueueTimes": Array<Models.MuAgentQueueTimeRequest>;
	}
	
	export interface PerformanceProfile { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description": string;
		"metricOrders": Array<string>;
		"dateCreated"?: string;
		"reportingIntervals"?: Array<Models.ReportingInterval>;
		"active"?: boolean;
		"memberCount"?: number;
		"maxLeaderboardRankSize"?: number;
		"selfUri"?: string;
	}
	
	export interface PermissionCollectionEntityListing { 
		"entities"?: Array<Models.DomainPermissionCollection>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PermissionDetails { 
		"type"?: string;
		"permissions"?: Array<string>;
		"allowsCurrentUser"?: boolean;
		"enforced"?: boolean;
	}
	
	export interface Permissions { 
		"ids": Array<string>;
	}
	
	export interface Phone { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"site": Models.DomainEntityRef;
		"phoneBaseSettings": Models.PhoneBaseSettings;
		"lineBaseSettings"?: Models.DomainEntityRef;
		"phoneMetaBase"?: Models.DomainEntityRef;
		"lines": Array<Models.Line>;
		"status"?: Models.PhoneStatus;
		"secondaryStatus"?: Models.PhoneStatus;
		"userAgentInfo"?: Models.UserAgentInfo;
		"properties"?: { [key: string]: object; };
		"capabilities"?: Models.PhoneCapabilities;
		"webRtcUser"?: Models.DomainEntityRef;
		"primaryEdge"?: Models.Edge;
		"secondaryEdge"?: Models.Edge;
		"selfUri"?: string;
	}
	
	export interface PhoneBase { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"phoneMetaBase": Models.DomainEntityRef;
		"lines": Array<Models.LineBase>;
		"properties"?: { [key: string]: object; };
		"capabilities"?: Models.PhoneCapabilities;
		"selfUri"?: string;
	}
	
	export interface PhoneBaseEntityListing { 
		"entities"?: Array<Models.PhoneBase>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"totalNumberOfEntities"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PhoneBaseSettings { 
		"id": string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface PhoneCapabilities { 
		"provisions"?: boolean;
		"registers"?: boolean;
		"dualRegisters"?: boolean;
		"hardwareIdType"?: string;
		"allowReboot"?: boolean;
		"noRebalance"?: boolean;
		"noCloudProvisioning"?: boolean;
		"mediaCodecs"?: Array<string>;
		"cdm"?: boolean;
	}
	
	export interface PhoneChangeTopicEdgeReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface PhoneChangeTopicLineStatus { 
		"id"?: string;
		"reachable"?: boolean;
		"addressOfRecord"?: string;
		"contactAddresses"?: Array<string>;
		"reachableStateTime"?: string;
	}
	
	export interface PhoneChangeTopicPhone { 
		"userAgentInfo"?: Models.PhoneChangeTopicUserAgentInfo;
		"id"?: string;
		"status"?: Models.PhoneChangeTopicPhoneStatus;
		"secondaryStatus"?: Models.PhoneChangeTopicPhoneStatus;
	}
	
	export interface PhoneChangeTopicPhoneStatus { 
		"id"?: string;
		"operationalStatus"?: string;
		"edge"?: Models.PhoneChangeTopicEdgeReference;
		"provision"?: Models.PhoneChangeTopicProvisionInfo;
		"lineStatuses"?: Array<Models.PhoneChangeTopicLineStatus>;
		"eventCreationTime"?: string;
	}
	
	export interface PhoneChangeTopicProvisionInfo { 
		"time"?: string;
		"source"?: string;
		"errorInfo"?: string;
	}
	
	export interface PhoneChangeTopicUserAgentInfo { 
		"firmwareVersion"?: string;
		"manufacturer"?: string;
		"model"?: string;
	}
	
	export interface PhoneColumn { 
		"columnName": string;
		"type": string;
	}
	
	export interface PhoneEntityListing { 
		"entities"?: Array<Models.Phone>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PhoneEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"phoneNumber"?: string;
		"ani"?: string;
		"dnis"?: string;
		"initialConfiguration": Models.InitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface PhoneMetaBaseEntityListing { 
		"entities"?: Array<Models.Metabase>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"totalNumberOfEntities"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PhoneNumber { 
		"display"?: string;
		"extension"?: number;
		"acceptsSMS"?: boolean;
		"normalizationCountryCode"?: string;
		"userInput"?: string;
		"e164"?: string;
		"countryCode"?: string;
	}
	
	export interface PhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface PhoneNumberStatus { 
		"callable"?: boolean;
	}
	
	export interface PhoneStatus { 
		"id"?: string;
		"name"?: string;
		"operationalStatus"?: string;
		"edgesStatus"?: string;
		"eventCreationTime"?: string;
		"provision"?: Models.ProvisionInfo;
		"lineStatuses"?: Array<Models.LineStatus>;
		"phoneAssignmentToEdgeType"?: string;
		"edge"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface PhoneTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationPhoneNumber": string;
	}
	
	export interface PhonesReboot { 
		"phoneIds"?: Array<string>;
		"siteId"?: string;
	}
	
	export interface Phrase { 
		"text": string;
		"strictness"?: string;
		"sentiment"?: string;
	}
	
	export interface PhraseAssociations { 
		"phraseId": string;
		"documentId": string;
	}
	
	export interface PhysicalInterfaceEntityListing { 
		"entities"?: Array<Models.DomainPhysicalInterface>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PingIdentity { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface PinnedMessageRequest { 
		"pinnedMessageIds": Array<string>;
	}
	
	export interface PlanningGroup { 
		"id"?: string;
		"name"?: string;
		"serviceGoalTemplate"?: Models.ServiceGoalTemplateReference;
		"routePaths"?: Array<Models.RoutePathResponse>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface PlanningGroupList { 
		"entities"?: Array<Models.PlanningGroup>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface PlanningGroupOutputs { 
		"planningGroupId": string;
		"serviceLevelPerInterval": Array<number>;
		"occupancyPerInterval": Array<number>;
		"averageSpeedOfAnswerSecondsPerInterval": Array<number>;
		"abandonRatePerInterval": Array<number>;
	}
	
	export interface PlanningGroupReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface PlanningPeriodSettings { 
		"weekCount": number;
		"startDate": string;
	}
	
	export interface Policy { 
		"id"?: string;
		"name"?: string;
		"modifiedDate"?: string;
		"createdDate"?: string;
		"order"?: number;
		"description"?: string;
		"enabled"?: boolean;
		"mediaPolicies"?: Models.MediaPolicies;
		"conditions"?: Models.PolicyConditions;
		"actions"?: Models.PolicyActions;
		"policyErrors"?: Models.PolicyErrors;
		"selfUri"?: string;
	}
	
	export interface PolicyActions { 
		"retainRecording"?: boolean;
		"deleteRecording"?: boolean;
		"alwaysDelete"?: boolean;
		"assignEvaluations"?: Array<Models.EvaluationAssignment>;
		"assignMeteredEvaluations"?: Array<Models.MeteredEvaluationAssignment>;
		"assignMeteredAssignmentByAgent"?: Array<Models.MeteredAssignmentByAgent>;
		"assignCalibrations"?: Array<Models.CalibrationAssignment>;
		"assignSurveys"?: Array<Models.SurveyAssignment>;
		"retentionDuration"?: Models.RetentionDuration;
		"initiateScreenRecording"?: Models.InitiateScreenRecording;
		"mediaTranscriptions"?: Array<Models.MediaTranscription>;
		"integrationExport"?: Models.IntegrationExport;
	}
	
	export interface PolicyConditions { 
		"forUsers"?: Array<Models.User>;
		"directions"?: Array<string>;
		"dateRanges"?: Array<string>;
		"mediaTypes"?: Array<string>;
		"forQueues"?: Array<Models.Queue>;
		"duration"?: Models.DurationCondition;
		"wrapupCodes"?: Array<Models.WrapupCode>;
		"timeAllowed"?: Models.TimeAllowed;
		"teams"?: Array<Models.Team>;
		"customerParticipation"?: string;
	}
	
	export interface PolicyCreate { 
		"id"?: string;
		"name": string;
		"modifiedDate"?: string;
		"createdDate"?: string;
		"order"?: number;
		"description"?: string;
		"enabled"?: boolean;
		"mediaPolicies"?: Models.MediaPolicies;
		"conditions"?: Models.PolicyConditions;
		"actions"?: Models.PolicyActions;
		"policyErrors"?: Models.PolicyErrors;
		"selfUri"?: string;
	}
	
	export interface PolicyEntityListing { 
		"entities"?: Array<Models.Policy>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PolicyErrorMessage { 
		"statusCode"?: number;
		"userMessage"?: object;
		"userParamsMessage"?: string;
		"errorCode"?: string;
		"correlationId"?: string;
		"userParams"?: Array<Models.UserParam>;
		"insertDate"?: string;
	}
	
	export interface PolicyErrors { 
		"policyErrorMessages"?: Array<Models.PolicyErrorMessage>;
	}
	
	export interface PolicyUpdate { 
		"enabled"?: boolean;
	}
	
	export interface PositionSettings { 
		"alignment"?: string;
		"sideSpace"?: number;
		"bottomSpace"?: number;
	}
	
	export interface PossibleWorkShiftsForWeek { 
		"id"?: number;
		"dailyPossibleShifts"?: Array<Models.DailyPossibleShift>;
	}
	
	export interface PostActionInput { 
		"category": string;
		"name": string;
		"integrationId": string;
		"config": Models.ActionConfig;
		"contract": Models.ActionContractInput;
		"secure"?: boolean;
	}
	
	export interface PostInputContract { 
		"inputSchema": Models.JsonSchemaDocument;
	}
	
	export interface PostOutputContract { 
		"successSchema": Models.JsonSchemaDocument;
	}
	
	export interface PostTextMessage { 
		"type": string;
		"text"?: string;
		"content"?: Array<Models.ConversationMessageContent>;
	}
	
	export interface PostTextRequest { 
		"botId": string;
		"botAlias"?: string;
		"integrationId": string;
		"botSessionId": string;
		"postTextMessage": Models.PostTextMessage;
		"languageCode"?: string;
		"botSessionTimeoutMinutes"?: number;
		"botChannels"?: Array<string>;
		"botCorrelationId"?: string;
		"messagingPlatformType"?: string;
		"amazonLexRequest"?: Models.AmazonLexRequest;
		"googleDialogflow"?: Models.GoogleDialogflowCustomSettings;
		"genesysBotConnector"?: Models.GenesysBotConnector;
		"nuanceMixDlg"?: Models.NuanceMixDlgSettings;
	}
	
	export interface PostTextResponse { 
		"botState": string;
		"replyMessages"?: Array<Models.PostTextMessage>;
		"intentName"?: string;
		"slots"?: { [key: string]: string; };
		"botCorrelationId"?: string;
		"amazonLex"?: { [key: string]: object; };
		"googleDialogFlow"?: { [key: string]: object; };
		"genesysDialogEngine"?: { [key: string]: object; };
		"genesysBotConnector"?: { [key: string]: object; };
		"nuanceMixDlg"?: { [key: string]: object; };
	}
	
	export interface PredictionResults { 
		"intent"?: string;
		"formula": string;
		"estimatedWaitTimeSeconds": number;
	}
	
	export interface PredictiveRouting { 
		"respectSkills"?: boolean;
		"enableConversationScoreBiasing"?: boolean;
	}
	
	export interface Predictor { 
		"id"?: string;
		"queues": Array<Models.AddressableEntityRef>;
		"kpi": string;
		"routingTimeoutSeconds"?: number;
		"schedule"?: Models.PredictorSchedule;
		"state"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"workloadBalancingConfig"?: Models.PredictorWorkloadBalancing;
		"errorCode"?: string;
		"models"?: Array<Models.PredictorModelBrief>;
		"selfUri"?: string;
	}
	
	export interface PredictorListing { 
		"entities"?: Array<Models.Predictor>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface PredictorModel { 
		"id"?: string;
		"kpi"?: string;
		"queues"?: Array<Models.AddressableEntityRef>;
		"dateCreated"?: string;
		"dateTrained"?: string;
		"mediaType"?: string;
		"features"?: Array<Models.PredictorModelFeature>;
	}
	
	export interface PredictorModelBrief { 
		"mediaType"?: string;
		"dateModified"?: string;
		"retrainingErrors"?: Array<Models.PredictorModelRetrainingError>;
		"state"?: string;
	}
	
	export interface PredictorModelFeature { 
		"id"?: string;
		"type"?: string;
		"percentageImportance"?: number;
	}
	
	export interface PredictorModelFeatureListing { 
		"entities"?: Array<Models.PredictorModelFeature>;
	}
	
	export interface PredictorModelRetrainingError { 
		"id"?: string;
		"errorCode": string;
		"dateOfFirstOccurrence": string;
	}
	
	export interface PredictorModels { 
		"entities"?: Array<Models.PredictorModel>;
		"predictorModels"?: Array<Models.PredictorModel>;
	}
	
	export interface PredictorSchedule { 
		"scheduleType": string;
		"dateStarted"?: string;
	}
	
	export interface PredictorWorkloadBalancing { 
		"enabled": boolean;
		"minimumOccupancy"?: number;
		"maximumOccupancy"?: number;
	}
	
	export interface PreprocessingRule { 
		"find"?: string;
		"replaceWith"?: string;
		"global"?: boolean;
		"ignoreCase"?: boolean;
	}
	
	export interface PresenceDefinition { 
		"id"?: string;
		"systemPresence"?: string;
		"selfUri"?: string;
	}
	
	export interface PresenceDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.PresenceDetailQueryPredicate>;
	}
	
	export interface PresenceDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.PresenceDetailQueryClause>;
		"predicates"?: Array<Models.PresenceDetailQueryPredicate>;
	}
	
	export interface PresenceDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface PresenceEventOrganizationPresence { 
		"id"?: string;
		"systemPresence"?: string;
	}
	
	export interface PresenceEventUserPresence { 
		"source"?: string;
		"presenceDefinition"?: Models.PresenceEventOrganizationPresence;
		"primary"?: boolean;
		"message"?: string;
		"modifiedDate"?: string;
	}
	
	export interface PresenceSettings { 
		"id"?: string;
		"name"?: string;
		"restorePresenceSettings"?: Models.RestorePresenceSettings;
		"selfUri"?: string;
	}
	
	export interface ProcessScheduleUpdateUploadRequest { 
		"uploadKey": string;
		"teamIds"?: Array<string>;
		"managementUnitIdsForAddedTeamUsers"?: Array<string>;
	}
	
	export interface ProfileWithDateRange { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"selfUri"?: string;
	}
	
	export interface Program { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"published"?: boolean;
		"topics"?: Array<Models.BaseTopicEntitiy>;
		"tags"?: Array<string>;
		"modifiedBy"?: Models.AddressableEntityRef;
		"dateModified"?: string;
		"publishedBy"?: Models.AddressableEntityRef;
		"datePublished"?: string;
		"selfUri"?: string;
	}
	
	export interface ProgramJob { 
		"id"?: string;
		"state"?: string;
		"programs"?: Array<Models.BaseProgramEntity>;
		"createdBy"?: Models.AddressableEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface ProgramJobRequest { 
		"programIds": Array<string>;
	}
	
	export interface ProgramMappings { 
		"program"?: Models.BaseProgramEntity;
		"queues"?: Array<Models.AddressableEntityRef>;
		"flows"?: Array<Models.AddressableEntityRef>;
		"modifiedBy"?: Models.AddressableEntityRef;
		"dateModified"?: string;
	}
	
	export interface ProgramMappingsRequest { 
		"queueIds": Array<string>;
		"flowIds": Array<string>;
	}
	
	export interface ProgramRequest { 
		"name": string;
		"description"?: string;
		"topicIds"?: Array<string>;
		"tags"?: Array<string>;
	}
	
	export interface ProgramTranscriptionEngine { 
		"engine"?: string;
		"dialects"?: Array<string>;
		"engineIntegration"?: Models.EngineIntegration;
	}
	
	export interface ProgramTranscriptionEngines { 
		"id"?: string;
		"program"?: Models.BaseProgramEntity;
		"transcriptionEngines"?: Array<Models.ProgramTranscriptionEngine>;
		"modifiedBy"?: Models.AddressableEntityRef;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface ProgramsEntityListing { 
		"entities"?: Array<Models.ListedProgram>;
		"pageSize"?: number;
		"nextUri"?: string;
		"selfUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ProgramsMappingsEntityListing { 
		"entities"?: Array<Models.ProgramMappings>;
		"pageSize"?: number;
		"nextUri"?: string;
		"pageCount"?: number;
		"selfUri"?: string;
	}
	
	export interface ProgressConsultTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"initiatingCommunicationId": string;
		"destinationCommunicationId": string;
		"objectCommunicationId": string;
	}
	
	export interface ProgressTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"commandId": string;
		"objectCommunicationId": string;
		"destinationCommunicationId": string;
	}
	
	export interface Prompt { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"resources"?: Array<Models.PromptAsset>;
		"currentOperation"?: Models.Operation;
		"selfUri"?: string;
	}
	
	export interface PromptAsset { 
		"id"?: string;
		"name"?: string;
		"promptId"?: string;
		"language"?: string;
		"mediaUri"?: string;
		"ttsString"?: string;
		"text"?: string;
		"uploadStatus"?: string;
		"uploadUri"?: string;
		"languageDefault"?: boolean;
		"tags"?: { [key: string]: Array<string>; };
		"durationSeconds"?: number;
		"selfUri"?: string;
	}
	
	export interface PromptAssetCreate { 
		"id"?: string;
		"name"?: string;
		"promptId"?: string;
		"language": string;
		"mediaUri"?: string;
		"ttsString"?: string;
		"text"?: string;
		"uploadStatus"?: string;
		"uploadUri"?: string;
		"languageDefault"?: boolean;
		"tags"?: { [key: string]: Array<string>; };
		"durationSeconds"?: number;
		"selfUri"?: string;
	}
	
	export interface PromptAssetEntityListing { 
		"entities"?: Array<Models.PromptAsset>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PromptEntityListing { 
		"entities"?: Array<Models.Prompt>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface PropertyChange { 
		"property"?: string;
		"oldValues"?: Array<string>;
		"newValues"?: Array<string>;
	}
	
	export interface PropertyIndexRequest { 
		"sessionId": string;
		"targetDate": string;
		"properties": Array<Models.AnalyticsProperty>;
	}
	
	export interface ProvisionInfo { 
		"time"?: string;
		"source"?: string;
		"errorInfo"?: string;
	}
	
	export interface PublishDraftInput { 
		"version": number;
	}
	
	export interface PublishForm { 
		"published": boolean;
		"id": string;
	}
	
	export interface PublishProgramTopicsDefinitionsJob { 
		"id"?: string;
		"state"?: string;
	}
	
	export interface PublishScriptRequestData { 
		"scriptId": string;
		"versionId"?: string;
	}
	
	export interface PublishTopicTopicsDefinitionsJob { 
		"id"?: string;
		"state"?: string;
	}
	
	export interface PublishedSurveyFormReference { 
		"id"?: string;
		"name"?: string;
		"contextId"?: string;
		"selfUri"?: string;
	}
	
	export interface PunctualityEvent { 
		"dateScheduleStart"?: string;
		"dateStart"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"activityCode"?: string;
		"activityName"?: string;
		"category"?: string;
		"points"?: number;
		"delta"?: number;
		"bullseye"?: boolean;
	}
	
	export interface PureCloud { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"selfUri"?: string;
	}
	
	export interface PureEngage { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"autoProvisionUsers"?: boolean;
		"selfUri"?: string;
	}
	
	export interface QMAuditQueryRequest { 
		"interval": string;
		"filters": Array<Models.QualityAuditQueryFilter>;
		"sort"?: Array<Models.AuditQuerySort>;
	}
	
	export interface QualityAuditLogMessage { 
		"id"?: string;
		"userHomeOrgId"?: string;
		"userTrusteeOrgId"?: string;
		"user"?: Models.DomainEntityRef;
		"client"?: Models.AddressableEntityRef;
		"remoteIps"?: Array<string>;
		"serviceName"?: string;
		"level"?: string;
		"status"?: string;
		"eventDate"?: string;
		"messageInfo"?: Models.MessageInfo;
		"action"?: string;
		"entity"?: Models.DomainEntityRef;
		"entityType"?: string;
		"propertyChanges"?: Array<Models.PropertyChange>;
		"context"?: { [key: string]: string; };
	}
	
	export interface QualityAuditQueryExecutionResultsResponse { 
		"id"?: string;
		"pageSize"?: number;
		"cursor"?: string;
		"entities"?: Array<Models.QualityAuditLogMessage>;
	}
	
	export interface QualityAuditQueryExecutionStatusResponse { 
		"id"?: string;
		"state"?: string;
		"dateStart"?: string;
		"interval"?: string;
		"filters"?: Array<Models.QualityAuditQueryFilter>;
		"sort"?: Array<Models.AuditQuerySort>;
	}
	
	export interface QualityAuditQueryFilter { 
		"property": string;
		"value": string;
	}
	
	export interface QualityEvaluationScoreItem { 
		"evaluationId"?: string;
		"conversationId"?: string;
		"conversationDate"?: string;
		"conversationEndDate"?: string;
		"formName"?: string;
		"points"?: number;
		"evaluationScore"?: number;
		"maxPoints"?: number;
		"mediaTypes"?: Array<string>;
	}
	
	export interface QueryAdherenceExplanationsResponse { 
		"job"?: Models.AdherenceExplanationJobReference;
		"result"?: Models.AdherenceExplanationListing;
		"downloadUrl"?: string;
	}
	
	export interface QueryAgentsIntegrationsRequest { 
		"agentIds": Array<string>;
	}
	
	export interface QueryCriteria { 
		"criteriaKey"?: string;
		"criteriaGroups"?: Array<string>;
		"description"?: string;
		"operators"?: Array<string>;
		"dataType"?: string;
		"categoryInfo"?: Models.CriteriaCategoryInfo;
	}
	
	export interface QueryDivision { 
	}
	
	export interface QueryFacetInfo { 
		"attributes"?: Array<Models.FacetKeyAttribute>;
		"facets"?: Array<Models.FacetEntry>;
	}
	
	export interface QueryRequest { 
		"queryPhrase"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
		"facetNameRequests"?: Array<string>;
		"sort"?: Array<Models.SortItem>;
		"filters"?: Array<Models.ContentFilterItem>;
		"attributeFilters"?: Array<Models.AttributeFilterItem>;
		"includeShares"?: boolean;
	}
	
	export interface QueryRequestClause { 
		"type": string;
		"predicates": Array<Models.QueryRequestPredicate>;
	}
	
	export interface QueryRequestFilter { 
		"type": string;
		"clauses": Array<Models.QueryRequestClause>;
	}
	
	export interface QueryRequestPredicate { 
		"dimension": string;
		"value": string;
	}
	
	export interface QueryResponseData { 
		"interval"?: string;
		"metrics"?: Array<Models.QueryResponseMetric>;
	}
	
	export interface QueryResponseGroupedData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.QueryResponseData>;
	}
	
	export interface QueryResponseMetric { 
		"metric"?: string;
		"stats"?: Models.QueryResponseStats;
	}
	
	export interface QueryResponseStats { 
		"count"?: number;
	}
	
	export interface QueryResult { 
		"id"?: string;
		"name"?: string;
		"body"?: Models.DomainEntity;
		"selfUri"?: string;
	}
	
	export interface QueryResults { 
		"results"?: Models.DomainEntityListingQueryResult;
		"facetInfo"?: Models.QueryFacetInfo;
	}
	
	export interface QueryTimeOffIntegrationStatusRequest { 
		"timeOffRequestLookups": Array<Models.TimeOffRequestLookup>;
	}
	
	export interface QueryTimeOffLimitValuesRequest { 
		"timeOffLimitId"?: string;
		"activityCodeId"?: string;
		"dateRanges": Array<Models.LocalDateRange>;
	}
	
	export interface QueryTimeOffLimitValuesResponse { 
		"values"?: Array<Models.TimeOffLimitValueRange>;
	}
	
	export interface QueryUserStaffingGroupListRequest { 
		"userIds": Array<string>;
	}
	
	export interface QueryWaitlistPositionsRequest { 
		"timeOffRequests": Array<Models.UserTimeOffRequestReference>;
	}
	
	export interface Queue { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"memberCount"?: number;
		"userMemberCount"?: number;
		"joinedMemberCount"?: number;
		"mediaSettings"?: Models.QueueMediaSettings;
		"routingRules"?: Array<Models.RoutingRule>;
		"conditionalGroupRouting"?: Models.ConditionalGroupRouting;
		"bullseye"?: Models.Bullseye;
		"scoringMethod"?: string;
		"acwSettings"?: Models.AcwSettings;
		"skillEvaluationMethod"?: string;
		"memberGroups"?: Array<Models.MemberGroup>;
		"queueFlow"?: Models.DomainEntityRef;
		"emailInQueueFlow"?: Models.DomainEntityRef;
		"messageInQueueFlow"?: Models.DomainEntityRef;
		"whisperPrompt"?: Models.DomainEntityRef;
		"onHoldPrompt"?: Models.DomainEntityRef;
		"autoAnswerOnly"?: boolean;
		"enableTranscription"?: boolean;
		"enableAudioMonitoring"?: boolean;
		"enableManualAssignment"?: boolean;
		"agentOwnedRouting"?: Models.AgentOwnedRouting;
		"directRouting"?: Models.DirectRouting;
		"callingPartyName"?: string;
		"callingPartyNumber"?: string;
		"defaultScripts"?: { [key: string]: Models.Script; };
		"outboundMessagingAddresses"?: Models.QueueMessagingAddresses;
		"outboundEmailAddress"?: Models.QueueEmailAddress;
		"peerId"?: string;
		"suppressInQueueCallRecording"?: boolean;
		"selfUri"?: string;
	}
	
	export interface QueueConversationCallEventTopicCallConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationCallEventTopicCallMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
		"recordingState"?: string;
		"securePause"?: boolean;
		"maxParticipants"?: number;
	}
	
	export interface QueueConversationCallEventTopicCallMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationCallEventTopicUriReference;
		"queue"?: Models.QueueConversationCallEventTopicUriReference;
		"team"?: Models.QueueConversationCallEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationCallEventTopicErrorBody;
		"script"?: Models.QueueConversationCallEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationCallEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationCallEventTopicUriReference;
		"wrapup"?: Models.QueueConversationCallEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationCallEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationCallEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationCallEventTopicQueueMediaSettings;
		"muted"?: boolean;
		"confined"?: boolean;
		"recording"?: boolean;
		"recordingState"?: string;
		"securePause"?: boolean;
		"group"?: Models.QueueConversationCallEventTopicUriReference;
		"ani"?: string;
		"dnis"?: string;
		"documentId"?: string;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"bargedTime"?: string;
		"consultParticipantId"?: string;
		"faxStatus"?: Models.QueueConversationCallEventTopicFaxStatus;
	}
	
	export interface QueueConversationCallEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationCallEventTopicUriReference;
		"language"?: Models.QueueConversationCallEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationCallEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationCallEventTopicScoredAgent>;
	}
	
	export interface QueueConversationCallEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationCallEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationCallEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationCallEventTopicErrorBody>;
	}
	
	export interface QueueConversationCallEventTopicFaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"dataRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface QueueConversationCallEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationCallEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationCallEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationCallEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationCallEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationCallEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationCallEventTopicJourneyAction;
	}
	
	export interface QueueConversationCallEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationCallEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationCallEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationCallEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationCallEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationCallEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationCallEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicCallbackConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationCallbackEventTopicCallbackMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicCallbackMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationCallbackEventTopicUriReference;
		"queue"?: Models.QueueConversationCallbackEventTopicUriReference;
		"team"?: Models.QueueConversationCallbackEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationCallbackEventTopicErrorBody;
		"script"?: Models.QueueConversationCallbackEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationCallbackEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationCallbackEventTopicUriReference;
		"wrapup"?: Models.QueueConversationCallbackEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationCallbackEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationCallbackEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationCallbackEventTopicQueueMediaSettings;
		"outboundPreview"?: Models.QueueConversationCallbackEventTopicDialerPreview;
		"voicemail"?: Models.QueueConversationCallbackEventTopicVoicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"skipEnabled"?: boolean;
		"externalCampaign"?: boolean;
		"timeoutSeconds"?: number;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationCallbackEventTopicUriReference;
		"language"?: Models.QueueConversationCallbackEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationCallbackEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationCallbackEventTopicScoredAgent>;
	}
	
	export interface QueueConversationCallbackEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicDialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.QueueConversationCallbackEventTopicPhoneNumberColumn>;
	}
	
	export interface QueueConversationCallbackEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationCallbackEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationCallbackEventTopicErrorBody>;
	}
	
	export interface QueueConversationCallbackEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationCallbackEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationCallbackEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationCallbackEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationCallbackEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationCallbackEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationCallbackEventTopicJourneyAction;
	}
	
	export interface QueueConversationCallbackEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationCallbackEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationCallbackEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationCallbackEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicVoicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface QueueConversationCallbackEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationChatEventTopicChatConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationChatEventTopicChatMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface QueueConversationChatEventTopicChatMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationChatEventTopicUriReference;
		"queue"?: Models.QueueConversationChatEventTopicUriReference;
		"team"?: Models.QueueConversationChatEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationChatEventTopicErrorBody;
		"script"?: Models.QueueConversationChatEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationChatEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationChatEventTopicUriReference;
		"wrapup"?: Models.QueueConversationChatEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationChatEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationChatEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationChatEventTopicQueueMediaSettings;
		"roomId"?: string;
		"avatarImageUrl"?: string;
	}
	
	export interface QueueConversationChatEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationChatEventTopicUriReference;
		"language"?: Models.QueueConversationChatEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationChatEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationChatEventTopicScoredAgent>;
	}
	
	export interface QueueConversationChatEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationChatEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationChatEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationChatEventTopicErrorBody>;
	}
	
	export interface QueueConversationChatEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationChatEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationChatEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationChatEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationChatEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationChatEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationChatEventTopicJourneyAction;
	}
	
	export interface QueueConversationChatEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationChatEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationChatEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationChatEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationChatEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationChatEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationChatEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationCobrowseEventTopicCobrowseConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationCobrowseEventTopicCobrowseMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface QueueConversationCobrowseEventTopicCobrowseMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"queue"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"team"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationCobrowseEventTopicErrorBody;
		"script"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"wrapup"?: Models.QueueConversationCobrowseEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationCobrowseEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationCobrowseEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationCobrowseEventTopicQueueMediaSettings;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"viewerUrl"?: string;
		"providerEventTime"?: string;
		"controlling"?: Array<string>;
	}
	
	export interface QueueConversationCobrowseEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"language"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationCobrowseEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationCobrowseEventTopicScoredAgent>;
	}
	
	export interface QueueConversationCobrowseEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationCobrowseEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationCobrowseEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationCobrowseEventTopicErrorBody>;
	}
	
	export interface QueueConversationCobrowseEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationCobrowseEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationCobrowseEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationCobrowseEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationCobrowseEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationCobrowseEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationCobrowseEventTopicJourneyAction;
	}
	
	export interface QueueConversationCobrowseEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationCobrowseEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationCobrowseEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationCobrowseEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationCobrowseEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationCobrowseEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationCobrowseEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationEmailEventTopicAttachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
	}
	
	export interface QueueConversationEmailEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationEmailEventTopicUriReference;
		"language"?: Models.QueueConversationEmailEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationEmailEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationEmailEventTopicScoredAgent>;
	}
	
	export interface QueueConversationEmailEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationEmailEventTopicEmailConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationEmailEventTopicEmailMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface QueueConversationEmailEventTopicEmailMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationEmailEventTopicUriReference;
		"queue"?: Models.QueueConversationEmailEventTopicUriReference;
		"team"?: Models.QueueConversationEmailEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationEmailEventTopicErrorBody;
		"script"?: Models.QueueConversationEmailEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationEmailEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationEmailEventTopicUriReference;
		"wrapup"?: Models.QueueConversationEmailEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationEmailEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationEmailEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationEmailEventTopicQueueMediaSettings;
		"subject"?: string;
		"messagesSent"?: number;
		"autoGenerated"?: boolean;
		"messageId"?: string;
		"draftAttachments"?: Array<Models.QueueConversationEmailEventTopicAttachment>;
		"spam"?: boolean;
	}
	
	export interface QueueConversationEmailEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationEmailEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationEmailEventTopicErrorBody>;
	}
	
	export interface QueueConversationEmailEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationEmailEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationEmailEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationEmailEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationEmailEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationEmailEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationEmailEventTopicJourneyAction;
	}
	
	export interface QueueConversationEmailEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationEmailEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationEmailEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationEmailEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationEmailEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationEmailEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationEmailEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationEventTopicAddress { 
		"name"?: string;
		"nameRaw"?: string;
		"addressNormalized"?: string;
		"addressRaw"?: string;
		"addressDisplayable"?: string;
	}
	
	export interface QueueConversationEventTopicAfterCallWork { 
		"state"?: string;
		"startTime"?: string;
		"endTime"?: string;
	}
	
	export interface QueueConversationEventTopicAttachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
	}
	
	export interface QueueConversationEventTopicCall { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"recording"?: boolean;
		"recordingState"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"securePause"?: boolean;
		"errorInfo"?: Models.QueueConversationEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"direction"?: string;
		"documentId"?: string;
		"self"?: Models.QueueConversationEventTopicAddress;
		"other"?: Models.QueueConversationEventTopicAddress;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"disconnectReasons"?: Array<Models.QueueConversationEventTopicDisconnectReason>;
		"faxStatus"?: Models.QueueConversationEventTopicFaxStatus;
		"uuiData"?: string;
		"bargedTime"?: string;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicCallback { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"direction"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"dialerPreview"?: Models.QueueConversationEventTopicDialerPreview;
		"voicemail"?: Models.QueueConversationEventTopicVoicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"provider"?: string;
		"timeoutSeconds"?: number;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"callerId"?: string;
		"callerIdName"?: string;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicChat { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"roomId"?: string;
		"avatarImageUrl"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"journeyContext"?: Models.QueueConversationEventTopicJourneyContext;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicCobrowse { 
		"state"?: string;
		"initialState"?: string;
		"disconnectType"?: string;
		"id"?: string;
		"self"?: Models.QueueConversationEventTopicAddress;
		"roomId"?: string;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"controlling"?: Array<string>;
		"viewerUrl"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"providerEventTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicConversation { 
		"id"?: string;
		"maxParticipants"?: number;
		"participants"?: Array<Models.QueueConversationEventTopicParticipant>;
		"recentTransfers"?: Array<Models.QueueConversationEventTopicRecentTransfer>;
		"recordingState"?: string;
		"address"?: string;
		"externalTag"?: string;
		"utilizationLabelId"?: string;
		"securePause"?: boolean;
	}
	
	export interface QueueConversationEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationEventTopicUriReference;
		"language"?: Models.QueueConversationEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationEventTopicScoredAgent>;
	}
	
	export interface QueueConversationEventTopicDestination { 
		"userId"?: string;
		"address"?: string;
	}
	
	export interface QueueConversationEventTopicDialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.QueueConversationEventTopicPhoneNumberColumn>;
	}
	
	export interface QueueConversationEventTopicDisconnectReason { 
		"type"?: string;
		"code"?: number;
		"phrase"?: string;
	}
	
	export interface QueueConversationEventTopicEmail { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"held"?: boolean;
		"autoGenerated"?: boolean;
		"subject"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"messagesSent"?: number;
		"errorInfo"?: Models.QueueConversationEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"messageId"?: string;
		"direction"?: string;
		"draftAttachments"?: Array<Models.QueueConversationEventTopicAttachment>;
		"spam"?: boolean;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
		"resumeTime"?: string;
	}
	
	export interface QueueConversationEventTopicErrorDetails { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"uri"?: string;
	}
	
	export interface QueueConversationEventTopicFaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"baudRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface QueueConversationEventTopicInitiator { 
		"userId"?: string;
	}
	
	export interface QueueConversationEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationEventTopicJourneyAction;
	}
	
	export interface QueueConversationEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationEventTopicMessage { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"held"?: boolean;
		"errorInfo"?: Models.QueueConversationEventTopicErrorDetails;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"toAddress"?: Models.QueueConversationEventTopicAddress;
		"fromAddress"?: Models.QueueConversationEventTopicAddress;
		"messages"?: Array<Models.QueueConversationEventTopicMessageDetails>;
		"messagesTranscriptUri"?: string;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"journeyContext"?: Models.QueueConversationEventTopicJourneyContext;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"byoSmsIntegrationId"?: string;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicMessageDetails { 
		"messageId"?: string;
		"messageTime"?: string;
		"messageStatus"?: string;
		"messageSegmentCount"?: number;
		"media"?: Array<Models.QueueConversationEventTopicMessageMedia>;
		"errorInfo"?: Models.QueueConversationEventTopicErrorDetails;
		"stickers"?: Array<Models.QueueConversationEventTopicMessageSticker>;
		"messageMetadata"?: Models.QueueConversationEventTopicMessageMetadata;
	}
	
	export interface QueueConversationEventTopicMessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationEventTopicMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.QueueConversationEventTopicMessageMetadataEvent>;
		"content"?: Array<Models.QueueConversationEventTopicMessageMetadataContent>;
	}
	
	export interface QueueConversationEventTopicMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationEventTopicMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationEventTopicMessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationEventTopicModifiedBy { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface QueueConversationEventTopicObject { 
	}
	
	export interface QueueConversationEventTopicParticipant { 
		"id"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"name"?: string;
		"queueId"?: string;
		"groupId"?: string;
		"teamId"?: string;
		"purpose"?: string;
		"consultParticipantId"?: string;
		"address"?: string;
		"wrapupRequired"?: boolean;
		"wrapupExpected"?: boolean;
		"wrapupPrompt"?: string;
		"wrapupTimeoutMs"?: number;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"conversationRoutingData"?: Models.QueueConversationEventTopicConversationRoutingData;
		"alertingTimeoutMs"?: number;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"mediaRoles"?: Array<string>;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"attributes"?: { [key: string]: string; };
		"calls"?: Array<Models.QueueConversationEventTopicCall>;
		"callbacks"?: Array<Models.QueueConversationEventTopicCallback>;
		"chats"?: Array<Models.QueueConversationEventTopicChat>;
		"cobrowsesessions"?: Array<Models.QueueConversationEventTopicCobrowse>;
		"emails"?: Array<Models.QueueConversationEventTopicEmail>;
		"messages"?: Array<Models.QueueConversationEventTopicMessage>;
		"screenshares"?: Array<Models.QueueConversationEventTopicScreenshare>;
		"socialExpressions"?: Array<Models.QueueConversationEventTopicSocialExpression>;
		"videos"?: Array<Models.QueueConversationEventTopicVideo>;
		"workflow"?: Models.QueueConversationEventTopicWorkflow;
	}
	
	export interface QueueConversationEventTopicPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationEventTopicRecentTransfer { 
		"id"?: string;
		"state"?: string;
		"dateIssued"?: string;
		"initiator"?: Models.QueueConversationEventTopicInitiator;
		"modifiedBy"?: Models.QueueConversationEventTopicModifiedBy;
		"destination"?: Models.QueueConversationEventTopicDestination;
		"transferType"?: string;
	}
	
	export interface QueueConversationEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationEventTopicScreenshare { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.QueueConversationEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"sharing"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"peerCount"?: object;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicSocialExpression { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"socialMediaId"?: string;
		"socialMediaHub"?: string;
		"socialUserName"?: string;
		"previewText"?: string;
		"recordingId"?: string;
		"held"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface QueueConversationEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationEventTopicVideo { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.QueueConversationEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"audioMuted"?: boolean;
		"videoMuted"?: boolean;
		"sharingScreen"?: boolean;
		"peerCount"?: object;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"msids"?: Array<string>;
		"wrapup"?: Models.QueueConversationEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationEventTopicVoicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface QueueConversationEventTopicWorkflow { 
		"workflowId"?: string;
	}
	
	export interface QueueConversationEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationMessageEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationMessageEventTopicUriReference;
		"language"?: Models.QueueConversationMessageEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationMessageEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationMessageEventTopicScoredAgent>;
	}
	
	export interface QueueConversationMessageEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationMessageEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationMessageEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationMessageEventTopicErrorBody>;
	}
	
	export interface QueueConversationMessageEventTopicErrorDetails { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"uri"?: string;
	}
	
	export interface QueueConversationMessageEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationMessageEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationMessageEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationMessageEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationMessageEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationMessageEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationMessageEventTopicJourneyAction;
	}
	
	export interface QueueConversationMessageEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationMessageEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationMessageEventTopicMessageConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationMessageEventTopicMessageMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface QueueConversationMessageEventTopicMessageDetails { 
		"message"?: Models.QueueConversationMessageEventTopicUriReference;
		"messageTime"?: string;
		"messageSegmentCount"?: number;
		"messageStatus"?: string;
		"media"?: Array<Models.QueueConversationMessageEventTopicMessageMedia>;
		"stickers"?: Array<Models.QueueConversationMessageEventTopicMessageSticker>;
		"errorInfo"?: Models.QueueConversationMessageEventTopicErrorDetails;
		"messageMetadata"?: Models.QueueConversationMessageEventTopicMessageMetadata;
	}
	
	export interface QueueConversationMessageEventTopicMessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationMessageEventTopicMessageMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationMessageEventTopicUriReference;
		"queue"?: Models.QueueConversationMessageEventTopicUriReference;
		"team"?: Models.QueueConversationMessageEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationMessageEventTopicErrorBody;
		"script"?: Models.QueueConversationMessageEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationMessageEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationMessageEventTopicUriReference;
		"wrapup"?: Models.QueueConversationMessageEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationMessageEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationMessageEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationMessageEventTopicQueueMediaSettings;
		"messages"?: Array<Models.QueueConversationMessageEventTopicMessageDetails>;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"byoSmsIntegrationId"?: string;
		"monitoredParticipantId"?: string;
	}
	
	export interface QueueConversationMessageEventTopicMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.QueueConversationMessageEventTopicMessageMetadataEvent>;
		"content"?: Array<Models.QueueConversationMessageEventTopicMessageMetadataContent>;
	}
	
	export interface QueueConversationMessageEventTopicMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationMessageEventTopicMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationMessageEventTopicMessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationMessageEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationMessageEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationMessageEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationMessageEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationMessageEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationScreenShareEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"language"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationScreenShareEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationScreenShareEventTopicScoredAgent>;
	}
	
	export interface QueueConversationScreenShareEventTopicDetail { 
		"errorCode"?: string;
		"fieldName"?: string;
		"entityId"?: string;
		"entityName"?: string;
	}
	
	export interface QueueConversationScreenShareEventTopicErrorBody { 
		"message"?: string;
		"code"?: string;
		"status"?: number;
		"entityId"?: string;
		"entityName"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"details"?: Array<Models.QueueConversationScreenShareEventTopicDetail>;
		"errors"?: Array<Models.QueueConversationScreenShareEventTopicErrorBody>;
	}
	
	export interface QueueConversationScreenShareEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationScreenShareEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationScreenShareEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationScreenShareEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationScreenShareEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationScreenShareEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationScreenShareEventTopicJourneyAction;
	}
	
	export interface QueueConversationScreenShareEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationScreenShareEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationScreenShareEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationScreenShareEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationScreenShareEventTopicScreenShareConversation { 
		"id"?: string;
		"name"?: string;
		"participants"?: Array<Models.QueueConversationScreenShareEventTopicScreenShareMediaParticipant>;
		"otherMediaUris"?: Array<string>;
		"address"?: string;
		"utilizationLabelId"?: string;
	}
	
	export interface QueueConversationScreenShareEventTopicScreenShareMediaParticipant { 
		"id"?: string;
		"name"?: string;
		"address"?: string;
		"startTime"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"startHoldTime"?: string;
		"purpose"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"disconnectType"?: string;
		"held"?: boolean;
		"wrapupRequired"?: boolean;
		"wrapupPrompt"?: string;
		"user"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"queue"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"team"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"attributes"?: { [key: string]: string; };
		"errorInfo"?: Models.QueueConversationScreenShareEventTopicErrorBody;
		"script"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"wrapupTimeoutMs"?: number;
		"wrapupSkipped"?: boolean;
		"alertingTimeoutMs"?: number;
		"provider"?: string;
		"externalContact"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"externalOrganization"?: Models.QueueConversationScreenShareEventTopicUriReference;
		"wrapup"?: Models.QueueConversationScreenShareEventTopicWrapup;
		"conversationRoutingData"?: Models.QueueConversationScreenShareEventTopicConversationRoutingData;
		"peer"?: string;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"journeyContext"?: Models.QueueConversationScreenShareEventTopicJourneyContext;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"resumeTime"?: string;
		"mediaRoles"?: Array<string>;
		"queueMediaSettings"?: Models.QueueConversationScreenShareEventTopicQueueMediaSettings;
		"context"?: string;
		"peerCount"?: number;
		"sharing"?: boolean;
	}
	
	export interface QueueConversationScreenShareEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationScreenShareEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicAddress { 
		"name"?: string;
		"nameRaw"?: string;
		"addressNormalized"?: string;
		"addressRaw"?: string;
		"addressDisplayable"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicAfterCallWork { 
		"state"?: string;
		"startTime"?: string;
		"endTime"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicAttachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
	}
	
	export interface QueueConversationSocialExpressionEventTopicCall { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"recording"?: boolean;
		"recordingState"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"securePause"?: boolean;
		"errorInfo"?: Models.QueueConversationSocialExpressionEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"direction"?: string;
		"documentId"?: string;
		"self"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"other"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"disconnectReasons"?: Array<Models.QueueConversationSocialExpressionEventTopicDisconnectReason>;
		"faxStatus"?: Models.QueueConversationSocialExpressionEventTopicFaxStatus;
		"uuiData"?: string;
		"bargedTime"?: string;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicCallback { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"direction"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"dialerPreview"?: Models.QueueConversationSocialExpressionEventTopicDialerPreview;
		"voicemail"?: Models.QueueConversationSocialExpressionEventTopicVoicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"provider"?: string;
		"timeoutSeconds"?: number;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"callerId"?: string;
		"callerIdName"?: string;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicChat { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"roomId"?: string;
		"avatarImageUrl"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"journeyContext"?: Models.QueueConversationSocialExpressionEventTopicJourneyContext;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicCobrowse { 
		"state"?: string;
		"initialState"?: string;
		"disconnectType"?: string;
		"id"?: string;
		"self"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"roomId"?: string;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"controlling"?: Array<string>;
		"viewerUrl"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"providerEventTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicConversation { 
		"id"?: string;
		"maxParticipants"?: number;
		"participants"?: Array<Models.QueueConversationSocialExpressionEventTopicParticipant>;
		"recentTransfers"?: Array<Models.QueueConversationSocialExpressionEventTopicRecentTransfer>;
		"recordingState"?: string;
		"address"?: string;
		"externalTag"?: string;
		"utilizationLabelId"?: string;
		"securePause"?: boolean;
	}
	
	export interface QueueConversationSocialExpressionEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationSocialExpressionEventTopicUriReference;
		"language"?: Models.QueueConversationSocialExpressionEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationSocialExpressionEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationSocialExpressionEventTopicScoredAgent>;
	}
	
	export interface QueueConversationSocialExpressionEventTopicDestination { 
		"userId"?: string;
		"address"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicDialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.QueueConversationSocialExpressionEventTopicPhoneNumberColumn>;
	}
	
	export interface QueueConversationSocialExpressionEventTopicDisconnectReason { 
		"type"?: string;
		"code"?: number;
		"phrase"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicEmail { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"held"?: boolean;
		"autoGenerated"?: boolean;
		"subject"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"messagesSent"?: number;
		"errorInfo"?: Models.QueueConversationSocialExpressionEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"messageId"?: string;
		"direction"?: string;
		"draftAttachments"?: Array<Models.QueueConversationSocialExpressionEventTopicAttachment>;
		"spam"?: boolean;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
		"resumeTime"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicErrorDetails { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"uri"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicFaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"baudRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface QueueConversationSocialExpressionEventTopicInitiator { 
		"userId"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationSocialExpressionEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationSocialExpressionEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationSocialExpressionEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationSocialExpressionEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationSocialExpressionEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationSocialExpressionEventTopicJourneyAction;
	}
	
	export interface QueueConversationSocialExpressionEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessage { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"held"?: boolean;
		"errorInfo"?: Models.QueueConversationSocialExpressionEventTopicErrorDetails;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"toAddress"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"fromAddress"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"messages"?: Array<Models.QueueConversationSocialExpressionEventTopicMessageDetails>;
		"messagesTranscriptUri"?: string;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"journeyContext"?: Models.QueueConversationSocialExpressionEventTopicJourneyContext;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"byoSmsIntegrationId"?: string;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessageDetails { 
		"messageId"?: string;
		"messageTime"?: string;
		"messageStatus"?: string;
		"messageSegmentCount"?: number;
		"media"?: Array<Models.QueueConversationSocialExpressionEventTopicMessageMedia>;
		"errorInfo"?: Models.QueueConversationSocialExpressionEventTopicErrorDetails;
		"stickers"?: Array<Models.QueueConversationSocialExpressionEventTopicMessageSticker>;
		"messageMetadata"?: Models.QueueConversationSocialExpressionEventTopicMessageMetadata;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.QueueConversationSocialExpressionEventTopicMessageMetadataEvent>;
		"content"?: Array<Models.QueueConversationSocialExpressionEventTopicMessageMetadataContent>;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicMessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicModifiedBy { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicObject { 
	}
	
	export interface QueueConversationSocialExpressionEventTopicParticipant { 
		"id"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"name"?: string;
		"queueId"?: string;
		"groupId"?: string;
		"teamId"?: string;
		"purpose"?: string;
		"consultParticipantId"?: string;
		"address"?: string;
		"wrapupRequired"?: boolean;
		"wrapupExpected"?: boolean;
		"wrapupPrompt"?: string;
		"wrapupTimeoutMs"?: number;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"conversationRoutingData"?: Models.QueueConversationSocialExpressionEventTopicConversationRoutingData;
		"alertingTimeoutMs"?: number;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"mediaRoles"?: Array<string>;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"attributes"?: { [key: string]: string; };
		"calls"?: Array<Models.QueueConversationSocialExpressionEventTopicCall>;
		"callbacks"?: Array<Models.QueueConversationSocialExpressionEventTopicCallback>;
		"chats"?: Array<Models.QueueConversationSocialExpressionEventTopicChat>;
		"cobrowsesessions"?: Array<Models.QueueConversationSocialExpressionEventTopicCobrowse>;
		"emails"?: Array<Models.QueueConversationSocialExpressionEventTopicEmail>;
		"messages"?: Array<Models.QueueConversationSocialExpressionEventTopicMessage>;
		"screenshares"?: Array<Models.QueueConversationSocialExpressionEventTopicScreenshare>;
		"socialExpressions"?: Array<Models.QueueConversationSocialExpressionEventTopicSocialExpression>;
		"videos"?: Array<Models.QueueConversationSocialExpressionEventTopicVideo>;
		"workflow"?: Models.QueueConversationSocialExpressionEventTopicWorkflow;
	}
	
	export interface QueueConversationSocialExpressionEventTopicPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationSocialExpressionEventTopicRecentTransfer { 
		"id"?: string;
		"state"?: string;
		"dateIssued"?: string;
		"initiator"?: Models.QueueConversationSocialExpressionEventTopicInitiator;
		"modifiedBy"?: Models.QueueConversationSocialExpressionEventTopicModifiedBy;
		"destination"?: Models.QueueConversationSocialExpressionEventTopicDestination;
		"transferType"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationSocialExpressionEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationSocialExpressionEventTopicScreenshare { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"sharing"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"peerCount"?: object;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicSocialExpression { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"socialMediaId"?: string;
		"socialMediaHub"?: string;
		"socialUserName"?: string;
		"previewText"?: string;
		"recordingId"?: string;
		"held"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface QueueConversationSocialExpressionEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicVideo { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.QueueConversationSocialExpressionEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"audioMuted"?: boolean;
		"videoMuted"?: boolean;
		"sharingScreen"?: boolean;
		"peerCount"?: object;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"msids"?: Array<string>;
		"wrapup"?: Models.QueueConversationSocialExpressionEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationSocialExpressionEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationSocialExpressionEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationSocialExpressionEventTopicVoicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicWorkflow { 
		"workflowId"?: string;
	}
	
	export interface QueueConversationSocialExpressionEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueConversationVideoEventTopicAddress { 
		"name"?: string;
		"nameRaw"?: string;
		"addressNormalized"?: string;
		"addressRaw"?: string;
		"addressDisplayable"?: string;
	}
	
	export interface QueueConversationVideoEventTopicAfterCallWork { 
		"state"?: string;
		"startTime"?: string;
		"endTime"?: string;
	}
	
	export interface QueueConversationVideoEventTopicAttachment { 
		"attachmentId"?: string;
		"name"?: string;
		"contentUri"?: string;
		"contentType"?: string;
		"contentLength"?: number;
	}
	
	export interface QueueConversationVideoEventTopicCall { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"recording"?: boolean;
		"recordingState"?: string;
		"muted"?: boolean;
		"confined"?: boolean;
		"held"?: boolean;
		"securePause"?: boolean;
		"errorInfo"?: Models.QueueConversationVideoEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"direction"?: string;
		"documentId"?: string;
		"self"?: Models.QueueConversationVideoEventTopicAddress;
		"other"?: Models.QueueConversationVideoEventTopicAddress;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"disconnectReasons"?: Array<Models.QueueConversationVideoEventTopicDisconnectReason>;
		"faxStatus"?: Models.QueueConversationVideoEventTopicFaxStatus;
		"uuiData"?: string;
		"bargedTime"?: string;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicCallback { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"direction"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"dialerPreview"?: Models.QueueConversationVideoEventTopicDialerPreview;
		"voicemail"?: Models.QueueConversationVideoEventTopicVoicemail;
		"callbackNumbers"?: Array<string>;
		"callbackUserName"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"externalCampaign"?: boolean;
		"skipEnabled"?: boolean;
		"provider"?: string;
		"timeoutSeconds"?: number;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"callbackScheduledTime"?: string;
		"automatedCallbackConfigId"?: string;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"callerId"?: string;
		"callerIdName"?: string;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicChat { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"roomId"?: string;
		"avatarImageUrl"?: string;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"journeyContext"?: Models.QueueConversationVideoEventTopicJourneyContext;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicCobrowse { 
		"state"?: string;
		"initialState"?: string;
		"disconnectType"?: string;
		"id"?: string;
		"self"?: Models.QueueConversationVideoEventTopicAddress;
		"roomId"?: string;
		"cobrowseSessionId"?: string;
		"cobrowseRole"?: string;
		"controlling"?: Array<string>;
		"viewerUrl"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"providerEventTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicConversation { 
		"id"?: string;
		"maxParticipants"?: number;
		"participants"?: Array<Models.QueueConversationVideoEventTopicParticipant>;
		"recentTransfers"?: Array<Models.QueueConversationVideoEventTopicRecentTransfer>;
		"recordingState"?: string;
		"address"?: string;
		"externalTag"?: string;
		"utilizationLabelId"?: string;
		"securePause"?: boolean;
	}
	
	export interface QueueConversationVideoEventTopicConversationRoutingData { 
		"queue"?: Models.QueueConversationVideoEventTopicUriReference;
		"language"?: Models.QueueConversationVideoEventTopicUriReference;
		"priority"?: number;
		"skills"?: Array<Models.QueueConversationVideoEventTopicUriReference>;
		"scoredAgents"?: Array<Models.QueueConversationVideoEventTopicScoredAgent>;
	}
	
	export interface QueueConversationVideoEventTopicDestination { 
		"userId"?: string;
		"address"?: string;
	}
	
	export interface QueueConversationVideoEventTopicDialerPreview { 
		"id"?: string;
		"contactId"?: string;
		"contactListId"?: string;
		"campaignId"?: string;
		"phoneNumberColumns"?: Array<Models.QueueConversationVideoEventTopicPhoneNumberColumn>;
	}
	
	export interface QueueConversationVideoEventTopicDisconnectReason { 
		"type"?: string;
		"code"?: number;
		"phrase"?: string;
	}
	
	export interface QueueConversationVideoEventTopicEmail { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"held"?: boolean;
		"autoGenerated"?: boolean;
		"subject"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"messagesSent"?: number;
		"errorInfo"?: Models.QueueConversationVideoEventTopicErrorDetails;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"messageId"?: string;
		"direction"?: string;
		"draftAttachments"?: Array<Models.QueueConversationVideoEventTopicAttachment>;
		"spam"?: boolean;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
		"resumeTime"?: string;
	}
	
	export interface QueueConversationVideoEventTopicErrorDetails { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageWithParams"?: string;
		"messageParams"?: { [key: string]: string; };
		"contextId"?: string;
		"uri"?: string;
	}
	
	export interface QueueConversationVideoEventTopicFaxStatus { 
		"direction"?: string;
		"expectedPages"?: number;
		"activePage"?: number;
		"linesTransmitted"?: number;
		"bytesTransmitted"?: number;
		"baudRate"?: number;
		"pageErrors"?: number;
		"lineErrors"?: number;
	}
	
	export interface QueueConversationVideoEventTopicInitiator { 
		"userId"?: string;
	}
	
	export interface QueueConversationVideoEventTopicJourneyAction { 
		"id"?: string;
		"actionMap"?: Models.QueueConversationVideoEventTopicJourneyActionMap;
	}
	
	export interface QueueConversationVideoEventTopicJourneyActionMap { 
		"id"?: string;
		"version"?: number;
	}
	
	export interface QueueConversationVideoEventTopicJourneyContext { 
		"customer"?: Models.QueueConversationVideoEventTopicJourneyCustomer;
		"customerSession"?: Models.QueueConversationVideoEventTopicJourneyCustomerSession;
		"triggeringAction"?: Models.QueueConversationVideoEventTopicJourneyAction;
	}
	
	export interface QueueConversationVideoEventTopicJourneyCustomer { 
		"id"?: string;
		"idType"?: string;
	}
	
	export interface QueueConversationVideoEventTopicJourneyCustomerSession { 
		"id"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationVideoEventTopicMessage { 
		"id"?: string;
		"state"?: string;
		"initialState"?: string;
		"direction"?: string;
		"held"?: boolean;
		"errorInfo"?: Models.QueueConversationVideoEventTopicErrorDetails;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"toAddress"?: Models.QueueConversationVideoEventTopicAddress;
		"fromAddress"?: Models.QueueConversationVideoEventTopicAddress;
		"messages"?: Array<Models.QueueConversationVideoEventTopicMessageDetails>;
		"messagesTranscriptUri"?: string;
		"type"?: string;
		"recipientCountry"?: string;
		"recipientType"?: string;
		"journeyContext"?: Models.QueueConversationVideoEventTopicJourneyContext;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"agentAssistantId"?: string;
		"byoSmsIntegrationId"?: string;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicMessageDetails { 
		"messageId"?: string;
		"messageTime"?: string;
		"messageStatus"?: string;
		"messageSegmentCount"?: number;
		"media"?: Array<Models.QueueConversationVideoEventTopicMessageMedia>;
		"errorInfo"?: Models.QueueConversationVideoEventTopicErrorDetails;
		"stickers"?: Array<Models.QueueConversationVideoEventTopicMessageSticker>;
		"messageMetadata"?: Models.QueueConversationVideoEventTopicMessageMetadata;
	}
	
	export interface QueueConversationVideoEventTopicMessageMedia { 
		"url"?: string;
		"mediaType"?: string;
		"contentLengthBytes"?: number;
		"name"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationVideoEventTopicMessageMetadata { 
		"type"?: string;
		"events"?: Array<Models.QueueConversationVideoEventTopicMessageMetadataEvent>;
		"content"?: Array<Models.QueueConversationVideoEventTopicMessageMetadataContent>;
	}
	
	export interface QueueConversationVideoEventTopicMessageMetadataContent { 
		"contentType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationVideoEventTopicMessageMetadataEvent { 
		"eventType"?: string;
		"subType"?: string;
	}
	
	export interface QueueConversationVideoEventTopicMessageSticker { 
		"url"?: string;
		"id"?: string;
	}
	
	export interface QueueConversationVideoEventTopicModifiedBy { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface QueueConversationVideoEventTopicObject { 
	}
	
	export interface QueueConversationVideoEventTopicParticipant { 
		"id"?: string;
		"connectedTime"?: string;
		"endTime"?: string;
		"userId"?: string;
		"externalContactId"?: string;
		"externalOrganizationId"?: string;
		"name"?: string;
		"queueId"?: string;
		"groupId"?: string;
		"teamId"?: string;
		"purpose"?: string;
		"consultParticipantId"?: string;
		"address"?: string;
		"wrapupRequired"?: boolean;
		"wrapupExpected"?: boolean;
		"wrapupPrompt"?: string;
		"wrapupTimeoutMs"?: number;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"startAcwTime"?: string;
		"endAcwTime"?: string;
		"conversationRoutingData"?: Models.QueueConversationVideoEventTopicConversationRoutingData;
		"alertingTimeoutMs"?: number;
		"monitoredParticipantId"?: string;
		"coachedParticipantId"?: string;
		"bargedParticipantId"?: string;
		"mediaRoles"?: Array<string>;
		"screenRecordingState"?: string;
		"flaggedReason"?: string;
		"attributes"?: { [key: string]: string; };
		"calls"?: Array<Models.QueueConversationVideoEventTopicCall>;
		"callbacks"?: Array<Models.QueueConversationVideoEventTopicCallback>;
		"chats"?: Array<Models.QueueConversationVideoEventTopicChat>;
		"cobrowsesessions"?: Array<Models.QueueConversationVideoEventTopicCobrowse>;
		"emails"?: Array<Models.QueueConversationVideoEventTopicEmail>;
		"messages"?: Array<Models.QueueConversationVideoEventTopicMessage>;
		"screenshares"?: Array<Models.QueueConversationVideoEventTopicScreenshare>;
		"socialExpressions"?: Array<Models.QueueConversationVideoEventTopicSocialExpression>;
		"videos"?: Array<Models.QueueConversationVideoEventTopicVideo>;
		"workflow"?: Models.QueueConversationVideoEventTopicWorkflow;
	}
	
	export interface QueueConversationVideoEventTopicPhoneNumberColumn { 
		"columnName"?: string;
		"type"?: string;
	}
	
	export interface QueueConversationVideoEventTopicQueueMediaSettings { 
		"alertingTimeoutSeconds"?: number;
		"autoAnswerAlertToneSeconds"?: number;
		"manualAnswerAlertToneSeconds"?: number;
		"enableAutoAnswer"?: boolean;
	}
	
	export interface QueueConversationVideoEventTopicRecentTransfer { 
		"id"?: string;
		"state"?: string;
		"dateIssued"?: string;
		"initiator"?: Models.QueueConversationVideoEventTopicInitiator;
		"modifiedBy"?: Models.QueueConversationVideoEventTopicModifiedBy;
		"destination"?: Models.QueueConversationVideoEventTopicDestination;
		"transferType"?: string;
	}
	
	export interface QueueConversationVideoEventTopicScoredAgent { 
		"agent"?: Models.QueueConversationVideoEventTopicUriReference;
		"score"?: number;
	}
	
	export interface QueueConversationVideoEventTopicScreenshare { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.QueueConversationVideoEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"sharing"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"peerCount"?: object;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicSocialExpression { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"socialMediaId"?: string;
		"socialMediaHub"?: string;
		"socialUserName"?: string;
		"previewText"?: string;
		"recordingId"?: string;
		"held"?: boolean;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface QueueConversationVideoEventTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface QueueConversationVideoEventTopicVideo { 
		"state"?: string;
		"initialState"?: string;
		"self"?: Models.QueueConversationVideoEventTopicAddress;
		"id"?: string;
		"context"?: string;
		"audioMuted"?: boolean;
		"videoMuted"?: boolean;
		"sharingScreen"?: boolean;
		"peerCount"?: object;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"disconnectType"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"msids"?: Array<string>;
		"wrapup"?: Models.QueueConversationVideoEventTopicWrapup;
		"afterCallWork"?: Models.QueueConversationVideoEventTopicAfterCallWork;
		"afterCallWorkRequired"?: boolean;
		"queueMediaSettings"?: Models.QueueConversationVideoEventTopicQueueMediaSettings;
	}
	
	export interface QueueConversationVideoEventTopicVoicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface QueueConversationVideoEventTopicWorkflow { 
		"workflowId"?: string;
	}
	
	export interface QueueConversationVideoEventTopicWrapup { 
		"code"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
	}
	
	export interface QueueEmailAddress { 
		"domain"?: Models.DomainEntityRef;
		"route"?: Models.InboundRoute;
	}
	
	export interface QueueEntityListing { 
		"entities"?: Array<Models.Queue>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface QueueMediaSettings { 
		"call"?: Models.MediaSettings;
		"callback"?: Models.CallbackMediaSettings;
		"chat"?: Models.MediaSettings;
		"email"?: Models.MediaSettings;
		"message"?: Models.MediaSettings;
	}
	
	export interface QueueMember { 
		"id"?: string;
		"name"?: string;
		"user"?: Models.User;
		"ringNumber"?: number;
		"joined"?: boolean;
		"memberBy"?: string;
		"routingStatus"?: Models.RoutingStatus;
		"selfUri"?: string;
	}
	
	export interface QueueMemberEntityListing { 
		"entities"?: Array<Models.QueueMember>;
		"pageNumber"?: number;
		"pageSize"?: number;
		"nextUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface QueueMemberEntityListingV1 { 
		"entities"?: Array<Models.QueueMember>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface QueueMessagingAddresses { 
		"smsAddress"?: Models.DomainEntityRef;
		"openMessagingRecipient"?: Models.DomainEntityRef;
		"whatsAppRecipient"?: Models.DomainEntityRef;
	}
	
	export interface QueueObservationDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.ObservationMetricData>;
	}
	
	export interface QueueObservationQuery { 
		"filter": Models.QueueObservationQueryFilter;
		"metrics": Array<string>;
		"detailMetrics"?: Array<string>;
	}
	
	export interface QueueObservationQueryClause { 
		"type": string;
		"predicates": Array<Models.QueueObservationQueryPredicate>;
	}
	
	export interface QueueObservationQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.QueueObservationQueryClause>;
		"predicates"?: Array<Models.QueueObservationQueryPredicate>;
	}
	
	export interface QueueObservationQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface QueueObservationQueryResponse { 
		"systemToOrganizationMappings"?: { [key: string]: Array<string>; };
		"results"?: Array<Models.QueueObservationDataContainer>;
	}
	
	export interface QueueReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface QueueRequest { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"memberCount"?: number;
		"userMemberCount"?: number;
		"joinedMemberCount"?: number;
		"mediaSettings"?: Models.QueueMediaSettings;
		"routingRules"?: Array<Models.RoutingRule>;
		"conditionalGroupRouting"?: Models.ConditionalGroupRouting;
		"bullseye"?: Models.Bullseye;
		"scoringMethod"?: string;
		"acwSettings"?: Models.AcwSettings;
		"skillEvaluationMethod"?: string;
		"memberGroups"?: Array<Models.MemberGroup>;
		"queueFlow"?: Models.DomainEntityRef;
		"emailInQueueFlow"?: Models.DomainEntityRef;
		"messageInQueueFlow"?: Models.DomainEntityRef;
		"whisperPrompt"?: Models.DomainEntityRef;
		"onHoldPrompt"?: Models.DomainEntityRef;
		"autoAnswerOnly"?: boolean;
		"enableTranscription"?: boolean;
		"enableAudioMonitoring"?: boolean;
		"enableManualAssignment"?: boolean;
		"agentOwnedRouting"?: Models.AgentOwnedRouting;
		"directRouting"?: Models.DirectRouting;
		"callingPartyName"?: string;
		"callingPartyNumber"?: string;
		"defaultScripts"?: { [key: string]: Models.Script; };
		"outboundMessagingAddresses"?: Models.QueueMessagingAddresses;
		"outboundEmailAddress"?: Models.QueueEmailAddress;
		"peerId"?: string;
		"suppressInQueueCallRecording"?: boolean;
		"selfUri"?: string;
	}
	
	export interface QueueUserEventTopicObject { 
	}
	
	export interface QueueUserEventTopicQueueMember { 
		"id"?: string;
		"user"?: Models.QueueUserEventTopicUserReference;
		"queueId"?: string;
		"joined"?: boolean;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface QueueUserEventTopicUserReference { 
		"id"?: string;
	}
	
	export interface QueueUtilizationDiagnostic { 
		"queue"?: Models.DomainEntityRef;
		"usersInQueue"?: number;
		"activeUsersInQueue"?: number;
		"usersOnQueue"?: number;
		"usersNotUtilized"?: number;
		"usersOnQueueWithStation"?: number;
		"usersOnACampaignCall"?: number;
		"usersOnDifferentEdgeGroup"?: number;
		"usersOnANonCampaignCall"?: number;
	}
	
	export interface QuickReply { 
		"text"?: string;
		"payload"?: string;
		"url"?: string;
		"action"?: string;
		"isSelected"?: boolean;
	}
	
	export interface Range { 
		"type": string;
		"end"?: string;
		"numberOfOccurrences"?: number;
	}
	
	export interface RateLimitAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface RateLimitAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.RateLimitAggregateQueryPredicate>;
	}
	
	export interface RateLimitAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.RateLimitAggregateQueryClause>;
		"predicates"?: Array<Models.RateLimitAggregateQueryPredicate>;
	}
	
	export interface RateLimitAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface RateLimitAggregateQueryResponse { 
		"results"?: Array<Models.RateLimitAggregateDataContainer>;
	}
	
	export interface RateLimitAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.RateLimitAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.RateLimitAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface RateLimitAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface Reaction { 
		"data"?: string;
		"name"?: string;
		"reactionType": string;
	}
	
	export interface RealTimeAdherenceExplanation { 
		"id"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface RecallEntry { 
		"nbrAttempts"?: number;
		"minutesBetweenAttempts"?: number;
	}
	
	export interface Recipient { 
		"id"?: string;
		"name"?: string;
		"flow"?: Models.Flow;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.User;
		"modifiedBy"?: Models.User;
		"messengerType"?: string;
		"selfUri"?: string;
	}
	
	export interface RecipientAdditionalIdentifier { 
		"type": string;
		"value": string;
	}
	
	export interface RecipientFlow { 
		"id"?: string;
	}
	
	export interface RecipientListing { 
		"entities"?: Array<Models.Recipient>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface RecipientRequest { 
		"flow"?: Models.RecipientFlow;
	}
	
	export interface Record { 
		"name": string;
		"type": string;
		"value": string;
	}
	
	export interface Recording { 
		"id"?: string;
		"name"?: string;
		"conversationId"?: string;
		"path"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"media"?: string;
		"mediaSubtype"?: string;
		"mediaSubject"?: string;
		"annotations"?: Array<Models.Annotation>;
		"transcript"?: Array<Models.ChatMessage>;
		"emailTranscript"?: Array<Models.RecordingEmailMessage>;
		"messagingTranscript"?: Array<Models.RecordingMessagingMessage>;
		"fileState"?: string;
		"restoreExpirationTime"?: string;
		"mediaUris"?: { [key: string]: Models.MediaResult; };
		"estimatedTranscodeTimeMs"?: number;
		"actualTranscodeTimeMs"?: number;
		"archiveDate"?: string;
		"archiveMedium"?: string;
		"deleteDate"?: string;
		"exportDate"?: string;
		"exportedDate"?: string;
		"outputDurationMs"?: number;
		"outputSizeInBytes"?: number;
		"maxAllowedRestorationsForOrg"?: number;
		"remainingRestorationsAllowedForOrg"?: number;
		"sessionId"?: string;
		"users"?: Array<Models.User>;
		"recordingFileRole"?: string;
		"recordingErrorStatus"?: string;
		"originalRecordingStartTime"?: string;
		"creationTime"?: string;
		"selfUri"?: string;
	}
	
	export interface RecordingAnnotationFlow { 
		"name": string;
		"id": string;
	}
	
	export interface RecordingAnnotationQueue { 
		"name": string;
		"id": string;
	}
	
	export interface RecordingArchiveRestoreTopicMediaResult { 
		"channelId"?: string;
		"waveUri"?: string;
		"mediaUri"?: string;
		"waveformData"?: Array<number>;
	}
	
	export interface RecordingArchiveRestoreTopicRecording { 
		"id"?: string;
		"conversationId"?: string;
		"fileState"?: string;
		"mediaUris"?: Array<Models.RecordingArchiveRestoreTopicMediaResult>;
		"estimatedTranscodeTimeMs"?: number;
		"actualTranscodeTimeMs"?: number;
	}
	
	export interface RecordingButtonComponent { 
		"title"?: string;
		"actions"?: Models.RecordingContentActions;
		"isSelected"?: boolean;
	}
	
	export interface RecordingContentActions { 
		"url"?: string;
		"urlTarget"?: string;
		"textback"?: string;
	}
	
	export interface RecordingContentStory { 
		"type"?: string;
		"url"?: string;
		"replyToId"?: string;
	}
	
	export interface RecordingEmailMessage { 
		"htmlBody"?: string;
		"textBody"?: string;
		"id"?: string;
		"to"?: Array<Models.EmailAddress>;
		"cc"?: Array<Models.EmailAddress>;
		"bcc"?: Array<Models.EmailAddress>;
		"from"?: Models.EmailAddress;
		"subject"?: string;
		"attachments"?: Array<Models.EmailAttachment>;
		"time"?: string;
	}
	
	export interface RecordingEncryptionConfiguration { 
		"id"?: string;
		"url": string;
		"apiId"?: string;
		"apiKey"?: string;
		"keyConfigurationType": string;
		"lastError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface RecordingEncryptionConfigurationListing { 
		"total"?: number;
		"entities"?: Array<Models.RecordingEncryptionConfiguration>;
		"selfUri"?: string;
	}
	
	export interface RecordingEventMediaResult { 
		"channelId"?: string;
		"waveUri"?: string;
		"mediaUri"?: string;
		"waveformData"?: Array<number>;
	}
	
	export interface RecordingEventRecording { 
		"id"?: string;
		"conversationId"?: string;
		"fileState"?: string;
		"mediaUris"?: Array<Models.RecordingEventMediaResult>;
		"estimatedTranscodeTimeMs"?: number;
		"actualTranscodeTimeMs"?: number;
	}
	
	export interface RecordingJob { 
		"id"?: string;
		"state": string;
		"recordingJobsQuery"?: Models.RecordingJobsQuery;
		"dateCreated"?: string;
		"totalConversations"?: number;
		"totalRecordings"?: number;
		"totalSkippedRecordings"?: number;
		"totalFailedRecordings"?: number;
		"totalProcessedRecordings"?: number;
		"percentProgress"?: number;
		"errorMessage"?: string;
		"failedRecordings"?: string;
		"selfUri"?: string;
		"user"?: Models.AddressableEntityRef;
	}
	
	export interface RecordingJobEntityListing { 
		"entities"?: Array<Models.RecordingJob>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface RecordingJobFailedRecording { 
		"conversation"?: Models.AddressableEntityRef;
		"recording"?: Models.AddressableEntityRef;
	}
	
	export interface RecordingJobsQuery { 
		"action": string;
		"actionDate"?: string;
		"actionAge"?: number;
		"screenRecordingActionDate"?: string;
		"screenRecordingActionAge"?: number;
		"integrationId"?: string;
		"includeRecordingsWithSensitiveData"?: boolean;
		"includeScreenRecordings"?: boolean;
		"clearExport"?: boolean;
		"conversationQuery"?: Models.AsyncConversationQuery;
		"agedConversationInterval"?: string;
	}
	
	export interface RecordingMessagingMessage { 
		"from"?: string;
		"fromUser"?: Models.User;
		"fromExternalContact"?: Models.ExternalContact;
		"to"?: string;
		"timestamp"?: string;
		"id"?: string;
		"messageText"?: string;
		"messageMediaAttachments"?: Array<Models.MessageMediaAttachment>;
		"messageStickerAttachments"?: Array<Models.MessageStickerAttachment>;
		"quickReplies"?: Array<Models.QuickReply>;
		"buttonResponse"?: Models.ButtonResponse;
		"story"?: Models.RecordingContentStory;
		"cards"?: Array<Models.Card>;
		"contentType"?: string;
	}
	
	export interface RecordingMetadata { 
		"id"?: string;
		"name"?: string;
		"conversationId"?: string;
		"path"?: string;
		"startTime"?: string;
		"endTime"?: string;
		"media"?: string;
		"mediaSubtype"?: string;
		"mediaSubject"?: string;
		"annotations"?: Array<Models.Annotation>;
		"fileState"?: string;
		"restoreExpirationTime"?: string;
		"archiveDate"?: string;
		"archiveMedium"?: string;
		"deleteDate"?: string;
		"exportDate"?: string;
		"exportedDate"?: string;
		"maxAllowedRestorationsForOrg"?: number;
		"remainingRestorationsAllowedForOrg"?: number;
		"sessionId"?: string;
		"selfUri"?: string;
	}
	
	export interface RecordingRetention { 
		"conversationId"?: string;
		"recordingId"?: string;
		"archiveDate"?: string;
		"archiveMedium"?: string;
		"deleteDate"?: string;
		"exportDate"?: string;
		"exportedDate"?: string;
		"creationTime"?: string;
	}
	
	export interface RecordingRetentionCursorEntityListing { 
		"entities"?: Array<Models.RecordingRetention>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface RecordingSettings { 
		"maxSimultaneousStreams"?: number;
		"maxConfigurableScreenRecordingStreams"?: number;
		"regionalRecordingStorageEnabled"?: boolean;
	}
	
	export interface RecordingTranscodeCompleteTopicMediaResult { 
		"channelId"?: string;
		"waveUri"?: string;
		"mediaUri"?: string;
		"waveformData"?: Array<number>;
	}
	
	export interface RecordingTranscodeCompleteTopicRecording { 
		"id"?: string;
		"conversationId"?: string;
		"fileState"?: string;
		"mediaUris"?: Array<Models.RecordingTranscodeCompleteTopicMediaResult>;
		"estimatedTranscodeTimeMs"?: number;
		"actualTranscodeTimeMs"?: number;
	}
	
	export interface RecordingUploadReport { 
		"id"?: string;
		"name"?: string;
		"state"?: string;
		"signedUrl"?: string;
		"selfUri"?: string;
	}
	
	export interface RecordingUploadReportRequest { 
		"dateSince": string;
		"uploadStatus"?: string;
	}
	
	export interface Referrer { 
		"url": string;
		"domain": string;
		"hostname": string;
		"keywords"?: string;
		"pathname": string;
		"queryString"?: string;
		"fragment"?: string;
		"name"?: string;
		"medium": string;
	}
	
	export interface RegionTimeZone { 
		"id"?: string;
		"name"?: string;
		"offset"?: number;
		"selfUri"?: string;
	}
	
	export interface RegisterArchitectJobResponse { 
		"id"?: string;
		"presignedUrl"?: string;
		"headers"?: { [key: string]: string; };
		"selfUri"?: string;
	}
	
	export interface Relationship { 
		"id"?: string;
		"user": Models.User;
		"externalOrganization": Models.ExternalOrganization;
		"relationship": string;
		"externalDataSources"?: Array<Models.ExternalDataSource>;
		"selfUri"?: string;
	}
	
	export interface RelationshipListing { 
		"entities"?: Array<Models.Relationship>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"partialResults"?: boolean;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Reoccurrence { 
		"id"?: string;
		"start": string;
		"end": string;
		"timeZone": string;
		"pattern": Models.Pattern;
		"range": Models.Range;
		"alterations"?: Array<Models.Alteration>;
	}
	
	export interface ReplaceRequest { 
		"changeNumber"?: number;
		"name"?: string;
		"authToken"?: string;
	}
	
	export interface ReplaceResponse { 
		"id"?: string;
		"name"?: string;
		"changeNumber"?: number;
		"uploadStatus"?: Models.DomainEntityRef;
		"uploadDestinationUri"?: string;
		"uploadMethod"?: string;
	}
	
	export interface ReplacementTerm { 
		"type"?: string;
		"existingValue"?: string;
		"updatedValue"?: string;
	}
	
	export interface ReplyToEmailAddress { 
		"domain": Models.DomainEntityRef;
		"route": Models.DomainEntityRef;
	}
	
	export interface ReportMetaData { 
		"id"?: string;
		"name"?: string;
		"title"?: string;
		"description"?: string;
		"keywords"?: Array<string>;
		"availableLocales"?: Array<string>;
		"parameters"?: Array<Models.Parameter>;
		"exampleUrl"?: string;
		"selfUri"?: string;
	}
	
	export interface ReportMetaDataEntityListing { 
		"entities"?: Array<Models.ReportMetaData>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ReportRunEntry { 
		"id"?: string;
		"name"?: string;
		"reportId"?: string;
		"runTime"?: string;
		"runStatus"?: string;
		"errorMessage"?: string;
		"runDurationMsec"?: number;
		"reportUrl"?: string;
		"reportFormat"?: string;
		"scheduleUri"?: string;
		"selfUri"?: string;
	}
	
	export interface ReportRunEntryEntityDomainListing { 
		"entities"?: Array<Models.ReportRunEntry>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ReportSchedule { 
		"id"?: string;
		"name"?: string;
		"quartzCronExpression": string;
		"nextFireTime"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"description"?: string;
		"timeZone"?: string;
		"timePeriod"?: string;
		"interval": string;
		"reportFormat"?: string;
		"locale"?: string;
		"enabled"?: boolean;
		"reportId": string;
		"parameters"?: { [key: string]: object; };
		"lastRun"?: Models.ReportRunEntry;
		"selfUri"?: string;
	}
	
	export interface ReportScheduleEntityListing { 
		"entities"?: Array<Models.ReportSchedule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ReportingDataExportTopicDataExportNotification { 
		"id"?: string;
		"runId"?: string;
		"name"?: string;
		"status"?: string;
		"exportFormat"?: string;
		"downloadUrl"?: string;
		"viewType"?: string;
		"exportErrorMessagesType"?: string;
		"read"?: boolean;
		"createdDateTime"?: string;
		"modifiedDateTime"?: string;
		"percentageComplete"?: number;
		"emailStatuses"?: { [key: string]: string; };
		"emailErrorDescription"?: string;
		"scheduleExpression"?: string;
		"scheduleStaticLinkUrl"?: string;
		"exportAllowedToRerun"?: boolean;
	}
	
	export interface ReportingExportJobListing { 
		"entities"?: Array<Models.ReportingExportJobResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ReportingExportJobRequest { 
		"name": string;
		"timeZone": string;
		"exportFormat": string;
		"interval": string;
		"period": string;
		"viewType": string;
		"filter": Models.ViewFilter;
		"read"?: boolean;
		"locale": string;
		"hasFormatDurations"?: boolean;
		"hasSplitFilters"?: boolean;
		"excludeEmptyRows"?: boolean;
		"hasSplitByMedia"?: boolean;
		"hasSummaryRow"?: boolean;
		"csvDelimiter"?: string;
		"selectedColumns"?: Array<Models.SelectedColumns>;
		"hasCustomParticipantAttributes"?: boolean;
		"recipientEmails"?: Array<string>;
		"includeDurationFormatInHeader"?: boolean;
		"durationFormat"?: string;
	}
	
	export interface ReportingExportJobResponse { 
		"id"?: string;
		"name"?: string;
		"runId": string;
		"status": string;
		"timeZone": string;
		"exportFormat": string;
		"interval": string;
		"downloadUrl"?: string;
		"viewType": string;
		"exportErrorMessagesType"?: string;
		"period": string;
		"filter": Models.ViewFilter;
		"read": boolean;
		"createdDateTime": string;
		"modifiedDateTime": string;
		"locale": string;
		"percentageComplete": number;
		"hasFormatDurations"?: boolean;
		"hasSplitFilters"?: boolean;
		"excludeEmptyRows"?: boolean;
		"hasSplitByMedia"?: boolean;
		"hasSummaryRow"?: boolean;
		"csvDelimiter"?: string;
		"selectedColumns"?: Array<Models.SelectedColumns>;
		"hasCustomParticipantAttributes"?: boolean;
		"recipientEmails"?: Array<string>;
		"emailStatuses"?: { [key: string]: string; };
		"emailErrorDescription"?: string;
		"includeDurationFormatInHeader"?: boolean;
		"durationFormat"?: string;
		"exportAllowedToRerun"?: boolean;
		"enabled"?: boolean;
		"selfUri"?: string;
	}
	
	export interface ReportingExportMetadataJobListing { 
		"entities"?: Array<Models.ReportingExportMetadataJobResponse>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ReportingExportMetadataJobResponse { 
		"id"?: string;
		"name"?: string;
		"viewType"?: string;
		"dateLimitations"?: string;
		"requiredFilters"?: Array<string>;
		"supportedFilters"?: Array<string>;
		"requiredColumnIds"?: Array<string>;
		"dependentColumnIds"?: { [key: string]: Array<string>; };
		"availableColumnIds"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface ReportingInterval { 
		"intervalType": string;
		"intervalValue": number;
	}
	
	export interface ReportingTurn { 
		"userInput"?: string;
		"botPrompts"?: Array<string>;
		"sessionId"?: string;
		"askAction"?: Models.ReportingTurnAction;
		"intent"?: Models.ReportingTurnIntent;
		"knowledge"?: Models.ReportingTurnKnowledge;
		"dateCreated"?: string;
		"askActionResult"?: string;
		"sessionEndDetails"?: Models.SessionEndDetails;
		"conversation"?: Models.AddressableEntityRef;
	}
	
	export interface ReportingTurnAction { 
		"actionId"?: string;
		"actionName"?: string;
		"actionNumber"?: number;
		"actionType"?: string;
	}
	
	export interface ReportingTurnIntent { 
		"name"?: string;
		"confidence"?: number;
		"slots"?: Array<Models.ReportingTurnIntentSlot>;
	}
	
	export interface ReportingTurnIntentSlot { 
		"name"?: string;
		"value"?: string;
		"type"?: string;
		"confidence"?: number;
	}
	
	export interface ReportingTurnKnowledge { 
		"knowledgeBaseId"?: string;
		"feedback"?: Models.ReportingTurnKnowledgeFeedback;
		"search"?: Models.ReportingTurnKnowledgeSearch;
	}
	
	export interface ReportingTurnKnowledgeDocument { 
		"id"?: string;
		"question"?: string;
		"answer"?: string;
		"confidence"?: number;
	}
	
	export interface ReportingTurnKnowledgeFeedback { 
		"searchId"?: string;
		"rating"?: number;
		"documents"?: Array<Models.ReportingTurnKnowledgeDocument>;
	}
	
	export interface ReportingTurnKnowledgeSearch { 
		"searchId"?: string;
		"documents"?: Array<Models.ReportingTurnKnowledgeDocument>;
		"query"?: string;
	}
	
	export interface ReportingTurnsResponse { 
		"entities"?: Array<Models.ReportingTurn>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface RequestConfig { 
		"requestUrlTemplate"?: string;
		"requestTemplate"?: string;
		"requestTemplateUri"?: string;
		"requestType"?: string;
		"headers"?: { [key: string]: string; };
	}
	
	export interface RequestContext { 
		"patterns"?: Array<Models.RequestContextPattern>;
	}
	
	export interface RequestContextPattern { 
		"criteria": Array<Models.RequestEntityTypeCriteria>;
	}
	
	export interface RequestCriteria { 
		"key": string;
		"values": Array<string>;
		"shouldIgnoreCase"?: boolean;
		"operator"?: string;
	}
	
	export interface RequestDevice { 
		"category": string;
		"type": string;
		"isMobile"?: boolean;
		"screenHeight"?: number;
		"screenWidth"?: number;
		"screenDensity"?: number;
		"fingerprint"?: string;
		"osFamily": string;
		"osVersion": string;
		"manufacturer"?: string;
	}
	
	export interface RequestEntityTypeCriteria { 
		"key": string;
		"values": Array<string>;
		"shouldIgnoreCase"?: boolean;
		"operator"?: string;
		"entityType": string;
	}
	
	export interface RequestExternalSegment { 
		"id": string;
		"name": string;
		"source"?: string;
	}
	
	export interface RequestJourney { 
		"patterns"?: Array<Models.RequestJourneyPattern>;
	}
	
	export interface RequestJourneyPattern { 
		"criteria": Array<Models.RequestCriteria>;
		"count": number;
		"streamType": string;
		"sessionType": string;
		"eventName"?: string;
	}
	
	export interface RequestMapping { 
		"name"?: string;
		"attributeType"?: string;
		"mappingType"?: string;
		"value"?: string;
	}
	
	export interface RequestScoredAgent { 
		"id"?: string;
		"score"?: number;
	}
	
	export interface ReschedulingManagementUnitResponse { 
		"managementUnit"?: Models.ManagementUnitReference;
		"applied"?: boolean;
	}
	
	export interface ReschedulingOptionsRunResponse { 
		"existingSchedule"?: Models.BuScheduleReference;
		"startDate"?: string;
		"endDate"?: string;
		"managementUnits"?: Array<Models.ReschedulingManagementUnitResponse>;
		"agentCount"?: number;
		"activityCodeIds"?: Array<string>;
		"doNotChangeWeeklyPaidTime"?: boolean;
		"doNotChangeDailyPaidTime"?: boolean;
		"doNotChangeShiftStartTimes"?: boolean;
		"doNotChangeManuallyEditedShifts"?: boolean;
	}
	
	export interface ResolutionAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface ResolutionAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.ResolutionAggregateQueryPredicate>;
	}
	
	export interface ResolutionAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.ResolutionAggregateQueryClause>;
		"predicates"?: Array<Models.ResolutionAggregateQueryPredicate>;
	}
	
	export interface ResolutionAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface ResolutionAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface ResolutionAsyncAggregateQueryResponse { 
		"results"?: Array<Models.ResolutionAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface ResolutionAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.ResolutionAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.ResolutionAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface ResolutionDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.ResolutionDetailQueryPredicate>;
	}
	
	export interface ResolutionDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.ResolutionDetailQueryClause>;
		"predicates"?: Array<Models.ResolutionDetailQueryPredicate>;
	}
	
	export interface ResolutionDetailQueryPredicate { 
		"type"?: string;
		"metric"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface ResourceConditionNode { 
		"variableName"?: string;
		"conjunction"?: string;
		"operator"?: string;
		"operands"?: Array<Models.ResourceConditionValue>;
		"terms"?: Array<Models.ResourceConditionNode>;
	}
	
	export interface ResourceConditionValue { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface ResourcePermissionPolicy { 
		"id"?: string;
		"domain"?: string;
		"entityName"?: string;
		"policyName"?: string;
		"policyDescription"?: string;
		"actionSetKey"?: string;
		"allowConditions"?: boolean;
		"resourceConditionNode"?: Models.ResourceConditionNode;
		"namedResources"?: Array<string>;
		"resourceCondition"?: string;
		"actionSet"?: Array<string>;
	}
	
	export interface Response { 
		"id"?: string;
		"name"?: string;
		"version"?: number;
		"libraries": Array<Models.DomainEntityRef>;
		"texts": Array<Models.ResponseText>;
		"createdBy"?: Models.User;
		"dateCreated"?: string;
		"interactionType"?: string;
		"substitutions"?: Array<Models.ResponseSubstitution>;
		"substitutionsSchema"?: Models.JsonSchemaDocument;
		"responseType"?: string;
		"messagingTemplate"?: Models.MessagingTemplate;
		"assets"?: Array<Models.AddressableEntityRef>;
		"footer"?: Models.FooterTemplate;
		"selfUri"?: string;
	}
	
	export interface ResponseAsset { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"contentLength"?: number;
		"contentLocation"?: string;
		"contentType"?: string;
		"dateCreated"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"dateModified"?: string;
		"modifiedBy"?: Models.DomainEntityRef;
		"responses"?: Array<Models.DomainEntityRef>;
		"selfUri"?: string;
	}
	
	export interface ResponseAssetFilter { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"fields"?: Array<string>;
		"value"?: string;
		"type"?: string;
	}
	
	export interface ResponseAssetRequest { 
		"name": string;
		"divisionId"?: string;
	}
	
	export interface ResponseAssetSearchRequest { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"sortOrder"?: string;
		"sortBy"?: string;
		"query": Array<Models.ResponseAssetFilter>;
	}
	
	export interface ResponseAssetSearchResults { 
		"total"?: number;
		"pageCount"?: number;
		"pageSize"?: number;
		"pageNumber"?: number;
		"results"?: Array<Models.ResponseAsset>;
	}
	
	export interface ResponseAssetStatus { 
		"id"?: string;
		"status"?: string;
		"errorCode"?: string;
		"errorMessage"?: string;
	}
	
	export interface ResponseConfig { 
		"translationMap"?: { [key: string]: string; };
		"translationMapDefaults"?: { [key: string]: string; };
		"successTemplate"?: string;
		"successTemplateUri"?: string;
	}
	
	export interface ResponseEntityList { 
		"entities"?: Array<Models.Response>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ResponseEntityListing { 
		"entities"?: Array<Models.Response>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ResponseFilter { 
		"name": string;
		"operator": string;
		"values": Array<string>;
	}
	
	export interface ResponseQueryRequest { 
		"queryPhrase"?: string;
		"pageSize"?: number;
		"filters"?: Array<Models.ResponseFilter>;
	}
	
	export interface ResponseQueryResults { 
		"results": Models.ResponseEntityList;
	}
	
	export interface ResponseSet { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"responses": { [key: string]: Models.Reaction; };
		"beepDetectionEnabled"?: boolean;
		"amdSpeechDistinguishEnabled"?: boolean;
		"selfUri"?: string;
	}
	
	export interface ResponseSetEntityListing { 
		"entities"?: Array<Models.ResponseSet>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ResponseSubstitution { 
		"id": string;
		"description"?: string;
		"defaultValue"?: string;
	}
	
	export interface ResponseText { 
		"content": string;
		"contentType"?: string;
	}
	
	export interface RestErrorDetail { 
		"error": string;
		"details"?: string;
	}
	
	export interface RestorePresenceSettings { 
		"enabled": boolean;
		"restoreTimeMilliseconds": number;
		"restoreOnQueueEnabled": boolean;
	}
	
	export interface ResultCounters { 
		"success"?: number;
		"failure"?: number;
	}
	
	export interface RetentionDuration { 
		"archiveRetention"?: Models.ArchiveRetention;
		"deleteRetention"?: Models.DeleteRetention;
	}
	
	export interface ReverseWhitepagesLookupResult { 
		"contacts"?: Array<Models.ExternalContact>;
		"externalOrganizations"?: Array<Models.ExternalOrganization>;
	}
	
	export interface ReviewAssessmentResults { 
	}
	
	export interface Ring { 
		"expansionCriteria"?: Array<Models.ExpansionCriterium>;
		"actions"?: Models.Actions;
		"memberGroups"?: Array<Models.MemberGroup>;
	}
	
	export interface RoleDivision { 
		"roleId": string;
		"divisionId": string;
	}
	
	export interface RoleDivisionGrants { 
		"grants": Array<Models.RoleDivisionPair>;
	}
	
	export interface RoleDivisionPair { 
		"roleId": string;
		"divisionId": string;
	}
	
	export interface Room { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"roomType"?: string;
		"description"?: string;
		"subject"?: string;
		"participantLimit"?: number;
		"owners"?: Array<Models.UserReference>;
		"pinnedMessages"?: Array<Models.AddressableEntityRef>;
		"selfUri"?: string;
	}
	
	export interface RoomParticipant { 
		"participantJid": string;
	}
	
	export interface RoomParticipantResponse { 
		"jid"?: string;
		"user"?: Models.AddressableEntityRef;
	}
	
	export interface RoomParticipantsResponse { 
		"participants"?: Array<Models.RoomParticipantResponse>;
	}
	
	export interface RoomUpdateRequest { 
		"description"?: string;
		"subject"?: string;
		"pinnedMessageIds"?: Array<string>;
		"ownerIds"?: Array<string>;
	}
	
	export interface RoutePathRequest { 
		"queueId": string;
		"mediaType": string;
		"languageId"?: string;
		"skillIds"?: Array<string>;
		"sourcePlanningGroup"?: Models.SourcePlanningGroupRequest;
	}
	
	export interface RoutePathResponse { 
		"queue"?: Models.QueueReference;
		"mediaType"?: string;
		"language"?: Models.LanguageReference;
		"skills"?: Array<Models.RoutingSkillReference>;
	}
	
	export interface RoutingActivityData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.RoutingActivityMetricValue>;
		"truncated"?: boolean;
		"entities"?: Array<Models.RoutingActivityEntityData>;
	}
	
	export interface RoutingActivityEntityData { 
		"activityDate": string;
		"organizationPresenceId"?: string;
		"presenceDate"?: string;
		"queueId"?: string;
		"queueMembershipStatus"?: string;
		"routingStatus"?: string;
		"routingStatusDate"?: string;
		"systemPresence"?: string;
		"teamId"?: string;
		"userId"?: string;
	}
	
	export interface RoutingActivityMetricValue { 
		"metric"?: string;
		"count"?: number;
	}
	
	export interface RoutingActivityQuery { 
		"metrics": Array<Models.RoutingActivityQueryMetric>;
		"groupBy": Array<string>;
		"filter"?: Models.RoutingActivityQueryFilter;
		"order"?: string;
	}
	
	export interface RoutingActivityQueryClause { 
		"type": string;
		"predicates": Array<Models.RoutingActivityQueryPredicate>;
	}
	
	export interface RoutingActivityQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.RoutingActivityQueryClause>;
		"predicates"?: Array<Models.RoutingActivityQueryPredicate>;
	}
	
	export interface RoutingActivityQueryMetric { 
		"metric": string;
		"details"?: boolean;
	}
	
	export interface RoutingActivityQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
	}
	
	export interface RoutingActivityResponse { 
		"results"?: Array<Models.RoutingActivityData>;
		"entityIdDimension"?: string;
	}
	
	export interface RoutingConversationAttributesRequest { 
		"priority"?: number;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"requestScoredAgents"?: Array<Models.RequestScoredAgent>;
	}
	
	export interface RoutingConversationAttributesResponse { 
		"priority"?: number;
		"skills"?: Array<Models.RoutingSkill>;
		"language"?: Models.Language;
		"scoredAgents"?: Array<Models.ScoredAgent>;
	}
	
	export interface RoutingData { 
		"queueId": string;
		"languageId"?: string;
		"label"?: string;
		"priority"?: number;
		"skillIds"?: Array<string>;
		"preferredAgentIds"?: Array<string>;
		"scoredAgents"?: Array<Models.ScoredAgent>;
		"routingFlags"?: Array<string>;
	}
	
	export interface RoutingEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"phoneNumber"?: string;
		"queueId": string;
		"ani"?: string;
		"dnis"?: string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"initialConfiguration": Models.InitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface RoutingRule { 
		"operator"?: string;
		"threshold"?: number;
		"waitSeconds"?: number;
	}
	
	export interface RoutingSettings { 
		"resetAgentScoreOnPresenceChange"?: boolean;
	}
	
	export interface RoutingSkill { 
		"id"?: string;
		"name": string;
		"dateModified"?: string;
		"state"?: string;
		"version"?: string;
		"selfUri"?: string;
	}
	
	export interface RoutingSkillReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface RoutingStatus { 
		"userId"?: string;
		"status"?: string;
		"startTime"?: string;
	}
	
	export interface RoutingStatusDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.RoutingStatusDetailQueryPredicate>;
	}
	
	export interface RoutingStatusDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.RoutingStatusDetailQueryClause>;
		"predicates"?: Array<Models.RoutingStatusDetailQueryPredicate>;
	}
	
	export interface RoutingStatusDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface RoutingTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationQueueId": string;
		"languageId"?: string;
		"skillIds"?: Array<string>;
	}
	
	export interface RuleSet { 
		"id"?: string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"contactList"?: Models.DomainEntityRef;
		"queue"?: Models.DomainEntityRef;
		"rules": Array<Models.DialerRule>;
		"selfUri"?: string;
	}
	
	export interface RuleSetDiagnostic { 
		"ruleSet"?: Models.DomainEntityRef;
		"warnings"?: Array<string>;
	}
	
	export interface RuleSetEntityListing { 
		"entities"?: Array<Models.RuleSet>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface RunNowResponse { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface SIPSearchPublicRequest { 
		"id"?: string;
		"name"?: string;
		"callId"?: string;
		"toUser"?: string;
		"fromUser"?: string;
		"conversationId"?: string;
		"participantId"?: string;
		"dateStart": string;
		"dateEnd": string;
		"selfUri"?: string;
	}
	
	export interface SMSAvailablePhoneNumberEntityListing { 
		"entities"?: Array<Models.SmsAvailablePhoneNumber>;
	}
	
	export interface Salesforce { 
		"id"?: string;
		"name"?: string;
		"disabled"?: boolean;
		"issuerURI"?: string;
		"ssoTargetURI"?: string;
		"sloURI"?: string;
		"sloBinding"?: string;
		"relyingPartyIdentifier"?: string;
		"certificate"?: string;
		"certificates"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface Schedule { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"start": string;
		"end": string;
		"rrule"?: string;
		"selfUri"?: string;
	}
	
	export interface ScheduleActivity { 
		"dateStart"?: string;
		"lengthMinutes"?: number;
		"description"?: string;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"timeOffRequestId"?: string;
		"externalActivityId"?: string;
		"externalActivityType"?: string;
	}
	
	export interface ScheduleDivisionViewEntityListing { 
		"entities"?: Array<Models.SchedulesDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ScheduleEntityListing { 
		"entities"?: Array<Models.Schedule>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ScheduleGenerationMessage { 
		"type"?: string;
		"arguments"?: Array<Models.SchedulerMessageArgument>;
	}
	
	export interface ScheduleGenerationResult { 
		"failed"?: boolean;
		"runId"?: string;
		"messageCount"?: number;
		"messages"?: Array<Models.ScheduleGenerationMessage>;
		"messageSeverities"?: Array<Models.SchedulerMessageTypeSeverity>;
	}
	
	export interface ScheduleGenerationResultSummary { 
		"failed"?: boolean;
		"runId"?: string;
		"messageCount"?: number;
		"messageSeverityCounts"?: Array<Models.SchedulerMessageSeverityCount>;
	}
	
	export interface ScheduleGenerationWarning { 
		"userId"?: string;
		"userNotLicensed"?: boolean;
		"unableToMeetMaxDays"?: boolean;
		"unableToScheduleRequiredDays"?: Array<string>;
		"unableToMeetMinPaidForTheWeek"?: boolean;
		"unableToMeetMaxPaidForTheWeek"?: boolean;
		"noNeedDays"?: Array<string>;
		"shiftsTooCloseTogether"?: boolean;
	}
	
	export interface ScheduleGroup { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"timeZone"?: string;
		"openSchedules"?: Array<Models.DomainEntityRef>;
		"closedSchedules"?: Array<Models.DomainEntityRef>;
		"holidaySchedules"?: Array<Models.DomainEntityRef>;
		"selfUri"?: string;
	}
	
	export interface ScheduleGroupDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"selfUri"?: string;
	}
	
	export interface ScheduleGroupDivisionViewEntityListing { 
		"entities"?: Array<Models.ScheduleGroupDivisionView>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ScheduleGroupEntityListing { 
		"entities"?: Array<Models.ScheduleGroup>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ScheduleInterval { 
		"start": string;
		"end": string;
	}
	
	export interface ScheduleUploadProcessingResponse { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.BuScheduleMetadata;
	}
	
	export interface SchedulerMessageArgument { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface SchedulerMessageSeverityCount { 
		"severity"?: string;
		"count"?: number;
	}
	
	export interface SchedulerMessageTypeSeverity { 
		"type"?: string;
		"severity"?: string;
	}
	
	export interface SchedulesDivisionView { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"selfUri"?: string;
	}
	
	export interface SchedulingNoForecastOptionsRequest { 
		"shiftLength"?: string;
		"shiftStart"?: string;
	}
	
	export interface SchedulingOptionsRequest { 
		"noForecastOptions"?: Models.SchedulingNoForecastOptionsRequest;
	}
	
	export interface SchedulingProcessingError { 
		"internalErrorCode"?: string;
		"description"?: string;
	}
	
	export interface SchedulingSettingsRequest { 
		"maxOccupancyPercentForDeferredWork"?: number;
		"defaultShrinkagePercent"?: number;
		"shrinkageOverrides"?: Models.ShrinkageOverrides;
		"planningPeriod"?: Models.ValueWrapperPlanningPeriodSettings;
		"startDayOfWeekend"?: string;
	}
	
	export interface SchedulingSettingsResponse { 
		"maxOccupancyPercentForDeferredWork"?: number;
		"defaultShrinkagePercent"?: number;
		"shrinkageOverrides"?: Models.ShrinkageOverrides;
		"planningPeriod"?: Models.PlanningPeriodSettings;
		"startDayOfWeekend"?: string;
	}
	
	export interface SchedulingStatusResponse { 
		"id"?: string;
		"status"?: string;
		"errorDetails"?: Array<Models.SchedulingProcessingError>;
		"schedulingResultUri"?: string;
		"percentComplete"?: number;
	}
	
	export interface SchedulingTestingOptionsRequest { 
		"fastScheduling"?: boolean;
		"delayScheduling"?: boolean;
		"failScheduling"?: boolean;
		"populateWarnings"?: boolean;
		"populateDeprecatedWarnings"?: boolean;
	}
	
	export interface Schema { 
		"title"?: string;
		"description"?: string;
		"type"?: Array<string>;
		"items"?: Models.Items;
		"pattern"?: string;
	}
	
	export interface SchemaQuantityLimits { 
		"id"?: string;
		"name"?: string;
		"minFieldNameCharacters"?: number;
		"maxFieldNameCharacters"?: number;
		"minFieldDescriptionCharacters"?: number;
		"maxFieldDescriptionCharacters"?: number;
		"minSchemaNameCharacters"?: number;
		"maxSchemaNameCharacters"?: number;
		"minSchemaDescriptionCharacters"?: number;
		"maxSchemaDescriptionCharacters"?: number;
		"maxNumberOfSchemasPerOrg"?: number;
		"maxNumberOfFieldsPerSchema"?: number;
		"maxNumberOfFieldsPerOrg"?: number;
		"selfUri"?: string;
	}
	
	export interface ScimConfigResourceType { 
		"id"?: string;
		"schemas"?: Array<string>;
		"name"?: string;
		"description"?: string;
		"schema"?: string;
		"schemaExtensions"?: Array<Models.ScimConfigResourceTypeSchemaExtension>;
		"endpoint"?: string;
		"meta"?: Models.ScimMetadata;
	}
	
	export interface ScimConfigResourceTypeSchemaExtension { 
		"schema"?: string;
		"required"?: boolean;
	}
	
	export interface ScimConfigResourceTypesListResponse { 
		"schemas"?: Array<string>;
		"totalResults"?: number;
		"startIndex"?: number;
		"itemsPerPage"?: number;
		"Resources"?: Array<Models.ScimConfigResourceType>;
	}
	
	export interface ScimEmail { 
		"value"?: string;
		"type"?: string;
		"primary"?: boolean;
	}
	
	export interface ScimError { 
		"schemas"?: Array<string>;
		"status"?: string;
		"scimType"?: string;
		"detail"?: string;
	}
	
	export interface ScimGenesysUserExternalId { 
		"authority": string;
		"value": string;
	}
	
	export interface ScimGroupListResponse { 
		"schemas"?: Array<string>;
		"totalResults"?: number;
		"startIndex"?: number;
		"itemsPerPage"?: number;
		"Resources"?: Array<Models.ScimV2Group>;
	}
	
	export interface ScimMetadata { 
		"resourceType"?: string;
		"lastModified"?: string;
		"location"?: string;
		"version"?: string;
	}
	
	export interface ScimPhoneNumber { 
		"value"?: string;
		"type"?: string;
		"primary"?: boolean;
	}
	
	export interface ScimServiceProviderConfig { 
		"schemas"?: Array<string>;
		"documentationUri"?: string;
		"patch"?: Models.ScimServiceProviderConfigSimpleFeature;
		"filter"?: Models.ScimServiceProviderConfigFilterFeature;
		"etag"?: Models.ScimServiceProviderConfigSimpleFeature;
		"sort"?: Models.ScimServiceProviderConfigSimpleFeature;
		"bulk"?: Models.ScimServiceProviderConfigBulkFeature;
		"changePassword"?: Models.ScimServiceProviderConfigSimpleFeature;
		"authenticationSchemes"?: Array<Models.ScimServiceProviderConfigAuthenticationScheme>;
		"meta"?: Models.ScimMetadata;
	}
	
	export interface ScimServiceProviderConfigAuthenticationScheme { 
		"name": string;
		"description": string;
		"specUri"?: string;
		"documentationUri"?: string;
		"type": string;
		"primary"?: boolean;
	}
	
	export interface ScimServiceProviderConfigBulkFeature { 
		"supported"?: boolean;
		"maxOperations"?: number;
		"maxPayloadSize"?: number;
	}
	
	export interface ScimServiceProviderConfigFilterFeature { 
		"supported"?: boolean;
		"maxResults"?: number;
	}
	
	export interface ScimServiceProviderConfigSimpleFeature { 
		"supported"?: boolean;
	}
	
	export interface ScimUserExtensions { 
		"routingSkills"?: Array<Models.ScimUserRoutingSkill>;
		"routingLanguages"?: Array<Models.ScimUserRoutingLanguage>;
		"externalIds"?: Array<Models.ScimGenesysUserExternalId>;
	}
	
	export interface ScimUserListResponse { 
		"schemas"?: Array<string>;
		"totalResults"?: number;
		"startIndex"?: number;
		"itemsPerPage"?: number;
		"Resources"?: Array<Models.ScimV2User>;
	}
	
	export interface ScimUserRole { 
		"value"?: string;
	}
	
	export interface ScimUserRoutingLanguage { 
		"name": string;
		"proficiency"?: number;
	}
	
	export interface ScimUserRoutingSkill { 
		"name": string;
		"proficiency"?: number;
	}
	
	export interface ScimV2CreateUser { 
		"schemas"?: Array<string>;
		"active"?: boolean;
		"userName": string;
		"displayName": string;
		"password"?: string;
		"title"?: string;
		"phoneNumbers"?: Array<Models.ScimPhoneNumber>;
		"emails"?: Array<Models.ScimEmail>;
		"externalId"?: string;
		"groups"?: Array<Models.ScimV2GroupReference>;
		"roles"?: Array<Models.ScimUserRole>;
		"urn:ietf:params:scim:schemas:extension:enterprise:2.0:User"?: Models.ScimV2EnterpriseUser;
		"urn:ietf:params:scim:schemas:extension:genesys:purecloud:2.0:User"?: Models.ScimUserExtensions;
	}
	
	export interface ScimV2EnterpriseUser { 
		"division"?: string;
		"department"?: string;
		"manager"?: Models.Manager;
		"employeeNumber"?: string;
	}
	
	export interface ScimV2Group { 
		"id"?: string;
		"schemas"?: Array<string>;
		"displayName": string;
		"externalId"?: string;
		"members"?: Array<Models.ScimV2MemberReference>;
		"meta"?: Models.ScimMetadata;
	}
	
	export interface ScimV2GroupReference { 
		"type"?: string;
		"value"?: string;
		"$ref"?: string;
	}
	
	export interface ScimV2MemberReference { 
		"type"?: string;
		"value"?: string;
		"$ref"?: string;
	}
	
	export interface ScimV2PatchOperation { 
		"op": string;
		"path"?: string;
		"value"?: object;
	}
	
	export interface ScimV2PatchRequest { 
		"schemas": Array<string>;
		"Operations"?: Array<Models.ScimV2PatchOperation>;
	}
	
	export interface ScimV2SchemaAttribute { 
		"name"?: string;
		"type"?: string;
		"subAttributes"?: Array<Models.ScimV2SchemaAttribute>;
		"multiValued"?: boolean;
		"description"?: string;
		"required"?: boolean;
		"canonicalValues"?: Array<string>;
		"caseExact"?: boolean;
		"mutability"?: string;
		"returned"?: string;
		"uniqueness"?: string;
		"referenceTypes"?: Array<string>;
	}
	
	export interface ScimV2SchemaDefinition { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"attributes"?: Array<Models.ScimV2SchemaAttribute>;
		"meta"?: Models.ScimMetadata;
	}
	
	export interface ScimV2SchemaListResponse { 
		"schemas"?: Array<string>;
		"totalResults"?: number;
		"startIndex"?: number;
		"itemsPerPage"?: number;
		"Resources"?: Array<Models.ScimV2SchemaDefinition>;
	}
	
	export interface ScimV2User { 
		"id"?: string;
		"schemas"?: Array<string>;
		"active"?: boolean;
		"userName"?: string;
		"displayName"?: string;
		"password"?: string;
		"title"?: string;
		"phoneNumbers"?: Array<Models.ScimPhoneNumber>;
		"emails"?: Array<Models.ScimEmail>;
		"externalId"?: string;
		"groups"?: Array<Models.ScimV2GroupReference>;
		"roles"?: Array<Models.ScimUserRole>;
		"urn:ietf:params:scim:schemas:extension:enterprise:2.0:User"?: Models.ScimV2EnterpriseUser;
		"urn:ietf:params:scim:schemas:extension:genesys:purecloud:2.0:User"?: Models.ScimUserExtensions;
		"meta"?: Models.ScimMetadata;
	}
	
	export interface ScorableSurvey { 
		"id"?: string;
		"name"?: string;
		"surveyForm"?: Models.SurveyForm;
		"status"?: string;
		"answers"?: Models.SurveyScoringSet;
		"selfUri"?: string;
	}
	
	export interface ScoredAgent { 
		"agent"?: Models.DomainEntityRef;
		"score"?: number;
	}
	
	export interface ScreenRecordingActiveSessions { 
		"count"?: number;
	}
	
	export interface ScreenRecordingMetaData { 
		"trackId"?: string;
		"mediaId"?: string;
		"screenId"?: string;
		"originX"?: number;
		"originY"?: number;
		"primary"?: boolean;
		"main"?: boolean;
	}
	
	export interface ScreenRecordingMetaDataRequest { 
		"participantJid"?: string;
		"roomId"?: string;
		"metaData"?: Array<Models.ScreenRecordingMetaData>;
	}
	
	export interface ScreenRecordingSession { 
		"id"?: string;
		"name"?: string;
		"user"?: Models.User;
		"communicationId"?: string;
		"conversation"?: Models.Conversation;
		"startTime"?: string;
		"selfUri"?: string;
	}
	
	export interface ScreenRecordingSessionListing { 
		"entities"?: Array<Models.ScreenRecordingSession>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ScreenRecordingSessionRequest { 
		"state"?: string;
		"archiveDate"?: string;
		"deleteDate"?: string;
	}
	
	export interface ScreenRecordingUserAuthenticatedInfo { 
		"backgroundAssistantId": string;
	}
	
	export interface Screenshare { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"context"?: string;
		"sharing"?: boolean;
		"peerCount"?: number;
		"disconnectType"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"provider"?: string;
		"peerId"?: string;
		"segments"?: Array<Models.Segment>;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface Script { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"versionId"?: string;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"publishedDate"?: string;
		"versionDate"?: string;
		"startPageId"?: string;
		"startPageName"?: string;
		"features"?: object;
		"variables"?: object;
		"customActions"?: object;
		"pages"?: Array<Models.Page>;
		"selfUri"?: string;
	}
	
	export interface ScriptEntityListing { 
		"entities"?: Array<Models.Script>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface ScrollPercentageEventTrigger { 
		"percentage": number;
		"eventName": string;
	}
	
	export interface SdkLibrary { 
		"name": string;
		"version": string;
	}
	
	export interface SearchAggregation { 
		"field"?: string;
		"name"?: string;
		"type"?: string;
		"value"?: string;
		"size"?: number;
		"order"?: Array<string>;
	}
	
	export interface SearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.SearchCriteria>;
		"dateFormat"?: string;
		"type"?: string;
		"fields"?: Array<string>;
	}
	
	export interface SearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"returnFields"?: Array<string>;
		"expand"?: Array<string>;
		"types": Array<string>;
		"query"?: Array<Models.SearchCriteria>;
		"aggregations"?: Array<Models.SearchAggregation>;
	}
	
	export interface SearchShiftTradeResponse { 
		"trade"?: Models.ShiftTradeResponse;
		"matchingReceivingShiftIds"?: Array<string>;
		"preview"?: Models.ShiftTradePreviewResponse;
	}
	
	export interface SearchShiftTradesRequest { 
		"receivingScheduleId": string;
		"receivingShiftIds"?: Array<string>;
	}
	
	export interface SearchShiftTradesResponse { 
		"trades"?: Array<Models.SearchShiftTradeResponse>;
		"downloadUrl"?: string;
	}
	
	export interface SearchSort { 
		"sortOrder"?: string;
		"sortBy"?: string;
	}
	
	export interface SearchUpdateRequest { 
		"sessionId"?: string;
		"answered": boolean;
		"selectedAnswer"?: Models.SelectedAnswer;
	}
	
	export interface SecondaryPresence { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface Section { 
		"fieldList"?: Array<Models.FieldList>;
		"instructionText"?: string;
		"key"?: string;
		"state"?: string;
	}
	
	export interface SecureSession { 
		"id"?: string;
		"flow": Models.DomainEntityRef;
		"userData"?: string;
		"state": string;
		"sourceParticipantId"?: string;
		"disconnect"?: boolean;
		"selfUri"?: string;
	}
	
	export interface SecureSessionEntityListing { 
		"entities"?: Array<Models.SecureSession>;
	}
	
	export interface SecurityProfile { 
		"id"?: string;
		"name"?: string;
		"permissions"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface SecurityProfileEntityListing { 
		"entities"?: Array<Models.SecurityProfile>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Segment { 
		"startTime": string;
		"endTime": string;
		"type"?: string;
		"howEnded"?: string;
		"disconnectType"?: string;
	}
	
	export interface SegmentAssignmentEvent { 
		"segment": Models.AddressableEntityRef;
	}
	
	export interface SegmentDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.SegmentDetailQueryPredicate>;
	}
	
	export interface SegmentDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.SegmentDetailQueryClause>;
		"predicates"?: Array<Models.SegmentDetailQueryPredicate>;
	}
	
	export interface SegmentDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"propertyType"?: string;
		"property"?: string;
		"metric"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface SegmentEstimateCount { 
		"segmentId"?: string;
		"count"?: number;
	}
	
	export interface SegmentListing { 
		"entities"?: Array<Models.JourneySegment>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SegmentUrl { 
		"recording"?: Models.AddressableEntityRef;
		"url"?: string;
	}
	
	export interface SelectedAnswer { 
		"document": Models.AddressableEntityRef;
	}
	
	export interface SelectedColumns { 
		"columnOrder"?: number;
		"columnName"?: string;
	}
	
	export interface SelectorEventTrigger { 
		"selector": string;
		"eventName": string;
	}
	
	export interface SendAgentlessOutboundMessageRequest { 
		"fromAddress": string;
		"toAddress": string;
		"toAddressMessengerType": string;
		"textBody"?: string;
		"messagingTemplate"?: Models.MessagingTemplateRequest;
		"useExistingActiveConversation"?: boolean;
	}
	
	export interface SendAgentlessOutboundMessageResponse { 
		"id"?: string;
		"conversationId"?: string;
		"fromAddress"?: string;
		"toAddress"?: string;
		"messengerType"?: string;
		"textBody"?: string;
		"messagingTemplate"?: Models.MessagingTemplateRequest;
		"useExistingActiveConversation"?: boolean;
		"message"?: Models.MessageData;
		"timestamp"?: string;
		"selfUri"?: string;
		"user"?: Models.AddressableEntityRef;
	}
	
	export interface SendMessageBody { 
		"message": string;
		"mentions"?: Array<string>;
		"threadId"?: string;
	}
	
	export interface SentimentFeedback { 
		"id"?: string;
		"phrase": string;
		"dialect": string;
		"feedbackValue": string;
		"dateCreated"?: string;
		"createdBy"?: Models.AddressableEntityRef;
	}
	
	export interface SentimentFeedbackEntityListing { 
		"entities"?: Array<Models.SentimentFeedback>;
	}
	
	export interface SequenceSchedule { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"intervals": Array<Models.ScheduleInterval>;
		"timeZone": string;
		"sequence": Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface ServerDate { 
		"currentDate"?: string;
	}
	
	export interface ServiceContext { 
		"name"?: string;
	}
	
	export interface ServiceGoalTemplate { 
		"id"?: string;
		"name"?: string;
		"serviceLevel"?: Models.BuServiceLevel;
		"averageSpeedOfAnswer"?: Models.BuAverageSpeedOfAnswer;
		"abandonRate"?: Models.BuAbandonRate;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"impactOverride"?: Models.ServiceGoalTemplateImpactOverride;
		"selfUri"?: string;
	}
	
	export interface ServiceGoalTemplateImpactOverride { 
		"enabled": boolean;
		"impact": Models.WfmServiceGoalImpactSettings;
	}
	
	export interface ServiceGoalTemplateList { 
		"entities"?: Array<Models.ServiceGoalTemplate>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface ServiceGoalTemplateReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface ServiceLevel { 
		"percentage"?: number;
		"durationMs"?: number;
	}
	
	export interface Session { 
		"id": string;
		"customerId"?: string;
		"customerIdType"?: string;
		"type": string;
		"externalId"?: string;
		"externalUrl"?: string;
		"shortId"?: string;
		"outcomeAchievements"?: Array<Models.OutcomeAchievement>;
		"segmentAssignments"?: Array<Models.SessionSegmentAssignment>;
		"attributes"?: { [key: string]: Models.CustomEventAttribute; };
		"attributeLists"?: { [key: string]: Models.CustomEventAttributeList; };
		"browser"?: Models.Browser;
		"device"?: Models.Device;
		"geolocation"?: Models.JourneyGeolocation;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"lastPage"?: Models.JourneyPage;
		"mktCampaign"?: Models.JourneyCampaign;
		"referrer"?: Models.Referrer;
		"app"?: Models.JourneyApp;
		"sdkLibrary"?: Models.SdkLibrary;
		"networkConnectivity"?: Models.NetworkConnectivity;
		"searchTerms"?: Array<string>;
		"userAgentString"?: string;
		"durationInSeconds"?: number;
		"eventCount": number;
		"pageviewCount"?: number;
		"screenviewCount"?: number;
		"lastEvent": Models.SessionLastEvent;
		"lastConnectedQueue"?: Models.ConnectedQueue;
		"lastConnectedUser"?: Models.ConnectedUser;
		"lastUserDisposition"?: Models.ConversationUserDisposition;
		"conversationChannels"?: Array<Models.ConversationChannel>;
		"originatingDirection"?: string;
		"conversationSubject"?: string;
		"lastUserDisconnectType"?: string;
		"lastAcdOutcome"?: string;
		"authenticated": boolean;
		"selfUri"?: string;
		"createdDate": string;
		"endedDate"?: string;
		"externalContact"?: Models.AddressableEntityRef;
		"awayDate"?: string;
		"idleDate"?: string;
		"conversation"?: Models.AddressableEntityRef;
	}
	
	export interface SessionEndDetails { 
		"type"?: string;
		"reason"?: string;
	}
	
	export interface SessionLastEvent { 
		"id": string;
		"eventName": string;
		"createdDate": string;
	}
	
	export interface SessionListing { 
		"entities"?: Array<Models.Session>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface SessionSegmentAssignment { 
		"segment": Models.AssignedSegment;
		"assignedDate": string;
	}
	
	export interface SessionsResponse { 
		"entities"?: Array<Models.BotFlowSession>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface SetContentTemplateActionSettings { 
		"smsContentTemplateId": string;
		"emailContentTemplateId": string;
	}
	
	export interface SetRecordingState { 
		"recordingState"?: string;
	}
	
	export interface SetSmsPhoneNumberActionSettings { 
		"senderSmsPhoneNumber": string;
	}
	
	export interface SetTimeOffIntegrationStatusRequest { 
		"integrationStatus": string;
	}
	
	export interface SetTimeOffLimitValuesRequest { 
		"values"?: Array<Models.TimeOffLimitRange>;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface SetUuiDataRequest { 
		"uuiData"?: string;
	}
	
	export interface SetWrapperDayOfWeek { 
		"values"?: Array<string>;
	}
	
	export interface SetWrapperRoutePathRequest { 
		"values"?: Array<Models.RoutePathRequest>;
	}
	
	export interface SetWrapperString { 
		"values"?: Array<string>;
	}
	
	export interface SetWrapperSyncTimeOffProperty { 
		"values"?: Array<string>;
	}
	
	export interface SettingDirection { 
		"inbound"?: string;
		"outbound"?: string;
	}
	
	export interface Settings { 
		"communicationBasedACW"?: boolean;
		"includeNonAgentConversationSummary"?: boolean;
		"allowCallbackQueueSelection"?: boolean;
		"callbacksInheritRoutingFromInboundCall"?: boolean;
		"completeAcwWhenAgentTransitionsOffline"?: boolean;
		"totalActiveCallback"?: boolean;
	}
	
	export interface Share { 
		"id"?: string;
		"name"?: string;
		"sharedEntityType"?: string;
		"sharedEntity"?: Models.DomainEntityRef;
		"memberType"?: string;
		"member"?: Models.DomainEntityRef;
		"sharedBy"?: Models.DomainEntityRef;
		"workspace"?: Models.DomainEntityRef;
		"user"?: Models.User;
		"group"?: Models.Group;
		"selfUri"?: string;
	}
	
	export interface ShareEntityListing { 
		"entities"?: Array<Models.Share>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SharedEntity { 
		"id"?: string;
	}
	
	export interface SharedResponse { 
		"id"?: string;
		"downloadUri"?: string;
		"viewUri"?: string;
		"document"?: Models.Document;
		"share"?: Models.Share;
	}
	
	export interface ShiftStartVariance { 
		"applicableDays": Array<string>;
		"maxShiftStartVarianceMinutes": number;
	}
	
	export interface ShiftTradeActivityPreviewResponse { 
		"startDate"?: string;
		"lengthMinutes"?: number;
		"activityCodeId"?: string;
		"countsAsPaidTime"?: boolean;
		"payableMinutes"?: number;
	}
	
	export interface ShiftTradeActivityRule { 
		"activityCategory": string;
		"action": string;
		"activityCodeIdReplacement"?: string;
	}
	
	export interface ShiftTradeListResponse { 
		"entities"?: Array<Models.ShiftTradeResponse>;
	}
	
	export interface ShiftTradeMatchReviewResponse { 
		"initiatingUser"?: Models.ShiftTradeMatchReviewUserResponse;
		"receivingUser"?: Models.ShiftTradeMatchReviewUserResponse;
		"violations"?: Array<Models.ShiftTradeMatchViolation>;
		"adminReviewViolations"?: Array<Models.ShiftTradeMatchViolation>;
	}
	
	export interface ShiftTradeMatchReviewUserResponse { 
		"weeklyMinimumPaidMinutes"?: number;
		"weeklyMaximumPaidMinutes"?: number;
		"preTradeSchedulePaidMinutes"?: number;
		"postTradeSchedulePaidMinutes"?: number;
		"postTradeNewShift"?: Models.ShiftTradePreviewResponse;
	}
	
	export interface ShiftTradeMatchViolation { 
		"type"?: string;
		"params"?: { [key: string]: string; };
	}
	
	export interface ShiftTradeMatchesSummaryResponse { 
		"entities"?: Array<Models.WeekShiftTradeMatchesSummaryResponse>;
	}
	
	export interface ShiftTradeNotification { 
		"weekDate"?: string;
		"tradeId"?: string;
		"oneSided"?: boolean;
		"newState"?: string;
		"initiatingUser"?: Models.UserReference;
		"initiatingShiftDate"?: string;
		"receivingUser"?: Models.UserReference;
		"receivingShiftDate"?: string;
	}
	
	export interface ShiftTradePreviewResponse { 
		"activities"?: Array<Models.ShiftTradeActivityPreviewResponse>;
	}
	
	export interface ShiftTradeResponse { 
		"id"?: string;
		"weekDate"?: string;
		"schedule"?: Models.BuScheduleReferenceForMuRoute;
		"state"?: string;
		"initiatingUser"?: Models.UserReference;
		"initiatingShiftId"?: string;
		"initiatingShiftStart"?: string;
		"initiatingShiftEnd"?: string;
		"receivingUser"?: Models.UserReference;
		"receivingShiftId"?: string;
		"receivingShiftStart"?: string;
		"receivingShiftEnd"?: string;
		"expiration"?: string;
		"oneSided"?: boolean;
		"acceptableIntervals"?: Array<string>;
		"reviewedBy"?: Models.UserReference;
		"reviewedDate"?: string;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface ShiftTradeSettings { 
		"enabled"?: boolean;
		"autoReview"?: boolean;
		"allowDirectTrades"?: boolean;
		"minHoursInFuture"?: number;
		"unequalPaid"?: string;
		"oneSided"?: string;
		"weeklyMinPaidViolations"?: string;
		"weeklyMaxPaidViolations"?: string;
		"requiresMatchingQueues"?: boolean;
		"requiresMatchingLanguages"?: boolean;
		"requiresMatchingSkills"?: boolean;
		"requiresMatchingPlanningGroups"?: boolean;
		"activityCategoryRules"?: Array<Models.ShiftTradeActivityRule>;
	}
	
	export interface ShortTermForecastReference { 
		"id"?: string;
		"selfUri"?: string;
		"weekDate": string;
		"description"?: string;
	}
	
	export interface ShortTermForecastingSettings { 
		"defaultHistoryWeeks"?: number;
	}
	
	export interface ShrinkageOverride { 
		"intervalIndex": number;
		"shrinkagePercent"?: number;
	}
	
	export interface ShrinkageOverrides { 
		"clear"?: boolean;
		"values"?: Array<Models.ShrinkageOverride>;
	}
	
	export interface Signature { 
		"enabled"?: boolean;
		"cannedResponseId"?: string;
		"alwaysIncluded"?: boolean;
		"inclusionType"?: string;
	}
	
	export interface SignedData { 
		"jwt"?: string;
	}
	
	export interface SignedUrlResponse { 
		"id"?: string;
		"name"?: string;
		"url"?: string;
		"selfUri"?: string;
	}
	
	export interface SingleWorkdayAveragePoints { 
		"dateWorkday"?: string;
		"division"?: Models.Division;
		"averagePoints"?: number;
		"performanceProfile"?: Models.AddressableEntityRef;
	}
	
	export interface SingleWorkdayAverageValues { 
		"dateWorkday"?: string;
		"division"?: Models.Division;
		"user"?: Models.UserReference;
		"timezone"?: string;
		"results"?: Array<Models.WorkdayValuesMetricItem>;
		"performanceProfile"?: Models.AddressableEntityRef;
	}
	
	export interface SipDownloadResponse { 
		"downloadId"?: string;
		"documentId"?: string;
	}
	
	export interface SipSearchResult { 
		"id"?: string;
		"status"?: number;
		"sid"?: string;
		"auth"?: string;
		"message"?: string;
		"data"?: Array<Models.HomerRecord>;
		"count"?: number;
		"selfUri"?: string;
	}
	
	export interface Site { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"primarySites"?: Array<Models.DomainEntityRef>;
		"secondarySites"?: Array<Models.DomainEntityRef>;
		"primaryEdges"?: Array<Models.Edge>;
		"secondaryEdges"?: Array<Models.Edge>;
		"addresses"?: Array<Models.Contact>;
		"edges"?: Array<Models.Edge>;
		"edgeAutoUpdateConfig"?: Models.EdgeAutoUpdateConfig;
		"mediaRegionsUseLatencyBased"?: boolean;
		"location": Models.LocationDefinition;
		"managed"?: boolean;
		"ntpSettings"?: Models.NTPSettings;
		"mediaModel"?: string;
		"coreSite"?: boolean;
		"siteConnections"?: Array<Models.SiteConnection>;
		"mediaRegions"?: Array<string>;
		"callerId"?: string;
		"callerName"?: string;
		"cloudProxyForceTurn"?: boolean;
		"selfUri"?: string;
	}
	
	export interface SiteConnection { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
		"managed"?: boolean;
		"type"?: string;
		"enabled"?: boolean;
		"mediaModel"?: string;
		"edgeList"?: Array<Models.ConnectedEdge>;
		"coreSite"?: boolean;
		"primaryCoreSites"?: Array<Models.DomainEntityRef>;
		"secondaryCoreSites"?: Array<Models.DomainEntityRef>;
	}
	
	export interface SiteConnections { 
		"id"?: string;
		"name"?: string;
		"siteConnections"?: Array<Models.SiteConnection>;
		"selfUri"?: string;
	}
	
	export interface SiteEntityListing { 
		"entities"?: Array<Models.Site>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SkillEntityListing { 
		"entities"?: Array<Models.RoutingSkill>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SkillGroup { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"memberCount"?: number;
		"dateModified"?: string;
		"dateCreated"?: string;
		"status"?: string;
		"skillConditions": Array<Models.SkillGroupCondition>;
		"selfUri"?: string;
	}
	
	export interface SkillGroupCondition { 
		"routingSkillConditions": Array<Models.SkillGroupRoutingCondition>;
		"languageSkillConditions": Array<Models.SkillGroupLanguageCondition>;
		"operation": string;
	}
	
	export interface SkillGroupDefinition { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"memberCount"?: number;
		"dateModified"?: string;
		"dateCreated"?: string;
		"selfUri"?: string;
	}
	
	export interface SkillGroupEntityListing { 
		"entities"?: Array<Models.SkillGroupDefinition>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface SkillGroupLanguageCondition { 
		"languageSkill": string;
		"comparator": string;
		"proficiency": number;
		"childConditions"?: Array<Models.SkillGroupCondition>;
	}
	
	export interface SkillGroupMemberDivisionList { 
		"entities"?: Array<Models.Division>;
	}
	
	export interface SkillGroupMemberDivisions { 
		"addDivisionIds"?: Array<string>;
		"removeDivisionIds"?: Array<string>;
	}
	
	export interface SkillGroupMemberEntityListing { 
		"entities"?: Array<Models.UserReferenceWithName>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface SkillGroupRoutingCondition { 
		"routingSkill": string;
		"comparator": string;
		"proficiency": number;
		"childConditions"?: Array<Models.SkillGroupCondition>;
	}
	
	export interface SkillGroupWithMemberDivisions { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"memberCount"?: number;
		"dateModified"?: string;
		"dateCreated"?: string;
		"status"?: string;
		"skillConditions": Array<Models.SkillGroupCondition>;
		"memberDivisions"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface SkillsToRemove { 
		"name"?: string;
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface SmsAddress { 
		"id"?: string;
		"name"?: string;
		"street"?: string;
		"city"?: string;
		"region"?: string;
		"postalCode"?: string;
		"countryCode"?: string;
		"validated"?: boolean;
		"selfUri"?: string;
	}
	
	export interface SmsAddressEntityListing { 
		"entities"?: Array<Models.SmsAddress>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SmsAddressProvision { 
		"id"?: string;
		"name": string;
		"street": string;
		"city": string;
		"region": string;
		"postalCode": string;
		"countryCode": string;
		"autoCorrectAddress"?: boolean;
		"selfUri"?: string;
	}
	
	export interface SmsAlphanumericProvision { 
		"id"?: string;
		"phoneNumber": string;
		"selfUri"?: string;
	}
	
	export interface SmsAvailablePhoneNumber { 
		"id"?: string;
		"name"?: string;
		"phoneNumber"?: string;
		"countryCode"?: string;
		"region"?: string;
		"city"?: string;
		"capabilities"?: Array<string>;
		"phoneNumberType"?: string;
		"addressRequirement"?: string;
		"selfUri"?: string;
	}
	
	export interface SmsConfig { 
		"messageColumn": string;
		"phoneColumn": string;
		"senderSmsPhoneNumber": Models.SmsPhoneNumberRef;
		"contentTemplate"?: Models.DomainEntityRef;
	}
	
	export interface SmsPhoneNumber { 
		"id"?: string;
		"name"?: string;
		"phoneNumber": string;
		"phoneNumberType"?: string;
		"provisionedThroughPureCloud"?: boolean;
		"phoneNumberStatus"?: string;
		"capabilities"?: Array<string>;
		"countryCode"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.User;
		"modifiedBy"?: Models.User;
		"version": number;
		"purchaseDate"?: string;
		"cancellationDate"?: string;
		"renewalDate"?: string;
		"autoRenewable"?: string;
		"addressId"?: Models.SmsAddress;
		"shortCodeBillingType"?: string;
		"provisioningStatus"?: Models.SmsProvisioningStatus;
		"country"?: string;
		"supportsSms"?: boolean;
		"supportsMms"?: boolean;
		"supportsVoice"?: boolean;
		"integration"?: Models.DomainEntityRef;
		"compliance"?: Models.Compliance;
		"selfUri"?: string;
	}
	
	export interface SmsPhoneNumberEntityListing { 
		"entities"?: Array<Models.SmsPhoneNumber>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SmsPhoneNumberImport { 
		"id"?: string;
		"phoneNumber": string;
		"phoneNumberType": string;
		"countryCode": string;
		"integrationId": string;
		"compliance"?: Models.Compliance;
		"selfUri"?: string;
	}
	
	export interface SmsPhoneNumberProvision { 
		"id"?: string;
		"phoneNumber": string;
		"phoneNumberType": string;
		"countryCode": string;
		"name"?: string;
		"addressId"?: string;
		"selfUri"?: string;
	}
	
	export interface SmsPhoneNumberRef { 
		"phoneNumber": string;
		"selfUri"?: string;
	}
	
	export interface SmsProvisioningStatus { 
		"action"?: string;
		"state"?: string;
		"error"?: Models.ErrorBody;
		"version"?: number;
	}
	
	export interface SocialExpression { 
		"state"?: string;
		"id"?: string;
		"socialMediaId"?: string;
		"socialMediaHub"?: string;
		"socialUserName"?: string;
		"previewText"?: string;
		"recordingId"?: string;
		"segments"?: Array<Models.Segment>;
		"held"?: boolean;
		"disconnectType"?: string;
		"startHoldTime"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"provider"?: string;
		"scriptId"?: string;
		"peerId"?: string;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface SocialHandle { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface SortItem { 
		"name"?: string;
		"ascending"?: boolean;
	}
	
	export interface Source { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"type"?: string;
		"deactivated"?: boolean;
		"selfUri"?: string;
	}
	
	export interface SourceConfiguration { 
		"sourceId": string;
		"interactionId": string;
		"tagId"?: string;
	}
	
	export interface SourceEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.Source>;
		"selfUri"?: string;
	}
	
	export interface SourcePlanningGroupRequest { 
		"id": string;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface SpeechTextAnalyticsSettingsRequest { 
		"defaultProgramId"?: string;
		"expectedDialects"?: Array<string>;
		"textAnalyticsEnabled"?: boolean;
		"agentEmpathyEnabled"?: boolean;
	}
	
	export interface SpeechTextAnalyticsSettingsResponse { 
		"defaultProgram"?: Models.AddressableEntityRef;
		"expectedDialects"?: Array<string>;
		"textAnalyticsEnabled"?: boolean;
		"agentEmpathyEnabled"?: boolean;
	}
	
	export interface SplittingInformation { 
		"criteria"?: string;
		"criteriaValue"?: string;
		"createRemainderContactList"?: boolean;
		"useWaterfallRule"?: boolean;
	}
	
	export interface StaffingGroupListing { 
		"entities"?: Array<Models.StaffingGroupResponse>;
	}
	
	export interface StaffingGroupReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface StaffingGroupResponse { 
		"id"?: string;
		"name": string;
		"users"?: Array<Models.UserReference>;
		"managementUnit"?: Models.ManagementUnitReference;
		"metadata": Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface StaffingRequirementsPlanningGroupData { 
		"planningGroupId": string;
		"staffingRequirementsPerInterval": Array<number>;
	}
	
	export interface StarrableDivision { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface StatEventCampaignTopicIntervalMetrics { 
		"interval"?: string;
		"metrics"?: Array<Models.StatEventCampaignTopicMetricStats>;
	}
	
	export interface StatEventCampaignTopicMetricStats { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: { [key: string]: number; };
	}
	
	export interface StatEventCampaignTopicStatsNotification { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatEventCampaignTopicIntervalMetrics>;
	}
	
	export interface StatEventFlowOutcomeTopicIntervalMetrics { 
		"interval"?: string;
		"metrics"?: Array<Models.StatEventFlowOutcomeTopicMetricStats>;
	}
	
	export interface StatEventFlowOutcomeTopicMetricStats { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: { [key: string]: number; };
	}
	
	export interface StatEventFlowOutcomeTopicStatsNotification { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatEventFlowOutcomeTopicIntervalMetrics>;
	}
	
	export interface StatEventFlowTopicIntervalMetrics { 
		"interval"?: string;
		"metrics"?: Array<Models.StatEventFlowTopicMetricStats>;
	}
	
	export interface StatEventFlowTopicMetricStats { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: { [key: string]: number; };
	}
	
	export interface StatEventFlowTopicStatsNotification { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatEventFlowTopicIntervalMetrics>;
	}
	
	export interface StatEventQueueTopicIntervalMetrics { 
		"interval"?: string;
		"metrics"?: Array<Models.StatEventQueueTopicMetricStats>;
	}
	
	export interface StatEventQueueTopicMetricStats { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: { [key: string]: number; };
	}
	
	export interface StatEventQueueTopicStatsNotification { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatEventQueueTopicIntervalMetrics>;
	}
	
	export interface StatEventUserTopicIntervalMetrics { 
		"interval"?: string;
		"metrics"?: Array<Models.StatEventUserTopicMetricStats>;
	}
	
	export interface StatEventUserTopicMetricStats { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: { [key: string]: number; };
	}
	
	export interface StatEventUserTopicStatsNotification { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatEventUserTopicIntervalMetrics>;
	}
	
	export interface StatEventWrapUpCodeTopicIntervalMetrics { 
		"interval"?: string;
		"metrics"?: Array<Models.StatEventWrapUpCodeTopicMetricStats>;
	}
	
	export interface StatEventWrapUpCodeTopicMetricStats { 
		"metric"?: string;
		"qualifier"?: string;
		"stats"?: { [key: string]: number; };
	}
	
	export interface StatEventWrapUpCodeTopicStatsNotification { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatEventWrapUpCodeTopicIntervalMetrics>;
	}
	
	export interface Station { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"status"?: string;
		"userId"?: string;
		"webRtcUserId"?: string;
		"primaryEdge"?: Models.DomainEntityRef;
		"secondaryEdge"?: Models.DomainEntityRef;
		"type"?: string;
		"lineAppearanceId"?: string;
		"webRtcMediaDscp"?: number;
		"webRtcPersistentEnabled"?: boolean;
		"webRtcForceTurn"?: boolean;
		"webRtcCallAppearances"?: number;
		"webRtcRequireMediaHelper"?: boolean;
		"selfUri"?: string;
	}
	
	export interface StationEntityListing { 
		"entities"?: Array<Models.Station>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface StatisticalResponse { 
		"interval"?: string;
		"metrics"?: Array<Models.AggregateMetricData>;
		"views"?: Array<Models.AggregateViewData>;
	}
	
	export interface StatisticalSummary { 
		"max"?: number;
		"min"?: number;
		"count"?: number;
		"countNegative"?: number;
		"countPositive"?: number;
		"sum"?: number;
		"current"?: number;
		"ratio"?: number;
		"numerator"?: number;
		"denominator"?: number;
		"target"?: number;
		"p95"?: number;
		"p99"?: number;
	}
	
	export interface StatusChange { 
		"dateStatusChanged"?: string;
		"status"?: string;
		"previousStatus"?: string;
		"namespace"?: string;
		"message"?: string;
		"rejectReason"?: string;
	}
	
	export interface StopSettings { 
		"keyword": Array<string>;
		"response": Models.ComplianceResponse;
	}
	
	export interface StorySetting { 
		"mention"?: Models.InboundOnlySetting;
		"reply"?: Models.InboundOnlySetting;
	}
	
	export interface StreetAddress { 
		"country": string;
		"A1": string;
		"A3": string;
		"RD": string;
		"HNO": string;
		"LOC"?: string;
		"NAM"?: string;
		"PC": string;
	}
	
	export interface SttEngineEntity { 
		"id"?: string;
		"name"?: string;
		"grammarBased"?: boolean;
		"selfUri"?: string;
	}
	
	export interface SttEngineEntityListing { 
		"entities"?: Array<Models.SttEngineEntity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SubjectDivisionGrants { 
		"id"?: string;
		"name"?: string;
		"divisions"?: Array<Models.Division>;
		"type"?: string;
		"selfUri"?: string;
	}
	
	export interface SubjectDivisionGrantsEntityListing { 
		"entities"?: Array<Models.SubjectDivisionGrants>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SubjectDivisions { 
		"subjectIds": Array<string>;
		"divisionIds": Array<string>;
	}
	
	export interface SubscriberResponse { 
		"messageReturned"?: Array<string>;
		"status": string;
	}
	
	export interface Subscription { 
		"id"?: string;
		"topic"?: string;
	}
	
	export interface SubscriptionOverviewUsage { 
		"name": string;
		"partNumber": string;
		"grouping": string;
		"unitOfMeasureType": string;
		"usageQuantity": string;
		"overagePrice"?: string;
		"prepayQuantity": string;
		"prepayPrice"?: string;
		"usageNotes"?: string;
		"isCancellable"?: boolean;
		"bundleQuantity"?: string;
		"isThirdParty"?: boolean;
	}
	
	export interface SuggestSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.SuggestSearchCriteria>;
		"dateFormat"?: string;
		"fields"?: Array<string>;
	}
	
	export interface SuggestSearchRequest { 
		"expand"?: Array<string>;
		"types": Array<string>;
		"query": Array<Models.SuggestSearchCriteria>;
	}
	
	export interface SupportCenterCategory { 
		"id"?: string;
		"selfUri"?: string;
		"image"?: Models.SupportCenterImage;
	}
	
	export interface SupportCenterCompactCategoryModuleTemplate { 
		"active": boolean;
	}
	
	export interface SupportCenterCustomMessage { 
		"defaultValue": string;
		"type": string;
	}
	
	export interface SupportCenterDetailedCategoryModuleSidebar { 
		"enabled": boolean;
	}
	
	export interface SupportCenterDetailedCategoryModuleTemplate { 
		"active": boolean;
		"sidebar": Models.SupportCenterDetailedCategoryModuleSidebar;
	}
	
	export interface SupportCenterFeedbackSettings { 
		"enabled": boolean;
	}
	
	export interface SupportCenterGlobalStyle { 
		"backgroundColor": string;
		"primaryColor": string;
		"primaryColorDark": string;
		"primaryColorLight": string;
		"textColor": string;
		"fontFamily": string;
	}
	
	export interface SupportCenterHeroStyle { 
		"backgroundColor": string;
		"textColor": string;
		"image"?: Models.SupportCenterImage;
	}
	
	export interface SupportCenterImage { 
		"source": Models.SupportCenterImageSource;
	}
	
	export interface SupportCenterImageSource { 
		"defaultUrl": string;
	}
	
	export interface SupportCenterModuleSetting { 
		"type": string;
		"enabled": boolean;
		"compactCategoryModuleTemplate"?: Models.SupportCenterCompactCategoryModuleTemplate;
		"detailedCategoryModuleTemplate"?: Models.SupportCenterDetailedCategoryModuleTemplate;
	}
	
	export interface SupportCenterScreen { 
		"type": string;
		"moduleSettings": Array<Models.SupportCenterModuleSetting>;
	}
	
	export interface SupportCenterSettings { 
		"enabled": boolean;
		"knowledgeBase": Models.AddressableEntityRef;
		"customMessages"?: Array<Models.SupportCenterCustomMessage>;
		"routerType"?: string;
		"screens": Array<Models.SupportCenterScreen>;
		"enabledCategories": Array<Models.SupportCenterCategory>;
		"styleSetting": Models.SupportCenterStyleSetting;
		"feedback"?: Models.SupportCenterFeedbackSettings;
	}
	
	export interface SupportCenterStyleSetting { 
		"heroStyle": Models.SupportCenterHeroStyle;
		"globalStyle": Models.SupportCenterGlobalStyle;
	}
	
	export interface SupportedContent { 
		"id": string;
		"name": string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version"?: number;
		"mediaTypes"?: Models.MediaTypes;
		"selfUri"?: string;
	}
	
	export interface SupportedContentListing { 
		"entities"?: Array<Models.SupportedContent>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SupportedContentReference { 
		"id": string;
		"name"?: string;
		"selfUri"?: string;
		"mediaTypes"?: Models.MediaTypes;
	}
	
	export interface SupportedDialectsEntityListing { 
		"entities"?: Array<Models.SupportedDialectsTranscriptionEngine>;
	}
	
	export interface SupportedDialectsTranscriptionEngine { 
		"engine"?: string;
		"dialects"?: Array<string>;
		"engineIntegration"?: Models.EngineIntegration;
	}
	
	export interface SupportedEntityTypeStatus { 
		"listSlotType"?: string;
	}
	
	export interface SupportedLanguage { 
		"language"?: string;
		"isDefault"?: boolean;
	}
	
	export interface SupportedLanguagesInfoDefinition { 
		"language"?: string;
		"intentClassification"?: boolean;
		"status"?: string;
		"supportedEntityTypes"?: Array<string>;
		"supportedEntityTypeConfiguration"?: Models.SupportedEntityTypeStatus;
	}
	
	export interface Survey { 
		"id"?: string;
		"name"?: string;
		"conversation"?: Models.ConversationReference;
		"surveyForm"?: Models.SurveyForm;
		"agent"?: Models.DomainEntityRef;
		"status"?: string;
		"queue"?: Models.QueueReference;
		"answers"?: Models.SurveyScoringSet;
		"completedDate"?: string;
		"surveyErrorDetails"?: Models.SurveyErrorDetails;
		"agentTeam"?: Models.Team;
		"selfUri"?: string;
	}
	
	export interface SurveyAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface SurveyAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.SurveyAggregateQueryPredicate>;
	}
	
	export interface SurveyAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.SurveyAggregateQueryClause>;
		"predicates"?: Array<Models.SurveyAggregateQueryPredicate>;
	}
	
	export interface SurveyAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface SurveyAggregateQueryResponse { 
		"results"?: Array<Models.SurveyAggregateDataContainer>;
	}
	
	export interface SurveyAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.SurveyAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.SurveyAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface SurveyAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface SurveyAssignment { 
		"surveyForm"?: Models.PublishedSurveyFormReference;
		"flow"?: Models.DomainEntityRef;
		"inviteTimeInterval"?: string;
		"sendingUser"?: string;
		"sendingDomain": string;
	}
	
	export interface SurveyAsyncAggregateQueryResponse { 
		"results"?: Array<Models.SurveyAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface SurveyAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.SurveyAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.SurveyAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface SurveyDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.SurveyDetailQueryPredicate>;
	}
	
	export interface SurveyDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.SurveyDetailQueryClause>;
		"predicates"?: Array<Models.SurveyDetailQueryPredicate>;
	}
	
	export interface SurveyDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"metric"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface SurveyErrorDetails { 
		"flowDiagnosticInfo"?: Models.FlowDiagnosticInfo;
		"surveyErrorReason"?: string;
	}
	
	export interface SurveyForm { 
		"id"?: string;
		"name": string;
		"modifiedDate"?: string;
		"published"?: boolean;
		"disabled"?: boolean;
		"contextId": string;
		"language": string;
		"header"?: string;
		"footer"?: string;
		"questionGroups"?: Array<Models.SurveyQuestionGroup>;
		"publishedVersions"?: Models.DomainEntityListingSurveyForm;
		"selfUri"?: string;
	}
	
	export interface SurveyFormAndScoringSet { 
		"surveyForm"?: Models.SurveyForm;
		"answers"?: Models.SurveyScoringSet;
	}
	
	export interface SurveyFormEntityListing { 
		"entities"?: Array<Models.SurveyForm>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SurveyQuestion { 
		"id"?: string;
		"text"?: string;
		"helpText"?: string;
		"type"?: string;
		"naEnabled"?: boolean;
		"visibilityCondition"?: Models.VisibilityCondition;
		"answerOptions"?: Array<Models.AnswerOption>;
		"maxResponseCharacters"?: number;
		"explanationPrompt"?: string;
	}
	
	export interface SurveyQuestionGroup { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"naEnabled"?: boolean;
		"questions"?: Array<Models.SurveyQuestion>;
		"visibilityCondition"?: Models.VisibilityCondition;
	}
	
	export interface SurveyQuestionGroupScore { 
		"questionGroupId"?: string;
		"totalScore"?: number;
		"maxTotalScore"?: number;
		"markedNA"?: boolean;
		"systemMarkedNA"?: boolean;
		"questionScores"?: Array<Models.SurveyQuestionScore>;
	}
	
	export interface SurveyQuestionScore { 
		"questionId"?: string;
		"answerId"?: string;
		"score"?: number;
		"markedNA"?: boolean;
		"systemMarkedNA"?: boolean;
		"assistedAnswerId"?: string;
		"npsScore"?: number;
		"npsTextAnswer"?: string;
		"freeTextAnswer"?: string;
	}
	
	export interface SurveyScoringSet { 
		"totalScore"?: number;
		"npsScore"?: number;
		"questionGroupScores"?: Array<Models.SurveyQuestionGroupScore>;
	}
	
	export interface SystemMessageObject { 
	}
	
	export interface SystemMessageSystemMessage { 
		"channelId"?: string;
		"systemTopicType"?: string;
		"correlationId"?: string;
		"organizationId"?: string;
		"userId"?: string;
		"oauthClientId"?: string;
		"reason"?: string;
		"message"?: string;
		"data"?: { [key: string]: object; };
	}
	
	export interface SystemPresence { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface SystemPrompt { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"resources"?: Array<Models.SystemPromptAsset>;
		"selfUri"?: string;
	}
	
	export interface SystemPromptAsset { 
		"id"?: string;
		"name"?: string;
		"promptId"?: string;
		"language": string;
		"durationSeconds"?: number;
		"mediaUri"?: string;
		"ttsString"?: string;
		"text"?: string;
		"uploadUri"?: string;
		"uploadStatus"?: string;
		"hasDefault"?: boolean;
		"languageDefault"?: boolean;
		"tags"?: { [key: string]: Array<string>; };
		"selfUri"?: string;
	}
	
	export interface SystemPromptAssetEntityListing { 
		"entities"?: Array<Models.SystemPromptAsset>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface SystemPromptEntityListing { 
		"entities"?: Array<Models.SystemPrompt>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TagQueryRequest { 
		"query"?: string;
		"pageNumber"?: number;
		"pageSize"?: number;
	}
	
	export interface TagValue { 
		"id"?: string;
		"name": string;
		"inUse"?: boolean;
		"acl"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface TagValueEntityListing { 
		"entities"?: Array<Models.TagValue>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TargetPerformanceProfile { 
		"targetPerformanceProfileId": string;
	}
	
	export interface TaskManagementAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface TaskManagementAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.TaskManagementAggregateQueryPredicate>;
	}
	
	export interface TaskManagementAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.TaskManagementAggregateQueryClause>;
		"predicates"?: Array<Models.TaskManagementAggregateQueryPredicate>;
	}
	
	export interface TaskManagementAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface TaskManagementAggregateQueryResponse { 
		"results"?: Array<Models.TaskManagementAggregateDataContainer>;
	}
	
	export interface TaskManagementAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.TaskManagementAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.TaskManagementAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface TaskManagementAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface TaskManagementAsyncAggregateQueryResponse { 
		"results"?: Array<Models.TaskManagementAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface TaskManagementAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.TaskManagementAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.TaskManagementAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface TaskManagementErrorDetails { 
		"code"?: string;
		"message"?: string;
	}
	
	export interface Team { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableDivision;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"memberCount"?: number;
		"selfUri"?: string;
	}
	
	export interface TeamActivityData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.TeamActivityMetricValue>;
		"truncated"?: boolean;
		"entities"?: Array<Models.TeamActivityEntityData>;
	}
	
	export interface TeamActivityEntityData { 
		"activityDate": string;
		"organizationPresenceId"?: string;
		"presenceDate"?: string;
		"queueId"?: string;
		"queueMembershipStatus"?: string;
		"routingStatus"?: string;
		"routingStatusDate"?: string;
		"systemPresence"?: string;
		"teamId"?: string;
		"userId"?: string;
	}
	
	export interface TeamActivityMetricValue { 
		"metric"?: string;
		"count"?: number;
	}
	
	export interface TeamActivityQuery { 
		"metrics": Array<Models.TeamActivityQueryMetric>;
		"groupBy": Array<string>;
		"filter"?: Models.TeamActivityQueryFilter;
		"order"?: string;
	}
	
	export interface TeamActivityQueryClause { 
		"type": string;
		"predicates": Array<Models.TeamActivityQueryPredicate>;
	}
	
	export interface TeamActivityQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.TeamActivityQueryClause>;
		"predicates"?: Array<Models.TeamActivityQueryPredicate>;
	}
	
	export interface TeamActivityQueryMetric { 
		"metric": string;
		"details"?: boolean;
	}
	
	export interface TeamActivityQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
	}
	
	export interface TeamActivityResponse { 
		"results"?: Array<Models.TeamActivityData>;
		"entityIdDimension"?: string;
	}
	
	export interface TeamAddMemberFailure { 
		"id"?: string;
		"reason"?: string;
	}
	
	export interface TeamEntityListing { 
		"entities"?: Array<Models.Team>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface TeamMemberAddListingResponse { 
		"entities"?: Array<Models.UserReference>;
		"failures"?: Array<Models.TeamAddMemberFailure>;
	}
	
	export interface TeamMemberEntityListing { 
		"entities"?: Array<Models.UserReferenceWithName>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface TeamMembers { 
		"memberIds": Array<string>;
	}
	
	export interface TeamReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface TeamSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.TeamSearchCriteria>;
		"dateFormat"?: string;
		"fields"?: Array<string>;
		"type": string;
	}
	
	export interface TeamSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"query": Array<Models.TeamSearchCriteria>;
	}
	
	export interface TeamsSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.Team>;
	}
	
	export interface TemplateParameter { 
		"id"?: string;
		"value"?: string;
	}
	
	export interface TermAttribute { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
	}
	
	export interface TestExecutionOperationResult { 
		"step"?: number;
		"name"?: string;
		"success"?: boolean;
		"result"?: object;
		"error"?: Models.ErrorBody;
	}
	
	export interface TestExecutionResult { 
		"operations"?: Array<Models.TestExecutionOperationResult>;
		"error"?: Models.ErrorBody;
		"finalResult"?: object;
		"success"?: boolean;
	}
	
	export interface TestMatchesEventOperation { 
		"name"?: string;
		"step"?: number;
		"matchedTriggers"?: Array<Models.TestModeTrigger>;
		"unmatchedTriggers"?: Array<Models.TestModeTrigger>;
	}
	
	export interface TestMatchesOperation { 
		"name"?: string;
		"step"?: number;
		"matches"?: boolean;
		"details"?: Array<Models.MatchCriteriaTestResult>;
	}
	
	export interface TestMessage { 
		"id"?: string;
		"to": Array<Models.EmailAddress>;
		"from": Models.EmailAddress;
		"subject"?: string;
		"textBody": string;
		"htmlBody"?: string;
		"time"?: string;
	}
	
	export interface TestModeEventResults { 
		"schemaValidation"?: Models.TestSchemaOperation;
		"triggerMatchValidation"?: Models.TestMatchesEventOperation;
	}
	
	export interface TestModeResults { 
		"schemaValidation"?: Models.TestSchemaOperation;
		"targetValidation"?: Models.TestTargetOperation;
		"jsonPathValidation"?: Models.TestMatchesOperation;
		"triggerMatches"?: boolean;
	}
	
	export interface TestModeTrigger { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"selfUri"?: string;
	}
	
	export interface TestSchemaOperation { 
		"name"?: string;
		"step"?: number;
		"matches"?: boolean;
		"details"?: Array<string>;
	}
	
	export interface TestTargetOperation { 
		"name"?: string;
		"step"?: number;
		"matches"?: boolean;
		"details"?: Array<string>;
	}
	
	export interface TextBotChannel { 
		"name": string;
		"inputModes": Array<string>;
		"outputModes": Array<string>;
		"userAgent": Models.TextBotUserAgent;
	}
	
	export interface TextBotDisconnectAction { 
		"reason": string;
		"reasonExtendedInfo"?: string;
		"flowLocation"?: Models.TextBotFlowLocation;
		"flowOutcomes"?: Array<Models.TextBotFlowOutcome>;
	}
	
	export interface TextBotErrorInputEvent { 
		"code": string;
		"message": string;
	}
	
	export interface TextBotExitAction { 
		"reason": string;
		"reasonExtendedInfo"?: string;
		"activeIntent"?: string;
		"flowLocation"?: Models.TextBotFlowLocation;
		"outputData"?: Models.TextBotInputOutputData;
		"flowOutcomes"?: Array<Models.TextBotFlowOutcome>;
	}
	
	export interface TextBotFlow { 
		"id": string;
	}
	
	export interface TextBotFlowLaunchRequest { 
		"flow": Models.TextBotFlow;
		"externalSessionId": string;
		"conversationId"?: string;
		"inputData"?: Models.TextBotInputOutputData;
		"channel": Models.TextBotChannel;
		"language"?: string;
	}
	
	export interface TextBotFlowLaunchResponse { 
		"id": string;
	}
	
	export interface TextBotFlowLocation { 
		"actionName": string;
		"actionNumber": number;
		"sequenceName": string;
	}
	
	export interface TextBotFlowMilestone { 
		"id": string;
		"dateReached": string;
		"sequence": number;
	}
	
	export interface TextBotFlowOutcome { 
		"outcomeId"?: string;
		"outcomeValue"?: string;
		"dateStart"?: string;
		"dateEnd"?: string;
		"milestones"?: Array<Models.TextBotFlowMilestone>;
	}
	
	export interface TextBotFlowTurnRequest { 
		"previousTurn"?: Models.TextBotTurnReference;
		"inputEventType": string;
		"inputEventUserInput"?: Models.TextBotUserInputEvent;
		"inputEventError"?: Models.TextBotErrorInputEvent;
	}
	
	export interface TextBotFlowTurnResponse { 
		"id": string;
		"previousTurn"?: Models.TextBotTurnReference;
		"prompts"?: Models.TextBotOutputPrompts;
		"nextActionType": string;
		"nextActionDisconnect"?: Models.TextBotDisconnectAction;
		"nextActionWaitForInput"?: Models.TextBotWaitForInputAction;
		"nextActionExit"?: Models.TextBotExitAction;
	}
	
	export interface TextBotInputOutputData { 
		"variables": { [key: string]: object; };
	}
	
	export interface TextBotModeConstraints { 
		"text"?: Models.TextBotTextModeConstraints;
	}
	
	export interface TextBotModeOutputPrompts { 
		"segments": Array<Models.TextBotPromptSegment>;
	}
	
	export interface TextBotOutputPrompts { 
		"outputLanguage": string;
		"textPrompts"?: Models.TextBotModeOutputPrompts;
	}
	
	export interface TextBotPromptSegment { 
		"text": string;
		"type": string;
		"format"?: Models.Format;
		"content"?: Array<Models.MessageContent>;
	}
	
	export interface TextBotTextModeConstraints { 
		"languagePreferences": Array<string>;
		"noInputTimeoutMilliseconds"?: number;
	}
	
	export interface TextBotTranscript { 
		"text": string;
		"confidence"?: number;
	}
	
	export interface TextBotTurnReference { 
		"id": string;
	}
	
	export interface TextBotUserAgent { 
		"name": string;
	}
	
	export interface TextBotUserInputAlternative { 
		"transcript": Models.TextBotTranscript;
	}
	
	export interface TextBotUserInputEvent { 
		"mode": string;
		"alternatives": Array<Models.TextBotUserInputAlternative>;
	}
	
	export interface TextBotWaitForInputAction { 
		"modeConstraints": Models.TextBotModeConstraints;
	}
	
	export interface TextMessageListing { 
		"entities"?: Array<Models.MessageData>;
	}
	
	export interface TextStyleProperties { 
		"color"?: string;
		"font"?: string;
		"fontSize"?: string;
		"textAlign"?: string;
	}
	
	export interface Ticker { 
		"symbol": string;
		"exchange": string;
	}
	
	export interface TimeAllowed { 
		"timeSlots"?: Array<Models.TimeSlot>;
		"timeZoneId"?: string;
		"empty"?: boolean;
	}
	
	export interface TimeInterval { 
		"months"?: number;
		"weeks"?: number;
		"days"?: number;
		"hours"?: number;
	}
	
	export interface TimeOffBalanceJobReference { 
		"id"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface TimeOffBalanceJobResponse { 
		"entities"?: Array<Models.TimeOffBalanceResponse>;
		"status"?: string;
	}
	
	export interface TimeOffBalanceRequest { 
		"activityCodeIds": Array<string>;
		"dateRanges"?: Array<Models.LocalDateRange>;
	}
	
	export interface TimeOffBalanceResponse { 
		"activityCodeId": string;
		"hrisTimeOffTypeId": string;
		"hrisTimeOffTypeSecondaryId"?: string;
		"startDate"?: string;
		"balanceMinutesPerDay"?: Array<number>;
	}
	
	export interface TimeOffBalancesResponse { 
		"job"?: Models.TimeOffBalanceJobReference;
		"entities"?: Array<Models.TimeOffBalanceResponse>;
	}
	
	export interface TimeOffIntegrationStatusResponse { 
		"timeOffRequest": Models.TimeOffRequestReference;
		"integrationStatus": string;
	}
	
	export interface TimeOffIntegrationStatusResponseListing { 
		"entities"?: Array<Models.TimeOffIntegrationStatusResponse>;
	}
	
	export interface TimeOffLimit { 
		"id"?: string;
		"granularity"?: string;
		"defaultLimitMinutes"?: number;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface TimeOffLimitListing { 
		"entities"?: Array<Models.TimeOffLimit>;
	}
	
	export interface TimeOffLimitRange { 
		"startDate": string;
		"granularity": string;
		"limitMinutesPerInterval": Array<number>;
	}
	
	export interface TimeOffLimitReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface TimeOffLimitValueRange { 
		"timeOffLimit"?: Models.TimeOffLimitReference;
		"startDate": string;
		"granularity": string;
		"limitMinutesPerInterval"?: Array<number>;
		"allocatedMinutesPerInterval"?: Array<number>;
		"waitlistedMinutesPerInterval"?: Array<number>;
		"waitlistedRequestsPerInterval"?: Array<number>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface TimeOffPlan { 
		"id"?: string;
		"name"?: string;
		"activityCodeIds"?: Array<string>;
		"timeOffLimits"?: Array<Models.TimeOffLimitReference>;
		"autoApprovalRule"?: string;
		"daysBeforeStartToExpireFromWaitlist"?: number;
		"hrisTimeOffType"?: Models.HrisTimeOffType;
		"active"?: boolean;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface TimeOffPlanBusinessUnitAssociation { 
		"managementUnits"?: Array<Models.ManagementUnitReference>;
		"staffingGroups"?: Array<Models.StaffingGroupReference>;
	}
	
	export interface TimeOffPlanListing { 
		"entities"?: Array<Models.TimeOffPlan>;
	}
	
	export interface TimeOffPlanManagementUnitAssociation { 
		"managementUnit": Models.ManagementUnitReference;
		"staffingGroups"?: Array<Models.StaffingGroupReference>;
	}
	
	export interface TimeOffRequest { 
		"id": string;
		"user": Models.UserReference;
		"isFullDayRequest"?: boolean;
		"markedAsRead"?: boolean;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"status"?: string;
		"substatus"?: string;
		"partialDayStartDateTimes"?: Array<string>;
		"fullDayManagementUnitDates"?: Array<string>;
		"dailyDurationMinutes"?: number;
		"durationMinutes"?: Array<number>;
		"payableMinutes"?: Array<number>;
		"notes"?: string;
		"submittedBy"?: Models.UserReference;
		"submittedDate"?: string;
		"reviewedBy"?: Models.UserReference;
		"reviewedDate"?: string;
		"syncVersion"?: number;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface TimeOffRequestList { 
		"id"?: string;
		"name"?: string;
		"timeOffRequests"?: Array<Models.TimeOffRequestResponse>;
		"selfUri"?: string;
	}
	
	export interface TimeOffRequestListing { 
		"entities": Array<Models.TimeOffRequest>;
		"downloadUrl"?: string;
	}
	
	export interface TimeOffRequestLookup { 
		"timeOffRequestId": string;
		"userId": string;
	}
	
	export interface TimeOffRequestNotification { 
		"timeOffRequestId"?: string;
		"user"?: Models.UserReference;
		"isFullDayRequest"?: boolean;
		"status"?: string;
		"partialDayStartDateTimes"?: Array<string>;
		"fullDayManagementUnitDates"?: Array<string>;
	}
	
	export interface TimeOffRequestQueryBody { 
		"ids"?: Array<string>;
		"userIds"?: Array<string>;
		"statuses"?: Array<string>;
		"substatuses"?: Array<string>;
		"dateRange"?: Models.DateRange;
	}
	
	export interface TimeOffRequestReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface TimeOffRequestResponse { 
		"id"?: string;
		"user"?: Models.UserReference;
		"isFullDayRequest"?: boolean;
		"markedAsRead"?: boolean;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"status"?: string;
		"substatus"?: string;
		"partialDayStartDateTimes"?: Array<string>;
		"fullDayManagementUnitDates"?: Array<string>;
		"dailyDurationMinutes"?: number;
		"durationMinutes"?: Array<number>;
		"payableMinutes"?: Array<number>;
		"notes"?: string;
		"submittedBy"?: Models.UserReference;
		"submittedDate"?: string;
		"reviewedBy"?: Models.UserReference;
		"reviewedDate"?: string;
		"modifiedBy"?: Models.UserReference;
		"modifiedDate"?: string;
		"syncVersion"?: number;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface TimeOffRequestSettings { 
		"submissionRangeEnforced"?: boolean;
		"submissionEarliestDaysFromNow"?: number;
		"submissionLatestDaysFromNow"?: number;
	}
	
	export interface TimeSlot { 
		"startTime"?: string;
		"stopTime"?: string;
		"day"?: number;
	}
	
	export interface TimeZoneEntityListing { 
		"entities"?: Array<Models.RegionTimeZone>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TimeZoneMappingPreview { 
		"contactList"?: Models.DomainEntityRef;
		"contactsPerTimeZone"?: { [key: string]: number; };
		"contactsMappedUsingZipCode"?: { [key: string]: number; };
		"contactsMappedToASingleZone"?: number;
		"contactsMappedToASingleZoneUsingZipCode"?: number;
		"contactsMappedToMultipleZones"?: number;
		"contactsMappedToMultipleZonesUsingZipCode"?: number;
		"contactsInDefaultWindow"?: number;
		"contactListSize"?: number;
	}
	
	export interface TokenInfo { 
		"organization"?: Models.NamedEntity;
		"homeOrganization"?: Models.NamedEntity;
		"authorizedScope"?: Array<string>;
		"clonedUser"?: Models.TokenInfoClonedUser;
		"OAuthClient"?: Models.OrgOAuthClient;
	}
	
	export interface TokenInfoClonedUser { 
		"id"?: string;
		"organization"?: Models.Entity;
	}
	
	export interface Topic { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"published"?: boolean;
		"strictness"?: string;
		"programs"?: Array<Models.BaseProgramEntity>;
		"tags"?: Array<string>;
		"dialect"?: string;
		"participants"?: string;
		"phrases"?: Array<Models.Phrase>;
		"modifiedBy"?: Models.AddressableEntityRef;
		"dateModified"?: string;
		"publishedBy"?: Models.AddressableEntityRef;
		"datePublished"?: string;
		"selfUri"?: string;
	}
	
	export interface TopicCursorEntityListing { 
		"entities"?: Array<string>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface TopicDuration { 
		"totalMilliseconds"?: number;
	}
	
	export interface TopicJob { 
		"id"?: string;
		"state"?: string;
		"topics"?: Array<Models.BaseTopicEntitiy>;
		"createdBy"?: Models.AddressableEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"selfUri"?: string;
	}
	
	export interface TopicJobRequest { 
		"topicIds": Array<string>;
	}
	
	export interface TopicOffset { 
		"wordCount"?: number;
		"characterCount"?: number;
	}
	
	export interface TopicPhrase { 
		"id"?: string;
		"text"?: string;
		"utteranceCount"?: number;
	}
	
	export interface TopicRequest { 
		"name": string;
		"description"?: string;
		"strictness"?: string;
		"programIds"?: Array<string>;
		"tags"?: Array<string>;
		"dialect": string;
		"participants"?: string;
		"phrases"?: Array<Models.Phrase>;
	}
	
	export interface TopicsEntityListing { 
		"entities"?: Array<Models.ListedTopic>;
		"pageSize"?: number;
		"total"?: number;
		"nextUri"?: string;
		"selfUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Touchpoint { 
		"conversationId"?: string;
		"agentId": string;
		"associatedValue": number;
		"mediaType"?: string;
		"createdDate"?: string;
	}
	
	export interface TouchpointResponse { 
		"conversationId"?: string;
		"agentId": string;
		"associatedValue": number;
		"mediaType"?: string;
		"state": string;
		"message"?: string;
		"createdDate"?: string;
	}
	
	export interface TrainingListing { 
		"entities"?: Array<Models.KnowledgeTraining>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface TranscriptAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface TranscriptAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.TranscriptAggregateQueryPredicate>;
	}
	
	export interface TranscriptAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.TranscriptAggregateQueryClause>;
		"predicates"?: Array<Models.TranscriptAggregateQueryPredicate>;
	}
	
	export interface TranscriptAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface TranscriptAggregateQueryResponse { 
		"results"?: Array<Models.TranscriptAggregateDataContainer>;
	}
	
	export interface TranscriptAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.TranscriptAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.TranscriptAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface TranscriptAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface TranscriptAsyncAggregateQueryResponse { 
		"results"?: Array<Models.TranscriptAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface TranscriptAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.TranscriptAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.TranscriptAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface TranscriptConversationDetailSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.TranscriptConversationDetailSearchCriteria>;
		"dateFormat"?: string;
		"fields"?: Array<string>;
		"type"?: string;
	}
	
	export interface TranscriptConversationDetailSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"types": Array<string>;
		"query"?: Array<Models.TranscriptConversationDetailSearchCriteria>;
	}
	
	export interface TranscriptSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.TranscriptSearchCriteria>;
		"dateFormat"?: string;
		"type"?: string;
		"fields"?: Array<string>;
	}
	
	export interface TranscriptSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"returnFields"?: Array<string>;
		"types": Array<string>;
		"query"?: Array<Models.TranscriptSearchCriteria>;
	}
	
	export interface TranscriptTopic { 
		"id"?: string;
		"name"?: string;
		"topicPhrase"?: string;
		"transcriptPhrase"?: string;
		"confidence"?: number;
		"startTimeMilliseconds"?: number;
		"duration"?: Models.TopicDuration;
		"offset"?: Models.TopicOffset;
		"recordingLocation"?: number;
	}
	
	export interface TranscriptTopics { 
		"includes"?: Array<string>;
		"excludes"?: Array<string>;
	}
	
	export interface TranscriptUrl { 
		"url"?: string;
	}
	
	export interface TranscriptUrls { 
		"conversation"?: Models.AddressableEntityRef;
		"communicationId"?: string;
		"urls"?: Array<Models.SegmentUrl>;
	}
	
	export interface TranscriptionEnginesRequest { 
		"transcriptionEngines": Array<Models.ProgramTranscriptionEngine>;
	}
	
	export interface TranscriptionSettings { 
		"transcription": string;
		"transcriptionConfidenceThreshold": number;
		"lowLatencyTranscriptionEnabled"?: boolean;
		"contentSearchEnabled"?: boolean;
		"pciDssRedactionEnabled"?: boolean;
		"piiRedactionEnabled"?: boolean;
	}
	
	export interface TranscriptionTopicTranscriptAlternative { 
		"confidence"?: number;
		"offsetMs"?: number;
		"durationMs"?: number;
		"transcript"?: string;
		"words"?: Array<Models.TranscriptionTopicTranscriptWord>;
		"decoratedTranscript"?: string;
		"decoratedWords"?: Array<Models.TranscriptionTopicTranscriptWord>;
	}
	
	export interface TranscriptionTopicTranscriptResult { 
		"utteranceId"?: string;
		"isFinal"?: boolean;
		"channel"?: string;
		"alternatives"?: Array<Models.TranscriptionTopicTranscriptAlternative>;
		"agentAssistantId"?: string;
		"engineId"?: string;
		"dialect"?: string;
		"speechTextAnalyticsProgramId"?: string;
		"agentAssistEnabled"?: boolean;
		"voiceTranscriptionEnabled"?: boolean;
	}
	
	export interface TranscriptionTopicTranscriptWord { 
		"confidence"?: number;
		"startTimeMs"?: number;
		"offsetMs"?: number;
		"durationMs"?: number;
		"word"?: string;
	}
	
	export interface TranscriptionTopicTranscriptionMessage { 
		"eventTime"?: string;
		"organizationId"?: string;
		"conversationId"?: string;
		"communicationId"?: string;
		"sessionStartTimeMs"?: number;
		"transcriptionStartTimeMs"?: number;
		"transcripts"?: Array<Models.TranscriptionTopicTranscriptResult>;
		"status"?: Models.TranscriptionTopicTranscriptionRequestStatus;
	}
	
	export interface TranscriptionTopicTranscriptionRequestStatus { 
		"offsetMs"?: number;
		"status"?: string;
	}
	
	export interface Transcripts { 
		"exactMatch"?: Array<string>;
		"contains"?: Array<string>;
		"doesNotContain"?: Array<string>;
	}
	
	export interface TransferDestination { 
		"userId"?: string;
		"address"?: string;
	}
	
	export interface TransferInitiator { 
		"userId"?: string;
	}
	
	export interface TransferRequest { 
		"transferType"?: string;
		"userId"?: string;
		"address"?: string;
		"userName"?: string;
		"queueId"?: string;
		"voicemail"?: boolean;
	}
	
	export interface TransferResponse { 
		"id"?: string;
		"state"?: string;
		"dateIssued"?: string;
		"initiator"?: Models.TransferInitiator;
		"modifiedBy"?: Models.TransferResponseModifiedBy;
		"destination"?: Models.TransferDestination;
		"transferType"?: string;
	}
	
	export interface TransferResponseModifiedBy { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface TransferToAgentRequest { 
		"transferType"?: string;
		"userId"?: string;
		"userName"?: string;
		"userDisplayName"?: string;
		"voicemail"?: boolean;
	}
	
	export interface TransferToExternalRequest { 
		"transferType"?: string;
		"address"?: string;
	}
	
	export interface TransferToQueueRequest { 
		"transferType"?: string;
		"queueId"?: string;
		"queueName"?: string;
	}
	
	export interface TrendData { 
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"percentOfGoal"?: number;
		"averageValue"?: number;
	}
	
	export interface Trigger { 
		"id"?: string;
		"name"?: string;
		"topicName"?: string;
		"target"?: Models.TriggerTarget;
		"version"?: number;
		"enabled"?: boolean;
		"matchCriteria"?: Array<Models.MatchCriteria>;
		"eventTTLSeconds"?: number;
		"delayBySeconds"?: number;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface TriggerEntityListing { 
		"entities"?: Array<Models.Trigger>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface TriggerTarget { 
		"type"?: string;
		"id"?: string;
		"workflowTargetSettings"?: Models.WorkflowTargetSettings;
	}
	
	export interface Trunk { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"trunkType"?: string;
		"edge"?: Models.DomainEntityRef;
		"trunkBase"?: Models.DomainEntityRef;
		"trunkMetabase"?: Models.DomainEntityRef;
		"edgeGroup"?: Models.DomainEntityRef;
		"inService"?: boolean;
		"enabled"?: boolean;
		"logicalInterface"?: Models.DomainEntityRef;
		"connectedStatus"?: Models.TrunkConnectedStatus;
		"optionsStatus"?: Array<Models.TrunkMetricsOptions>;
		"registersStatus"?: Array<Models.TrunkMetricsRegisters>;
		"ipStatus"?: Models.TrunkMetricsNetworkTypeIp;
		"optionsEnabledStatus"?: string;
		"registersEnabledStatus"?: string;
		"family"?: number;
		"proxyAddressList"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface TrunkBase { 
		"id"?: string;
		"name": string;
		"division"?: Models.Division;
		"description"?: string;
		"version"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"state"?: string;
		"modifiedByApp"?: string;
		"createdByApp"?: string;
		"trunkMetabase": Models.DomainEntityRef;
		"properties"?: { [key: string]: object; };
		"trunkType": string;
		"managed"?: boolean;
		"site"?: Models.DomainEntityRef;
		"inboundSite"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface TrunkBaseAssignment { 
		"family"?: number;
		"trunkBase"?: Models.TrunkBase;
	}
	
	export interface TrunkBaseEntityListing { 
		"entities"?: Array<Models.TrunkBase>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TrunkConnectedStatus { 
		"connected"?: boolean;
		"connectedStateTime"?: string;
	}
	
	export interface TrunkEntityListing { 
		"entities"?: Array<Models.Trunk>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TrunkErrorInfo { 
		"text"?: string;
		"code"?: string;
		"details"?: Models.TrunkErrorInfoDetails;
	}
	
	export interface TrunkErrorInfoDetails { 
		"code"?: string;
		"message"?: string;
		"hostname"?: string;
	}
	
	export interface TrunkInstanceTopicTrunk { 
		"id"?: string;
		"connectedStatus"?: Models.TrunkInstanceTopicTrunkConnectedStatus;
		"optionsStatus"?: Array<Models.TrunkInstanceTopicTrunkMetricsOptions>;
		"registersStatus"?: Array<Models.TrunkInstanceTopicTrunkMetricsRegisters>;
		"ipStatus"?: Models.TrunkInstanceTopicTrunkMetricsNetworkTypeIp;
	}
	
	export interface TrunkInstanceTopicTrunkConnectedStatus { 
		"connected"?: boolean;
		"connectedStateTime"?: string;
	}
	
	export interface TrunkInstanceTopicTrunkErrorInfo { 
		"text"?: string;
		"code"?: string;
		"details"?: Models.TrunkInstanceTopicTrunkErrorInfoDetails;
	}
	
	export interface TrunkInstanceTopicTrunkErrorInfoDetails { 
		"code"?: string;
		"message"?: string;
		"hostname"?: string;
	}
	
	export interface TrunkInstanceTopicTrunkMetricsNetworkTypeIp { 
		"address"?: string;
		"errorInfo"?: Models.TrunkInstanceTopicTrunkErrorInfo;
	}
	
	export interface TrunkInstanceTopicTrunkMetricsOptions { 
		"proxyAddress"?: string;
		"optionState"?: boolean;
		"optionStateTime"?: string;
		"errorInfo"?: Models.TrunkInstanceTopicTrunkErrorInfo;
	}
	
	export interface TrunkInstanceTopicTrunkMetricsRegisters { 
		"proxyAddress"?: string;
		"registerState"?: boolean;
		"registerStateTime"?: string;
		"errorInfo"?: Models.TrunkInstanceTopicTrunkErrorInfo;
	}
	
	export interface TrunkMetabaseEntityListing { 
		"entities"?: Array<Models.Metabase>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"totalNumberOfEntities"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TrunkMetrics { 
		"eventTime"?: string;
		"logicalInterface"?: Models.DomainEntityRef;
		"trunk"?: Models.DomainEntityRef;
		"calls"?: Models.TrunkMetricsCalls;
		"qos"?: Models.TrunkMetricsQoS;
	}
	
	export interface TrunkMetricsCalls { 
		"inboundCallCount"?: number;
		"outboundCallCount"?: number;
	}
	
	export interface TrunkMetricsNetworkTypeIp { 
		"address"?: string;
		"errorInfo"?: Models.TrunkErrorInfo;
	}
	
	export interface TrunkMetricsOptions { 
		"proxyAddress"?: string;
		"optionState"?: boolean;
		"optionStateTime"?: string;
		"errorInfo"?: Models.TrunkErrorInfo;
	}
	
	export interface TrunkMetricsQoS { 
		"mismatchCount": number;
	}
	
	export interface TrunkMetricsRegisters { 
		"proxyAddress"?: string;
		"registerState"?: boolean;
		"registerStateTime"?: string;
		"errorInfo"?: Models.TrunkErrorInfo;
	}
	
	export interface TrunkMetricsTopicTrunkMetrics { 
		"calls"?: Models.TrunkMetricsTopicTrunkMetricsCalls;
		"eventTime"?: string;
		"qos"?: Models.TrunkMetricsTopicTrunkMetricsQoS;
		"trunk"?: Models.TrunkMetricsTopicUriReference;
	}
	
	export interface TrunkMetricsTopicTrunkMetricsCalls { 
		"inboundCallCount"?: number;
		"outboundCallCount"?: number;
	}
	
	export interface TrunkMetricsTopicTrunkMetricsQoS { 
		"mismatchCount"?: number;
	}
	
	export interface TrunkMetricsTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface TrunkRecordingEnabledCount { 
		"enabledCount"?: number;
		"disabledCount"?: number;
	}
	
	export interface TrustCreate { 
		"pairingId"?: string;
		"enabled": boolean;
		"users"?: Array<Models.TrustMemberCreate>;
		"groups"?: Array<Models.TrustMemberCreate>;
		"dateExpired"?: string;
	}
	
	export interface TrustEntityListing { 
		"entities"?: Array<Models.Trustee>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TrustGroup { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"dateModified"?: string;
		"memberCount"?: number;
		"state"?: string;
		"version"?: number;
		"type": string;
		"images"?: Array<Models.UserImage>;
		"addresses"?: Array<Models.GroupContact>;
		"rulesVisible": boolean;
		"visibility": string;
		"rolesEnabled"?: boolean;
		"owners"?: Array<Models.User>;
		"dateCreated"?: string;
		"createdBy"?: Models.OrgUser;
	}
	
	export interface TrustGroupEntityListing { 
		"entities"?: Array<Models.TrustGroup>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TrustMemberCreate { 
		"id": string;
		"roleIds"?: Array<string>;
		"roleDivisions"?: Models.RoleDivisionGrants;
	}
	
	export interface TrustRequest { 
		"id"?: string;
		"createdBy"?: Models.OrgUser;
		"dateCreated"?: string;
		"trustee": Models.Organization;
		"users"?: Array<Models.OrgUser>;
		"groups"?: Array<Models.TrustGroup>;
		"selfUri"?: string;
	}
	
	export interface TrustRequestCreate { 
		"userIds"?: Array<string>;
		"groupIds"?: Array<string>;
	}
	
	export interface TrustUpdate { 
		"enabled": boolean;
		"dateExpired"?: string;
	}
	
	export interface TrustUser { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"chat"?: Models.Chat;
		"department"?: string;
		"email"?: string;
		"primaryContactInfo"?: Array<Models.Contact>;
		"addresses"?: Array<Models.Contact>;
		"state"?: string;
		"title"?: string;
		"username"?: string;
		"manager"?: Models.User;
		"images"?: Array<Models.UserImage>;
		"version": number;
		"certifications"?: Array<string>;
		"biography"?: Models.Biography;
		"employerInfo"?: Models.EmployerInfo;
		"preferredName"?: string;
		"routingStatus"?: Models.RoutingStatus;
		"presence"?: Models.UserPresence;
		"integrationPresence"?: Models.UserPresence;
		"conversationSummary"?: Models.UserConversationSummary;
		"outOfOffice"?: Models.OutOfOffice;
		"geolocation"?: Models.Geolocation;
		"station"?: Models.UserStations;
		"authorization"?: Models.UserAuthorization;
		"profileSkills"?: Array<string>;
		"locations"?: Array<Models.Location>;
		"groups"?: Array<Models.Group>;
		"team"?: Models.Team;
		"skills"?: Array<Models.UserRoutingSkill>;
		"languages"?: Array<Models.UserRoutingLanguage>;
		"acdAutoAnswer"?: boolean;
		"languagePreference"?: string;
		"lastTokenIssued"?: Models.OAuthLastTokenIssued;
		"dateLastLogin"?: string;
		"trustUserDetails"?: Models.TrustUserDetails;
	}
	
	export interface TrustUserDetails { 
		"dateCreated"?: string;
		"createdBy"?: Models.OrgUser;
	}
	
	export interface TrustUserEntityListing { 
		"entities"?: Array<Models.TrustUser>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Trustee { 
		"id"?: string;
		"enabled": boolean;
		"usesDefaultRole"?: boolean;
		"dateCreated"?: string;
		"dateExpired"?: string;
		"createdBy"?: Models.OrgUser;
		"organization"?: Models.Organization;
		"selfUri"?: string;
	}
	
	export interface TrusteeAuditQueryRequest { 
		"trusteeOrganizationIds": Array<string>;
		"trusteeUserIds": Array<string>;
		"startDate"?: string;
		"endDate"?: string;
		"queryPhrase"?: string;
		"facets"?: Array<Models.Facet>;
		"filters"?: Array<Models.Filter>;
	}
	
	export interface TrusteeAuthorization { 
		"permissions"?: Array<string>;
	}
	
	export interface TrusteeBillingOverview { 
		"id"?: string;
		"name"?: string;
		"organization": Models.NamedEntity;
		"currency": string;
		"enabledProducts": Array<string>;
		"subscriptionType": string;
		"rampPeriodStartDate"?: string;
		"rampPeriodEndDate"?: string;
		"billingPeriodStartDate"?: string;
		"billingPeriodEndDate"?: string;
		"usages": Array<Models.SubscriptionOverviewUsage>;
		"contractAmendmentDate"?: string;
		"contractEffectiveDate"?: string;
		"contractEndDate"?: string;
		"minimumMonthlyAmount"?: string;
		"inRampPeriod"?: boolean;
		"selfUri"?: string;
	}
	
	export interface Trustor { 
		"id"?: string;
		"enabled": boolean;
		"dateCreated"?: string;
		"createdBy"?: Models.OrgUser;
		"organization"?: Models.Organization;
		"authorization"?: Models.TrusteeAuthorization;
		"selfUri"?: string;
	}
	
	export interface TrustorAuditQueryRequest { 
		"trustorOrganizationId": string;
		"trusteeUserIds": Array<string>;
		"startDate"?: string;
		"endDate"?: string;
		"queryPhrase"?: string;
		"facets"?: Array<Models.Facet>;
		"filters"?: Array<Models.Filter>;
	}
	
	export interface TrustorEntityListing { 
		"entities"?: Array<Models.Trustor>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TtsEngineEntity { 
		"id"?: string;
		"name"?: string;
		"languages": Array<string>;
		"outputFormats": Array<string>;
		"voices"?: Array<Models.TtsVoiceEntity>;
		"isDefault"?: boolean;
		"isSecure"?: boolean;
		"selfUri"?: string;
	}
	
	export interface TtsEngineEntityListing { 
		"entities"?: Array<Models.TtsEngineEntity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TtsSettings { 
		"defaultEngine": string;
		"languageOverrides": Array<Models.LanguageOverride>;
	}
	
	export interface TtsVoiceEntity { 
		"id"?: string;
		"name"?: string;
		"gender": string;
		"language": string;
		"engine": Models.TtsEngineEntity;
		"isDefault"?: boolean;
		"selfUri"?: string;
	}
	
	export interface TtsVoiceEntityListing { 
		"entities"?: Array<Models.TtsVoiceEntity>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TwitterId { 
		"id"?: string;
		"name"?: string;
		"screenName"?: string;
		"verified"?: boolean;
		"profileUrl"?: string;
	}
	
	export interface TwitterIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"accessTokenKey": string;
		"consumerKey": string;
		"username"?: string;
		"userId"?: string;
		"status"?: string;
		"tier": string;
		"envName"?: string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version": number;
		"createStatus"?: string;
		"createError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface TwitterIntegrationEntityListing { 
		"entities"?: Array<Models.TwitterIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface TwitterIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"accessTokenKey": string;
		"accessTokenSecret": string;
		"consumerKey": string;
		"consumerSecret": string;
		"tier": string;
		"envName"?: string;
		"selfUri"?: string;
	}
	
	export interface TypingSetting { 
		"on"?: Models.SettingDirection;
	}
	
	export interface UCI10n { 
		"name"?: string;
	}
	
	export interface UCIcon { 
		"vector": string;
	}
	
	export interface UCIntegration { 
		"id"?: string;
		"name"?: string;
		"ucIntegrationKey": string;
		"integrationPresenceSource": string;
		"pbxPermission": string;
		"icon": Models.UCIcon;
		"badgeIcons": { [key: string]: Models.UCIcon; };
		"i10n": { [key: string]: Models.UCI10n; };
		"polledPresence": boolean;
		"userPermissions": Array<string>;
		"selfUri"?: string;
	}
	
	export interface UCIntegrationListing { 
		"entities"?: Array<Models.UCIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UCThirdPartyPresence { 
		"email": string;
		"presence": string;
		"message"?: string;
		"dateModified"?: string;
	}
	
	export interface UcUserPresence { 
		"id"?: string;
		"name"?: string;
		"userId"?: string;
		"source"?: string;
		"sourceId"?: string;
		"presenceDefinition"?: Models.PresenceDefinition;
		"message"?: string;
		"modifiedDate"?: string;
		"selfUri"?: string;
	}
	
	export interface UnansweredGroup { 
		"id"?: string;
		"label"?: string;
		"phraseGroups"?: Array<Models.UnansweredPhraseGroup>;
		"suggestedDocuments"?: Array<Models.UnansweredGroupSuggestedDocument>;
		"statistics"?: Models.KnowledgeGroupStatistics;
		"selfUri"?: string;
	}
	
	export interface UnansweredGroupSuggestedDocument { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface UnansweredGroups { 
		"entities"?: Array<Models.UnansweredGroup>;
	}
	
	export interface UnansweredPhrase { 
		"id"?: string;
		"text"?: string;
		"unlinkedPhraseHitCount"?: number;
	}
	
	export interface UnansweredPhraseGroup { 
		"id"?: string;
		"label"?: string;
		"phrases"?: Array<Models.UnansweredPhrase>;
		"unlinkedPhraseHitCount"?: number;
		"unlinkedPhraseCount"?: number;
		"selfUri"?: string;
	}
	
	export interface UnansweredPhraseGroupPatchRequestBody { 
		"phraseAssociations": Array<Models.PhraseAssociations>;
		"dateStart"?: string;
		"dateEnd"?: string;
	}
	
	export interface UnansweredPhraseGroupUpdateResponse { 
		"phraseAssociations"?: Array<Models.PhraseAssociations>;
		"group"?: Models.UnansweredGroup;
	}
	
	export interface UnifiedCommunicationsIntegration { 
		"id"?: string;
		"name"?: string;
		"ucIntegrationKey": Models.AddressableEntityRef;
		"integrationPresenceSource": string;
		"pbxPermission": string;
		"icon": Models.UCIcon;
		"badgeIcons": { [key: string]: Models.UCIcon; };
		"i10n": { [key: string]: Models.UCI10n; };
		"polledPresence": boolean;
		"pollIntervalSec"?: number;
		"userPermissions": Array<string>;
		"oauthScopes"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface UnifiedCommunicationsIntegrationListing { 
		"entities"?: Array<Models.UnifiedCommunicationsIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UnifiedGeneralTopic { 
		"name"?: string;
		"status"?: string;
	}
	
	export interface UnifiedGeneralTopicEntityListing { 
		"entities"?: Array<Models.UnifiedGeneralTopic>;
	}
	
	export interface UnpublishedProgramsEntityListing { 
		"entities"?: Array<Models.Program>;
		"pageSize"?: number;
		"nextUri"?: string;
		"pageCount"?: number;
		"selfUri"?: string;
	}
	
	export interface UnreadFields { 
		"state": boolean;
	}
	
	export interface UnreadMetric { 
		"count"?: number;
	}
	
	export interface UnreadStatus { 
		"unread"?: boolean;
	}
	
	export interface UpdateActionInput { 
		"category"?: string;
		"name"?: string;
		"config"?: Models.ActionConfig;
		"version": number;
	}
	
	export interface UpdateActivityCodeRequest { 
		"name"?: string;
		"category"?: string;
		"lengthInMinutes"?: number;
		"countsAsPaidTime"?: boolean;
		"countsAsWorkTime"?: boolean;
		"agentTimeOffSelectable"?: boolean;
		"countsTowardShrinkage"?: boolean;
		"plannedShrinkage"?: boolean;
		"interruptible"?: boolean;
		"secondaryPresences"?: Models.ListWrapperSecondaryPresence;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateAdherenceExplanationStatusRequest { 
		"status"?: string;
	}
	
	export interface UpdateAnalyticsDataRetentionRequest { 
		"retentionDays": number;
	}
	
	export interface UpdateBusinessUnitRequest { 
		"name"?: string;
		"divisionId"?: string;
		"settings"?: Models.UpdateBusinessUnitSettingsRequest;
	}
	
	export interface UpdateBusinessUnitSettingsRequest { 
		"startDayOfWeek"?: string;
		"timeZone"?: string;
		"shortTermForecasting"?: Models.BuShortTermForecastingSettings;
		"scheduling"?: Models.BuSchedulingSettingsRequest;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateCoachingAppointmentRequest { 
		"name"?: string;
		"description"?: string;
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"conversationIds"?: Array<string>;
		"documentIds"?: Array<string>;
		"status"?: string;
		"wfmSchedule"?: Models.WfmScheduleReference;
		"externalLinks"?: Array<string>;
	}
	
	export interface UpdateContactColumnActionSettings { 
		"properties": { [key: string]: string; };
		"updateOption": string;
	}
	
	export interface UpdateDraftInput { 
		"category"?: string;
		"name"?: string;
		"config"?: Models.ActionConfig;
		"contract"?: Models.ActionContractInput;
		"secure"?: boolean;
		"version": number;
	}
	
	export interface UpdateManagementUnitRequest { 
		"name"?: string;
		"divisionId"?: string;
		"settings"?: Models.ManagementUnitSettingsRequest;
	}
	
	export interface UpdateMuAgentRequest { 
		"schedulable"?: boolean;
		"userId": string;
	}
	
	export interface UpdateMuAgentsRequest { 
		"entities"?: Array<Models.UpdateMuAgentRequest>;
	}
	
	export interface UpdateNotificationResponse { 
		"mutableGroupId"?: string;
		"id"?: string;
	}
	
	export interface UpdateNotificationsRequest { 
		"entities": Array<Models.WfmUserNotification>;
	}
	
	export interface UpdateNotificationsResponse { 
		"entities"?: Array<Models.UpdateNotificationResponse>;
	}
	
	export interface UpdatePlanningGroupRequest { 
		"name"?: string;
		"routePaths"?: Models.SetWrapperRoutePathRequest;
		"serviceGoalTemplateId"?: string;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateScheduleUploadResponse { 
		"uploadKey"?: string;
		"url"?: string;
		"headers"?: { [key: string]: string; };
		"uploadBodySchema"?: Models.UpdateScheduleUploadSchema;
	}
	
	export interface UpdateScheduleUploadSchema { 
		"description"?: string;
		"published"?: boolean;
		"shortTermForecast"?: Models.BuShortTermForecastReference;
		"headcountForecast"?: Models.BuHeadcountForecast;
		"agentSchedules"?: Array<Models.BuUpdateAgentScheduleUploadSchema>;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateServiceGoalTemplate { 
		"name"?: string;
		"serviceLevel"?: Models.BuServiceLevel;
		"averageSpeedOfAnswer"?: Models.BuAverageSpeedOfAnswer;
		"abandonRate"?: Models.BuAbandonRate;
		"metadata": Models.WfmVersionedEntityMetadata;
		"impactOverride"?: Models.ServiceGoalTemplateImpactOverride;
	}
	
	export interface UpdateStaffingGroupRequest { 
		"name"?: string;
		"userIds"?: Models.SetWrapperString;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateTimeOffLimitRequest { 
		"defaultLimitMinutes"?: number;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateTimeOffPlanBusinessUnitAssociation { 
		"managementUnitIds"?: Models.SetWrapperString;
		"staffingGroupIds"?: Models.SetWrapperString;
	}
	
	export interface UpdateTimeOffPlanManagementUnitAssociation { 
		"staffingGroupIds"?: Models.SetWrapperString;
	}
	
	export interface UpdateTimeOffPlanRequest { 
		"name"?: string;
		"activityCodeIds"?: Models.SetWrapperString;
		"timeOffLimitIds"?: Models.SetWrapperString;
		"autoApprovalRule"?: string;
		"daysBeforeStartToExpireFromWaitlist"?: number;
		"hrisTimeOffType"?: Models.ValueWrapperHrisTimeOffType;
		"active"?: boolean;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UpdateTriggerRequest { 
		"version": number;
		"enabled": boolean;
		"target": Models.TriggerTarget;
		"matchCriteria"?: Array<Models.MatchCriteria>;
		"name": string;
		"topicName": string;
		"eventTTLSeconds"?: number;
		"delayBySeconds"?: number;
		"description"?: string;
	}
	
	export interface UpdateUser { 
		"id"?: string;
		"name"?: string;
		"chat"?: Models.Chat;
		"department"?: string;
		"email"?: string;
		"primaryContactInfo"?: Array<Models.Contact>;
		"addresses"?: Array<Models.Contact>;
		"title"?: string;
		"username"?: string;
		"preferredName"?: string;
		"manager"?: string;
		"images"?: Array<Models.UserImage>;
		"version": number;
		"profileSkills"?: Array<string>;
		"locations"?: Array<Models.Location>;
		"groups"?: Array<Models.Group>;
		"state"?: string;
		"acdAutoAnswer"?: boolean;
		"certifications"?: Array<string>;
		"biography"?: Models.Biography;
		"employerInfo"?: Models.EmployerInfo;
		"selfUri"?: string;
	}
	
	export interface UpdateUtilizationLabelRequest { 
		"name": string;
	}
	
	export interface UpdateVerifierRequest { 
		"name"?: string;
		"enabled"?: boolean;
		"default"?: boolean;
	}
	
	export interface UpdateWorkPlanRotationAgentRequest { 
		"userId": string;
		"dateRange"?: Models.DateRangeWithOptionalEnd;
		"position"?: number;
		"delete"?: boolean;
	}
	
	export interface UpdateWorkPlanRotationRequest { 
		"name"?: string;
		"enabled"?: boolean;
		"dateRange"?: Models.DateRangeWithOptionalEnd;
		"agents"?: Array<Models.UpdateWorkPlanRotationAgentRequest>;
		"pattern"?: Models.WorkPlanPatternRequest;
		"metadata": Models.WfmVersionedEntityMetadata;
	}
	
	export interface UploadUrlRequest { 
		"fileName"?: string;
		"contentMd5"?: string;
		"signedUrlTimeoutSeconds"?: number;
		"contentType"?: string;
		"serverSideEncryption"?: string;
	}
	
	export interface UploadUrlRequestBody { 
		"contentLengthBytes": number;
	}
	
	export interface UploadUrlResponse { 
		"url"?: string;
		"uploadKey"?: string;
		"headers"?: { [key: string]: string; };
	}
	
	export interface UrlCondition { 
		"values": Array<string>;
		"operator": string;
	}
	
	export interface UrlResponse { 
		"url"?: string;
	}
	
	export interface Usage { 
		"types"?: Array<Models.UsageItem>;
	}
	
	export interface UsageExecutionResult { 
		"executionId"?: string;
		"resultsUri"?: string;
	}
	
	export interface UsageItem { 
		"type"?: string;
		"totalDocumentByteCount"?: number;
		"totalDocumentCount"?: number;
	}
	
	export interface User { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"chat"?: Models.Chat;
		"department"?: string;
		"email"?: string;
		"primaryContactInfo"?: Array<Models.Contact>;
		"addresses"?: Array<Models.Contact>;
		"state"?: string;
		"title"?: string;
		"username"?: string;
		"manager"?: Models.User;
		"images"?: Array<Models.UserImage>;
		"version": number;
		"certifications"?: Array<string>;
		"biography"?: Models.Biography;
		"employerInfo"?: Models.EmployerInfo;
		"preferredName"?: string;
		"routingStatus"?: Models.RoutingStatus;
		"presence"?: Models.UserPresence;
		"integrationPresence"?: Models.UserPresence;
		"conversationSummary"?: Models.UserConversationSummary;
		"outOfOffice"?: Models.OutOfOffice;
		"geolocation"?: Models.Geolocation;
		"station"?: Models.UserStations;
		"authorization"?: Models.UserAuthorization;
		"profileSkills"?: Array<string>;
		"locations"?: Array<Models.Location>;
		"groups"?: Array<Models.Group>;
		"team"?: Models.Team;
		"skills"?: Array<Models.UserRoutingSkill>;
		"languages"?: Array<Models.UserRoutingLanguage>;
		"acdAutoAnswer"?: boolean;
		"languagePreference"?: string;
		"lastTokenIssued"?: Models.OAuthLastTokenIssued;
		"dateLastLogin"?: string;
		"selfUri"?: string;
	}
	
	export interface UserActivityData { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.UserActivityMetricValue>;
		"truncated"?: boolean;
		"entities"?: Array<Models.UserActivityEntityData>;
	}
	
	export interface UserActivityEntityData { 
		"activityDate": string;
		"organizationPresenceId"?: string;
		"presenceDate"?: string;
		"queueId"?: string;
		"queueMembershipStatus"?: string;
		"routingStatus"?: string;
		"routingStatusDate"?: string;
		"systemPresence"?: string;
		"teamId"?: string;
		"userId"?: string;
	}
	
	export interface UserActivityMetricValue { 
		"metric"?: string;
		"count"?: number;
	}
	
	export interface UserActivityQuery { 
		"metrics": Array<Models.UserActivityQueryMetric>;
		"groupBy": Array<string>;
		"filter"?: Models.UserActivityQueryFilter;
		"order"?: string;
	}
	
	export interface UserActivityQueryClause { 
		"type": string;
		"predicates": Array<Models.UserActivityQueryPredicate>;
	}
	
	export interface UserActivityQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.UserActivityQueryClause>;
		"predicates"?: Array<Models.UserActivityQueryPredicate>;
	}
	
	export interface UserActivityQueryMetric { 
		"metric": string;
		"details"?: boolean;
	}
	
	export interface UserActivityQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
	}
	
	export interface UserActivityResponse { 
		"results"?: Array<Models.UserActivityData>;
		"entityIdDimension"?: string;
	}
	
	export interface UserAgentInfo { 
		"firmwareVersion"?: string;
		"manufacturer"?: string;
		"model"?: string;
	}
	
	export interface UserAggregateDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.StatisticalResponse>;
	}
	
	export interface UserAggregateQueryClause { 
		"type": string;
		"predicates": Array<Models.UserAggregateQueryPredicate>;
	}
	
	export interface UserAggregateQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.UserAggregateQueryClause>;
		"predicates"?: Array<Models.UserAggregateQueryPredicate>;
	}
	
	export interface UserAggregateQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface UserAggregateQueryResponse { 
		"systemToOrganizationMappings"?: { [key: string]: Array<string>; };
		"results"?: Array<Models.UserAggregateDataContainer>;
	}
	
	export interface UserAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.UserAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.UserAggregationView>;
		"alternateTimeDimension"?: string;
	}
	
	export interface UserAggregationView { 
		"target": string;
		"name": string;
		"function": string;
		"range"?: Models.AggregationRange;
	}
	
	export interface UserApp { 
		"id"?: string;
		"name"?: string;
		"integrationType"?: Models.IntegrationType;
		"config"?: Models.UserAppConfigurationInfo;
		"selfUri"?: string;
	}
	
	export interface UserAppConfigurationInfo { 
		"current"?: Models.IntegrationConfiguration;
		"effective"?: Models.EffectiveConfiguration;
	}
	
	export interface UserAppEntityListing { 
		"entities"?: Array<Models.UserApp>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserAsyncAggregateQueryResponse { 
		"systemToOrganizationMappings"?: { [key: string]: Array<string>; };
		"results"?: Array<Models.UserAggregateDataContainer>;
		"cursor"?: string;
	}
	
	export interface UserAsyncAggregationQuery { 
		"interval": string;
		"granularity"?: string;
		"timeZone"?: string;
		"groupBy"?: Array<string>;
		"filter"?: Models.UserAggregateQueryFilter;
		"metrics": Array<string>;
		"flattenMultivaluedDimensions"?: boolean;
		"views"?: Array<Models.UserAggregationView>;
		"alternateTimeDimension"?: string;
		"pageSize"?: number;
	}
	
	export interface UserAuthorization { 
		"roles"?: Array<Models.DomainRole>;
		"unusedRoles"?: Array<Models.DomainRole>;
		"permissions"?: Array<string>;
		"permissionPolicies"?: Array<Models.ResourcePermissionPolicy>;
	}
	
	export interface UserAvailableTimes { 
		"user"?: Models.UserReference;
		"availableTimes"?: Array<Models.AvailableTime>;
	}
	
	export interface UserBestPoints { 
		"user"?: Models.UserReference;
		"bestPoints"?: Array<Models.UserBestPointsItem>;
	}
	
	export interface UserBestPointsItem { 
		"granularityType"?: string;
		"points"?: number;
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"rank"?: number;
	}
	
	export interface UserConversationSummary { 
		"userId"?: string;
		"call"?: Models.MediaSummary;
		"callback"?: Models.MediaSummary;
		"email"?: Models.MediaSummary;
		"message"?: Models.MediaSummary;
		"chat"?: Models.MediaSummary;
		"socialExpression"?: Models.MediaSummary;
		"video"?: Models.MediaSummary;
	}
	
	export interface UserConversationsEventMediaSummary { 
		"contactCenter"?: Models.UserConversationsEventMediaSummaryDetail;
		"enterprise"?: Models.UserConversationsEventMediaSummaryDetail;
	}
	
	export interface UserConversationsEventMediaSummaryDetail { 
		"active"?: number;
		"acw"?: number;
	}
	
	export interface UserConversationsEventUserConversationSummary { 
		"userId"?: string;
		"call"?: Models.UserConversationsEventMediaSummary;
		"callback"?: Models.UserConversationsEventMediaSummary;
		"email"?: Models.UserConversationsEventMediaSummary;
		"message"?: Models.UserConversationsEventMediaSummary;
		"chat"?: Models.UserConversationsEventMediaSummary;
		"socialExpression"?: Models.UserConversationsEventMediaSummary;
		"video"?: Models.UserConversationsEventMediaSummary;
	}
	
	export interface UserDetailQueryClause { 
		"type": string;
		"predicates": Array<Models.UserDetailQueryPredicate>;
	}
	
	export interface UserDetailQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.UserDetailQueryClause>;
		"predicates"?: Array<Models.UserDetailQueryPredicate>;
	}
	
	export interface UserDetailQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface UserDetailsDatalakeAvailabilityTopicDataAvailabilityChangeNotification { 
		"dataAvailabilityDate"?: string;
	}
	
	export interface UserDetailsQuery { 
		"interval": string;
		"userFilters"?: Array<Models.UserDetailQueryFilter>;
		"presenceFilters"?: Array<Models.PresenceDetailQueryFilter>;
		"routingStatusFilters"?: Array<Models.RoutingStatusDetailQueryFilter>;
		"order"?: string;
		"presenceAggregations"?: Array<Models.AnalyticsQueryAggregation>;
		"routingStatusAggregations"?: Array<Models.AnalyticsQueryAggregation>;
		"paging"?: Models.PagingSpec;
	}
	
	export interface UserDevice { 
		"id"?: string;
		"name"?: string;
		"deviceToken": string;
		"notificationId": string;
		"make": string;
		"model": string;
		"acceptNotifications": boolean;
		"type": string;
		"sessionHash"?: string;
		"selfUri"?: string;
	}
	
	export interface UserEndDetailEventTopicUserEndEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"disconnectType"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"userId"?: string;
		"divisionId"?: string;
		"queueId"?: string;
		"interactingDurationMs"?: number;
		"heldDurationMs"?: number;
		"alertingDurationMs"?: number;
		"contactingDurationMs"?: number;
		"dialingDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface UserEntityListing { 
		"entities"?: Array<Models.User>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserEstablishedEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"communicationId": string;
		"phoneNumber"?: string;
		"userId": string;
		"stationId"?: string;
		"ani"?: string;
		"dnis"?: string;
		"afterCallWorkRequired"?: boolean;
		"queueId"?: string;
		"initialConfiguration": Models.InitialConfiguration;
		"sourceConfiguration": Models.SourceConfiguration;
	}
	
	export interface UserExpands { 
		"routingStatus"?: Models.RoutingStatus;
		"presence"?: Models.UserPresence;
		"integrationPresence"?: Models.UserPresence;
		"conversationSummary"?: Models.UserConversationSummary;
		"outOfOffice"?: Models.OutOfOffice;
		"geolocation"?: Models.Geolocation;
		"station"?: Models.UserStations;
		"authorization"?: Models.UserAuthorization;
	}
	
	export interface UserExternalIdentifier { 
		"authorityName": string;
		"externalKey": string;
		"selfUri"?: string;
	}
	
	export interface UserGreetingEventGreeting { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"ownerType"?: string;
		"owner"?: Models.UserGreetingEventGreetingOwner;
		"greetingAudioFile"?: Models.UserGreetingEventGreetingAudioFile;
		"audioTTS"?: string;
	}
	
	export interface UserGreetingEventGreetingAudioFile { 
		"durationMilliseconds"?: number;
		"sizeBytes"?: number;
	}
	
	export interface UserGreetingEventGreetingOwner { 
		"id"?: string;
	}
	
	export interface UserImage { 
		"resolution"?: string;
		"imageUri"?: string;
	}
	
	export interface UserInsightsTrend { 
		"performanceProfile"?: Models.AddressableEntityRef;
		"division"?: Models.DivisionReference;
		"granularity"?: string;
		"comparativePeriod"?: Models.WorkdayPeriod;
		"primaryPeriod"?: Models.WorkdayPeriod;
		"user"?: Models.UserReference;
		"entities"?: Array<Models.UserInsightsTrendMetricItem>;
		"total"?: Models.UserInsightsTrendTotalItem;
	}
	
	export interface UserInsightsTrendMetricItem { 
		"metric"?: Models.AddressableEntityRef;
		"trends"?: Models.UserInsightsTrends;
	}
	
	export interface UserInsightsTrendTotalItem { 
		"trends"?: Models.UserInsightsTrends;
	}
	
	export interface UserInsightsTrends { 
		"comparativePeriod"?: Array<Models.UserTrendData>;
		"primaryPeriod"?: Array<Models.UserTrendData>;
	}
	
	export interface UserLanguageEntityListing { 
		"entities"?: Array<Models.UserRoutingLanguage>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserLicenses { 
		"id"?: string;
		"licenses"?: Array<string>;
		"selfUri"?: string;
	}
	
	export interface UserLicensesEntityListing { 
		"entities"?: Array<Models.UserLicenses>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface UserListScheduleRequestBody { 
		"userIds": Array<string>;
		"startDate": string;
		"endDate": string;
		"loadFullWeeks"?: boolean;
	}
	
	export interface UserMe { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"chat"?: Models.Chat;
		"department"?: string;
		"email"?: string;
		"primaryContactInfo"?: Array<Models.Contact>;
		"addresses"?: Array<Models.Contact>;
		"state"?: string;
		"title"?: string;
		"username"?: string;
		"manager"?: Models.User;
		"images"?: Array<Models.UserImage>;
		"version": number;
		"certifications"?: Array<string>;
		"biography"?: Models.Biography;
		"employerInfo"?: Models.EmployerInfo;
		"preferredName"?: string;
		"routingStatus"?: Models.RoutingStatus;
		"presence"?: Models.UserPresence;
		"integrationPresence"?: Models.UserPresence;
		"conversationSummary"?: Models.UserConversationSummary;
		"outOfOffice"?: Models.OutOfOffice;
		"geolocation"?: Models.Geolocation;
		"station"?: Models.UserStations;
		"authorization"?: Models.UserAuthorization;
		"profileSkills"?: Array<string>;
		"locations"?: Array<Models.Location>;
		"groups"?: Array<Models.Group>;
		"team"?: Models.Team;
		"skills"?: Array<Models.UserRoutingSkill>;
		"languages"?: Array<Models.UserRoutingLanguage>;
		"acdAutoAnswer"?: boolean;
		"languagePreference"?: string;
		"lastTokenIssued"?: Models.OAuthLastTokenIssued;
		"dateLastLogin"?: string;
		"date"?: Models.ServerDate;
		"geolocationSettings"?: Models.GeolocationSettings;
		"organization"?: Models.Organization;
		"presenceDefinitions"?: Array<Models.OrganizationPresence>;
		"divisionedPresenceDefinitions"?: Array<Models.OrganizationPresenceDefinition>;
		"locationDefinitions"?: Array<Models.LocationDefinition>;
		"orgAuthorization"?: Array<Models.DomainOrganizationRole>;
		"favorites"?: Array<Models.User>;
		"superiors"?: Array<Models.User>;
		"directReports"?: Array<Models.User>;
		"adjacents"?: Models.Adjacents;
		"routingSkills"?: Array<Models.RoutingSkill>;
		"fieldConfigs"?: Models.FieldConfigs;
		"token"?: Models.TokenInfo;
		"trustors"?: Array<Models.Trustor>;
		"orgProducts"?: Array<Models.DomainOrganizationProduct>;
		"selfUri"?: string;
	}
	
	export interface UserObservationDataContainer { 
		"group"?: { [key: string]: string; };
		"data"?: Array<Models.ObservationMetricData>;
	}
	
	export interface UserObservationQuery { 
		"filter": Models.UserObservationQueryFilter;
		"metrics": Array<string>;
		"detailMetrics"?: Array<string>;
	}
	
	export interface UserObservationQueryClause { 
		"type": string;
		"predicates": Array<Models.UserObservationQueryPredicate>;
	}
	
	export interface UserObservationQueryFilter { 
		"type": string;
		"clauses"?: Array<Models.UserObservationQueryClause>;
		"predicates"?: Array<Models.UserObservationQueryPredicate>;
	}
	
	export interface UserObservationQueryPredicate { 
		"type"?: string;
		"dimension"?: string;
		"operator"?: string;
		"value"?: string;
		"range"?: Models.NumericRange;
	}
	
	export interface UserObservationQueryResponse { 
		"results"?: Array<Models.UserObservationDataContainer>;
	}
	
	export interface UserParam { 
		"key"?: string;
		"value"?: string;
	}
	
	export interface UserPresence { 
		"id"?: string;
		"name"?: string;
		"source"?: string;
		"sourceId"?: string;
		"primary"?: boolean;
		"presenceDefinition"?: Models.PresenceDefinition;
		"message"?: string;
		"modifiedDate"?: string;
		"selfUri"?: string;
	}
	
	export interface UserPresenceEvent { 
		"eventId": string;
		"eventDateTime": string;
		"userId": string;
		"sourceId": string;
		"presenceDefinitionId"?: string;
		"message"?: string;
	}
	
	export interface UserPrimarySource { 
		"id"?: string;
		"name"?: string;
		"sourceId"?: string;
		"registered"?: boolean;
		"selfUri"?: string;
	}
	
	export interface UserProfile { 
		"id"?: string;
		"name"?: string;
		"state"?: string;
		"dateModified"?: string;
		"version": number;
		"expands"?: Models.UserExpands;
		"selfUri"?: string;
	}
	
	export interface UserProfileEntityListing { 
		"entities"?: Array<Models.UserProfile>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserProfilesInDateRange { 
		"user"?: Models.UserReference;
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"profiles"?: Array<Models.ProfileWithDateRange>;
	}
	
	export interface UserProfilesInDateRangeRequest { 
		"startWorkday": string;
		"endWorkday": string;
	}
	
	export interface UserQueue { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: string;
		"createdBy"?: string;
		"memberCount"?: number;
		"userMemberCount"?: number;
		"joinedMemberCount"?: number;
		"mediaSettings"?: Models.QueueMediaSettings;
		"routingRules"?: Array<Models.RoutingRule>;
		"conditionalGroupRouting"?: Models.ConditionalGroupRouting;
		"bullseye"?: Models.Bullseye;
		"scoringMethod"?: string;
		"acwSettings"?: Models.AcwSettings;
		"skillEvaluationMethod"?: string;
		"memberGroups"?: Array<Models.MemberGroup>;
		"queueFlow"?: Models.DomainEntityRef;
		"emailInQueueFlow"?: Models.DomainEntityRef;
		"messageInQueueFlow"?: Models.DomainEntityRef;
		"whisperPrompt"?: Models.DomainEntityRef;
		"onHoldPrompt"?: Models.DomainEntityRef;
		"enableTranscription"?: boolean;
		"enableAudioMonitoring"?: boolean;
		"enableManualAssignment"?: boolean;
		"agentOwnedRouting"?: Models.AgentOwnedRouting;
		"directRouting"?: Models.DirectRouting;
		"callingPartyName"?: string;
		"callingPartyNumber"?: string;
		"defaultScripts"?: { [key: string]: Models.Script; };
		"outboundMessagingAddresses"?: Models.QueueMessagingAddresses;
		"outboundEmailAddress"?: Models.QueueEmailAddress;
		"peerId"?: string;
		"suppressInQueueCallRecording"?: boolean;
		"joined"?: boolean;
		"selfUri"?: string;
	}
	
	export interface UserQueueEntityListing { 
		"entities"?: Array<Models.UserQueue>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserRecording { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"contentUri"?: string;
		"workspace"?: Models.DomainEntityRef;
		"createdBy"?: Models.DomainEntityRef;
		"conversation"?: Models.Conversation;
		"contentLength"?: number;
		"durationMilliseconds"?: number;
		"thumbnails"?: Array<Models.DocumentThumbnail>;
		"read"?: boolean;
		"selfUri"?: string;
	}
	
	export interface UserRecordingEntityListing { 
		"entities"?: Array<Models.UserRecording>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface UserReferenceWithName { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface UserRoutingLanguage { 
		"id"?: string;
		"name"?: string;
		"proficiency"?: number;
		"state"?: string;
		"languageUri"?: string;
		"selfUri"?: string;
	}
	
	export interface UserRoutingLanguagePost { 
		"id": string;
		"proficiency": number;
		"languageUri"?: string;
		"selfUri"?: string;
	}
	
	export interface UserRoutingSkill { 
		"id"?: string;
		"name"?: string;
		"proficiency"?: number;
		"state"?: string;
		"skillUri"?: string;
		"selfUri"?: string;
	}
	
	export interface UserRoutingSkillPost { 
		"id": string;
		"proficiency": number;
		"skillUri"?: string;
		"selfUri"?: string;
	}
	
	export interface UserRoutingStatusErrorInfo { 
		"errorCode"?: string;
		"status"?: number;
		"correlationId"?: string;
		"userMessage"?: string;
		"userParamsMessage"?: string;
		"userParams"?: Array<Models.UserRoutingStatusUserParam>;
	}
	
	export interface UserRoutingStatusEvent { 
		"eventId": string;
		"eventDateTime": string;
		"agentId": string;
		"status": string;
		"sourceId": string;
	}
	
	export interface UserRoutingStatusObject { 
	}
	
	export interface UserRoutingStatusRoutingStatus { 
		"status"?: string;
		"startTime"?: string;
	}
	
	export interface UserRoutingStatusUserParam { 
		"key"?: string;
		"value"?: string;
		"additionalProperties"?: { [key: string]: object; };
	}
	
	export interface UserRoutingStatusUserRoutingStatus { 
		"id"?: string;
		"routingStatus"?: Models.UserRoutingStatusRoutingStatus;
		"errorInfo"?: Models.UserRoutingStatusErrorInfo;
	}
	
	export interface UserSchedule { 
		"shifts"?: Array<Models.UserScheduleShift>;
		"fullDayTimeOffMarkers"?: Array<Models.UserScheduleFullDayTimeOffMarker>;
		"delete"?: boolean;
		"metadata": Models.WfmVersionedEntityMetadata;
		"workPlanId"?: string;
	}
	
	export interface UserScheduleActivity { 
		"activityCodeId"?: string;
		"startDate"?: string;
		"lengthInMinutes"?: number;
		"description"?: string;
		"countsAsPaidTime"?: boolean;
		"isDstFallback"?: boolean;
		"timeOffRequestId"?: string;
	}
	
	export interface UserScheduleAdherence { 
		"id"?: string;
		"name"?: string;
		"user"?: Models.UserReference;
		"businessUnit"?: Models.BusinessUnitReference;
		"managementUnit"?: Models.ManagementUnitReference;
		"team"?: Models.TeamReference;
		"scheduledActivityCategory"?: string;
		"scheduledActivityCode"?: Models.ActivityCodeReference;
		"systemPresence"?: string;
		"organizationSecondaryPresenceId"?: string;
		"routingStatus"?: string;
		"actualActivityCategory"?: string;
		"isOutOfOffice"?: boolean;
		"adherenceState"?: string;
		"impact"?: string;
		"adherenceExplanation"?: Models.RealTimeAdherenceExplanation;
		"timeOfAdherenceChange"?: string;
		"presenceUpdateTime"?: string;
		"activeQueues"?: Array<Models.QueueReference>;
		"activeQueuesModifiedTime"?: string;
		"removedFromManagementUnit"?: boolean;
		"selfUri"?: string;
	}
	
	export interface UserScheduleAdherenceListing { 
		"entities"?: Array<Models.UserScheduleAdherence>;
		"downloadUrl"?: string;
	}
	
	export interface UserScheduleContainer { 
		"managementUnitTimeZone"?: string;
		"publishedSchedules"?: Array<Models.WeekScheduleReference>;
		"userSchedules"?: { [key: string]: Models.UserSchedule; };
	}
	
	export interface UserScheduleFullDayTimeOffMarker { 
		"managementUnitDate"?: string;
		"activityCodeId"?: string;
		"isPaid"?: boolean;
		"lengthInMinutes"?: number;
		"description"?: string;
		"delete"?: boolean;
	}
	
	export interface UserScheduleShift { 
		"weekSchedule"?: Models.WeekScheduleReference;
		"id"?: string;
		"startDate"?: string;
		"lengthInMinutes"?: number;
		"activities"?: Array<Models.UserScheduleActivity>;
		"delete"?: boolean;
		"manuallyEdited"?: boolean;
	}
	
	export interface UserSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.UserSearchCriteria>;
		"dateFormat"?: string;
		"fields"?: Array<string>;
		"type": string;
	}
	
	export interface UserSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"expand"?: Array<string>;
		"query"?: Array<Models.UserSearchCriteria>;
		"integrationPresenceSource"?: string;
		"enforcePermissions"?: boolean;
	}
	
	export interface UserSkillEntityListing { 
		"entities"?: Array<Models.UserRoutingSkill>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UserSkillGroupEntityListing { 
		"entities"?: Array<Models.SkillGroup>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface UserStaffingGroupListing { 
		"entities"?: Array<Models.UserStaffingGroupResponse>;
	}
	
	export interface UserStaffingGroupResponse { 
		"user"?: Models.UserReference;
		"staffingGroup"?: Models.StaffingGroupReference;
	}
	
	export interface UserStartDetailEventTopicUserStartEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"userId"?: string;
		"divisionId"?: string;
		"queueId"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface UserState { 
		"state"?: string;
		"version"?: number;
		"stateChangeReason"?: string;
		"stateChangeDate"?: string;
	}
	
	export interface UserStation { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
		"associatedUser"?: Models.User;
		"associatedDate"?: string;
		"defaultUser"?: Models.User;
		"providerInfo"?: { [key: string]: string; };
		"webRtcCallAppearances"?: number;
	}
	
	export interface UserStationChangeTopicUser { 
		"id"?: string;
	}
	
	export interface UserStationChangeTopicUserStation { 
		"id"?: string;
		"name"?: string;
		"associatedUser"?: Models.UserStationChangeTopicUser;
	}
	
	export interface UserStationChangeTopicUserStations { 
		"associatedStation"?: Models.UserStationChangeTopicUserStation;
	}
	
	export interface UserStations { 
		"associatedStation"?: Models.UserStation;
		"effectiveStation"?: Models.UserStation;
		"defaultStation"?: Models.UserStation;
		"lastAssociatedStation"?: Models.UserStation;
	}
	
	export interface UserTimeOffIntegrationStatusResponse { 
		"timeOffRequest": Models.TimeOffRequestReference;
		"integrationStatus": string;
		"user": Models.UserReference;
	}
	
	export interface UserTimeOffIntegrationStatusResponseListing { 
		"entities"?: Array<Models.UserTimeOffIntegrationStatusResponse>;
	}
	
	export interface UserTimeOffRequestReference { 
		"id"?: string;
		"user": Models.UserReference;
		"selfUri"?: string;
	}
	
	export interface UserTokensTopicTokenNotification { 
		"user"?: Models.UserTokensTopicUriReference;
		"ipAddress"?: string;
		"dateCreated"?: string;
		"tokenExpirationDate"?: string;
		"sessionId"?: string;
		"clientId"?: string;
		"tokenHash"?: string;
	}
	
	export interface UserTokensTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface UserTransferEvent { 
		"eventId": string;
		"eventDateTime": string;
		"conversationId": string;
		"transferType": string;
		"commandId": string;
		"initiatingCommunicationId": string;
		"targetCommunicationId": string;
		"objectCommunicationId": string;
		"destinationUserId": string;
	}
	
	export interface UserTrendData { 
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"percentOfGoal"?: number;
		"averageValue"?: number;
		"rankTotalPoints"?: number;
		"rankPercentagePoints"?: number;
	}
	
	export interface UserVideoSettings { 
		"allowCamera"?: boolean;
		"allowScreenShare"?: boolean;
	}
	
	export interface UsersSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.User>;
	}
	
	export interface UtilizationLabel { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface UtilizationLabelEntityListing { 
		"entities"?: Array<Models.UtilizationLabel>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface UtilizationRequest { 
		"utilization"?: { [key: string]: Models.MediaUtilization; };
	}
	
	export interface UtilizationResponse { 
		"utilization"?: { [key: string]: Models.MediaUtilization; };
	}
	
	export interface UtilizationTag { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface UtilizationTagEntityListing { 
		"entities"?: Array<Models.UtilizationTag>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface Utterance { 
		"utteranceText"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationButtonComponent { 
		"title"?: string;
		"actions"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentActions;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentActions { 
		"url"?: string;
		"urlTarget"?: string;
		"textback"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentAttachment { 
		"id"?: string;
		"mediaType"?: string;
		"url"?: string;
		"mime"?: string;
		"text"?: string;
		"sha256"?: string;
		"filename"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentButtonResponse { 
		"type"?: string;
		"text"?: string;
		"payload"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentGeneric { 
		"title"?: string;
		"description"?: string;
		"image"?: string;
		"video"?: string;
		"actions"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentActions;
		"components"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationButtonComponent>;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentLocation { 
		"url"?: string;
		"address"?: string;
		"text"?: string;
		"latitude"?: number;
		"longitude"?: number;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentNotificationTemplate { 
		"id"?: string;
		"language"?: string;
		"header"?: Models.V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateHeader;
		"body"?: Models.V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateBody;
		"footer"?: Models.V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateFooter;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentQuickReply { 
		"text"?: string;
		"payload"?: string;
		"image"?: string;
		"action"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationContentStory { 
		"type"?: string;
		"url"?: string;
		"replyToId"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationEventCoBrowse { 
		"type"?: string;
		"sessionId"?: string;
		"sessionJoinToken"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationEventTyping { 
		"type"?: string;
		"duration"?: number;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationMessageContent { 
		"contentType"?: string;
		"location"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentLocation;
		"story"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentStory;
		"attachment"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentAttachment;
		"quickReply"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentQuickReply;
		"template"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentNotificationTemplate;
		"buttonResponse"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentButtonResponse;
		"generic"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentGeneric;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationMessageEvent { 
		"eventType"?: string;
		"coBrowse"?: Models.V2ConversationMessageTypingEventForUserTopicConversationEventCoBrowse;
		"typing"?: Models.V2ConversationMessageTypingEventForUserTopicConversationEventTyping;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationMessagingChannel { 
		"id"?: string;
		"platform"?: string;
		"messageId"?: string;
		"to"?: Models.V2ConversationMessageTypingEventForUserTopicConversationMessagingToRecipient;
		"from"?: Models.V2ConversationMessageTypingEventForUserTopicConversationMessagingFromRecipient;
		"time"?: string;
		"dateModified"?: string;
		"dateDeleted"?: string;
		"metadata"?: Models.V2ConversationMessageTypingEventForUserTopicConversationMessagingChannelMetadata;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationMessagingChannelMetadata { 
		"customAttributes"?: { [key: string]: string; };
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationMessagingFromRecipient { 
		"nickname"?: string;
		"id"?: string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationRecipientAdditionalIdentifier>;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationMessagingToRecipient { 
		"nickname"?: string;
		"id"?: string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationRecipientAdditionalIdentifier>;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationNormalizedMessage { 
		"id"?: string;
		"channel"?: Models.V2ConversationMessageTypingEventForUserTopicConversationMessagingChannel;
		"type"?: string;
		"text"?: string;
		"content"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationMessageContent>;
		"events"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationMessageEvent>;
		"status"?: string;
		"reasons"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationReason>;
		"originatingEntity"?: string;
		"isFinalReceipt"?: boolean;
		"direction"?: string;
		"metadata"?: { [key: string]: string; };
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateBody { 
		"text"?: string;
		"parameters"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateParameter>;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateFooter { 
		"text"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateHeader { 
		"type"?: string;
		"text"?: string;
		"media"?: Models.V2ConversationMessageTypingEventForUserTopicConversationContentAttachment;
		"parameters"?: Array<Models.V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateParameter>;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationNotificationTemplateParameter { 
		"name"?: string;
		"text"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationReason { 
		"code"?: string;
		"message"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicConversationRecipientAdditionalIdentifier { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForUserTopicMessageData { 
		"conversationId"?: string;
		"normalizedMessage"?: Models.V2ConversationMessageTypingEventForUserTopicConversationNormalizedMessage;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationButtonComponent { 
		"title"?: string;
		"actions"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentActions;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentActions { 
		"url"?: string;
		"urlTarget"?: string;
		"textback"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentAttachment { 
		"id"?: string;
		"mediaType"?: string;
		"url"?: string;
		"mime"?: string;
		"text"?: string;
		"sha256"?: string;
		"filename"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentButtonResponse { 
		"type"?: string;
		"text"?: string;
		"payload"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentGeneric { 
		"title"?: string;
		"description"?: string;
		"image"?: string;
		"video"?: string;
		"actions"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentActions;
		"components"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationButtonComponent>;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentLocation { 
		"url"?: string;
		"address"?: string;
		"text"?: string;
		"latitude"?: number;
		"longitude"?: number;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentNotificationTemplate { 
		"id"?: string;
		"language"?: string;
		"header"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateHeader;
		"body"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateBody;
		"footer"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateFooter;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentQuickReply { 
		"text"?: string;
		"payload"?: string;
		"image"?: string;
		"action"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationContentStory { 
		"type"?: string;
		"url"?: string;
		"replyToId"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationEventCoBrowse { 
		"type"?: string;
		"sessionId"?: string;
		"sessionJoinToken"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationEventTyping { 
		"type"?: string;
		"duration"?: number;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationMessageContent { 
		"contentType"?: string;
		"location"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentLocation;
		"story"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentStory;
		"attachment"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentAttachment;
		"quickReply"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentQuickReply;
		"template"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentNotificationTemplate;
		"buttonResponse"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentButtonResponse;
		"generic"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentGeneric;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationMessageEvent { 
		"eventType"?: string;
		"coBrowse"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationEventCoBrowse;
		"typing"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationEventTyping;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingChannel { 
		"id"?: string;
		"platform"?: string;
		"messageId"?: string;
		"to"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingToRecipient;
		"from"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingFromRecipient;
		"time"?: string;
		"dateModified"?: string;
		"dateDeleted"?: string;
		"metadata"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingChannelMetadata;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingChannelMetadata { 
		"customAttributes"?: { [key: string]: string; };
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingFromRecipient { 
		"nickname"?: string;
		"id"?: string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationRecipientAdditionalIdentifier>;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingToRecipient { 
		"nickname"?: string;
		"id"?: string;
		"idType"?: string;
		"image"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"additionalIds"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationRecipientAdditionalIdentifier>;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationNormalizedMessage { 
		"id"?: string;
		"channel"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationMessagingChannel;
		"type"?: string;
		"text"?: string;
		"content"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationMessageContent>;
		"events"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationMessageEvent>;
		"status"?: string;
		"reasons"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationReason>;
		"originatingEntity"?: string;
		"isFinalReceipt"?: boolean;
		"direction"?: string;
		"metadata"?: { [key: string]: string; };
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateBody { 
		"text"?: string;
		"parameters"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateParameter>;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateFooter { 
		"text"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateHeader { 
		"type"?: string;
		"text"?: string;
		"media"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationContentAttachment;
		"parameters"?: Array<Models.V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateParameter>;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationNotificationTemplateParameter { 
		"name"?: string;
		"text"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationReason { 
		"code"?: string;
		"message"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicConversationRecipientAdditionalIdentifier { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface V2ConversationMessageTypingEventForWorkflowTopicMessageData { 
		"conversationId"?: string;
		"normalizedMessage"?: Models.V2ConversationMessageTypingEventForWorkflowTopicConversationNormalizedMessage;
	}
	
	export interface V2FlowExecutionDataFlowidTopicExecution { 
		"objectType"?: string;
		"objectId"?: string;
		"outputPathId"?: string;
		"executionId"?: string;
		"startDateTime"?: string;
		"error"?: Models.V2FlowExecutionDataFlowidTopicFlowErrorWarningInfo;
		"warning"?: Models.V2FlowExecutionDataFlowidTopicFlowErrorWarningInfo;
		"languageTag"?: string;
	}
	
	export interface V2FlowExecutionDataFlowidTopicFlow { 
		"flowExecutionId"?: string;
		"objectExecutionId"?: string;
	}
	
	export interface V2FlowExecutionDataFlowidTopicFlowErrorWarningInfo { 
		"reason"?: string;
		"executionId"?: string;
		"objectId"?: string;
	}
	
	export interface V2FlowExecutionDataFlowidTopicFlowExecutionHistory { 
		"executionId"?: string;
		"conversationId"?: string;
		"divisionId"?: string;
		"endDateTime"?: string;
		"endpoint"?: string;
		"errors"?: Array<Models.V2FlowExecutionDataFlowidTopicFlowErrorWarningInfo>;
		"execution"?: Array<Models.V2FlowExecutionDataFlowidTopicExecution>;
		"flowExitReason"?: string;
		"flowId"?: string;
		"flowIsDebug"?: boolean;
		"executionItemsTruncated"?: boolean;
		"flowType"?: string;
		"flowVersion"?: string;
		"messageType"?: string;
		"invokingContext"?: Models.V2FlowExecutionDataFlowidTopicInvokingContext;
		"startDateTime"?: string;
		"warnings"?: Array<Models.V2FlowExecutionDataFlowidTopicFlowErrorWarningInfo>;
	}
	
	export interface V2FlowExecutionDataFlowidTopicInvokingContext { 
		"flow"?: Models.V2FlowExecutionDataFlowidTopicFlow;
		"journeyActionMap"?: Models.V2FlowExecutionDataFlowidTopicJourneyActionMap;
		"processAutomation"?: Models.V2FlowExecutionDataFlowidTopicProcessAutomation;
		"quality"?: Models.V2FlowExecutionDataFlowidTopicQuality;
	}
	
	export interface V2FlowExecutionDataFlowidTopicJourneyActionMap { 
		"actionMapId"?: string;
		"actionId"?: string;
	}
	
	export interface V2FlowExecutionDataFlowidTopicProcessAutomation { 
		"triggerId"?: string;
		"triggerName"?: string;
	}
	
	export interface V2FlowExecutionDataFlowidTopicQuality { 
		"policyId"?: string;
		"policyName"?: string;
	}
	
	export interface V2MobiusAlertsTopicAddressableEntityRef { 
		"id"?: string;
	}
	
	export interface V2MobiusAlertsTopicAlert { 
		"rule"?: Models.V2MobiusAlertsTopicAlertRuleProperties;
		"id"?: string;
		"userId"?: string;
		"notifications"?: Array<Models.V2MobiusAlertsTopicAlertNotification>;
		"dateStart"?: string;
		"dateEnd"?: string;
		"conditions"?: Models.V2MobiusAlertsTopicCondition;
		"additionalProperties"?: { [key: string]: string; };
		"active"?: boolean;
		"unread"?: boolean;
		"muted"?: boolean;
		"snoozed"?: boolean;
		"dateMutedUntil"?: string;
		"dateSnoozedUntil"?: string;
		"action"?: string;
		"alertSummary"?: Models.V2MobiusAlertsTopicAlertSummary;
		"sendExitingAlarmNotification"?: boolean;
	}
	
	export interface V2MobiusAlertsTopicAlertNotification { 
		"recipient"?: string;
		"notificationTypes"?: Array<string>;
		"locale"?: string;
	}
	
	export interface V2MobiusAlertsTopicAlertRuleProperties { 
		"id"?: string;
		"name"?: string;
		"type"?: string;
	}
	
	export interface V2MobiusAlertsTopicAlertSummary { 
		"entities"?: Array<Models.V2MobiusAlertsTopicAlertSummaryEntity>;
		"conversation"?: Models.V2MobiusAlertsTopicAddressableEntityRef;
		"metricType"?: string;
		"isTeamMemberRuleSummary"?: boolean;
		"teamMemberRuleSummary"?: boolean;
	}
	
	export interface V2MobiusAlertsTopicAlertSummaryEntity { 
		"entityType"?: string;
		"user"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"group"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"queue"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"team"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"alerting"?: boolean;
	}
	
	export interface V2MobiusAlertsTopicAlertingAddressableEntityRef { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface V2MobiusAlertsTopicCondition { 
		"id"?: string;
		"conditions"?: Array<Models.V2MobiusAlertsTopicCondition>;
		"predicates"?: Array<Models.V2MobiusAlertsTopicConditionRulePredicate>;
		"type"?: string;
	}
	
	export interface V2MobiusAlertsTopicConditionRulePredicate { 
		"id"?: string;
		"entity"?: Models.V2MobiusAlertsTopicEntityProperties;
		"metric"?: string;
		"metricType"?: string;
		"metricValueType"?: string;
		"value"?: number;
		"status"?: string;
		"mediaType"?: string;
		"comparisonOperator"?: string;
	}
	
	export interface V2MobiusAlertsTopicEntityProperties { 
		"entityType"?: string;
		"user"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"group"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"queue"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
		"team"?: Models.V2MobiusAlertsTopicAlertingAddressableEntityRef;
	}
	
	export interface V2MobiusRulesTopicAlertNotification { 
		"recipient"?: string;
		"notificationTypes"?: Array<string>;
		"locale"?: string;
	}
	
	export interface V2MobiusRulesTopicAlertingAddressableEntityRef { 
		"id"?: string;
		"displayName"?: string;
	}
	
	export interface V2MobiusRulesTopicCondition { 
		"id"?: string;
		"conditions"?: Array<Models.V2MobiusRulesTopicCondition>;
		"predicates"?: Array<Models.V2MobiusRulesTopicConditionRulePredicate>;
		"type"?: string;
	}
	
	export interface V2MobiusRulesTopicConditionRulePredicate { 
		"id"?: string;
		"entity"?: Models.V2MobiusRulesTopicEntityProperties;
		"metric"?: string;
		"metricType"?: string;
		"metricValueType"?: string;
		"value"?: number;
		"status"?: string;
		"mediaType"?: string;
		"comparisonOperator"?: string;
	}
	
	export interface V2MobiusRulesTopicEntityProperties { 
		"entityType"?: string;
		"user"?: Models.V2MobiusRulesTopicAlertingAddressableEntityRef;
		"group"?: Models.V2MobiusRulesTopicAlertingAddressableEntityRef;
		"queue"?: Models.V2MobiusRulesTopicAlertingAddressableEntityRef;
		"team"?: Models.V2MobiusRulesTopicAlertingAddressableEntityRef;
	}
	
	export interface V2MobiusRulesTopicRule { 
		"id"?: string;
		"userId"?: string;
		"name"?: string;
		"type"?: string;
		"notifications"?: Array<Models.V2MobiusRulesTopicAlertNotification>;
		"conditions"?: Models.V2MobiusRulesTopicCondition;
		"enabled"?: boolean;
		"inAlarm"?: boolean;
		"action"?: string;
		"dateCreated"?: string;
		"sendExitingAlarmNotification"?: boolean;
		"waitBetweenNotificationMs"?: number;
	}
	
	export interface ValidateAddressRequest { 
		"address"?: Models.StreetAddress;
	}
	
	export interface ValidateAddressResponse { 
		"valid": boolean;
		"response"?: Models.SubscriberResponse;
	}
	
	export interface ValidateAssignUsers { 
		"membersToAssign": Array<string>;
	}
	
	export interface ValidateWorkPlanMessages { 
		"violationMessages"?: Array<Models.WorkPlanConfigurationViolationMessage>;
		"constraintConflictMessage"?: Models.ConstraintConflictMessage;
	}
	
	export interface ValidateWorkPlanResponse { 
		"workPlan"?: Models.WorkPlanReference;
		"valid"?: boolean;
		"messages"?: Models.ValidateWorkPlanMessages;
	}
	
	export interface ValidationLimits { 
		"minLength"?: Models.MinLength;
		"maxLength"?: Models.MaxLength;
		"minItems"?: Models.MinLength;
		"maxItems"?: Models.MaxLength;
		"minimum"?: Models.MinLength;
		"maximum"?: Models.MaxLength;
	}
	
	export interface ValidationServiceRequest { 
		"dateImportEnded": string;
		"uploadKey": string;
	}
	
	export interface ValueWrapperDate { 
		"value"?: string;
	}
	
	export interface ValueWrapperHrisTimeOffType { 
		"value"?: Models.HrisTimeOffType;
	}
	
	export interface ValueWrapperPlanningPeriodSettings { 
		"value"?: Models.PlanningPeriodSettings;
	}
	
	export interface ValueWrapperString { 
		"value"?: string;
	}
	
	export interface VerificationResult { 
		"status"?: string;
		"records"?: Array<Models.Record>;
	}
	
	export interface Verifier { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"default"?: boolean;
		"selfUri"?: string;
	}
	
	export interface VerifierEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.Verifier>;
		"selfUri"?: string;
	}
	
	export interface Video { 
		"state"?: string;
		"initialState"?: string;
		"id"?: string;
		"context"?: string;
		"audioMuted"?: boolean;
		"videoMuted"?: boolean;
		"sharingScreen"?: boolean;
		"peerCount"?: number;
		"disconnectType"?: string;
		"startAlertingTime"?: string;
		"connectedTime"?: string;
		"disconnectedTime"?: string;
		"provider"?: string;
		"peerId"?: string;
		"msids"?: Array<string>;
		"self"?: Models.Address;
		"wrapup"?: Models.Wrapup;
		"afterCallWork"?: Models.AfterCallWork;
		"afterCallWorkRequired"?: boolean;
	}
	
	export interface VideoConferenceDetails { 
		"conferenceId"?: string;
		"conversationId"?: string;
		"participantInfo"?: Models.ParticipantInfo;
	}
	
	export interface VideoConferenceUpdateTopicParticipantInfo { 
		"activeParticipantCount"?: number;
		"version"?: number;
	}
	
	export interface VideoConferenceUpdateTopicVideoConference { 
		"conversationId"?: string;
		"conferenceId"?: string;
		"participantInfo"?: Models.VideoConferenceUpdateTopicParticipantInfo;
	}
	
	export interface VideoSettings { 
		"enabled"?: boolean;
		"agent"?: Models.AgentVideoSettings;
		"user"?: Models.UserVideoSettings;
	}
	
	export interface ViewFilter { 
		"mediaTypes"?: Array<string>;
		"queueIds"?: Array<string>;
		"skillIds"?: Array<string>;
		"skillGroups"?: Array<string>;
		"languageIds"?: Array<string>;
		"languageGroups"?: Array<string>;
		"directions"?: Array<string>;
		"originatingDirections"?: Array<string>;
		"wrapUpCodes"?: Array<string>;
		"dnisList"?: Array<string>;
		"sessionDnisList"?: Array<string>;
		"filterQueuesByUserIds"?: Array<string>;
		"filterUsersByQueueIds"?: Array<string>;
		"userIds"?: Array<string>;
		"managementUnitIds"?: Array<string>;
		"addressTos"?: Array<string>;
		"addressFroms"?: Array<string>;
		"outboundCampaignIds"?: Array<string>;
		"outboundContactListIds"?: Array<string>;
		"contactIds"?: Array<string>;
		"externalContactIds"?: Array<string>;
		"externalOrgIds"?: Array<string>;
		"aniList"?: Array<string>;
		"durationsMilliseconds"?: Array<Models.NumericRange>;
		"acdDurationsMilliseconds"?: Array<Models.NumericRange>;
		"talkDurationsMilliseconds"?: Array<Models.NumericRange>;
		"acwDurationsMilliseconds"?: Array<Models.NumericRange>;
		"handleDurationsMilliseconds"?: Array<Models.NumericRange>;
		"holdDurationsMilliseconds"?: Array<Models.NumericRange>;
		"abandonDurationsMilliseconds"?: Array<Models.NumericRange>;
		"evaluationScore"?: Models.NumericRange;
		"evaluationCriticalScore"?: Models.NumericRange;
		"evaluationFormIds"?: Array<string>;
		"evaluatedAgentIds"?: Array<string>;
		"evaluatorIds"?: Array<string>;
		"transferred"?: boolean;
		"abandoned"?: boolean;
		"answered"?: boolean;
		"messageTypes"?: Array<string>;
		"divisionIds"?: Array<string>;
		"surveyFormIds"?: Array<string>;
		"surveyTotalScore"?: Models.NumericRange;
		"surveyNpsScore"?: Models.NumericRange;
		"mos"?: Models.NumericRange;
		"surveyQuestionGroupScore"?: Models.NumericRange;
		"surveyPromoterScore"?: Models.NumericRange;
		"surveyFormContextIds"?: Array<string>;
		"conversationIds"?: Array<string>;
		"sipCallIds"?: Array<string>;
		"isEnded"?: boolean;
		"isSurveyed"?: boolean;
		"surveyScores"?: Array<Models.NumericRange>;
		"promoterScores"?: Array<Models.NumericRange>;
		"isCampaign"?: boolean;
		"surveyStatuses"?: Array<string>;
		"conversationProperties"?: Models.ConversationProperties;
		"isBlindTransferred"?: boolean;
		"isConsulted"?: boolean;
		"isConsultTransferred"?: boolean;
		"remoteParticipants"?: Array<string>;
		"flowIds"?: Array<string>;
		"flowOutcomeIds"?: Array<string>;
		"flowOutcomeValues"?: Array<string>;
		"flowDestinationTypes"?: Array<string>;
		"flowDisconnectReasons"?: Array<string>;
		"flowTypes"?: Array<string>;
		"flowEntryTypes"?: Array<string>;
		"flowEntryReasons"?: Array<string>;
		"flowVersions"?: Array<string>;
		"groupIds"?: Array<string>;
		"hasJourneyCustomerId"?: boolean;
		"hasJourneyActionMapId"?: boolean;
		"hasJourneyVisitId"?: boolean;
		"hasMedia"?: boolean;
		"roleIds"?: Array<string>;
		"reportsTos"?: Array<string>;
		"locationIds"?: Array<string>;
		"flowOutTypes"?: Array<string>;
		"providerList"?: Array<string>;
		"callbackNumberList"?: Array<string>;
		"callbackInterval"?: string;
		"usedRoutingTypes"?: Array<string>;
		"requestedRoutingTypes"?: Array<string>;
		"hasAgentAssistId"?: boolean;
		"transcripts"?: Array<Models.Transcripts>;
		"transcriptLanguages"?: Array<string>;
		"participantPurposes"?: Array<string>;
		"showFirstQueue"?: boolean;
		"teamIds"?: Array<string>;
		"filterUsersByTeamIds"?: Array<string>;
		"journeyActionMapIds"?: Array<string>;
		"journeyOutcomeIds"?: Array<string>;
		"journeySegmentIds"?: Array<string>;
		"journeyActionMapTypes"?: Array<string>;
		"developmentRoleList"?: Array<string>;
		"developmentTypeList"?: Array<string>;
		"developmentStatusList"?: Array<string>;
		"developmentModuleIds"?: Array<string>;
		"developmentActivityOverdue"?: boolean;
		"customerSentimentScore"?: Models.NumericRange;
		"customerSentimentTrend"?: Models.NumericRange;
		"flowTransferTargets"?: Array<string>;
		"developmentName"?: string;
		"topicIds"?: Array<string>;
		"externalTags"?: Array<string>;
		"isNotResponding"?: boolean;
		"isAuthenticated"?: boolean;
		"botIds"?: Array<string>;
		"botVersions"?: Array<string>;
		"botMessageTypes"?: Array<string>;
		"botProviderList"?: Array<string>;
		"botProductList"?: Array<string>;
		"botRecognitionFailureReasonList"?: Array<string>;
		"botIntentList"?: Array<string>;
		"botFinalIntentList"?: Array<string>;
		"botSlotList"?: Array<string>;
		"botResultList"?: Array<string>;
		"blockedReasons"?: Array<string>;
		"isRecorded"?: boolean;
		"hasEvaluation"?: boolean;
		"hasScoredEvaluation"?: boolean;
		"emailDeliveryStatusList"?: Array<string>;
		"isAgentOwnedCallback"?: boolean;
		"agentCallbackOwnerIds"?: Array<string>;
		"transcriptTopics"?: Array<Models.TranscriptTopics>;
		"journeyFrequencyCapReasons"?: Array<string>;
		"journeyBlockingActionMapIds"?: Array<string>;
		"journeyActionTargetIds"?: Array<string>;
		"journeyBlockingScheduleGroupIds"?: Array<string>;
		"journeyBlockingEmergencyScheduleGroupIds"?: Array<string>;
		"journeyUrlEqualConditions"?: Array<string>;
		"journeyUrlNotEqualConditions"?: Array<string>;
		"journeyUrlStartsWithConditions"?: Array<string>;
		"journeyUrlEndsWithConditions"?: Array<string>;
		"journeyUrlContainsAnyConditions"?: Array<string>;
		"journeyUrlNotContainsAnyConditions"?: Array<string>;
		"journeyUrlContainsAllConditions"?: Array<string>;
		"journeyUrlNotContainsAllConditions"?: Array<string>;
		"flowMilestoneIds"?: Array<string>;
		"isAssessmentPassed"?: boolean;
		"conversationInitiators"?: Array<string>;
		"hasCustomerParticipated"?: boolean;
		"isAcdInteraction"?: boolean;
		"hasFax"?: boolean;
		"dataActionIds"?: Array<string>;
		"actionCategoryName"?: string;
		"integrationIds"?: Array<string>;
		"responseStatuses"?: Array<string>;
		"availableDashboard"?: string;
		"favouriteDashboard"?: boolean;
		"myDashboard"?: boolean;
		"stationErrors"?: Array<string>;
		"canonicalContactIds"?: Array<string>;
		"alertRuleIds"?: Array<string>;
		"evaluationFormContextIds"?: Array<string>;
		"evaluationStatuses"?: Array<string>;
		"workbinIds"?: Array<string>;
		"worktypeIds"?: Array<string>;
		"workitemIds"?: Array<string>;
		"workitemAssigneeIds"?: Array<string>;
		"workitemStatuses"?: Array<string>;
		"isAnalyzedForSensitiveData"?: boolean;
		"hasSensitiveData"?: boolean;
		"hasPciData"?: boolean;
		"hasPiiData"?: boolean;
		"subPath"?: string;
		"userState"?: string;
		"isClearedByCustomer"?: boolean;
		"evaluationAssigneeIds"?: Array<string>;
		"evaluationAssigned"?: boolean;
		"assistantIds"?: Array<string>;
		"knowledgeBaseIds"?: Array<string>;
		"isParked"?: boolean;
		"agentEmpathyScore"?: Models.NumericRange;
		"surveyTypes"?: Array<string>;
		"surveyResponseStatuses"?: Array<string>;
	}
	
	export interface VisibilityCondition { 
		"combiningOperation"?: string;
		"predicates"?: Array<object>;
	}
	
	export interface VmPairingInfo { 
		"meta-data"?: Models.MetaData;
		"edge-id"?: string;
		"auth-token"?: string;
		"org-id"?: string;
	}
	
	export interface Voicemail { 
		"id"?: string;
		"uploadStatus"?: string;
	}
	
	export interface VoicemailCopyRecord { 
		"user"?: Models.User;
		"group"?: Models.Group;
		"date"?: string;
	}
	
	export interface VoicemailEndDetailEventTopicVoicemailEndEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"disconnectType"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"userId"?: string;
		"queueId"?: string;
		"divisionId"?: string;
		"voicemailDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface VoicemailGroupPolicy { 
		"name"?: string;
		"group"?: Models.Group;
		"enabled"?: boolean;
		"sendEmailNotifications"?: boolean;
		"disableEmailPii"?: boolean;
		"includeEmailTranscriptions"?: boolean;
		"languagePreference"?: string;
		"rotateCallsSecs"?: number;
		"stopRingingAfterRotations"?: number;
		"overflowGroupId"?: string;
		"groupAlertType"?: string;
		"interactiveResponsePromptId"?: string;
		"interactiveResponseRequired"?: boolean;
	}
	
	export interface VoicemailMailboxInfo { 
		"usageSizeBytes"?: number;
		"totalCount"?: number;
		"unreadCount"?: number;
		"deletedCount"?: number;
		"createdDate"?: string;
		"modifiedDate"?: string;
	}
	
	export interface VoicemailMediaInfo { 
		"id"?: string;
		"mediaFileUri"?: string;
		"mediaImageUri"?: string;
		"waveformData"?: Array<number>;
	}
	
	export interface VoicemailMessage { 
		"id"?: string;
		"conversation"?: Models.Conversation;
		"read"?: boolean;
		"audioRecordingDurationSeconds"?: number;
		"audioRecordingSizeBytes"?: number;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"deletedDate"?: string;
		"callerAddress"?: string;
		"callerName"?: string;
		"callerUser"?: Models.User;
		"deleted"?: boolean;
		"note"?: string;
		"user"?: Models.User;
		"group"?: Models.Group;
		"queue"?: Models.Queue;
		"copiedFrom"?: Models.VoicemailCopyRecord;
		"copiedTo"?: Array<Models.VoicemailCopyRecord>;
		"deleteRetentionPolicy"?: Models.VoicemailRetentionPolicy;
		"selfUri"?: string;
	}
	
	export interface VoicemailMessageEntityListing { 
		"entities"?: Array<Models.VoicemailMessage>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface VoicemailMessagesTopicOwner { 
		"id"?: string;
	}
	
	export interface VoicemailMessagesTopicVoicemailCopyRecord { 
		"user"?: Models.VoicemailMessagesTopicOwner;
		"group"?: Models.VoicemailMessagesTopicOwner;
	}
	
	export interface VoicemailMessagesTopicVoicemailMessage { 
		"id"?: string;
		"read"?: boolean;
		"audioRecordingDurationSeconds"?: number;
		"audioRecordingSizeBytes"?: number;
		"createdDate"?: string;
		"modifiedDate"?: string;
		"createdDateString"?: string;
		"callerAddress"?: string;
		"callerName"?: string;
		"action"?: string;
		"note"?: string;
		"deleted"?: boolean;
		"modifiedByUserId"?: string;
		"copiedTo"?: Array<Models.VoicemailMessagesTopicVoicemailCopyRecord>;
		"copiedFrom"?: Models.VoicemailMessagesTopicVoicemailCopyRecord;
		"modifiedDateString"?: string;
	}
	
	export interface VoicemailOrganizationPolicy { 
		"enabled"?: boolean;
		"alertTimeoutSeconds"?: number;
		"pinConfiguration"?: Models.PINConfiguration;
		"voicemailExtension"?: string;
		"pinRequired"?: boolean;
		"interactiveResponseRequired"?: boolean;
		"sendEmailNotifications"?: boolean;
		"includeEmailTranscriptions"?: boolean;
		"disableEmailPii"?: boolean;
		"maximumRecordingTimeSeconds"?: number;
		"modifiedDate"?: string;
	}
	
	export interface VoicemailRetentionPolicy { 
		"voicemailRetentionPolicyType"?: string;
		"numberOfDays"?: number;
	}
	
	export interface VoicemailSearchCriteria { 
		"endValue"?: string;
		"values"?: Array<string>;
		"startValue"?: string;
		"value"?: string;
		"operator"?: string;
		"group"?: Array<Models.VoicemailSearchCriteria>;
		"dateFormat"?: string;
		"fields"?: Array<string>;
		"type": string;
	}
	
	export interface VoicemailSearchRequest { 
		"sortOrder"?: string;
		"sortBy"?: string;
		"pageSize"?: number;
		"pageNumber"?: number;
		"sort"?: Array<Models.SearchSort>;
		"expand"?: Array<string>;
		"query"?: Array<Models.VoicemailSearchCriteria>;
	}
	
	export interface VoicemailStartDetailEventTopicVoicemailStartEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"userId"?: string;
		"queueId"?: string;
		"divisionId"?: string;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface VoicemailUserPolicy { 
		"enabled"?: boolean;
		"alertTimeoutSeconds"?: number;
		"pin"?: string;
		"modifiedDate"?: string;
		"sendEmailNotifications"?: boolean;
	}
	
	export interface VoicemailsSearchResponse { 
		"total": number;
		"pageCount": number;
		"pageSize": number;
		"pageNumber": number;
		"previousPage"?: string;
		"currentPage"?: string;
		"nextPage"?: string;
		"types": Array<string>;
		"results": Array<Models.VoicemailMessage>;
	}
	
	export interface Void { 
	}
	
	export interface WaitlistPosition { 
		"timeOffRequest"?: Models.TimeOffRequestReference;
		"timeOffLimit"?: Models.TimeOffLimitReference;
		"date"?: string;
		"waitlistPosition"?: number;
	}
	
	export interface WaitlistPositionListing { 
		"entities"?: Array<Models.WaitlistPosition>;
	}
	
	export interface Warning { 
		"value"?: number;
		"rangeType"?: string;
		"color"?: string;
	}
	
	export interface WebActionEvent { 
		"action": Models.EventAction;
		"actionMap": Models.ActionEventActionMap;
		"actionTarget": Models.AddressableEntityRef;
		"timeToDisposition"?: number;
		"errorCode"?: string;
		"errorMessage"?: string;
		"userAgentString": string;
		"browser": Models.Browser;
		"device": Models.Device;
		"geolocation"?: Models.JourneyGeolocation;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"mktCampaign"?: Models.JourneyCampaign;
		"visitReferrer"?: Models.Referrer;
	}
	
	export interface WebChatConfig { 
		"webChatSkin"?: string;
	}
	
	export interface WebChatConversation { 
		"id"?: string;
		"name"?: string;
		"member"?: Models.WebChatMemberInfo;
		"selfUri"?: string;
	}
	
	export interface WebChatDeployment { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"authenticationRequired"?: boolean;
		"authenticationUrl"?: string;
		"disabled"?: boolean;
		"webChatConfig"?: Models.WebChatConfig;
		"allowedDomains"?: Array<string>;
		"flow"?: Models.DomainEntityRef;
		"selfUri"?: string;
	}
	
	export interface WebChatDeploymentEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.WebChatDeployment>;
		"selfUri"?: string;
	}
	
	export interface WebChatGuestMediaRequest { 
		"id"?: string;
		"name"?: string;
		"types": Array<string>;
		"state": string;
		"communicationId"?: string;
		"securityKey"?: string;
		"selfUri"?: string;
	}
	
	export interface WebChatGuestMediaRequestEntityList { 
		"entities"?: Array<Models.WebChatGuestMediaRequest>;
	}
	
	export interface WebChatMemberInfo { 
		"id"?: string;
		"displayName"?: string;
		"firstName"?: string;
		"lastName"?: string;
		"email"?: string;
		"phoneNumber"?: string;
		"avatarImageUrl"?: string;
		"role": string;
		"joinDate"?: string;
		"leaveDate"?: string;
		"authenticatedGuest"?: boolean;
		"customFields"?: { [key: string]: string; };
		"state"?: string;
	}
	
	export interface WebChatMemberInfoEntityList { 
		"entities"?: Array<Models.WebChatMemberInfo>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface WebChatMessage { 
		"id"?: string;
		"name"?: string;
		"conversation": Models.WebChatConversation;
		"sender": Models.WebChatMemberInfo;
		"body": string;
		"bodyType": string;
		"timestamp": string;
		"selfUri"?: string;
	}
	
	export interface WebChatMessageEntityList { 
		"pageSize"?: number;
		"entities"?: Array<Models.WebChatMessage>;
		"previousPage"?: string;
		"next"?: string;
		"selfUri"?: string;
	}
	
	export interface WebChatRoutingTarget { 
		"targetType": string;
		"targetAddress": string;
		"skills"?: Array<string>;
		"language"?: string;
		"priority"?: number;
	}
	
	export interface WebChatSettings { 
		"requireDeployment"?: boolean;
	}
	
	export interface WebChatTyping { 
		"id": string;
		"conversation": Models.WebChatConversation;
		"sender": Models.WebChatMemberInfo;
		"timestamp": string;
	}
	
	export interface WebDeployment { 
		"id"?: string;
		"name": string;
		"description"?: string;
		"allowAllDomains"?: boolean;
		"allowedDomains"?: Array<string>;
		"supportedContent"?: Models.SupportedContentReference;
		"snippet"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"lastModifiedUser"?: Models.AddressableEntityRef;
		"flow"?: Models.DomainEntityRef;
		"status"?: string;
		"configuration": Models.WebDeploymentConfigurationVersionEntityRef;
		"selfUri"?: string;
	}
	
	export interface WebDeploymentActiveConfigurationOnDeployment { 
		"configurationVersion"?: Models.WebDeploymentConfigurationVersion;
		"deployment"?: Models.WebDeployment;
	}
	
	export interface WebDeploymentConfigurationVersion { 
		"id"?: string;
		"name": string;
		"version"?: string;
		"headlessMode"?: Models.WebDeploymentHeadlessMode;
		"description"?: string;
		"languages"?: Array<string>;
		"defaultLanguage"?: string;
		"customI18nLabels"?: Array<Models.CustomI18nLabels>;
		"messenger"?: Models.MessengerSettings;
		"position"?: Models.PositionSettings;
		"supportCenter"?: Models.SupportCenterSettings;
		"cobrowse"?: Models.CobrowseSettings;
		"journeyEvents"?: Models.JourneyEventsSettings;
		"authenticationSettings"?: Models.AuthenticationSettings;
		"dateCreated"?: string;
		"dateModified"?: string;
		"datePublished"?: string;
		"lastModifiedUser"?: Models.AddressableEntityRef;
		"createdUser"?: Models.AddressableEntityRef;
		"publishedUser"?: Models.AddressableEntityRef;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface WebDeploymentConfigurationVersionEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.WebDeploymentConfigurationVersion>;
		"selfUri"?: string;
	}
	
	export interface WebDeploymentConfigurationVersionEntityRef { 
		"id": string;
		"name"?: string;
		"selfUri"?: string;
		"version": string;
	}
	
	export interface WebDeploymentConfigurationVersionResponse { 
		"id"?: string;
		"name": string;
		"version"?: string;
		"headlessMode"?: Models.WebDeploymentHeadlessMode;
		"description"?: string;
		"languages"?: Array<string>;
		"defaultLanguage"?: string;
		"customI18nLabels"?: Array<Models.CustomI18nLabels>;
		"messenger"?: Models.MessengerSettings;
		"position"?: Models.PositionSettings;
		"supportCenter"?: Models.SupportCenterSettings;
		"cobrowse"?: Models.CobrowseSettings;
		"journeyEvents"?: Models.JourneyEventsSettings;
		"authenticationSettings"?: Models.AuthenticationSettings;
		"dateCreated"?: string;
		"dateModified"?: string;
		"datePublished"?: string;
		"lastModifiedUser"?: Models.AddressableEntityRef;
		"createdUser"?: Models.AddressableEntityRef;
		"publishedUser"?: Models.AddressableEntityRef;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface WebDeploymentHeadlessMode { 
		"enabled"?: boolean;
	}
	
	export interface WebDeploymentsAuthorizationResponse { 
		"refreshToken"?: string;
		"jwt"?: string;
	}
	
	export interface WebDeploymentsConfigTopicWebMessagingConfigChangeEventBody { 
		"id"?: string;
		"version"?: string;
		"status"?: string;
	}
	
	export interface WebDeploymentsDeploymentTopicWebMessagingConfigChangeEventBody { 
		"id"?: string;
		"version"?: string;
		"status"?: string;
	}
	
	export interface WebDeploymentsDeploymentTopicWebMessagingDeploymentChangeEventBody { 
		"id"?: string;
		"configuration"?: Models.WebDeploymentsDeploymentTopicWebMessagingConfigChangeEventBody;
		"status"?: string;
	}
	
	export interface WebDeploymentsJourneyContext { 
		"journeyAction"?: Models.JourneyAction;
		"customer"?: Models.JourneyCustomer;
		"customerSession"?: Models.JourneyCustomerSession;
	}
	
	export interface WebDeploymentsOAuthExchangeRequest { 
		"deploymentId": string;
		"journeyContext"?: Models.WebDeploymentsJourneyContext;
		"oauth"?: Models.WebDeploymentsOAuthRequestParameters;
	}
	
	export interface WebDeploymentsOAuthRequestParameters { 
		"code": string;
		"redirectUri": string;
		"nonce"?: string;
		"maxAge"?: number;
		"codeVerifier"?: string;
		"iss"?: string;
	}
	
	export interface WebDeploymentsRefreshJWTRequest { 
		"refreshToken": string;
		"deploymentId": string;
	}
	
	export interface WebEvent { 
		"eventName": string;
		"totalEventCount": number;
		"totalPageviewCount": number;
		"page": Models.JourneyPage;
		"userAgentString": string;
		"browser": Models.Browser;
		"device": Models.Device;
		"geolocation"?: Models.JourneyGeolocation;
		"ipAddress"?: string;
		"ipOrganization"?: string;
		"mktCampaign"?: Models.JourneyCampaign;
		"referrer"?: Models.Referrer;
		"attributes": { [key: string]: Models.CustomEventAttribute; };
		"traits": { [key: string]: Models.CustomEventAttribute; };
		"searchQuery"?: string;
		"authenticated": boolean;
	}
	
	export interface WebMessagingAttachment { 
		"id"?: string;
		"mediaType"?: string;
		"url"?: string;
		"mime"?: string;
		"text"?: string;
		"sha256"?: string;
		"filename"?: string;
		"fileSize"?: number;
	}
	
	export interface WebMessagingButtonResponse { 
		"id"?: string;
		"type"?: string;
		"text": string;
		"payload": string;
	}
	
	export interface WebMessagingChannel { 
		"from"?: Models.WebMessagingRecipient;
		"to"?: Models.WebMessagingRecipient;
		"time"?: string;
		"messageId"?: string;
	}
	
	export interface WebMessagingContent { 
		"contentType"?: string;
		"attachment"?: Models.WebMessagingAttachment;
		"quickReply"?: Models.WebMessagingQuickReply;
		"buttonResponse"?: Models.WebMessagingButtonResponse;
		"generic"?: Models.WebMessagingGeneric;
		"card"?: Models.ContentCard;
		"carousel"?: Models.ContentCarousel;
	}
	
	export interface WebMessagingEvent { 
		"eventType": string;
		"coBrowse"?: Models.WebMessagingEventCoBrowse;
		"presence"?: Models.WebMessagingEventPresence;
	}
	
	export interface WebMessagingEventCoBrowse { 
		"type": string;
		"sessionId"?: string;
		"sessionJoinToken"?: string;
	}
	
	export interface WebMessagingEventPresence { 
		"type": string;
	}
	
	export interface WebMessagingGeneric { 
		"title"?: string;
		"description"?: string;
		"image"?: string;
		"actions"?: Models.ContentActions;
		"components"?: Array<Models.ButtonComponent>;
	}
	
	export interface WebMessagingMessage { 
		"id"?: string;
		"channel"?: Models.WebMessagingChannel;
		"type"?: string;
		"text"?: string;
		"content"?: Array<Models.WebMessagingContent>;
		"events"?: Array<Models.WebMessagingEvent>;
		"direction"?: string;
		"originatingEntity"?: string;
		"metadata"?: { [key: string]: string; };
	}
	
	export interface WebMessagingMessageEntityList { 
		"entities"?: Array<Models.WebMessagingMessage>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"pageCount"?: number;
	}
	
	export interface WebMessagingOfferFields { 
		"offerText"?: string;
		"architectFlow"?: Models.AddressableEntityRef;
	}
	
	export interface WebMessagingOfferProperties { 
		"offerText"?: string;
	}
	
	export interface WebMessagingQuickReply { 
		"text": string;
		"payload": string;
		"image"?: string;
		"action"?: string;
	}
	
	export interface WebMessagingRecipient { 
		"firstName"?: string;
		"lastName"?: string;
		"nickname"?: string;
		"image"?: string;
		"additionalIds"?: Array<Models.RecipientAdditionalIdentifier>;
	}
	
	export interface WeekSchedule { 
		"id"?: string;
		"selfUri"?: string;
		"weekDate"?: string;
		"description"?: string;
		"published"?: boolean;
		"generationResults"?: Models.WeekScheduleGenerationResult;
		"shortTermForecast"?: Models.ShortTermForecastReference;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"userSchedules"?: { [key: string]: Models.UserSchedule; };
		"headcountForecast"?: Models.HeadcountForecast;
		"agentSchedulesVersion"?: number;
	}
	
	export interface WeekScheduleGenerationResult { 
		"failed"?: boolean;
		"runId"?: string;
		"agentWarnings"?: Array<Models.ScheduleGenerationWarning>;
		"agentWarningCount"?: number;
	}
	
	export interface WeekScheduleListItemResponse { 
		"id"?: string;
		"selfUri"?: string;
		"weekDate"?: string;
		"description"?: string;
		"published"?: boolean;
		"generationResults"?: Models.WeekScheduleGenerationResult;
		"shortTermForecast"?: Models.ShortTermForecastReference;
		"metadata"?: Models.WfmVersionedEntityMetadata;
	}
	
	export interface WeekScheduleListResponse { 
		"entities"?: Array<Models.WeekScheduleListItemResponse>;
	}
	
	export interface WeekScheduleReference { 
		"id"?: string;
		"selfUri"?: string;
		"weekDate"?: string;
	}
	
	export interface WeekScheduleResponse { 
		"result"?: Models.WeekSchedule;
		"downloadUrl"?: string;
	}
	
	export interface WeekShiftTradeListResponse { 
		"entities"?: Array<Models.WeekShiftTradeResponse>;
		"downloadUrl"?: string;
	}
	
	export interface WeekShiftTradeMatchesSummaryResponse { 
		"weekDate"?: string;
		"count"?: number;
	}
	
	export interface WeekShiftTradeResponse { 
		"trade"?: Models.ShiftTradeResponse;
		"matchReview"?: Models.ShiftTradeMatchReviewResponse;
	}
	
	export interface WemCoachingUserNotificationTopicCoachingAppointmentReference { 
		"id"?: string;
	}
	
	export interface WemCoachingUserNotificationTopicCoachingUserNotification { 
		"id"?: string;
		"name"?: string;
		"markedAsRead"?: boolean;
		"actionType"?: string;
		"relationship"?: string;
		"appointment"?: Models.WemCoachingUserNotificationTopicCoachingAppointmentReference;
		"dateStart"?: string;
		"lengthInMinutes"?: number;
		"status"?: string;
	}
	
	export interface WfmAdherenceExplanationJobCompleteTopicAdherenceExplanationChangedNotification { 
		"id"?: string;
		"agent"?: Models.WfmAdherenceExplanationJobCompleteTopicUserReference;
		"managementUnit"?: Models.WfmAdherenceExplanationJobCompleteTopicManagementUnit;
		"businessUnit"?: Models.WfmAdherenceExplanationJobCompleteTopicBusinessUnit;
		"type"?: string;
		"status"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"notes"?: string;
		"reviewedBy"?: Models.WfmAdherenceExplanationJobCompleteTopicUserReference;
		"reviewedDate"?: string;
	}
	
	export interface WfmAdherenceExplanationJobCompleteTopicAdherenceExplanationJobNotification { 
		"id"?: string;
		"type"?: string;
		"status"?: string;
		"adherenceExplanation"?: Models.WfmAdherenceExplanationJobCompleteTopicAdherenceExplanationChangedNotification;
		"downloadUrl"?: string;
		"error"?: Models.WfmAdherenceExplanationJobCompleteTopicErrorBody;
	}
	
	export interface WfmAdherenceExplanationJobCompleteTopicBusinessUnit { 
		"id"?: string;
	}
	
	export interface WfmAdherenceExplanationJobCompleteTopicErrorBody { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface WfmAdherenceExplanationJobCompleteTopicManagementUnit { 
		"id"?: string;
	}
	
	export interface WfmAdherenceExplanationJobCompleteTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmAgent { 
		"id"?: string;
		"user"?: Models.UserReference;
		"workPlan"?: Models.WorkPlanReference;
		"workPlanRotation"?: Models.WorkPlanRotationReference;
		"acceptDirectShiftTrades"?: boolean;
		"queues"?: Array<Models.QueueReference>;
		"languages"?: Array<Models.LanguageReference>;
		"skills"?: Array<Models.RoutingSkillReference>;
		"schedulable"?: boolean;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedAgentTopicAdherenceExplanationChangedNotification { 
		"id"?: string;
		"agent"?: Models.WfmAgentAdherenceExplanationChangedAgentTopicUserReference;
		"managementUnit"?: Models.WfmAgentAdherenceExplanationChangedAgentTopicManagementUnit;
		"businessUnit"?: Models.WfmAgentAdherenceExplanationChangedAgentTopicBusinessUnit;
		"type"?: string;
		"status"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"notes"?: string;
		"reviewedBy"?: Models.WfmAgentAdherenceExplanationChangedAgentTopicUserReference;
		"reviewedDate"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedAgentTopicBusinessUnit { 
		"id"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedAgentTopicManagementUnit { 
		"id"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedAgentTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedBusinessUnitTopicAdherenceExplanationChangedNotification { 
		"id"?: string;
		"agent"?: Models.WfmAgentAdherenceExplanationChangedBusinessUnitTopicUserReference;
		"managementUnit"?: Models.WfmAgentAdherenceExplanationChangedBusinessUnitTopicManagementUnit;
		"businessUnit"?: Models.WfmAgentAdherenceExplanationChangedBusinessUnitTopicBusinessUnit;
		"type"?: string;
		"status"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"notes"?: string;
		"reviewedBy"?: Models.WfmAgentAdherenceExplanationChangedBusinessUnitTopicUserReference;
		"reviewedDate"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedBusinessUnitTopicBusinessUnit { 
		"id"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedBusinessUnitTopicManagementUnit { 
		"id"?: string;
	}
	
	export interface WfmAgentAdherenceExplanationChangedBusinessUnitTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmAgentScheduleUpdateTopicAgentScheduleShiftUpdate { 
		"type"?: string;
		"shiftStartDates"?: Array<string>;
	}
	
	export interface WfmAgentScheduleUpdateTopicAgentScheduleUpdateNotification { 
		"user"?: Models.WfmAgentScheduleUpdateTopicUserReference;
		"startDate"?: string;
		"endDate"?: string;
		"updates"?: Array<Models.WfmAgentScheduleUpdateTopicAgentScheduleShiftUpdate>;
	}
	
	export interface WfmAgentScheduleUpdateTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuIntradayDataGroup { 
		"mediaType"?: string;
		"forecastDataSummary"?: Models.WfmBuIntradayDataUpdateTopicBuIntradayForecastData;
		"forecastDataPerInterval"?: Array<Models.WfmBuIntradayDataUpdateTopicBuIntradayForecastData>;
		"scheduleDataSummary"?: Models.WfmBuIntradayDataUpdateTopicBuIntradayScheduleData;
		"scheduleDataPerInterval"?: Array<Models.WfmBuIntradayDataUpdateTopicBuIntradayScheduleData>;
		"performancePredictionDataSummary"?: Models.WfmBuIntradayDataUpdateTopicIntradayPerformancePredictionData;
		"performancePredictionDataPerInterval"?: Array<Models.WfmBuIntradayDataUpdateTopicIntradayPerformancePredictionData>;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuIntradayForecastData { 
		"offered"?: number;
		"averageHandleTimeSeconds"?: number;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuIntradayNotification { 
		"operationId"?: string;
		"result"?: Models.WfmBuIntradayDataUpdateTopicBuIntradayResult;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuIntradayResult { 
		"startDate"?: string;
		"endDate"?: string;
		"intervalLengthMinutes"?: number;
		"intradayDataGroupings"?: Array<Models.WfmBuIntradayDataUpdateTopicBuIntradayDataGroup>;
		"categories"?: Array<string>;
		"noDataReason"?: string;
		"schedule"?: Models.WfmBuIntradayDataUpdateTopicBuScheduleReference;
		"shortTermForecast"?: Models.WfmBuIntradayDataUpdateTopicBuShortTermForecastReference;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuIntradayScheduleData { 
		"onQueueTimeSeconds"?: number;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuScheduleReference { 
		"id"?: string;
		"weekDate"?: string;
	}
	
	export interface WfmBuIntradayDataUpdateTopicBuShortTermForecastReference { 
		"id"?: string;
		"weekDate"?: string;
		"description"?: string;
	}
	
	export interface WfmBuIntradayDataUpdateTopicIntradayPerformancePredictionData { 
		"serviceLevelPercent"?: number;
		"averageSpeedOfAnswerSeconds"?: number;
		"occupancyPercent"?: number;
	}
	
	export interface WfmBuScheduleQueryResultTopicBuScheduleSearchResultNotification { 
		"operationId"?: string;
		"businessUnitId"?: string;
		"downloadUrl"?: string;
	}
	
	export interface WfmBuScheduleRunTopicBuScheduleReference { 
		"id"?: string;
		"weekDate"?: string;
	}
	
	export interface WfmBuScheduleRunTopicBuScheduleRun { 
		"id"?: string;
		"percentComplete"?: number;
		"intradayRescheduling"?: boolean;
		"state"?: string;
		"weekCount"?: number;
		"schedule"?: Models.WfmBuScheduleRunTopicBuScheduleReference;
		"schedulingCanceledBy"?: Models.WfmBuScheduleRunTopicUserReference;
		"schedulingCompletedTime"?: string;
		"messageCount"?: number;
		"messageSeverityCounts"?: Array<Models.WfmBuScheduleRunTopicSchedulerMessageSeverityCount>;
	}
	
	export interface WfmBuScheduleRunTopicBuSchedulingRunProgressNotification { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.WfmBuScheduleRunTopicBuScheduleRun;
	}
	
	export interface WfmBuScheduleRunTopicSchedulerMessageSeverityCount { 
		"severity"?: string;
		"count"?: number;
	}
	
	export interface WfmBuScheduleRunTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuScheduleSearchResultTopicBuScheduleSearchResultNotification { 
		"operationId"?: string;
		"businessUnitId"?: string;
		"downloadUrl"?: string;
	}
	
	export interface WfmBuScheduleTopicBuManagementUnitScheduleSummary { 
		"managementUnit"?: Models.WfmBuScheduleTopicManagementUnit;
		"startDate"?: string;
		"endDate"?: string;
		"agents"?: Array<Models.WfmBuScheduleTopicUserReference>;
		"agentCount"?: number;
	}
	
	export interface WfmBuScheduleTopicBuScheduleGenerationResultSummary { 
		"failed"?: boolean;
		"runId"?: string;
		"messageCount"?: number;
		"messageSeverityCounts"?: Array<Models.WfmBuScheduleTopicSchedulerMessageSeverityCount>;
	}
	
	export interface WfmBuScheduleTopicBuScheduleMetadata { 
		"id"?: string;
		"weekDate"?: string;
		"weekCount"?: number;
		"description"?: string;
		"published"?: boolean;
		"shortTermForecast"?: Models.WfmBuScheduleTopicBuShortTermForecastReference;
		"managementUnits"?: Array<Models.WfmBuScheduleTopicBuManagementUnitScheduleSummary>;
		"generationResults"?: Models.WfmBuScheduleTopicBuScheduleGenerationResultSummary;
		"metadata"?: Models.WfmBuScheduleTopicWfmVersionedEntityMetadata;
	}
	
	export interface WfmBuScheduleTopicBuScheduleNotification { 
		"status"?: string;
		"operationId"?: string;
		"eventType"?: string;
		"result"?: Models.WfmBuScheduleTopicBuScheduleMetadata;
	}
	
	export interface WfmBuScheduleTopicBuShortTermForecastReference { 
		"id"?: string;
		"weekDate"?: string;
		"description"?: string;
	}
	
	export interface WfmBuScheduleTopicManagementUnit { 
		"id"?: string;
	}
	
	export interface WfmBuScheduleTopicSchedulerMessageSeverityCount { 
		"severity"?: string;
		"count"?: number;
	}
	
	export interface WfmBuScheduleTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuScheduleTopicWfmVersionedEntityMetadata { 
		"version"?: number;
		"modifiedBy"?: Models.WfmBuScheduleTopicUserReference;
		"dateModified"?: string;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicBuForecastModification { 
		"type"?: string;
		"startIntervalIndex"?: number;
		"endIntervalIndex"?: number;
		"metric"?: string;
		"legacyMetric"?: string;
		"value"?: number;
		"values"?: Array<Models.WfmBuShortTermForecastCopyCompleteTopicModificationIntervalOffsetValue>;
		"secondaryValues"?: Array<Models.WfmBuShortTermForecastCopyCompleteTopicModificationIntervalOffsetValue>;
		"enabled"?: boolean;
		"granularity"?: string;
		"secondaryGranularity"?: string;
		"displayGranularity"?: string;
		"planningGroupIds"?: Array<string>;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast { 
		"id"?: string;
		"weekDate"?: string;
		"creationMethod"?: string;
		"description"?: string;
		"legacy"?: boolean;
		"referenceStartDate"?: string;
		"sourceDays"?: Array<Models.WfmBuShortTermForecastCopyCompleteTopicForecastSourceDayPointer>;
		"modifications"?: Array<Models.WfmBuShortTermForecastCopyCompleteTopicBuForecastModification>;
		"timeZone"?: string;
		"planningGroupsVersion"?: number;
		"weekCount"?: number;
		"metadata"?: Models.WfmBuShortTermForecastCopyCompleteTopicWfmVersionedEntityMetadata;
		"canUseForScheduling"?: boolean;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecastNotification { 
		"status"?: string;
		"result"?: Models.WfmBuShortTermForecastCopyCompleteTopicBuShortTermForecast;
		"operationId"?: string;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicForecastSourceDayPointer { 
		"dayOfWeek"?: string;
		"weight"?: number;
		"date"?: string;
		"fileName"?: string;
		"dataKey"?: string;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicModificationIntervalOffsetValue { 
		"intervalIndex"?: number;
		"value"?: number;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuShortTermForecastCopyCompleteTopicWfmVersionedEntityMetadata { 
		"version"?: number;
		"modifiedBy"?: Models.WfmBuShortTermForecastCopyCompleteTopicUserReference;
		"dateModified"?: string;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicBuForecastModification { 
		"type"?: string;
		"startIntervalIndex"?: number;
		"endIntervalIndex"?: number;
		"metric"?: string;
		"legacyMetric"?: string;
		"value"?: number;
		"values"?: Array<Models.WfmBuShortTermForecastGenerateProgressTopicModificationIntervalOffsetValue>;
		"secondaryValues"?: Array<Models.WfmBuShortTermForecastGenerateProgressTopicModificationIntervalOffsetValue>;
		"enabled"?: boolean;
		"granularity"?: string;
		"secondaryGranularity"?: string;
		"displayGranularity"?: string;
		"planningGroupIds"?: Array<string>;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicBuShortTermForecast { 
		"id"?: string;
		"weekDate"?: string;
		"creationMethod"?: string;
		"description"?: string;
		"legacy"?: boolean;
		"referenceStartDate"?: string;
		"sourceDays"?: Array<Models.WfmBuShortTermForecastGenerateProgressTopicForecastSourceDayPointer>;
		"modifications"?: Array<Models.WfmBuShortTermForecastGenerateProgressTopicBuForecastModification>;
		"timeZone"?: string;
		"planningGroupsVersion"?: number;
		"weekCount"?: number;
		"metadata"?: Models.WfmBuShortTermForecastGenerateProgressTopicWfmVersionedEntityMetadata;
		"canUseForScheduling"?: boolean;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicForecastSourceDayPointer { 
		"dayOfWeek"?: string;
		"weight"?: number;
		"date"?: string;
		"fileName"?: string;
		"dataKey"?: string;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicGenerateBuShortTermForecastProgressNotification { 
		"status"?: string;
		"result"?: Models.WfmBuShortTermForecastGenerateProgressTopicBuShortTermForecast;
		"operationId"?: string;
		"progress"?: number;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicModificationIntervalOffsetValue { 
		"intervalIndex"?: number;
		"value"?: number;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuShortTermForecastGenerateProgressTopicWfmVersionedEntityMetadata { 
		"version"?: number;
		"modifiedBy"?: Models.WfmBuShortTermForecastGenerateProgressTopicUserReference;
		"dateModified"?: string;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicBuForecastModification { 
		"type"?: string;
		"startIntervalIndex"?: number;
		"endIntervalIndex"?: number;
		"metric"?: string;
		"legacyMetric"?: string;
		"value"?: number;
		"values"?: Array<Models.WfmBuShortTermForecastImportCompleteTopicModificationIntervalOffsetValue>;
		"secondaryValues"?: Array<Models.WfmBuShortTermForecastImportCompleteTopicModificationIntervalOffsetValue>;
		"enabled"?: boolean;
		"granularity"?: string;
		"secondaryGranularity"?: string;
		"displayGranularity"?: string;
		"planningGroupIds"?: Array<string>;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicBuShortTermForecast { 
		"id"?: string;
		"weekDate"?: string;
		"creationMethod"?: string;
		"description"?: string;
		"legacy"?: boolean;
		"referenceStartDate"?: string;
		"sourceDays"?: Array<Models.WfmBuShortTermForecastImportCompleteTopicForecastSourceDayPointer>;
		"modifications"?: Array<Models.WfmBuShortTermForecastImportCompleteTopicBuForecastModification>;
		"timeZone"?: string;
		"planningGroupsVersion"?: number;
		"weekCount"?: number;
		"metadata"?: Models.WfmBuShortTermForecastImportCompleteTopicWfmVersionedEntityMetadata;
		"canUseForScheduling"?: boolean;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicBuShortTermForecastNotification { 
		"status"?: string;
		"result"?: Models.WfmBuShortTermForecastImportCompleteTopicBuShortTermForecast;
		"operationId"?: string;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicForecastSourceDayPointer { 
		"dayOfWeek"?: string;
		"weight"?: number;
		"date"?: string;
		"fileName"?: string;
		"dataKey"?: string;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicModificationIntervalOffsetValue { 
		"intervalIndex"?: number;
		"value"?: number;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuShortTermForecastImportCompleteTopicWfmVersionedEntityMetadata { 
		"version"?: number;
		"modifiedBy"?: Models.WfmBuShortTermForecastImportCompleteTopicUserReference;
		"dateModified"?: string;
	}
	
	export interface WfmBuShortTermForecastStaffingRequirementsGenerateCompleteTopicBuForecastShortTermStaffingRequirementsNotification { 
		"businessUnitId"?: string;
		"state"?: string;
		"forecast"?: Models.WfmBuShortTermForecastStaffingRequirementsGenerateCompleteTopicBuShortTermForecastReference;
		"weekCount"?: number;
		"intervalLengthMinutes"?: number;
		"referenceStartDate"?: string;
		"results"?: Array<Models.WfmBuShortTermForecastStaffingRequirementsGenerateCompleteTopicBuForecastShortTermStaffingRequirementsResults>;
	}
	
	export interface WfmBuShortTermForecastStaffingRequirementsGenerateCompleteTopicBuForecastShortTermStaffingRequirementsResults { 
		"weekNumber"?: number;
		"downloadUrl"?: string;
		"downloadUrlExpirationDate"?: string;
	}
	
	export interface WfmBuShortTermForecastStaffingRequirementsGenerateCompleteTopicBuShortTermForecastReference { 
		"id"?: string;
		"weekDate"?: string;
		"description"?: string;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicBuForecastModification { 
		"type"?: string;
		"startIntervalIndex"?: number;
		"endIntervalIndex"?: number;
		"metric"?: string;
		"legacyMetric"?: string;
		"value"?: number;
		"values"?: Array<Models.WfmBuShortTermForecastUpdateCompleteTopicModificationIntervalOffsetValue>;
		"secondaryValues"?: Array<Models.WfmBuShortTermForecastUpdateCompleteTopicModificationIntervalOffsetValue>;
		"enabled"?: boolean;
		"granularity"?: string;
		"secondaryGranularity"?: string;
		"displayGranularity"?: string;
		"planningGroupIds"?: Array<string>;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicBuShortTermForecast { 
		"id"?: string;
		"weekDate"?: string;
		"creationMethod"?: string;
		"description"?: string;
		"legacy"?: boolean;
		"referenceStartDate"?: string;
		"sourceDays"?: Array<Models.WfmBuShortTermForecastUpdateCompleteTopicForecastSourceDayPointer>;
		"modifications"?: Array<Models.WfmBuShortTermForecastUpdateCompleteTopicBuForecastModification>;
		"timeZone"?: string;
		"planningGroupsVersion"?: number;
		"weekCount"?: number;
		"metadata"?: Models.WfmBuShortTermForecastUpdateCompleteTopicWfmVersionedEntityMetadata;
		"canUseForScheduling"?: boolean;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicBuShortTermForecastNotification { 
		"status"?: string;
		"result"?: Models.WfmBuShortTermForecastUpdateCompleteTopicBuShortTermForecast;
		"operationId"?: string;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicForecastSourceDayPointer { 
		"dayOfWeek"?: string;
		"weight"?: number;
		"date"?: string;
		"fileName"?: string;
		"dataKey"?: string;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicModificationIntervalOffsetValue { 
		"intervalIndex"?: number;
		"value"?: number;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBuShortTermForecastUpdateCompleteTopicWfmVersionedEntityMetadata { 
		"version"?: number;
		"modifiedBy"?: Models.WfmBuShortTermForecastUpdateCompleteTopicUserReference;
		"dateModified"?: string;
	}
	
	export interface WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateNotification { 
		"status"?: string;
		"operationId"?: string;
		"result"?: Models.WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResultListing;
		"weekDate"?: string;
	}
	
	export interface WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult { 
		"id"?: string;
		"state"?: string;
		"reviewedBy"?: Models.WfmBulkShiftTradeStateUpdateNotificationTopicUserReference;
		"reviewedDate"?: string;
		"failureReason"?: string;
		"metadata"?: Models.WfmBulkShiftTradeStateUpdateNotificationTopicWfmVersionedEntityMetadata;
	}
	
	export interface WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResultListing { 
		"entities"?: Array<Models.WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult>;
	}
	
	export interface WfmBulkShiftTradeStateUpdateNotificationTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmBulkShiftTradeStateUpdateNotificationTopicWfmVersionedEntityMetadata { 
		"version"?: number;
		"modifiedBy"?: Models.WfmBulkShiftTradeStateUpdateNotificationTopicUserReference;
		"dateModified"?: string;
	}
	
	export interface WfmBusinessUnitReference { 
		"id": string;
		"selfUri"?: string;
	}
	
	export interface WfmForecastModificationIntervalOffsetValue { 
		"intervalIndex": number;
		"value": number;
	}
	
	export interface WfmHistoricalAdherenceBulkCalculationsCompleteTopicWfmHistoricalAdherenceBulkCalculationsCompleteNotification { 
		"id"?: string;
		"downloadUrls"?: Array<string>;
		"queryState"?: string;
	}
	
	export interface WfmHistoricalAdherenceBulkItem { 
		"managementUnitId": string;
		"startDate": string;
		"endDate": string;
		"userIds"?: Array<string>;
		"includeExceptions"?: boolean;
		"includeActuals"?: boolean;
	}
	
	export interface WfmHistoricalAdherenceBulkJobReference { 
		"id"?: string;
		"status"?: string;
		"selfUri"?: string;
	}
	
	export interface WfmHistoricalAdherenceBulkQuery { 
		"items": Array<Models.WfmHistoricalAdherenceBulkItem>;
		"timeZone": string;
	}
	
	export interface WfmHistoricalAdherenceBulkResponse { 
		"job"?: Models.WfmHistoricalAdherenceBulkJobReference;
		"downloadUrls"?: Array<string>;
		"downloadResult"?: Models.WfmHistoricalAdherenceBulkResult;
	}
	
	export interface WfmHistoricalAdherenceBulkResult { 
		"startDate"?: string;
		"endDate"?: string;
		"managementUnitId"?: string;
		"userResults"?: Array<Models.WfmHistoricalAdherenceBulkUserResult>;
		"lookupIdToSecondaryPresenceId"?: { [key: string]: string; };
	}
	
	export interface WfmHistoricalAdherenceBulkUserDayMetrics { 
		"dayStartOffsetSeconds"?: number;
		"adherenceScheduleSeconds"?: number;
		"conformanceScheduleSeconds"?: number;
		"conformanceActualSeconds"?: number;
		"exceptionCount"?: number;
		"exceptionDurationSeconds"?: number;
		"impactSeconds"?: number;
		"scheduleLengthSeconds"?: number;
		"actualLengthSeconds"?: number;
		"adherencePercentage"?: number;
		"conformancePercentage"?: number;
	}
	
	export interface WfmHistoricalAdherenceBulkUserResult { 
		"userId"?: string;
		"adherencePercentage"?: number;
		"conformancePercentage"?: number;
		"impact"?: string;
		"exceptionInfo"?: Array<Models.HistoricalAdherenceExceptionInfo>;
		"actuals"?: Array<Models.HistoricalAdherenceActuals>;
		"dayMetrics"?: Array<Models.WfmHistoricalAdherenceBulkUserDayMetrics>;
	}
	
	export interface WfmHistoricalAdherenceCalculationsCompleteTopicWfmHistoricalAdherenceCalculationsCompleteNotice { 
		"id"?: string;
		"downloadUrl"?: string;
		"downloadUrls"?: Array<string>;
		"queryState"?: string;
	}
	
	export interface WfmHistoricalAdherenceQuery { 
		"startDate": string;
		"endDate"?: string;
		"timeZone"?: string;
		"userIds"?: Array<string>;
		"includeExceptions"?: boolean;
		"teamIds"?: Array<string>;
	}
	
	export interface WfmHistoricalAdherenceQueryForTeams { 
		"startDate": string;
		"endDate"?: string;
		"timeZone": string;
		"userIds"?: Array<string>;
		"includeExceptions"?: boolean;
	}
	
	export interface WfmHistoricalAdherenceQueryForUsers { 
		"startDate": string;
		"endDate"?: string;
		"timeZone": string;
		"userIds": Array<string>;
		"includeExceptions"?: boolean;
	}
	
	export interface WfmHistoricalAdherenceResponse { 
		"id"?: string;
		"downloadUrl"?: string;
		"downloadResult"?: Models.WfmHistoricalAdherenceResultWrapper;
		"downloadUrls"?: Array<string>;
		"queryState"?: string;
	}
	
	export interface WfmHistoricalAdherenceResultWrapper { 
		"entityId"?: string;
		"data"?: Array<Models.HistoricalAdherenceQueryResult>;
		"lookupIdToSecondaryPresenceId"?: { [key: string]: string; };
	}
	
	export interface WfmHistoricalDataUploadPurgeRequestStatusTopicHistoricalDataUploadPurgeRequestUpdate { 
		"status"?: string;
	}
	
	export interface WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate { 
		"requestId"?: string;
		"dateImportStarted"?: string;
		"dateImportEnded"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"status"?: string;
		"error"?: string;
		"active"?: boolean;
		"type"?: string;
	}
	
	export interface WfmHistoricalShrinkageCalculationsCompleteTopicHistoricalShrinkageCalculationsCompleteNotification { 
		"operationId"?: string;
		"downloadUrls"?: Array<string>;
		"state"?: string;
	}
	
	export interface WfmHistoricalShrinkageRequest { 
		"startDate": string;
		"endDate"?: string;
		"timeZone"?: string;
		"granularity"?: string;
	}
	
	export interface WfmHistoricalShrinkageResponse { 
		"operationId"?: string;
		"downloadUrls"?: Array<string>;
		"downloadResult"?: Models.HistoricalShrinkageResultListing;
		"state"?: string;
	}
	
	export interface WfmHistoricalShrinkageTeamsRequest { 
		"startDate": string;
		"endDate"?: string;
		"timeZone": string;
		"granularity"?: string;
	}
	
	export interface WfmIntegrationListing { 
		"entities"?: Array<Models.WfmIntegrationResponse>;
	}
	
	export interface WfmIntegrationReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface WfmIntegrationResponse { 
		"id"?: string;
		"name"?: string;
		"active": boolean;
		"selfUri"?: string;
	}
	
	export interface WfmIntegrationsHrisTimeOffTypesJobTopicErrorBody { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface WfmIntegrationsHrisTimeOffTypesJobTopicHrisTimeOffType { 
		"id"?: string;
		"name"?: string;
		"secondaryId"?: string;
	}
	
	export interface WfmIntegrationsHrisTimeOffTypesJobTopicHrisTimeOffTypesJobNotification { 
		"id"?: string;
		"entities"?: Array<Models.WfmIntegrationsHrisTimeOffTypesJobTopicHrisTimeOffType>;
		"status"?: string;
		"error"?: Models.WfmIntegrationsHrisTimeOffTypesJobTopicErrorBody;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayDataGroup { 
		"mediaType"?: string;
		"forecastDataPerInterval"?: Array<Models.WfmIntradayDataUpdateTopicIntradayForecastData>;
		"scheduleDataPerInterval"?: Array<Models.WfmIntradayDataUpdateTopicIntradayScheduleData>;
		"historicalAgentDataPerInterval"?: Array<Models.WfmIntradayDataUpdateTopicIntradayHistoricalAgentData>;
		"historicalQueueDataPerInterval"?: Array<Models.WfmIntradayDataUpdateTopicIntradayHistoricalQueueData>;
		"performancePredictionAgentDataPerInterval"?: Array<Models.WfmIntradayDataUpdateTopicIntradayPerformancePredictionAgentData>;
		"performancePredictionQueueDataPerInterval"?: Array<Models.WfmIntradayDataUpdateTopicIntradayPerformancePredictionQueueData>;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayDataUpdate { 
		"startDate"?: string;
		"endDate"?: string;
		"intervalLengthMinutes"?: number;
		"numberOfIntervals"?: number;
		"metrics"?: Array<Models.WfmIntradayDataUpdateTopicIntradayMetric>;
		"queueIds"?: Array<string>;
		"intradayDataGroupings"?: Array<Models.WfmIntradayDataUpdateTopicIntradayDataGroup>;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayForecastData { 
		"offered"?: number;
		"averageTalkTimeSeconds"?: number;
		"averageAfterCallWorkSeconds"?: number;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayHistoricalAgentData { 
		"onQueueTimeSeconds"?: number;
		"interactingTimeSeconds"?: number;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayHistoricalQueueData { 
		"offered"?: number;
		"completed"?: number;
		"answered"?: number;
		"abandoned"?: number;
		"averageTalkTimeSeconds"?: number;
		"averageAfterCallWorkSeconds"?: number;
		"serviceLevelPercent"?: number;
		"averageSpeedOfAnswerSeconds"?: number;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayMetric { 
		"category"?: string;
		"version"?: string;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayPerformancePredictionAgentData { 
		"interactingTimeSeconds"?: number;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayPerformancePredictionQueueData { 
		"serviceLevelPercent"?: number;
		"averageSpeedOfAnswerSeconds"?: number;
		"numberOfInteractions"?: number;
	}
	
	export interface WfmIntradayDataUpdateTopicIntradayScheduleData { 
		"onQueueTimeSeconds"?: number;
		"scheduledTimeSeconds"?: number;
	}
	
	export interface WfmIntradayPlanningGroupListing { 
		"entities"?: Array<Models.ForecastPlanningGroupResponse>;
		"noDataReason"?: string;
	}
	
	export interface WfmMoveAgentsCompleteTopicManagementUnit { 
		"id"?: string;
	}
	
	export interface WfmMoveAgentsCompleteTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmMoveAgentsCompleteTopicWfmMoveAgentData { 
		"user"?: Models.WfmMoveAgentsCompleteTopicUserReference;
		"result"?: string;
	}
	
	export interface WfmMoveAgentsCompleteTopicWfmMoveAgentsComplete { 
		"requestingUser"?: Models.WfmMoveAgentsCompleteTopicUserReference;
		"destinationManagementUnit"?: Models.WfmMoveAgentsCompleteTopicManagementUnit;
		"results"?: Array<Models.WfmMoveAgentsCompleteTopicWfmMoveAgentData>;
	}
	
	export interface WfmMoveManagementUnitTopicBusinessUnit { 
		"id"?: string;
	}
	
	export interface WfmMoveManagementUnitTopicMoveManagementUnitNotification { 
		"businessUnit"?: Models.WfmMoveManagementUnitTopicBusinessUnit;
		"status"?: string;
	}
	
	export interface WfmProcessUploadRequest { 
		"uploadKey": string;
	}
	
	export interface WfmScheduleActivity { 
		"userReference"?: Models.UserReference;
		"activities"?: Array<Models.ScheduleActivity>;
		"fullDayTimeOffMarkers"?: Array<Models.FullDayTimeOffMarker>;
	}
	
	export interface WfmScheduleReference { 
		"id": string;
		"businessUnit": Models.WfmBusinessUnitReference;
		"weekDate": string;
		"selfUri"?: string;
	}
	
	export interface WfmScheduleTopicWfmScheduleNotification { 
		"status"?: string;
		"operationId"?: string;
		"downloadUrl"?: string;
		"percentComplete"?: number;
		"eventType"?: string;
	}
	
	export interface WfmServiceGoalImpact { 
		"increaseByPercent": number;
		"decreaseByPercent": number;
	}
	
	export interface WfmServiceGoalImpactSettings { 
		"serviceLevel": Models.WfmServiceGoalImpact;
		"averageSpeedOfAnswer": Models.WfmServiceGoalImpact;
		"abandonRate": Models.WfmServiceGoalImpact;
	}
	
	export interface WfmTimeOffBalanceJobTopicErrorBody { 
		"status"?: number;
		"code"?: string;
		"message"?: string;
		"messageParams"?: { [key: string]: string; };
	}
	
	export interface WfmTimeOffBalanceJobTopicTimeOffBalance { 
		"activityCodeId"?: string;
		"hrisTimeOffTypeId"?: string;
		"hrisTimeOffTypeSecondaryId"?: string;
		"startDate"?: string;
		"balanceMinutesPerDay"?: Array<number>;
	}
	
	export interface WfmTimeOffBalanceJobTopicTimeOffBalanceJobNotification { 
		"id"?: string;
		"entities"?: Array<Models.WfmTimeOffBalanceJobTopicTimeOffBalance>;
		"status"?: string;
		"error"?: Models.WfmTimeOffBalanceJobTopicErrorBody;
	}
	
	export interface WfmTimeOffRequestUpdateTopicTimeOffRequestUpdate { 
		"id"?: string;
		"user"?: Models.WfmTimeOffRequestUpdateTopicUserReference;
		"isFullDayRequest"?: boolean;
		"markedAsRead"?: boolean;
		"activityCodeId"?: string;
		"paid"?: boolean;
		"status"?: string;
		"substatus"?: string;
		"partialDayStartDateTimes"?: Array<string>;
		"fullDayManagementUnitDates"?: Array<string>;
		"dailyDurationMinutes"?: number;
		"notes"?: string;
		"reviewedDate"?: string;
		"reviewedBy"?: string;
		"submittedDate"?: string;
		"submittedBy"?: string;
		"modifiedDate"?: string;
		"modifiedBy"?: string;
	}
	
	export interface WfmTimeOffRequestUpdateTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmUpdateAgentDetailsTopicWfmUpdateAgentDetailsComplete { 
		"status"?: string;
	}
	
	export interface WfmUserEntityListing { 
		"entities"?: Array<Models.User>;
	}
	
	export interface WfmUserNotification { 
		"id": string;
		"mutableGroupId": string;
		"timestamp"?: string;
		"type"?: string;
		"shiftTrade"?: Models.ShiftTradeNotification;
		"timeOffRequest"?: Models.TimeOffRequestNotification;
		"adherenceExplanation"?: Models.AdherenceExplanationNotification;
		"alternativeShift"?: Models.AlternativeShiftNotification;
		"markedAsRead": boolean;
		"agentNotification"?: boolean;
		"otherNotificationIdsInGroup"?: Array<string>;
	}
	
	export interface WfmUserNotificationTopicAdherenceExplanationNotification { 
		"id"?: string;
		"agent"?: Models.WfmUserNotificationTopicUserReference;
		"managementUnit"?: Models.WfmUserNotificationTopicManagementUnit;
		"businessUnit"?: Models.WfmUserNotificationTopicBusinessUnit;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"status"?: string;
		"type"?: string;
		"notes"?: string;
	}
	
	export interface WfmUserNotificationTopicAlternativeShiftNotification { 
		"id"?: string;
		"weekDate"?: string;
		"granularity"?: string;
		"newState"?: string;
		"initiatingUser"?: Models.WfmUserNotificationTopicUserReference;
		"initiatingShiftDate"?: string;
		"receivingUser"?: Models.WfmUserNotificationTopicUserReference;
		"receivingShiftDate"?: string;
	}
	
	export interface WfmUserNotificationTopicBusinessUnit { 
		"id"?: string;
	}
	
	export interface WfmUserNotificationTopicManagementUnit { 
		"id"?: string;
	}
	
	export interface WfmUserNotificationTopicShiftTradeNotification { 
		"weekDate"?: string;
		"tradeId"?: string;
		"oneSided"?: boolean;
		"newState"?: string;
		"initiatingUser"?: Models.WfmUserNotificationTopicUserReference;
		"initiatingShiftDate"?: string;
		"receivingUser"?: Models.WfmUserNotificationTopicUserReference;
		"receivingShiftDate"?: string;
	}
	
	export interface WfmUserNotificationTopicTimeOffRequestNotification { 
		"timeOffRequestId"?: string;
		"user"?: Models.WfmUserNotificationTopicUserReference;
		"isFullDayRequest"?: boolean;
		"status"?: string;
		"partialDayStartDateTimes"?: Array<string>;
		"fullDayManagementUnitDates"?: Array<string>;
	}
	
	export interface WfmUserNotificationTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmUserNotificationTopicWfmUserNotification { 
		"id"?: string;
		"mutableGroupId"?: string;
		"timestamp"?: string;
		"type"?: string;
		"shiftTrade"?: Models.WfmUserNotificationTopicShiftTradeNotification;
		"timeOffRequest"?: Models.WfmUserNotificationTopicTimeOffRequestNotification;
		"adherenceExplanation"?: Models.WfmUserNotificationTopicAdherenceExplanationNotification;
		"alternativeShift"?: Models.WfmUserNotificationTopicAlternativeShiftNotification;
		"agentNotification"?: boolean;
		"otherNotificationIdsInGroup"?: Array<string>;
		"markedAsRead"?: boolean;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicActivityCodeReference { 
		"id"?: string;
		"secondaryPresences"?: Array<Models.WfmUserScheduleAdherenceUpdatedMuTopicSecondaryPresenceReference>;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicQueueReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicRealTimeAdherenceExplanation { 
		"id"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"status"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicSecondaryPresenceReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedMuTopicUserScheduleAdherenceUpdate { 
		"user"?: Models.WfmUserScheduleAdherenceUpdatedMuTopicUserReference;
		"managementUnitId"?: string;
		"team"?: Models.WfmUserScheduleAdherenceUpdatedMuTopicUriReference;
		"scheduledActivityCategory"?: string;
		"scheduledActivityCode"?: Models.WfmUserScheduleAdherenceUpdatedMuTopicActivityCodeReference;
		"systemPresence"?: string;
		"organizationSecondaryPresenceId"?: string;
		"routingStatus"?: string;
		"actualActivityCategory"?: string;
		"isOutOfOffice"?: boolean;
		"adherenceState"?: string;
		"impact"?: string;
		"adherenceExplanation"?: Models.WfmUserScheduleAdherenceUpdatedMuTopicRealTimeAdherenceExplanation;
		"adherenceChangeTime"?: string;
		"presenceUpdateTime"?: string;
		"activeQueues"?: Array<Models.WfmUserScheduleAdherenceUpdatedMuTopicQueueReference>;
		"activeQueuesModifiedTime"?: string;
		"removedFromManagementUnit"?: boolean;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicActivityCodeReference { 
		"id"?: string;
		"secondaryPresences"?: Array<Models.WfmUserScheduleAdherenceUpdatedTeamTopicSecondaryPresenceReference>;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicQueueReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicRealTimeAdherenceExplanation { 
		"id"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"status"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicSecondaryPresenceReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTeamTopicUserScheduleAdherenceUpdate { 
		"user"?: Models.WfmUserScheduleAdherenceUpdatedTeamTopicUserReference;
		"managementUnitId"?: string;
		"team"?: Models.WfmUserScheduleAdherenceUpdatedTeamTopicUriReference;
		"scheduledActivityCategory"?: string;
		"scheduledActivityCode"?: Models.WfmUserScheduleAdherenceUpdatedTeamTopicActivityCodeReference;
		"systemPresence"?: string;
		"organizationSecondaryPresenceId"?: string;
		"routingStatus"?: string;
		"actualActivityCategory"?: string;
		"isOutOfOffice"?: boolean;
		"adherenceState"?: string;
		"impact"?: string;
		"adherenceExplanation"?: Models.WfmUserScheduleAdherenceUpdatedTeamTopicRealTimeAdherenceExplanation;
		"adherenceChangeTime"?: string;
		"presenceUpdateTime"?: string;
		"activeQueues"?: Array<Models.WfmUserScheduleAdherenceUpdatedTeamTopicQueueReference>;
		"activeQueuesModifiedTime"?: string;
		"removedFromManagementUnit"?: boolean;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicActivityCodeReference { 
		"id"?: string;
		"secondaryPresences"?: Array<Models.WfmUserScheduleAdherenceUpdatedTopicSecondaryPresenceReference>;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicQueueReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicRealTimeAdherenceExplanation { 
		"id"?: string;
		"startDate"?: string;
		"lengthMinutes"?: number;
		"status"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicSecondaryPresenceReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicUriReference { 
		"id"?: string;
		"name"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicUserReference { 
		"id"?: string;
	}
	
	export interface WfmUserScheduleAdherenceUpdatedTopicUserScheduleAdherenceUpdate { 
		"user"?: Models.WfmUserScheduleAdherenceUpdatedTopicUserReference;
		"managementUnitId"?: string;
		"team"?: Models.WfmUserScheduleAdherenceUpdatedTopicUriReference;
		"scheduledActivityCategory"?: string;
		"scheduledActivityCode"?: Models.WfmUserScheduleAdherenceUpdatedTopicActivityCodeReference;
		"systemPresence"?: string;
		"organizationSecondaryPresenceId"?: string;
		"routingStatus"?: string;
		"actualActivityCategory"?: string;
		"isOutOfOffice"?: boolean;
		"adherenceState"?: string;
		"impact"?: string;
		"adherenceExplanation"?: Models.WfmUserScheduleAdherenceUpdatedTopicRealTimeAdherenceExplanation;
		"adherenceChangeTime"?: string;
		"presenceUpdateTime"?: string;
		"activeQueues"?: Array<Models.WfmUserScheduleAdherenceUpdatedTopicQueueReference>;
		"activeQueuesModifiedTime"?: string;
		"removedFromManagementUnit"?: boolean;
	}
	
	export interface WfmVersionedEntityMetadata { 
		"version": number;
		"modifiedBy"?: Models.UserReference;
		"dateModified"?: string;
		"createdBy"?: Models.UserReference;
		"dateCreated"?: string;
	}
	
	export interface WhatsAppAvailablePhoneNumberDetails { 
		"name": string;
		"phoneNumber"?: string;
		"status": string;
	}
	
	export interface WhatsAppAvailablePhoneNumberDetailsListing { 
		"entities"?: Array<Models.WhatsAppAvailablePhoneNumberDetails>;
	}
	
	export interface WhatsAppDefinition { 
		"name": string;
		"namespace": string;
		"language": string;
	}
	
	export interface WhatsAppEmbeddedSignupIntegrationActivationRequest { 
		"id"?: string;
		"name"?: string;
		"phoneNumber": string;
		"pin": string;
		"selfUri"?: string;
	}
	
	export interface WhatsAppEmbeddedSignupIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"embeddedSignupAccessToken": string;
		"selfUri"?: string;
	}
	
	export interface WhatsAppId { 
		"phoneNumber"?: Models.PhoneNumber;
		"displayName"?: string;
	}
	
	export interface WhatsAppIntegration { 
		"id": string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingReference;
		"phoneNumber": string;
		"availablePhoneNumbers"?: Models.WhatsAppAvailablePhoneNumberDetailsListing;
		"status"?: string;
		"recipient"?: Models.DomainEntityRef;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: Models.DomainEntityRef;
		"modifiedBy"?: Models.DomainEntityRef;
		"version": number;
		"activationStatusCode"?: string;
		"activationErrorInfo"?: Models.ErrorBody;
		"createStatus"?: string;
		"createError"?: Models.ErrorBody;
		"selfUri"?: string;
	}
	
	export interface WhatsAppIntegrationEntityListing { 
		"entities"?: Array<Models.WhatsAppIntegration>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface WhatsAppIntegrationRequest { 
		"id"?: string;
		"name": string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"phoneNumber": string;
		"wabaCertificate": string;
		"selfUri"?: string;
	}
	
	export interface WhatsAppIntegrationUpdateRequest { 
		"id"?: string;
		"name"?: string;
		"supportedContent"?: Models.SupportedContentReference;
		"messagingSetting"?: Models.MessagingSettingRequestReference;
		"selfUri"?: string;
	}
	
	export interface Widget { 
		"row"?: number;
		"column"?: number;
		"title"?: string;
		"type": string;
		"metrics"?: Array<string>;
		"displayText"?: string;
		"displayTextColor"?: string;
		"webContentUrl"?: string;
		"splitFilters"?: boolean;
		"splitByMediaType"?: boolean;
		"showLongest"?: boolean;
		"displayAsTable"?: boolean;
		"showDuration"?: boolean;
		"sortOrder"?: string;
		"sortKey"?: string;
		"entityLimit"?: number;
		"displayAggregates"?: boolean;
		"isFullWidth"?: boolean;
		"showPercentageChange"?: boolean;
		"showProfilePicture"?: boolean;
		"filter"?: Models.ViewFilter;
		"periods"?: Array<string>;
		"mediaTypes"?: Array<string>;
		"warnings"?: Array<Models.Warning>;
		"showTimeInStatus"?: boolean;
		"showOfflineAgents"?: boolean;
		"selectedStatuses"?: Array<string>;
	}
	
	export interface WidgetClientConfig { 
		"v1"?: Models.WidgetClientConfigV1;
		"v2"?: object;
		"v1-http"?: Models.WidgetClientConfigV1Http;
		"third-party"?: object;
	}
	
	export interface WidgetClientConfigThirdParty { 
	}
	
	export interface WidgetClientConfigV1 { 
		"webChatSkin"?: string;
		"authenticationUrl"?: string;
	}
	
	export interface WidgetClientConfigV1Http { 
		"webChatSkin"?: string;
		"authenticationUrl"?: string;
	}
	
	export interface WidgetClientConfigV2 { 
	}
	
	export interface WidgetDeployment { 
		"id"?: string;
		"name"?: string;
		"description"?: string;
		"authenticationRequired"?: boolean;
		"disabled"?: boolean;
		"flow"?: Models.DomainEntityRef;
		"allowedDomains"?: Array<string>;
		"clientType"?: string;
		"clientConfig"?: Models.WidgetClientConfig;
		"selfUri"?: string;
	}
	
	export interface WidgetDeploymentEntityListing { 
		"total"?: number;
		"entities"?: Array<Models.WidgetDeployment>;
		"selfUri"?: string;
	}
	
	export interface WorkPlan { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"valid"?: boolean;
		"constrainWeeklyPaidTime"?: boolean;
		"flexibleWeeklyPaidTime"?: boolean;
		"weeklyExactPaidMinutes"?: number;
		"weeklyMinimumPaidMinutes"?: number;
		"weeklyMaximumPaidMinutes"?: number;
		"constrainPaidTimeGranularity"?: boolean;
		"paidTimeGranularityMinutes"?: number;
		"constrainMinimumTimeBetweenShifts"?: boolean;
		"minimumTimeBetweenShiftsMinutes"?: number;
		"maximumDays"?: number;
		"minimumConsecutiveNonWorkingMinutesPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingWeekends"?: boolean;
		"maximumConsecutiveWorkingWeekends"?: number;
		"minimumWorkingDaysPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingDays"?: boolean;
		"maximumConsecutiveWorkingDays"?: number;
		"minimumShiftStartDistanceMinutes"?: number;
		"minimumDaysOffPerPlanningPeriod"?: number;
		"maximumDaysOffPerPlanningPeriod"?: number;
		"minimumPaidMinutesPerPlanningPeriod"?: number;
		"maximumPaidMinutesPerPlanningPeriod"?: number;
		"optionalDays"?: Models.SetWrapperDayOfWeek;
		"shiftStartVarianceType"?: string;
		"shiftStartVariances"?: Models.ListWrapperShiftStartVariance;
		"shifts"?: Array<Models.WorkPlanShift>;
		"agents"?: Array<Models.DeletableUserReference>;
		"agentCount"?: number;
		"metadata": Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface WorkPlanActivity { 
		"activityCodeId"?: string;
		"description"?: string;
		"lengthMinutes"?: number;
		"startTimeIsRelativeToShiftStart"?: boolean;
		"flexibleStartTime"?: boolean;
		"earliestStartTimeMinutes"?: number;
		"latestStartTimeMinutes"?: number;
		"exactStartTimeMinutes"?: number;
		"startTimeIncrementMinutes"?: number;
		"countsAsPaidTime"?: boolean;
		"countsAsContiguousWorkTime"?: boolean;
		"minimumLengthFromShiftStartMinutes"?: number;
		"minimumLengthFromShiftEndMinutes"?: number;
		"id"?: string;
		"delete"?: boolean;
		"validationId"?: string;
	}
	
	export interface WorkPlanBidRanks { 
		"id"?: string;
		"workPlanBiddingPerformance"?: number;
		"biddingTieBreaker"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkPlanConfigurationViolationMessage { 
		"type"?: string;
		"arguments"?: Array<Models.WorkPlanValidationMessageArgument>;
		"severity"?: string;
	}
	
	export interface WorkPlanConstraintConflictMessage { 
		"type"?: string;
		"arguments"?: Array<Models.WorkPlanValidationMessageArgument>;
	}
	
	export interface WorkPlanConstraintMessage { 
		"type"?: string;
		"arguments"?: Array<Models.WorkPlanValidationMessageArgument>;
	}
	
	export interface WorkPlanListItemResponse { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"valid"?: boolean;
		"constrainWeeklyPaidTime"?: boolean;
		"flexibleWeeklyPaidTime"?: boolean;
		"weeklyExactPaidMinutes"?: number;
		"weeklyMinimumPaidMinutes"?: number;
		"weeklyMaximumPaidMinutes"?: number;
		"constrainPaidTimeGranularity"?: boolean;
		"paidTimeGranularityMinutes"?: number;
		"constrainMinimumTimeBetweenShifts"?: boolean;
		"minimumTimeBetweenShiftsMinutes"?: number;
		"maximumDays"?: number;
		"minimumConsecutiveNonWorkingMinutesPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingWeekends"?: boolean;
		"maximumConsecutiveWorkingWeekends"?: number;
		"minimumWorkingDaysPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingDays"?: boolean;
		"maximumConsecutiveWorkingDays"?: number;
		"minimumShiftStartDistanceMinutes"?: number;
		"minimumDaysOffPerPlanningPeriod"?: number;
		"maximumDaysOffPerPlanningPeriod"?: number;
		"minimumPaidMinutesPerPlanningPeriod"?: number;
		"maximumPaidMinutesPerPlanningPeriod"?: number;
		"optionalDays"?: Models.SetWrapperDayOfWeek;
		"shiftStartVarianceType"?: string;
		"shiftStartVariances"?: Models.ListWrapperShiftStartVariance;
		"shifts"?: Array<Models.WorkPlanShift>;
		"agents"?: Array<Models.DeletableUserReference>;
		"agentCount"?: number;
		"metadata": Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface WorkPlanListResponse { 
		"entities"?: Array<Models.WorkPlanListItemResponse>;
	}
	
	export interface WorkPlanPatternRequest { 
		"workPlanIds": Array<string>;
	}
	
	export interface WorkPlanPatternResponse { 
		"workPlans"?: Array<Models.WorkPlanReference>;
	}
	
	export interface WorkPlanReference { 
		"id"?: string;
		"managementUnit"?: Models.ManagementUnitReference;
		"selfUri"?: string;
	}
	
	export interface WorkPlanRotationAgentResponse { 
		"user"?: Models.UserReference;
		"dateRange"?: Models.DateRangeWithOptionalEnd;
		"position"?: number;
	}
	
	export interface WorkPlanRotationListResponse { 
		"entities"?: Array<Models.WorkPlanRotationResponse>;
	}
	
	export interface WorkPlanRotationReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkPlanRotationResponse { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"dateRange"?: Models.DateRangeWithOptionalEnd;
		"pattern"?: Models.WorkPlanPatternResponse;
		"agentCount"?: number;
		"agents"?: Array<Models.WorkPlanRotationAgentResponse>;
		"metadata"?: Models.WfmVersionedEntityMetadata;
		"selfUri"?: string;
	}
	
	export interface WorkPlanShift { 
		"name": string;
		"days"?: Models.SetWrapperDayOfWeek;
		"flexibleStartTime"?: boolean;
		"exactStartTimeMinutesFromMidnight"?: number;
		"earliestStartTimeMinutesFromMidnight"?: number;
		"latestStartTimeMinutesFromMidnight"?: number;
		"constrainStopTime"?: boolean;
		"constrainLatestStopTime"?: boolean;
		"latestStopTimeMinutesFromMidnight"?: number;
		"constrainEarliestStopTime"?: boolean;
		"earliestStopTimeMinutesFromMidnight"?: number;
		"startIncrementMinutes"?: number;
		"flexiblePaidTime"?: boolean;
		"exactPaidTimeMinutes"?: number;
		"minimumPaidTimeMinutes"?: number;
		"maximumPaidTimeMinutes"?: number;
		"constrainContiguousWorkTime"?: boolean;
		"minimumContiguousWorkTimeMinutes"?: number;
		"maximumContiguousWorkTimeMinutes"?: number;
		"constrainDayOff"?: boolean;
		"dayOffRule"?: string;
		"activities"?: Array<Models.WorkPlanActivity>;
		"id"?: string;
		"delete"?: boolean;
		"validationId"?: string;
	}
	
	export interface WorkPlanValidationMessageArgument { 
		"type"?: string;
		"value"?: string;
	}
	
	export interface WorkPlanValidationRequest { 
		"id"?: string;
		"name"?: string;
		"enabled"?: boolean;
		"valid"?: boolean;
		"constrainWeeklyPaidTime"?: boolean;
		"flexibleWeeklyPaidTime"?: boolean;
		"weeklyExactPaidMinutes"?: number;
		"weeklyMinimumPaidMinutes"?: number;
		"weeklyMaximumPaidMinutes"?: number;
		"constrainPaidTimeGranularity"?: boolean;
		"paidTimeGranularityMinutes"?: number;
		"constrainMinimumTimeBetweenShifts"?: boolean;
		"minimumTimeBetweenShiftsMinutes"?: number;
		"maximumDays"?: number;
		"minimumConsecutiveNonWorkingMinutesPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingWeekends"?: boolean;
		"maximumConsecutiveWorkingWeekends"?: number;
		"minimumWorkingDaysPerWeek"?: number;
		"constrainMaximumConsecutiveWorkingDays"?: boolean;
		"maximumConsecutiveWorkingDays"?: number;
		"minimumShiftStartDistanceMinutes"?: number;
		"minimumDaysOffPerPlanningPeriod"?: number;
		"maximumDaysOffPerPlanningPeriod"?: number;
		"minimumPaidMinutesPerPlanningPeriod"?: number;
		"maximumPaidMinutesPerPlanningPeriod"?: number;
		"optionalDays"?: Models.SetWrapperDayOfWeek;
		"shiftStartVarianceType"?: string;
		"shiftStartVariances"?: Models.ListWrapperShiftStartVariance;
		"shifts"?: Array<Models.WorkPlanShift>;
		"agents"?: Array<Models.DeletableUserReference>;
		"agentCount"?: number;
		"selfUri"?: string;
	}
	
	export interface Workbin { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: Models.UserReference;
		"selfUri"?: string;
	}
	
	export interface WorkbinChangeListing { 
		"entities"?: Array<Models.WorkitemsChangeWorkbinDelta>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
	}
	
	export interface WorkbinCreate { 
		"name": string;
		"description"?: string;
		"divisionId"?: string;
	}
	
	export interface WorkbinDelta { 
		"name"?: Models.WorkitemsAttributeChangeString;
		"description"?: Models.WorkitemsAttributeChangeString;
		"dateModified"?: Models.WorkitemsAttributeChangeInstant;
		"modifiedBy"?: Models.WorkitemsAttributeChangeString;
	}
	
	export interface WorkbinQueryEntityListing { 
		"entities"?: Array<Models.Workbin>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
		"count"?: number;
	}
	
	export interface WorkbinQueryRequest { 
		"pageSize"?: number;
		"select"?: string;
		"filters": Array<Models.WorkitemFilter>;
		"attributes"?: Array<string>;
		"after"?: string;
		"sort"?: Models.WorkbinQuerySort;
	}
	
	export interface WorkbinQuerySort { 
		"name"?: string;
		"ascending"?: boolean;
	}
	
	export interface WorkbinReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkbinUpdate { 
		"name"?: string;
		"description"?: string;
	}
	
	export interface WorkbinVersion { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"modifiedBy"?: Models.UserReference;
		"version"?: number;
		"selfUri"?: string;
	}
	
	export interface WorkbinVersionListing { 
		"entities"?: Array<Models.WorkbinVersion>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
	}
	
	export interface WorkdayMetric { 
		"metric"?: Models.Metric;
		"objective"?: Models.Objective;
		"points"?: number;
		"maxPoints"?: number;
		"value"?: number;
		"punctualityEvents"?: Array<Models.PunctualityEvent>;
		"evaluationDetails"?: Array<Models.QualityEvaluationScoreItem>;
	}
	
	export interface WorkdayMetricListing { 
		"entities"?: Array<Models.WorkdayMetric>;
	}
	
	export interface WorkdayPeriod { 
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
	}
	
	export interface WorkdayPointsTrend { 
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"user"?: Models.UserReference;
		"dayOfWeek"?: string;
		"averagePoints"?: number;
		"trend"?: Array<Models.WorkdayPointsTrendItem>;
	}
	
	export interface WorkdayPointsTrendItem { 
		"dateWorkday"?: string;
		"points"?: number;
	}
	
	export interface WorkdayValuesMetricItem { 
		"metric"?: Models.AddressableEntityRef;
		"metricDefinition"?: Models.DomainEntityRef;
		"average"?: number;
		"unitType"?: string;
		"trend"?: Array<Models.WorkdayValuesTrendItem>;
	}
	
	export interface WorkdayValuesTrend { 
		"dateStartWorkday"?: string;
		"dateEndWorkday"?: string;
		"dateReferenceWorkday"?: string;
		"division"?: Models.Division;
		"user"?: Models.UserReference;
		"timezone"?: string;
		"results"?: Array<Models.WorkdayValuesMetricItem>;
		"performanceProfile"?: Models.AddressableEntityRef;
		"metric"?: Models.AddressableEntityRef;
	}
	
	export interface WorkdayValuesTrendItem { 
		"dateWorkday"?: string;
		"value"?: number;
	}
	
	export interface WorkflowTargetSettings { 
		"dataFormat"?: string;
	}
	
	export interface Workitem { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"type"?: Models.WorktypeReference;
		"description"?: string;
		"language"?: Models.LanguageReference;
		"utilizationLabel"?: Models.WorkitemUtilizationLabelReference;
		"priority"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateDue"?: string;
		"dateExpires"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"status"?: Models.WorkitemStatusReference;
		"statusCategory"?: string;
		"dateStatusChanged"?: string;
		"dateClosed"?: string;
		"workbin"?: Models.WorkbinReference;
		"reporter"?: Models.UserReferenceWithName;
		"assignee"?: Models.UserReferenceWithName;
		"externalContact"?: Models.ExternalContactReference;
		"externalTag"?: string;
		"modifiedBy"?: Models.UserReference;
		"queue"?: Models.WorkitemQueueReference;
		"assignmentState"?: string;
		"dateAssignmentStateChanged"?: string;
		"alertTimeoutSeconds"?: number;
		"skills"?: Array<Models.RoutingSkillReference>;
		"preferredAgents"?: Array<Models.UserReference>;
		"autoStatusTransition"?: boolean;
		"schema"?: Models.WorkitemSchema;
		"customFields"?: { [key: string]: object; };
		"autoStatusTransitionDetail"?: Models.AutoStatusTransitionDetail;
		"scoredAgents"?: Array<Models.WorkitemScoredAgent>;
		"selfUri"?: string;
	}
	
	export interface WorkitemChangeListing { 
		"entities"?: Array<Models.WorkitemsChangeWorkitemDelta>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
	}
	
	export interface WorkitemCreate { 
		"name": string;
		"priority"?: number;
		"dateDue"?: string;
		"dateExpires"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"statusId"?: string;
		"workbinId"?: string;
		"autoStatusTransition"?: boolean;
		"description"?: string;
		"typeId": string;
		"customFields"?: { [key: string]: object; };
		"queueId"?: string;
		"assigneeId"?: string;
		"wrapupCode"?: string;
		"scoredAgents"?: Array<Models.WorkitemScoredAgentRequest>;
		"languageId"?: string;
		"utilizationLabelId"?: string;
		"externalContactId"?: string;
		"externalTag"?: string;
		"skillIds"?: Array<string>;
		"preferredAgentIds"?: Array<string>;
	}
	
	export interface WorkitemDelta { 
		"name"?: Models.WorkitemsAttributeChangeString;
		"description"?: Models.WorkitemsAttributeChangeString;
		"languageId"?: Models.WorkitemsAttributeChangeString;
		"utilizationLabelId"?: Models.WorkitemsAttributeChangeString;
		"priority"?: Models.WorkitemsAttributeChangeInteger;
		"skillIds"?: Models.WorkitemsAttributeChangeList;
		"preferredAgentIds"?: Models.WorkitemsAttributeChangeList;
		"dateDue"?: Models.WorkitemsAttributeChangeInstant;
		"dateExpires"?: Models.WorkitemsAttributeChangeInstant;
		"durationSeconds"?: Models.WorkitemsAttributeChangeInteger;
		"statusId"?: Models.WorkitemsAttributeChangeString;
		"reporterId"?: Models.WorkitemsAttributeChangeString;
		"externalContactId"?: Models.WorkitemsAttributeChangeString;
		"assigneeId"?: Models.WorkitemsAttributeChangeString;
		"workbinId"?: Models.WorkitemsAttributeChangeString;
		"queueId"?: Models.WorkitemsAttributeChangeString;
		"externalTag"?: Models.WorkitemsAttributeChangeString;
		"wrapupId"?: Models.WorkitemsAttributeChangeString;
		"ttl"?: Models.WorkitemsAttributeChangeInteger;
		"dateClosed"?: Models.WorkitemsAttributeChangeInstant;
		"assignmentState"?: Models.WorkitemsAttributeChangeString;
		"autoStatusTransition"?: Models.WorkitemsAttributeChangeBoolean;
		"customFields"?: Models.WorkitemsAttributeChangeMap;
		"dateModified"?: Models.WorkitemsAttributeChangeInstant;
		"modifiedBy"?: Models.WorkitemsAttributeChangeString;
		"statusCategory"?: Models.WorkitemsAttributeChangeWorkitemStatusCategory;
	}
	
	export interface WorkitemFilter { 
		"name": string;
		"type": string;
		"operator": string;
		"values": Array<string>;
	}
	
	export interface WorkitemManualAssign { 
		"id": string;
	}
	
	export interface WorkitemPagedEntityListing { 
		"entities"?: Array<Models.Workitem>;
		"pageSize"?: number;
		"pageNumber"?: number;
	}
	
	export interface WorkitemPostQueryEntityListing { 
		"entities"?: Array<Models.Workitem>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
		"count"?: number;
	}
	
	export interface WorkitemQueryJobCreate { 
		"pageSize"?: number;
		"pageNumber"?: number;
		"filters": Array<Models.WorkitemQueryJobFilter>;
		"expands"?: Array<string>;
		"attributes"?: Array<string>;
		"sort"?: Models.WorkitemQueryJobSort;
	}
	
	export interface WorkitemQueryJobError { 
		"code"?: string;
		"message"?: string;
	}
	
	export interface WorkitemQueryJobFilter { 
		"name": string;
		"operator": string;
		"values": Array<string>;
	}
	
	export interface WorkitemQueryJobResponse { 
		"id"?: string;
		"state"?: string;
		"dateStarted"?: string;
		"dateFinished"?: string;
		"error"?: Models.WorkitemQueryJobError;
		"selfUri"?: string;
	}
	
	export interface WorkitemQueryJobSort { 
		"name"?: string;
		"ascending"?: boolean;
	}
	
	export interface WorkitemQueryPostRequest { 
		"pageSize"?: number;
		"select"?: string;
		"filters": Array<Models.WorkitemFilter>;
		"attributes"?: Array<string>;
		"after"?: string;
		"sort"?: Models.WorkitemQuerySort;
		"expands"?: Array<string>;
	}
	
	export interface WorkitemQuerySort { 
		"name"?: string;
		"ascending"?: boolean;
	}
	
	export interface WorkitemQueueReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkitemReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkitemSchema { 
		"id"?: string;
		"name"?: string;
		"version": number;
		"selfUri"?: string;
	}
	
	export interface WorkitemScoredAgent { 
		"agent"?: Models.UserReference;
		"score"?: number;
	}
	
	export interface WorkitemScoredAgentRequest { 
		"id"?: string;
		"score"?: number;
	}
	
	export interface WorkitemStatus { 
		"id"?: string;
		"name"?: string;
		"category"?: string;
		"destinationStatuses"?: Array<Models.WorkitemStatusReference>;
		"description"?: string;
		"defaultDestinationStatus"?: Models.WorkitemStatusReference;
		"statusTransitionDelaySeconds"?: number;
		"statusTransitionTime"?: string;
		"worktype"?: Models.WorktypeReference;
		"selfUri"?: string;
	}
	
	export interface WorkitemStatusCreate { 
		"name": string;
		"category": string;
		"destinationStatusIds"?: Array<string>;
		"description"?: string;
		"defaultDestinationStatusId"?: string;
		"statusTransitionDelaySeconds"?: number;
		"statusTransitionTime"?: string;
	}
	
	export interface WorkitemStatusListing { 
		"total"?: number;
		"entities"?: Array<Models.WorkitemStatus>;
		"selfUri"?: string;
	}
	
	export interface WorkitemStatusReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkitemStatusUpdate { 
		"name"?: string;
		"destinationStatusIds"?: Array<string>;
		"description"?: string;
		"defaultDestinationStatusId"?: string;
		"statusTransitionDelaySeconds"?: number;
		"statusTransitionTime"?: string;
	}
	
	export interface WorkitemTerminate { 
		"statusId"?: string;
	}
	
	export interface WorkitemUpdate { 
		"name"?: string;
		"priority"?: number;
		"dateDue"?: string;
		"dateExpires"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"statusId"?: string;
		"workbinId"?: string;
		"autoStatusTransition"?: boolean;
		"description"?: string;
		"dateClosed"?: string;
		"assignmentState"?: string;
		"assignmentOperation"?: string;
		"customFields"?: { [key: string]: object; };
		"queueId"?: string;
		"assigneeId"?: string;
		"scoredAgents"?: Array<Models.WorkitemScoredAgentRequest>;
		"externalContactId"?: string;
		"externalTag"?: string;
		"skillIds"?: Array<string>;
		"languageId"?: string;
		"utilizationLabelId"?: string;
		"preferredAgentIds"?: Array<string>;
	}
	
	export interface WorkitemUtilizationLabelReference { 
		"id"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkitemVersion { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"type"?: Models.WorktypeReference;
		"description"?: string;
		"language"?: Models.LanguageReference;
		"utilizationLabel"?: Models.WorkitemUtilizationLabelReference;
		"priority"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateDue"?: string;
		"dateExpires"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"status"?: Models.WorkitemStatusReference;
		"statusCategory"?: string;
		"dateStatusChanged"?: string;
		"dateClosed"?: string;
		"workbin"?: Models.WorkbinReference;
		"reporter"?: Models.UserReferenceWithName;
		"assignee"?: Models.UserReferenceWithName;
		"externalContact"?: Models.ExternalContactReference;
		"externalTag"?: string;
		"modifiedBy"?: Models.UserReference;
		"queue"?: Models.WorkitemQueueReference;
		"assignmentState"?: string;
		"dateAssignmentStateChanged"?: string;
		"alertTimeoutSeconds"?: number;
		"skills"?: Array<Models.RoutingSkillReference>;
		"preferredAgents"?: Array<Models.UserReference>;
		"autoStatusTransition"?: boolean;
		"schema"?: Models.WorkitemSchema;
		"customFields"?: { [key: string]: object; };
		"autoStatusTransitionDetail"?: Models.AutoStatusTransitionDetail;
		"scoredAgents"?: Array<Models.WorkitemScoredAgent>;
		"version"?: number;
		"selfUri"?: string;
	}
	
	export interface WorkitemVersionListing { 
		"entities"?: Array<Models.WorkitemVersion>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
	}
	
	export interface WorkitemWrapup { 
		"workitem"?: Models.WorkitemReference;
		"wrapupCode"?: Models.WrapupIdReference;
		"modifiedBy"?: Models.UserReference;
		"user"?: Models.UserReference;
		"dateModified"?: string;
	}
	
	export interface WorkitemWrapupEntityListing { 
		"entities"?: Array<Models.WorkitemWrapup>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
	}
	
	export interface WorkitemWrapupUpdate { 
		"action": string;
		"wrapupCode": string;
	}
	
	export interface WorkitemsAttributeChangeBoolean { 
		"newValue"?: boolean;
		"oldValue"?: boolean;
	}
	
	export interface WorkitemsAttributeChangeInstant { 
		"newValue"?: string;
		"oldValue"?: string;
	}
	
	export interface WorkitemsAttributeChangeInteger { 
		"newValue"?: number;
		"oldValue"?: number;
	}
	
	export interface WorkitemsAttributeChangeList { 
		"newValue"?: Array<object>;
		"oldValue"?: Array<object>;
	}
	
	export interface WorkitemsAttributeChangeMap { 
		"newValue"?: { [key: string]: object; };
		"oldValue"?: { [key: string]: object; };
	}
	
	export interface WorkitemsAttributeChangeString { 
		"newValue"?: string;
		"oldValue"?: string;
	}
	
	export interface WorkitemsAttributeChangeWorkitemStatusCategory { 
		"newValue"?: string;
		"oldValue"?: string;
	}
	
	export interface WorkitemsChangeWorkbinDelta { 
		"version"?: number;
		"modifiedBy"?: Models.UserReference;
		"delta"?: Models.WorkbinDelta;
	}
	
	export interface WorkitemsChangeWorkitemDelta { 
		"version"?: number;
		"modifiedBy"?: Models.UserReference;
		"delta"?: Models.WorkitemDelta;
	}
	
	export interface WorkitemsChangeWorktypeDelta { 
		"version"?: number;
		"modifiedBy"?: Models.UserReference;
		"delta"?: Models.WorktypeDelta;
	}
	
	export interface WorkitemsEventsNotificationAssignmentSegment { 
		"startState"?: string;
		"endState"?: string;
		"durationMs"?: number;
	}
	
	export interface WorkitemsEventsNotificationCustomAttribute { 
		"dataType"?: string;
		"value"?: string;
	}
	
	export interface WorkitemsEventsNotificationDelta { 
		"op"?: string;
		"field"?: string;
		"oldValue"?: string;
		"newValue"?: string;
	}
	
	export interface WorkitemsEventsNotificationSession { 
		"type"?: string;
		"id"?: string;
		"status"?: string;
		"dateSessionStart"?: string;
		"dateSessionEnd"?: string;
		"assignmentSegments"?: Array<Models.WorkitemsEventsNotificationAssignmentSegment>;
	}
	
	export interface WorkitemsEventsNotificationWorkitem { 
		"id"?: string;
		"name"?: string;
		"typeId"?: string;
		"description"?: string;
		"languageId"?: string;
		"priority"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateDue"?: string;
		"dateExpires"?: string;
		"dateAssignmentStateChanged"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"statusId"?: string;
		"statusCategory"?: string;
		"dateClosed"?: string;
		"workbinId"?: string;
		"reporterId"?: string;
		"assigneeId"?: string;
		"externalContactId"?: string;
		"externalTag"?: string;
		"wrapupId"?: string;
		"modifiedBy"?: string;
		"operation"?: string;
		"changes"?: Array<Models.WorkitemsEventsNotificationDelta>;
		"assignmentState"?: string;
		"assignmentId"?: string;
		"alertTimeoutSeconds"?: number;
		"queueId"?: string;
		"customFields"?: { [key: string]: Models.WorkitemsEventsNotificationCustomAttribute; };
		"wrapup"?: Models.WorkitemsEventsNotificationWrapup;
		"sessions"?: Array<Models.WorkitemsEventsNotificationSession>;
		"skillIds"?: Array<string>;
	}
	
	export interface WorkitemsEventsNotificationWrapup { 
		"code"?: string;
		"userId"?: string;
		"op"?: string;
		"action"?: string;
	}
	
	export interface WorkitemsQueueEventsNotificationAssignmentSegment { 
		"startState"?: string;
		"endState"?: string;
		"durationMs"?: number;
	}
	
	export interface WorkitemsQueueEventsNotificationCustomAttribute { 
		"dataType"?: string;
		"value"?: string;
	}
	
	export interface WorkitemsQueueEventsNotificationDelta { 
		"op"?: string;
		"field"?: string;
		"oldValue"?: string;
		"newValue"?: string;
	}
	
	export interface WorkitemsQueueEventsNotificationSession { 
		"type"?: string;
		"id"?: string;
		"status"?: string;
		"dateSessionStart"?: string;
		"dateSessionEnd"?: string;
		"assignmentSegments"?: Array<Models.WorkitemsQueueEventsNotificationAssignmentSegment>;
	}
	
	export interface WorkitemsQueueEventsNotificationWorkitem { 
		"id"?: string;
		"name"?: string;
		"typeId"?: string;
		"description"?: string;
		"languageId"?: string;
		"priority"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateDue"?: string;
		"dateExpires"?: string;
		"dateAssignmentStateChanged"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"statusId"?: string;
		"statusCategory"?: string;
		"dateClosed"?: string;
		"workbinId"?: string;
		"reporterId"?: string;
		"assigneeId"?: string;
		"externalContactId"?: string;
		"externalTag"?: string;
		"wrapupId"?: string;
		"modifiedBy"?: string;
		"operation"?: string;
		"changes"?: Array<Models.WorkitemsQueueEventsNotificationDelta>;
		"assignmentState"?: string;
		"assignmentId"?: string;
		"alertTimeoutSeconds"?: number;
		"queueId"?: string;
		"customFields"?: { [key: string]: Models.WorkitemsQueueEventsNotificationCustomAttribute; };
		"wrapup"?: Models.WorkitemsQueueEventsNotificationWrapup;
		"sessions"?: Array<Models.WorkitemsQueueEventsNotificationSession>;
		"skillIds"?: Array<string>;
	}
	
	export interface WorkitemsQueueEventsNotificationWrapup { 
		"code"?: string;
		"userId"?: string;
		"op"?: string;
		"action"?: string;
	}
	
	export interface WorkitemsUserEventsNotificationAssignmentSegment { 
		"startState"?: string;
		"endState"?: string;
		"durationMs"?: number;
	}
	
	export interface WorkitemsUserEventsNotificationCustomAttribute { 
		"dataType"?: string;
		"value"?: string;
	}
	
	export interface WorkitemsUserEventsNotificationDelta { 
		"op"?: string;
		"field"?: string;
		"oldValue"?: string;
		"newValue"?: string;
	}
	
	export interface WorkitemsUserEventsNotificationSession { 
		"type"?: string;
		"id"?: string;
		"status"?: string;
		"dateSessionStart"?: string;
		"dateSessionEnd"?: string;
		"assignmentSegments"?: Array<Models.WorkitemsUserEventsNotificationAssignmentSegment>;
	}
	
	export interface WorkitemsUserEventsNotificationWorkitem { 
		"id"?: string;
		"name"?: string;
		"typeId"?: string;
		"description"?: string;
		"languageId"?: string;
		"priority"?: number;
		"dateCreated"?: string;
		"dateModified"?: string;
		"dateDue"?: string;
		"dateExpires"?: string;
		"dateAssignmentStateChanged"?: string;
		"durationSeconds"?: number;
		"ttl"?: number;
		"statusId"?: string;
		"statusCategory"?: string;
		"dateClosed"?: string;
		"workbinId"?: string;
		"reporterId"?: string;
		"assigneeId"?: string;
		"externalContactId"?: string;
		"externalTag"?: string;
		"wrapupId"?: string;
		"modifiedBy"?: string;
		"operation"?: string;
		"changes"?: Array<Models.WorkitemsUserEventsNotificationDelta>;
		"assignmentState"?: string;
		"assignmentId"?: string;
		"alertTimeoutSeconds"?: number;
		"queueId"?: string;
		"customFields"?: { [key: string]: Models.WorkitemsUserEventsNotificationCustomAttribute; };
		"wrapup"?: Models.WorkitemsUserEventsNotificationWrapup;
		"sessions"?: Array<Models.WorkitemsUserEventsNotificationSession>;
		"skillIds"?: Array<string>;
	}
	
	export interface WorkitemsUserEventsNotificationWrapup { 
		"code"?: string;
		"userId"?: string;
		"op"?: string;
		"action"?: string;
	}
	
	export interface Workspace { 
		"id"?: string;
		"name": string;
		"type"?: string;
		"isCurrentUserWorkspace"?: boolean;
		"user"?: Models.DomainEntityRef;
		"bucket"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"summary"?: Models.WorkspaceSummary;
		"acl"?: Array<string>;
		"description"?: string;
		"selfUri"?: string;
	}
	
	export interface WorkspaceCreate { 
		"name": string;
		"bucket"?: string;
		"description"?: string;
	}
	
	export interface WorkspaceEntityListing { 
		"entities"?: Array<Models.Workspace>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface WorkspaceMember { 
		"id"?: string;
		"name"?: string;
		"workspace"?: Models.DomainEntityRef;
		"memberType": string;
		"member"?: Models.DomainEntityRef;
		"user"?: Models.User;
		"group"?: Models.Group;
		"securityProfile"?: Models.SecurityProfile;
		"selfUri"?: string;
	}
	
	export interface WorkspaceMemberEntityListing { 
		"entities"?: Array<Models.WorkspaceMember>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface WorkspaceSummary { 
		"totalDocumentCount"?: number;
		"totalDocumentByteCount"?: number;
	}
	
	export interface Worktype { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"defaultWorkbin"?: Models.WorkbinReference;
		"defaultStatus"?: Models.WorkitemStatusReference;
		"statuses"?: Array<Models.WorkitemStatus>;
		"defaultDurationSeconds"?: number;
		"defaultExpirationSeconds"?: number;
		"defaultDueDurationSeconds"?: number;
		"defaultPriority"?: number;
		"defaultLanguage"?: Models.LanguageReference;
		"defaultTtlSeconds"?: number;
		"modifiedBy"?: Models.UserReference;
		"defaultQueue"?: Models.WorkitemQueueReference;
		"defaultSkills"?: Array<Models.RoutingSkillReference>;
		"assignmentEnabled"?: boolean;
		"schema"?: Models.WorkitemSchema;
		"serviceLevelTarget"?: number;
		"selfUri"?: string;
	}
	
	export interface WorktypeChangeListing { 
		"entities"?: Array<Models.WorkitemsChangeWorktypeDelta>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
	}
	
	export interface WorktypeCreate { 
		"name": string;
		"defaultWorkbinId": string;
		"defaultDurationSeconds"?: number;
		"defaultExpirationSeconds"?: number;
		"defaultDueDurationSeconds"?: number;
		"defaultPriority"?: number;
		"defaultTtlSeconds"?: number;
		"assignmentEnabled"?: boolean;
		"schemaId"?: string;
		"serviceLevelTarget"?: number;
		"description"?: string;
		"divisionId"?: string;
		"disableDefaultStatusCreation"?: boolean;
		"schemaVersion"?: number;
		"defaultQueueId"?: string;
		"defaultLanguageId"?: string;
		"defaultSkillIds"?: Array<string>;
	}
	
	export interface WorktypeDelta { 
		"name"?: Models.WorkitemsAttributeChangeString;
		"description"?: Models.WorkitemsAttributeChangeString;
		"statuses"?: Models.WorkitemsAttributeChangeList;
		"defaultWorkbinId"?: Models.WorkitemsAttributeChangeString;
		"defaultDurationSeconds"?: Models.WorkitemsAttributeChangeInteger;
		"defaultExpirationSeconds"?: Models.WorkitemsAttributeChangeInteger;
		"defaultDueDurationSeconds"?: Models.WorkitemsAttributeChangeInteger;
		"defaultPriority"?: Models.WorkitemsAttributeChangeInteger;
		"defaultSkillIds"?: Models.WorkitemsAttributeChangeList;
		"defaultStatusId"?: Models.WorkitemsAttributeChangeString;
		"defaultLanguageId"?: Models.WorkitemsAttributeChangeString;
		"defaultTtlSeconds"?: Models.WorkitemsAttributeChangeInteger;
		"assignmentEnabled"?: Models.WorkitemsAttributeChangeBoolean;
		"defaultQueueId"?: Models.WorkitemsAttributeChangeString;
		"schemaId"?: Models.WorkitemsAttributeChangeString;
		"schemaVersion"?: Models.WorkitemsAttributeChangeString;
		"dateModified"?: Models.WorkitemsAttributeChangeInstant;
		"modifiedBy"?: Models.WorkitemsAttributeChangeString;
	}
	
	export interface WorktypeQueryEntityListing { 
		"entities"?: Array<Models.Worktype>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
		"count"?: number;
	}
	
	export interface WorktypeQueryRequest { 
		"pageSize"?: number;
		"select"?: string;
		"filters": Array<Models.WorkitemFilter>;
		"attributes"?: Array<string>;
		"after"?: string;
		"sort"?: Models.WorktypeQuerySort;
	}
	
	export interface WorktypeQuerySort { 
		"name"?: string;
		"ascending"?: boolean;
	}
	
	export interface WorktypeReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WorktypeUpdate { 
		"name"?: string;
		"defaultWorkbinId"?: string;
		"defaultDurationSeconds"?: number;
		"defaultExpirationSeconds"?: number;
		"defaultDueDurationSeconds"?: number;
		"defaultPriority"?: number;
		"defaultTtlSeconds"?: number;
		"assignmentEnabled"?: boolean;
		"schemaId"?: string;
		"serviceLevelTarget"?: number;
		"description"?: string;
		"defaultStatusId"?: string;
		"schemaVersion"?: number;
		"defaultLanguageId"?: string;
		"defaultSkillIds"?: Array<string>;
		"defaultQueueId"?: string;
	}
	
	export interface WorktypeVersion { 
		"id"?: string;
		"name"?: string;
		"division"?: Models.Division;
		"description"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"defaultWorkbin"?: Models.WorkbinReference;
		"defaultStatus"?: Models.WorkitemStatusReference;
		"statuses"?: Array<Models.WorkitemStatus>;
		"defaultDurationSeconds"?: number;
		"defaultExpirationSeconds"?: number;
		"defaultDueDurationSeconds"?: number;
		"defaultPriority"?: number;
		"defaultLanguage"?: Models.LanguageReference;
		"defaultTtlSeconds"?: number;
		"modifiedBy"?: Models.UserReference;
		"defaultQueue"?: Models.WorkitemQueueReference;
		"defaultSkills"?: Array<Models.RoutingSkillReference>;
		"assignmentEnabled"?: boolean;
		"schema"?: Models.WorkitemSchema;
		"serviceLevelTarget"?: number;
		"version"?: number;
		"selfUri"?: string;
	}
	
	export interface WorktypeVersionListing { 
		"entities"?: Array<Models.WorktypeVersion>;
		"nextUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"after"?: string;
	}
	
	export interface WrapUpCodeConfig { 
		"values": Array<string>;
	}
	
	export interface WrapUpCodeMapping { 
		"id"?: string;
		"name"?: string;
		"dateCreated"?: string;
		"dateModified"?: string;
		"version"?: number;
		"defaultSet"?: Array<string>;
		"mapping"?: { [key: string]: Array<string>; };
		"selfUri"?: string;
	}
	
	export interface WrapUpCodeReference { 
		"id"?: string;
	}
	
	export interface Wrapup { 
		"code"?: string;
		"name"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
		"provisional"?: boolean;
	}
	
	export interface WrapupCode { 
		"id"?: string;
		"name": string;
		"division"?: Models.StarrableDivision;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: string;
		"modifiedBy"?: string;
		"selfUri"?: string;
	}
	
	export interface WrapupCodeEntityListing { 
		"entities"?: Array<Models.WrapupCode>;
		"pageSize"?: number;
		"pageNumber"?: number;
		"total"?: number;
		"nextUri"?: string;
		"lastUri"?: string;
		"firstUri"?: string;
		"selfUri"?: string;
		"previousUri"?: string;
		"pageCount"?: number;
	}
	
	export interface WrapupCodeRequest { 
		"id"?: string;
		"name": string;
		"division"?: Models.WritableStarrableDivision;
		"dateCreated"?: string;
		"dateModified"?: string;
		"createdBy"?: string;
		"modifiedBy"?: string;
		"selfUri"?: string;
	}
	
	export interface WrapupDetailEventTopicWrapupEvent { 
		"eventTime"?: number;
		"conversationId"?: string;
		"participantId"?: string;
		"sessionId"?: string;
		"mediaType"?: string;
		"provider"?: string;
		"direction"?: string;
		"ani"?: string;
		"dnis"?: string;
		"addressTo"?: string;
		"addressFrom"?: string;
		"callbackUserName"?: string;
		"callbackNumbers"?: Array<string>;
		"callbackScheduledTime"?: number;
		"subject"?: string;
		"messageType"?: string;
		"queueId"?: string;
		"wrapupCode"?: string;
		"wrapupNotes"?: string;
		"wrapupDurationMs"?: number;
		"conversationExternalContactIds"?: Array<string>;
		"conversationExternalOrganizationIds"?: Array<string>;
	}
	
	export interface WrapupIdReference { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WrapupInput { 
		"code"?: string;
		"name"?: string;
		"notes"?: string;
		"tags"?: Array<string>;
		"durationSeconds"?: number;
		"endTime"?: string;
		"provisional"?: boolean;
		"disableEndTimeUpdates"?: boolean;
	}
	
	export interface WritableDialerContact { 
		"id"?: string;
		"contactListId": string;
		"data": { [key: string]: string; };
		"latestSmsEvaluations"?: { [key: string]: Models.MessageEvaluation; };
		"latestEmailEvaluations"?: { [key: string]: Models.MessageEvaluation; };
		"callable"?: boolean;
		"phoneNumberStatus"?: { [key: string]: Models.PhoneNumberStatus; };
		"contactableStatus"?: { [key: string]: Models.ContactableStatus; };
		"dateCreated"?: string;
	}
	
	export interface WritableDivision { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
	export interface WritableEntity { 
		"id"?: string;
	}
	
	export interface WritableStarrableDivision { 
		"id"?: string;
		"name"?: string;
		"selfUri"?: string;
	}
	
}
